@@ -27,13 +27,14 @@
 #include <unotools/accessiblestatesethelper.hxx>
 #include <unotools/accessiblerelationsethelper.hxx>
 #include <vcl/svapp.hxx>
+#include <vcl/settings.hxx>
 #include <toolkit/helper/convert.hxx>
 
 
-//.........................................................................
+
 namespace accessibility
 {
-//.........................................................................
+
 
     using namespace ::com::sun::star::accessibility;
     using namespace ::com::sun::star::uno;
@@ -41,9 +42,9 @@ namespace accessibility
     using namespace ::com::sun::star;
     using namespace ::comphelper;
 
-    // -----------------------------------------------------------------------------
+
     // class AccessibleTabBarPageList
-    // -----------------------------------------------------------------------------
+
 
     AccessibleTabBarPageList::AccessibleTabBarPageList( TabBar* pTabBar, sal_Int32 nIndexInParent )
         :AccessibleTabBarBase( pTabBar )
@@ -53,33 +54,15 @@ namespace accessibility
             m_aAccessibleChildren.assign( m_pTabBar->GetPageCount(), Reference< XAccessible >() );
     }
 
-    // -----------------------------------------------------------------------------
+
 
     AccessibleTabBarPageList::~AccessibleTabBarPageList()
     {
     }
 
-    // -----------------------------------------------------------------------------
-
-    void AccessibleTabBarPageList::UpdateEnabled( sal_Int32 i, sal_Bool bEnabled )
+    void AccessibleTabBarPageList::UpdateShowing( bool bShowing )
     {
-        if ( i >= 0 && i < (sal_Int32)m_aAccessibleChildren.size() )
-        {
-            Reference< XAccessible > xChild( m_aAccessibleChildren[i] );
-            if ( xChild.is() )
-            {
-                AccessibleTabBarPage* pAccessibleTabBarPage = static_cast< AccessibleTabBarPage* >( xChild.get() );
-                if ( pAccessibleTabBarPage )
-                    pAccessibleTabBarPage->SetEnabled( bEnabled );
-            }
-        }
-    }
-
-    // -----------------------------------------------------------------------------
-
-    void AccessibleTabBarPageList::UpdateShowing( sal_Bool bShowing )
-    {
-        for ( sal_uInt32 i = 0; i < m_aAccessibleChildren.size(); ++i )
+        for ( size_t i = 0; i < m_aAccessibleChildren.size(); ++i )
         {
             Reference< XAccessible > xChild( m_aAccessibleChildren[i] );
             if ( xChild.is() )
@@ -91,9 +74,9 @@ namespace accessibility
         }
     }
 
-    // -----------------------------------------------------------------------------
 
-    void AccessibleTabBarPageList::UpdateSelected( sal_Int32 i, sal_Bool bSelected )
+
+    void AccessibleTabBarPageList::UpdateSelected( sal_Int32 i, bool bSelected )
     {
         NotifyAccessibleEvent( AccessibleEventId::SELECTION_CHANGED, Any(), Any() );
 
@@ -109,7 +92,7 @@ namespace accessibility
         }
     }
 
-    // -----------------------------------------------------------------------------
+
 
     void AccessibleTabBarPageList::UpdatePageText( sal_Int32 i )
     {
@@ -131,7 +114,7 @@ namespace accessibility
         }
     }
 
-    // -----------------------------------------------------------------------------
+
 
     void AccessibleTabBarPageList::InsertChild( sal_Int32 i )
     {
@@ -151,7 +134,7 @@ namespace accessibility
         }
     }
 
-    // -----------------------------------------------------------------------------
+
 
     void AccessibleTabBarPageList::RemoveChild( sal_Int32 i )
     {
@@ -177,7 +160,7 @@ namespace accessibility
         }
     }
 
-    // -----------------------------------------------------------------------------
+
 
     void AccessibleTabBarPageList::MoveChild( sal_Int32 i, sal_Int32 j )
     {
@@ -198,7 +181,7 @@ namespace accessibility
         }
     }
 
-    // -----------------------------------------------------------------------------
+
 
     void AccessibleTabBarPageList::ProcessWindowEvent( const VclWindowEvent& rVclWindowEvent )
     {
@@ -227,7 +210,7 @@ namespace accessibility
                 Any aOldValue, aNewValue;
                 aNewValue <<= AccessibleStateType::SHOWING;
                 NotifyAccessibleEvent( AccessibleEventId::STATE_CHANGED, aOldValue, aNewValue );
-                UpdateShowing( sal_True );
+                UpdateShowing( true );
             }
             break;
             case VCLEVENT_WINDOW_HIDE:
@@ -235,27 +218,7 @@ namespace accessibility
                 Any aOldValue, aNewValue;
                 aOldValue <<= AccessibleStateType::SHOWING;
                 NotifyAccessibleEvent( AccessibleEventId::STATE_CHANGED, aOldValue, aNewValue );
-                UpdateShowing( sal_False );
-            }
-            break;
-            case VCLEVENT_TABBAR_PAGEENABLED:
-            {
-                if ( m_pTabBar )
-                {
-                    sal_uInt16 nPageId = (sal_uInt16)(sal_IntPtr) rVclWindowEvent.GetData();
-                    sal_uInt16 nPagePos = m_pTabBar->GetPagePos( nPageId );
-                    UpdateEnabled( nPagePos, sal_True );
-                }
-            }
-            break;
-            case VCLEVENT_TABBAR_PAGEDISABLED:
-            {
-                if ( m_pTabBar )
-                {
-                    sal_uInt16 nPageId = (sal_uInt16)(sal_IntPtr) rVclWindowEvent.GetData();
-                    sal_uInt16 nPagePos = m_pTabBar->GetPagePos( nPageId );
-                    UpdateEnabled( nPagePos, sal_False );
-                }
+                UpdateShowing( false );
             }
             break;
             case VCLEVENT_TABBAR_PAGESELECTED:
@@ -267,9 +230,9 @@ namespace accessibility
             {
                 if ( m_pTabBar )
                 {
-                    sal_uInt16 nPageId = (sal_uInt16)(sal_IntPtr) rVclWindowEvent.GetData();
+                    sal_uInt16 nPageId = (sal_uInt16)reinterpret_cast<sal_IntPtr>(rVclWindowEvent.GetData());
                     sal_uInt16 nPagePos = m_pTabBar->GetPagePos( nPageId );
-                    UpdateSelected( nPagePos, sal_True );
+                    UpdateSelected( nPagePos, true );
                 }
             }
             break;
@@ -277,9 +240,9 @@ namespace accessibility
             {
                 if ( m_pTabBar )
                 {
-                    sal_uInt16 nPageId = (sal_uInt16)(sal_IntPtr) rVclWindowEvent.GetData();
+                    sal_uInt16 nPageId = (sal_uInt16)reinterpret_cast<sal_IntPtr>(rVclWindowEvent.GetData());
                     sal_uInt16 nPagePos = m_pTabBar->GetPagePos( nPageId );
-                    UpdateSelected( nPagePos, sal_False );
+                    UpdateSelected( nPagePos, false );
                 }
             }
             break;
@@ -287,7 +250,7 @@ namespace accessibility
             {
                 if ( m_pTabBar )
                 {
-                    sal_uInt16 nPageId = (sal_uInt16)(sal_IntPtr) rVclWindowEvent.GetData();
+                    sal_uInt16 nPageId = (sal_uInt16)reinterpret_cast<sal_IntPtr>(rVclWindowEvent.GetData());
                     sal_uInt16 nPagePos = m_pTabBar->GetPagePos( nPageId );
                     InsertChild( nPagePos );
                 }
@@ -297,7 +260,7 @@ namespace accessibility
             {
                 if ( m_pTabBar )
                 {
-                    sal_uInt16 nPageId = (sal_uInt16)(sal_IntPtr) rVclWindowEvent.GetData();
+                    sal_uInt16 nPageId = (sal_uInt16)reinterpret_cast<sal_IntPtr>(rVclWindowEvent.GetData());
 
                     if ( nPageId == TabBar::PAGE_NOT_FOUND )
                     {
@@ -325,14 +288,14 @@ namespace accessibility
             break;
             case VCLEVENT_TABBAR_PAGEMOVED:
             {
-                Pair* pPair = (Pair*) rVclWindowEvent.GetData();
+                Pair* pPair = static_cast<Pair*>(rVclWindowEvent.GetData());
                 if ( pPair )
                     MoveChild( pPair->A(), pPair->B() );
             }
             break;
             case VCLEVENT_TABBAR_PAGETEXTCHANGED:
             {
-                sal_uInt16 nPageId = (sal_uInt16)(sal_IntPtr) rVclWindowEvent.GetData();
+                sal_uInt16 nPageId = (sal_uInt16)reinterpret_cast<sal_IntPtr>(rVclWindowEvent.GetData());
                 sal_uInt16 nPagePos = m_pTabBar->GetPagePos( nPageId );
                 UpdatePageText( nPagePos );
             }
@@ -345,7 +308,7 @@ namespace accessibility
         }
     }
 
-    // -----------------------------------------------------------------------------
+
 
     void AccessibleTabBarPageList::FillAccessibleStateSet( utl::AccessibleStateSetHelper& rStateSet )
     {
@@ -364,9 +327,9 @@ namespace accessibility
         }
     }
 
-    // -----------------------------------------------------------------------------
+
     // OCommonAccessibleComponent
-    // -----------------------------------------------------------------------------
+
 
     awt::Rectangle AccessibleTabBarPageList::implGetBounds() throw (RuntimeException)
     {
@@ -377,28 +340,28 @@ namespace accessibility
         return aBounds;
     }
 
-    // -----------------------------------------------------------------------------
+
     // XInterface
-    // -----------------------------------------------------------------------------
+
 
     IMPLEMENT_FORWARD_XINTERFACE2( AccessibleTabBarPageList, AccessibleExtendedComponentHelper_BASE, AccessibleTabBarPageList_BASE )
 
-    // -----------------------------------------------------------------------------
+
     // XTypeProvider
-    // -----------------------------------------------------------------------------
+
 
     IMPLEMENT_FORWARD_XTYPEPROVIDER2( AccessibleTabBarPageList, AccessibleExtendedComponentHelper_BASE, AccessibleTabBarPageList_BASE )
 
-    // -----------------------------------------------------------------------------
+
     // XComponent
-    // -----------------------------------------------------------------------------
+
 
     void AccessibleTabBarPageList::disposing()
     {
         AccessibleTabBarBase::disposing();
 
         // dispose all children
-        for ( sal_uInt32 i = 0; i < m_aAccessibleChildren.size(); ++i )
+        for ( size_t i = 0; i < m_aAccessibleChildren.size(); ++i )
         {
             Reference< XComponent > xComponent( m_aAccessibleChildren[i], UNO_QUERY );
             if ( xComponent.is() )
@@ -407,56 +370,55 @@ namespace accessibility
         m_aAccessibleChildren.clear();
     }
 
-    // -----------------------------------------------------------------------------
-    // XServiceInfo
-    // -----------------------------------------------------------------------------
 
-    OUString AccessibleTabBarPageList::getImplementationName() throw (RuntimeException)
+    // XServiceInfo
+
+
+    OUString AccessibleTabBarPageList::getImplementationName() throw (RuntimeException, std::exception)
     {
         return OUString( "com.sun.star.comp.svtools.AccessibleTabBarPageList" );
     }
 
-    // -----------------------------------------------------------------------------
 
-    sal_Bool AccessibleTabBarPageList::supportsService( const OUString& rServiceName ) throw (RuntimeException)
+
+    sal_Bool AccessibleTabBarPageList::supportsService( const OUString& rServiceName ) throw (RuntimeException, std::exception)
     {
         return cppu::supportsService(this, rServiceName);
     }
 
-    // -----------------------------------------------------------------------------
 
-    Sequence< OUString > AccessibleTabBarPageList::getSupportedServiceNames() throw (RuntimeException)
+
+    Sequence< OUString > AccessibleTabBarPageList::getSupportedServiceNames() throw (RuntimeException, std::exception)
     {
-        Sequence< OUString > aNames(1);
-        aNames[0] = "com.sun.star.awt.AccessibleTabBarPageList";
+        Sequence< OUString > aNames { "com.sun.star.awt.AccessibleTabBarPageList" };
         return aNames;
     }
 
-    // -----------------------------------------------------------------------------
-    // XAccessible
-    // -----------------------------------------------------------------------------
 
-    Reference< XAccessibleContext > AccessibleTabBarPageList::getAccessibleContext(  ) throw (RuntimeException)
+    // XAccessible
+
+
+    Reference< XAccessibleContext > AccessibleTabBarPageList::getAccessibleContext(  ) throw (RuntimeException, std::exception)
     {
         OExternalLockGuard aGuard( this );
 
         return this;
     }
 
-    // -----------------------------------------------------------------------------
-    // XAccessibleContext
-    // -----------------------------------------------------------------------------
 
-    sal_Int32 AccessibleTabBarPageList::getAccessibleChildCount() throw (RuntimeException)
+    // XAccessibleContext
+
+
+    sal_Int32 AccessibleTabBarPageList::getAccessibleChildCount() throw (RuntimeException, std::exception)
     {
         OExternalLockGuard aGuard( this );
 
         return m_aAccessibleChildren.size();
     }
 
-    // -----------------------------------------------------------------------------
 
-    Reference< XAccessible > AccessibleTabBarPageList::getAccessibleChild( sal_Int32 i ) throw (IndexOutOfBoundsException, RuntimeException)
+
+    Reference< XAccessible > AccessibleTabBarPageList::getAccessibleChild( sal_Int32 i ) throw (IndexOutOfBoundsException, RuntimeException, std::exception)
     {
         OExternalLockGuard aGuard( this );
 
@@ -480,9 +442,9 @@ namespace accessibility
         return xChild;
     }
 
-    // -----------------------------------------------------------------------------
 
-    Reference< XAccessible > AccessibleTabBarPageList::getAccessibleParent(  ) throw (RuntimeException)
+
+    Reference< XAccessible > AccessibleTabBarPageList::getAccessibleParent(  ) throw (RuntimeException, std::exception)
     {
         OExternalLockGuard aGuard( this );
 
@@ -493,45 +455,45 @@ namespace accessibility
         return xParent;
     }
 
-    // -----------------------------------------------------------------------------
 
-    sal_Int32 AccessibleTabBarPageList::getAccessibleIndexInParent(  ) throw (RuntimeException)
+
+    sal_Int32 AccessibleTabBarPageList::getAccessibleIndexInParent(  ) throw (RuntimeException, std::exception)
     {
         OExternalLockGuard aGuard( this );
 
         return m_nIndexInParent;
     }
 
-    // -----------------------------------------------------------------------------
 
-    sal_Int16 AccessibleTabBarPageList::getAccessibleRole(  ) throw (RuntimeException)
+
+    sal_Int16 AccessibleTabBarPageList::getAccessibleRole(  ) throw (RuntimeException, std::exception)
     {
         OExternalLockGuard aGuard( this );
 
         return AccessibleRole::PAGE_TAB_LIST;
     }
 
-    // -----------------------------------------------------------------------------
 
-    OUString AccessibleTabBarPageList::getAccessibleDescription( ) throw (RuntimeException)
+
+    OUString AccessibleTabBarPageList::getAccessibleDescription( ) throw (RuntimeException, std::exception)
     {
         OExternalLockGuard aGuard( this );
 
         return OUString();
     }
 
-    // -----------------------------------------------------------------------------
 
-    OUString AccessibleTabBarPageList::getAccessibleName(  ) throw (RuntimeException)
+
+    OUString AccessibleTabBarPageList::getAccessibleName(  ) throw (RuntimeException, std::exception)
     {
         OExternalLockGuard aGuard( this );
 
         return OUString();
     }
 
-    // -----------------------------------------------------------------------------
 
-    Reference< XAccessibleRelationSet > AccessibleTabBarPageList::getAccessibleRelationSet(  ) throw (RuntimeException)
+
+    Reference< XAccessibleRelationSet > AccessibleTabBarPageList::getAccessibleRelationSet(  ) throw (RuntimeException, std::exception)
     {
         OExternalLockGuard aGuard( this );
 
@@ -540,9 +502,9 @@ namespace accessibility
         return xSet;
     }
 
-    // -----------------------------------------------------------------------------
 
-    Reference< XAccessibleStateSet > AccessibleTabBarPageList::getAccessibleStateSet(  ) throw (RuntimeException)
+
+    Reference< XAccessibleStateSet > AccessibleTabBarPageList::getAccessibleStateSet(  ) throw (RuntimeException, std::exception)
     {
         OExternalLockGuard aGuard( this );
 
@@ -561,25 +523,25 @@ namespace accessibility
         return xSet;
     }
 
-    // -----------------------------------------------------------------------------
 
-    Locale AccessibleTabBarPageList::getLocale(  ) throw (IllegalAccessibleComponentStateException, RuntimeException)
+
+    Locale AccessibleTabBarPageList::getLocale(  ) throw (IllegalAccessibleComponentStateException, RuntimeException, std::exception)
     {
         OExternalLockGuard aGuard( this );
 
         return Application::GetSettings().GetLanguageTag().getLocale();
     }
 
-    // -----------------------------------------------------------------------------
-    // XAccessibleComponent
-    // -----------------------------------------------------------------------------
 
-    Reference< XAccessible > AccessibleTabBarPageList::getAccessibleAtPoint( const awt::Point& rPoint ) throw (RuntimeException)
+    // XAccessibleComponent
+
+
+    Reference< XAccessible > AccessibleTabBarPageList::getAccessibleAtPoint( const awt::Point& rPoint ) throw (RuntimeException, std::exception)
     {
         OExternalLockGuard aGuard( this );
 
         Reference< XAccessible > xChild;
-        for ( sal_uInt32 i = 0; i < m_aAccessibleChildren.size(); ++i )
+        for ( size_t i = 0; i < m_aAccessibleChildren.size(); ++i )
         {
             Reference< XAccessible > xAcc = getAccessibleChild( i );
             if ( xAcc.is() )
@@ -601,16 +563,16 @@ namespace accessibility
         return xChild;
     }
 
-    // -----------------------------------------------------------------------------
 
-    void AccessibleTabBarPageList::grabFocus(  ) throw (RuntimeException)
+
+    void AccessibleTabBarPageList::grabFocus(  ) throw (RuntimeException, std::exception)
     {
         // no focus
     }
 
-    // -----------------------------------------------------------------------------
 
-    sal_Int32 AccessibleTabBarPageList::getForeground(  ) throw (RuntimeException)
+
+    sal_Int32 AccessibleTabBarPageList::getForeground(  ) throw (RuntimeException, std::exception)
     {
         OExternalLockGuard aGuard( this );
 
@@ -626,9 +588,9 @@ namespace accessibility
         return nColor;
     }
 
-    // -----------------------------------------------------------------------------
 
-    sal_Int32 AccessibleTabBarPageList::getBackground(  ) throw (RuntimeException)
+
+    sal_Int32 AccessibleTabBarPageList::getBackground(  ) throw (RuntimeException, std::exception)
     {
         OExternalLockGuard aGuard( this );
 
@@ -644,11 +606,11 @@ namespace accessibility
         return nColor;
     }
 
-    // -----------------------------------------------------------------------------
-    // XAccessibleExtendedComponent
-    // -----------------------------------------------------------------------------
 
-    Reference< awt::XFont > AccessibleTabBarPageList::getFont(  ) throw (RuntimeException)
+    // XAccessibleExtendedComponent
+
+
+    Reference< awt::XFont > AccessibleTabBarPageList::getFont(  ) throw (RuntimeException, std::exception)
     {
         OExternalLockGuard aGuard( this );
 
@@ -664,29 +626,29 @@ namespace accessibility
         return xFont;
     }
 
-    // -----------------------------------------------------------------------------
 
-    OUString AccessibleTabBarPageList::getTitledBorderText(  ) throw (RuntimeException)
+
+    OUString AccessibleTabBarPageList::getTitledBorderText(  ) throw (RuntimeException, std::exception)
     {
         OExternalLockGuard aGuard( this );
 
         return OUString();
     }
 
-    // -----------------------------------------------------------------------------
 
-    OUString AccessibleTabBarPageList::getToolTipText(  ) throw (RuntimeException)
+
+    OUString AccessibleTabBarPageList::getToolTipText(  ) throw (RuntimeException, std::exception)
     {
         OExternalLockGuard aGuard( this );
 
         return OUString();
     }
 
-    // -----------------------------------------------------------------------------
+
     // XAccessibleSelection
-    // -----------------------------------------------------------------------------
 
-    void AccessibleTabBarPageList::selectAccessibleChild( sal_Int32 nChildIndex ) throw (IndexOutOfBoundsException, RuntimeException)
+
+    void AccessibleTabBarPageList::selectAccessibleChild( sal_Int32 nChildIndex ) throw (IndexOutOfBoundsException, RuntimeException, std::exception)
     {
         OExternalLockGuard aGuard( this );
 
@@ -702,50 +664,50 @@ namespace accessibility
         }
     }
 
-    // -----------------------------------------------------------------------------
 
-    sal_Bool AccessibleTabBarPageList::isAccessibleChildSelected( sal_Int32 nChildIndex ) throw (IndexOutOfBoundsException, RuntimeException)
+
+    sal_Bool AccessibleTabBarPageList::isAccessibleChildSelected( sal_Int32 nChildIndex ) throw (IndexOutOfBoundsException, RuntimeException, std::exception)
     {
         OExternalLockGuard aGuard( this );
 
         if ( nChildIndex < 0 || nChildIndex >= getAccessibleChildCount() )
             throw IndexOutOfBoundsException();
 
-        sal_Bool bSelected = sal_False;
+        bool bSelected = false;
         if ( m_pTabBar && m_pTabBar->GetCurPageId() == m_pTabBar->GetPageId( (sal_uInt16)nChildIndex ) )
-            bSelected = sal_True;
+            bSelected = true;
 
         return bSelected;
     }
 
-    // -----------------------------------------------------------------------------
 
-    void AccessibleTabBarPageList::clearAccessibleSelection(  ) throw (RuntimeException)
+
+    void AccessibleTabBarPageList::clearAccessibleSelection(  ) throw (RuntimeException, std::exception)
     {
         // This method makes no sense in a TabBar, and so does nothing.
     }
 
-    // -----------------------------------------------------------------------------
 
-    void AccessibleTabBarPageList::selectAllAccessibleChildren(  ) throw (RuntimeException)
+
+    void AccessibleTabBarPageList::selectAllAccessibleChildren(  ) throw (RuntimeException, std::exception)
     {
         OExternalLockGuard aGuard( this );
 
         selectAccessibleChild( 0 );
     }
 
-    // -----------------------------------------------------------------------------
 
-    sal_Int32 AccessibleTabBarPageList::getSelectedAccessibleChildCount(  ) throw (RuntimeException)
+
+    sal_Int32 AccessibleTabBarPageList::getSelectedAccessibleChildCount(  ) throw (RuntimeException, std::exception)
     {
         OExternalLockGuard aGuard( this );
 
         return 1;
     }
 
-    // -----------------------------------------------------------------------------
 
-    Reference< XAccessible > AccessibleTabBarPageList::getSelectedAccessibleChild( sal_Int32 nSelectedChildIndex ) throw (IndexOutOfBoundsException, RuntimeException)
+
+    Reference< XAccessible > AccessibleTabBarPageList::getSelectedAccessibleChild( sal_Int32 nSelectedChildIndex ) throw (IndexOutOfBoundsException, RuntimeException, std::exception)
     {
         OExternalLockGuard aGuard( this );
 
@@ -766,9 +728,9 @@ namespace accessibility
         return xChild;
     }
 
-    // -----------------------------------------------------------------------------
 
-    void AccessibleTabBarPageList::deselectAccessibleChild( sal_Int32 nChildIndex ) throw (IndexOutOfBoundsException, RuntimeException)
+
+    void AccessibleTabBarPageList::deselectAccessibleChild( sal_Int32 nChildIndex ) throw (IndexOutOfBoundsException, RuntimeException, std::exception)
     {
         OExternalLockGuard aGuard( this );
 
@@ -778,10 +740,10 @@ namespace accessibility
         // This method makes no sense in a TabBar, and so does nothing.
     }
 
-    // -----------------------------------------------------------------------------
 
-//.........................................................................
+
+
 }   // namespace accessibility
-//.........................................................................
+
 
 /* vim:set shiftwidth=4 softtabstop=4 expandtab: */
