@@ -59,7 +59,7 @@ VCLXAccessibleTabControl::~VCLXAccessibleTabControl()
 
 void VCLXAccessibleTabControl::UpdateFocused()
 {
-    for ( sal_uInt32 i = 0; i < m_aAccessibleChildren.size(); ++i )
+    for ( size_t i = 0; i < m_aAccessibleChildren.size(); ++i )
     {
         Reference< XAccessible > xChild( m_aAccessibleChildren[i] );
         if ( xChild.is() )
@@ -240,10 +240,10 @@ void VCLXAccessibleTabControl::ProcessWindowEvent( const VclWindowEvent& rVclWin
         {
             if ( m_pTabControl )
             {
-                m_pTabControl = NULL;
+                m_pTabControl = nullptr;
 
                 // dispose all tab pages
-                for ( sal_uInt32 i = 0; i < m_aAccessibleChildren.size(); ++i )
+                for ( size_t i = 0; i < m_aAccessibleChildren.size(); ++i )
                 {
                     Reference< XComponent > xComponent( m_aAccessibleChildren[i], UNO_QUERY );
                     if ( xComponent.is() )
@@ -323,10 +323,10 @@ void VCLXAccessibleTabControl::disposing()
 
     if ( m_pTabControl )
     {
-        m_pTabControl = NULL;
+        m_pTabControl = nullptr;
 
         // dispose all tab pages
-        for ( sal_uInt32 i = 0; i < m_aAccessibleChildren.size(); ++i )
+        for ( size_t i = 0; i < m_aAccessibleChildren.size(); ++i )
         {
             Reference< XComponent > xComponent( m_aAccessibleChildren[i], UNO_QUERY );
             if ( xComponent.is() )
@@ -349,8 +349,7 @@ OUString VCLXAccessibleTabControl::getImplementationName() throw (RuntimeExcepti
 
 Sequence< OUString > VCLXAccessibleTabControl::getSupportedServiceNames() throw (RuntimeException, std::exception)
 {
-    Sequence< OUString > aNames(1);
-    aNames[0] = "com.sun.star.awt.AccessibleTabControl";
+    Sequence< OUString > aNames { "com.sun.star.awt.AccessibleTabControl" };
     return aNames;
 }
 
