@@ -79,7 +79,7 @@ MediaControl::MediaControl( vcl::Window* pParent, MediaControlStyle eControlStyl
 
     SetBackground();
     SetPaintTransparent( true );
-    SetParentClipMode( PARENTCLIPMODE_NOCLIP );
+    SetParentClipMode( ParentClipMode::NoClip );
 
     if( MEDIACONTROLSTYLE_SINGLELINE != meControlStyle )
     {
@@ -156,7 +156,6 @@ MediaControl::MediaControl( vcl::Window* pParent, MediaControlStyle eControlStyl
     maMinSize.Width() += maMuteToolBox->GetSizePixel().Width();
 
     maVolumeSlider->SetSlideHdl( LINK( this, MediaControl, implVolumeHdl ) );
-    maVolumeSlider->SetEndSlideHdl( LINK( this, MediaControl, implVolumeEndHdl ) );
     maVolumeSlider->SetRange( Range( AVMEDIA_DB_RANGE, 0 ) );
     maVolumeSlider->SetUpdateMode( true );
     maVolumeSlider->SetHelpId( HID_AVMEDIA_VOLUMESLIDER );
@@ -201,7 +200,7 @@ MediaControl::~MediaControl()
 
 void MediaControl::dispose()
 {
-    maZoomToolBox->SetItemWindow( AVMEDIA_TOOLBOXITEM_ZOOM, NULL );
+    maZoomToolBox->SetItemWindow( AVMEDIA_TOOLBOXITEM_ZOOM, nullptr );
     mpZoomListBox.disposeAndClear();
     maTimeEdit.disposeAndClear();
     maZoomToolBox.disposeAndClear();
@@ -319,23 +318,23 @@ void MediaControl::implUpdateToolboxes()
         maPlayToolBox->Enable();
         maMuteToolBox->Enable();
 
-        if( MEDIASTATE_PLAY == maItem.getState() )
+        if( MediaState::Play == maItem.getState() )
         {
-            maPlayToolBox->CheckItem( AVMEDIA_TOOLBOXITEM_PLAY, true );
+            maPlayToolBox->CheckItem( AVMEDIA_TOOLBOXITEM_PLAY );
             maPlayToolBox->CheckItem( AVMEDIA_TOOLBOXITEM_PAUSE, false );
             maPlayToolBox->CheckItem( AVMEDIA_TOOLBOXITEM_STOP, false );
         }
         else if( maItem.getTime() > 0.0 && ( maItem.getTime() < maItem.getDuration() ) )
         {
             maPlayToolBox->CheckItem( AVMEDIA_TOOLBOXITEM_PLAY, false );
-            maPlayToolBox->CheckItem( AVMEDIA_TOOLBOXITEM_PAUSE, true );
+            maPlayToolBox->CheckItem( AVMEDIA_TOOLBOXITEM_PAUSE );
             maPlayToolBox->CheckItem( AVMEDIA_TOOLBOXITEM_STOP, false );
         }
         else
         {
             maPlayToolBox->CheckItem( AVMEDIA_TOOLBOXITEM_PLAY, false );
             maPlayToolBox->CheckItem( AVMEDIA_TOOLBOXITEM_PAUSE, false );
-            maPlayToolBox->CheckItem( AVMEDIA_TOOLBOXITEM_STOP, true );
+            maPlayToolBox->CheckItem( AVMEDIA_TOOLBOXITEM_STOP );
         }
 
         maPlayToolBox->CheckItem( AVMEDIA_TOOLBOXITEM_LOOP, maItem.isLoop() );
@@ -347,11 +346,11 @@ void MediaControl::implUpdateToolboxes()
 
             switch( maItem.getZoom() )
             {
-                case( ::com::sun::star::media::ZoomLevel_ZOOM_1_TO_2 ): nSelectEntryPos = AVMEDIA_ZOOMLEVEL_50; break;
-                case( ::com::sun::star::media::ZoomLevel_ORIGINAL ): nSelectEntryPos = AVMEDIA_ZOOMLEVEL_100; break;
-                case( ::com::sun::star::media::ZoomLevel_ZOOM_2_TO_1 ): nSelectEntryPos = AVMEDIA_ZOOMLEVEL_200; break;
-                case( ::com::sun::star::media::ZoomLevel_FIT_TO_WINDOW_FIXED_ASPECT ): nSelectEntryPos = AVMEDIA_ZOOMLEVEL_FIT; break;
-                case( ::com::sun::star::media::ZoomLevel_FIT_TO_WINDOW ): nSelectEntryPos = AVMEDIA_ZOOMLEVEL_SCALED; break;
+                case( css::media::ZoomLevel_ZOOM_1_TO_2 ): nSelectEntryPos = AVMEDIA_ZOOMLEVEL_50; break;
+                case( css::media::ZoomLevel_ORIGINAL ): nSelectEntryPos = AVMEDIA_ZOOMLEVEL_100; break;
+                case( css::media::ZoomLevel_ZOOM_2_TO_1 ): nSelectEntryPos = AVMEDIA_ZOOMLEVEL_200; break;
+                case( css::media::ZoomLevel_FIT_TO_WINDOW_FIXED_ASPECT ): nSelectEntryPos = AVMEDIA_ZOOMLEVEL_FIT; break;
+                case( css::media::ZoomLevel_FIT_TO_WINDOW ): nSelectEntryPos = AVMEDIA_ZOOMLEVEL_SCALED; break;
 
                 default: nSelectEntryPos = AVMEDIA_ZOOMLEVEL_INVALID; break;
             }
@@ -440,18 +439,16 @@ Image MediaControl::implGetImage( sal_Int32 nImageId ) const
 
 
 
-IMPL_LINK( MediaControl, implTimeHdl, Slider*, p )
+IMPL_LINK_TYPED( MediaControl, implTimeHdl, Slider*, p, void )
 {
     mbLocked = true;
     maIdle.Stop();
     implUpdateTimeField( p->GetThumbPos() * maItem.getDuration() / AVMEDIA_TIME_RANGE );
-
-    return 0;
 }
 
 
 
-IMPL_LINK( MediaControl, implTimeEndHdl, Slider*, p )
+IMPL_LINK_TYPED( MediaControl, implTimeEndHdl, Slider*, p, void )
 {
     MediaItem aExecItem;
 
@@ -460,28 +457,17 @@ IMPL_LINK( MediaControl, implTimeEndHdl, Slider*, p )
     update();
     maIdle.Start();
     mbLocked = false;
-
-    return 0;
 }
 
 
 
-IMPL_LINK( MediaControl, implVolumeHdl, Slider*, p )
+IMPL_LINK_TYPED( MediaControl, implVolumeHdl, Slider*, p, void )
 {
     MediaItem aExecItem;
 
     aExecItem.setVolumeDB( static_cast< sal_Int16 >( p->GetThumbPos() ) );
     execute( aExecItem );
     update();
-
-    return 0;
-}
-
-
-
-IMPL_STATIC_LINK_NOARG(MediaControl, implVolumeEndHdl)
-{
-    return 0;
 }
 
 
@@ -499,14 +485,14 @@ IMPL_LINK_TYPED( MediaControl, implSelectHdl, ToolBox*, p, void )
                 OUString aURL;
 
                  if (::avmedia::MediaWindow::executeMediaURLDialog(
-                             GetParent(), aURL, 0))
+                             GetParent(), aURL, nullptr))
                  {
                      if( !::avmedia::MediaWindow::isMediaURL( aURL, ""/*TODO?*/, true ) )
                         ::avmedia::MediaWindow::executeFormatErrorBox( this );
                     else
                     {
                         aExecItem.setURL( aURL, "", ""/*TODO?*/ );
-                        aExecItem.setState( MEDIASTATE_PLAY );
+                        aExecItem.setState( MediaState::Play );
                     }
                 }
             }
@@ -523,7 +509,7 @@ IMPL_LINK_TYPED( MediaControl, implSelectHdl, ToolBox*, p, void )
 
             case( AVMEDIA_TOOLBOXITEM_PLAY ):
             {
-                aExecItem.setState( MEDIASTATE_PLAY );
+                aExecItem.setState( MediaState::Play );
 
                 if( maItem.getTime() == maItem.getDuration() )
                     aExecItem.setTime( 0.0 );
@@ -534,13 +520,13 @@ IMPL_LINK_TYPED( MediaControl, implSelectHdl, ToolBox*, p, void )
 
             case( AVMEDIA_TOOLBOXITEM_PAUSE ):
             {
-                aExecItem.setState( MEDIASTATE_PAUSE );
+                aExecItem.setState( MediaState::Pause );
             }
             break;
 
             case( AVMEDIA_TOOLBOXITEM_STOP ):
             {
-                aExecItem.setState( MEDIASTATE_STOP );
+                aExecItem.setState( MediaState::Stop );
                 aExecItem.setTime( 0.0 );
             }
             break;
@@ -568,36 +554,31 @@ IMPL_LINK_TYPED( MediaControl, implSelectHdl, ToolBox*, p, void )
     update();
     if(p)
     {
-        p->Invalidate( INVALIDATE_UPDATE );
+        p->Invalidate( InvalidateFlags::Update );
     }
 }
 
 
 
-IMPL_LINK( MediaControl, implZoomSelectHdl, ListBox*, p )
+IMPL_LINK_TYPED( MediaControl, implZoomSelectHdl, ListBox&, p, void )
 {
-    if( p )
+    MediaItem aExecItem;
+    css::media::ZoomLevel eLevel;
+
+    switch( p.GetSelectEntryPos() )
     {
-        MediaItem aExecItem;
-        ::com::sun::star::media::ZoomLevel eLevel;
+        case( AVMEDIA_ZOOMLEVEL_50 ): eLevel = css::media::ZoomLevel_ZOOM_1_TO_2; break;
+        case( AVMEDIA_ZOOMLEVEL_100 ): eLevel = css::media::ZoomLevel_ORIGINAL; break;
+        case( AVMEDIA_ZOOMLEVEL_200 ): eLevel = css::media::ZoomLevel_ZOOM_2_TO_1; break;
+        case( AVMEDIA_ZOOMLEVEL_FIT ): eLevel = css::media::ZoomLevel_FIT_TO_WINDOW_FIXED_ASPECT; break;
+        case( AVMEDIA_ZOOMLEVEL_SCALED ): eLevel = css::media::ZoomLevel_FIT_TO_WINDOW; break;
 
-        switch( p->GetSelectEntryPos() )
-        {
-            case( AVMEDIA_ZOOMLEVEL_50 ): eLevel = ::com::sun::star::media::ZoomLevel_ZOOM_1_TO_2; break;
-            case( AVMEDIA_ZOOMLEVEL_100 ): eLevel = ::com::sun::star::media::ZoomLevel_ORIGINAL; break;
-            case( AVMEDIA_ZOOMLEVEL_200 ): eLevel = ::com::sun::star::media::ZoomLevel_ZOOM_2_TO_1; break;
-            case( AVMEDIA_ZOOMLEVEL_FIT ): eLevel = ::com::sun::star::media::ZoomLevel_FIT_TO_WINDOW_FIXED_ASPECT; break;
-            case( AVMEDIA_ZOOMLEVEL_SCALED ): eLevel = ::com::sun::star::media::ZoomLevel_FIT_TO_WINDOW; break;
-
-            default: eLevel = ::com::sun::star::media::ZoomLevel_NOT_AVAILABLE; break;
-        }
-
-        aExecItem.setZoom( eLevel );
-        execute( aExecItem );
-        update();
+        default: eLevel = css::media::ZoomLevel_NOT_AVAILABLE; break;
     }
 
-    return 0;
+    aExecItem.setZoom( eLevel );
+    execute( aExecItem );
+    update();
 }
 
 
