@@ -1,4 +1,22 @@
-#include <boost/bind.hpp>
+/* -*- Mode: C++; tab-width: 4; indent-tabs-mode: nil; c-basic-offset: 4 -*- */
+/*
+ * This file is part of the LibreOffice project.
+ *
+ * This Source Code Form is subject to the terms of the Mozilla Public
+ * License, v. 2.0. If a copy of the MPL was not distributed with this
+ * file, You can obtain one at http://mozilla.org/MPL/2.0/.
+ *
+ * This file incorporates work covered by the following license notice:
+ *
+ *   Licensed to the Apache Software Foundation (ASF) under one or more
+ *   contributor license agreements. See the NOTICE file distributed
+ *   with this work for additional information regarding copyright
+ *   ownership. The ASF licenses this file to you under the Apache
+ *   License, Version 2.0 (the "License"); you may not use this file
+ *   except in compliance with the License. You may obtain a copy of
+ *   the License at http://www.apache.org/licenses/LICENSE-2.0 .
+ */
+
 #include <vcl/syschild.hxx>
 #include <vcl/sysdata.hxx>
 #include <cppuhelper/supportsservice.hxx>
@@ -47,7 +65,7 @@ unsigned VLCPlayer::getHeight() const
     return mPlayer.getHeight();
 }
 
-void SAL_CALL VLCPlayer::start() throw ( ::com::sun::star::uno::RuntimeException, std::exception )
+void SAL_CALL VLCPlayer::start() throw ( css::uno::RuntimeException, std::exception )
 {
     ::osl::MutexGuard aGuard(m_aMutex);
     if (!mPlayer.play())
@@ -56,19 +74,19 @@ void SAL_CALL VLCPlayer::start() throw ( ::com::sun::star::uno::RuntimeException
     }
 }
 
-void SAL_CALL VLCPlayer::stop() throw ( ::com::sun::star::uno::RuntimeException, std::exception )
+void SAL_CALL VLCPlayer::stop() throw ( css::uno::RuntimeException, std::exception )
 {
     ::osl::MutexGuard aGuard(m_aMutex);
     mPlayer.pause();
 }
 
-sal_Bool SAL_CALL VLCPlayer::isPlaying() throw ( ::com::sun::star::uno::RuntimeException, std::exception )
+sal_Bool SAL_CALL VLCPlayer::isPlaying() throw ( css::uno::RuntimeException, std::exception )
 {
     ::osl::MutexGuard aGuard(m_aMutex);
     return mPlayer.isPlaying();
 }
 
-double SAL_CALL VLCPlayer::getDuration() throw ( ::com::sun::star::uno::RuntimeException, std::exception )
+double SAL_CALL VLCPlayer::getDuration() throw ( css::uno::RuntimeException, std::exception )
 {
     ::osl::MutexGuard aGuard(m_aMutex);
     return static_cast<double>( mMedia.getDuration() ) / MS_IN_SEC;
@@ -80,7 +98,7 @@ void SAL_CALL VLCPlayer::setScale( float factor )
     mPlayer.setScale( factor );
 }
 
-void SAL_CALL VLCPlayer::setMediaTime( double fTime ) throw ( ::com::sun::star::uno::RuntimeException, std::exception )
+void SAL_CALL VLCPlayer::setMediaTime( double fTime ) throw ( css::uno::RuntimeException, std::exception )
 {
     ::osl::MutexGuard aGuard(m_aMutex);
     if ( fTime < 0.00000001 && !mPlayer.isPlaying() )
@@ -91,7 +109,7 @@ void SAL_CALL VLCPlayer::setMediaTime( double fTime ) throw ( ::com::sun::star::
     mPlayer.setTime( fTime * MS_IN_SEC );
 }
 
-double SAL_CALL VLCPlayer::getMediaTime() throw ( ::com::sun::star::uno::RuntimeException, std::exception )
+double SAL_CALL VLCPlayer::getMediaTime() throw ( css::uno::RuntimeException, std::exception )
 {
     ::osl::MutexGuard aGuard(m_aMutex);
     return static_cast<double>( mPlayer.getTime() ) / MS_IN_SEC;
@@ -105,48 +123,48 @@ void VLCPlayer::replay()
     start();
 }
 
-void SAL_CALL VLCPlayer::setPlaybackLoop( sal_Bool bSet ) throw ( ::com::sun::star::uno::RuntimeException, std::exception )
+void SAL_CALL VLCPlayer::setPlaybackLoop( sal_Bool bSet ) throw ( css::uno::RuntimeException, std::exception )
 {
     ::osl::MutexGuard aGuard(m_aMutex);
     mPlaybackLoop = bSet;
 
     if ( bSet )
-        mEventManager.onEndReached(boost::bind(&VLCPlayer::replay, this));
+        mEventManager.onEndReached([this](){ this->replay(); });
     else
         mEventManager.onEndReached();
 }
 
-sal_Bool SAL_CALL VLCPlayer::isPlaybackLoop() throw ( ::com::sun::star::uno::RuntimeException, std::exception )
+sal_Bool SAL_CALL VLCPlayer::isPlaybackLoop() throw ( css::uno::RuntimeException, std::exception )
 {
     ::osl::MutexGuard aGuard(m_aMutex);
     return mPlaybackLoop;
 }
 
-void SAL_CALL VLCPlayer::setVolumeDB( ::sal_Int16 nDB ) throw ( ::com::sun::star::uno::RuntimeException, std::exception )
+void SAL_CALL VLCPlayer::setVolumeDB( ::sal_Int16 nDB ) throw ( css::uno::RuntimeException, std::exception )
 {
     ::osl::MutexGuard aGuard(m_aMutex);
     mPlayer.setVolume( static_cast<sal_Int16>( ( nDB + 40 ) * 10.0  / 4 ) );
 }
 
-::sal_Int16 SAL_CALL VLCPlayer::getVolumeDB() throw ( ::com::sun::star::uno::RuntimeException, std::exception )
+::sal_Int16 SAL_CALL VLCPlayer::getVolumeDB() throw ( css::uno::RuntimeException, std::exception )
 {
     ::osl::MutexGuard aGuard(m_aMutex);
     return static_cast<sal_Int16>( mPlayer.getVolume() / 10.0 * 4 - 40 );
 }
 
-void SAL_CALL VLCPlayer::setMute( sal_Bool bSet ) throw ( ::com::sun::star::uno::RuntimeException, std::exception )
+void SAL_CALL VLCPlayer::setMute( sal_Bool bSet ) throw ( css::uno::RuntimeException, std::exception )
 {
     ::osl::MutexGuard aGuard(m_aMutex);
     mPlayer.setMute( bSet );
 }
 
-sal_Bool SAL_CALL VLCPlayer::isMute() throw ( ::com::sun::star::uno::RuntimeException, std::exception )
+sal_Bool SAL_CALL VLCPlayer::isMute() throw ( css::uno::RuntimeException, std::exception )
 {
     ::osl::MutexGuard aGuard(m_aMutex);
     return mPlayer.getMute();
 }
 
-css::awt::Size SAL_CALL VLCPlayer::getPreferredPlayerWindowSize() throw ( ::com::sun::star::uno::RuntimeException, std::exception )
+css::awt::Size SAL_CALL VLCPlayer::getPreferredPlayerWindowSize() throw ( css::uno::RuntimeException, std::exception )
 {
     return css::awt::Size( 480, 360 );
 }
@@ -166,9 +184,9 @@ namespace
 
         SystemChildWindow *pParentWindow = reinterpret_cast< SystemChildWindow* >( pIntPtr );
 
-        const SystemEnvData* pEnvData = pParentWindow ? pParentWindow->GetSystemData() : NULL;
+        const SystemEnvData* pEnvData = pParentWindow ? pParentWindow->GetSystemData() : nullptr;
 
-        if (pEnvData == NULL)
+        if (pEnvData == nullptr)
             return -1;
 
 #if defined MACOSX
@@ -197,7 +215,7 @@ void VLCPlayer::setVideoSize( unsigned width, unsigned height )
 }
 
 uno::Reference< css::media::XPlayerWindow > SAL_CALL VLCPlayer::createPlayerWindow( const uno::Sequence< uno::Any >& aArguments )
-     throw ( ::com::sun::star::uno::RuntimeException, std::exception )
+     throw ( css::uno::RuntimeException, std::exception )
 {
     ::osl::MutexGuard aGuard( m_aMutex );
 
@@ -216,40 +234,39 @@ uno::Reference< css::media::XPlayerWindow > SAL_CALL VLCPlayer::createPlayerWind
         setWindowID( winID );
     }
 
-    return ::com::sun::star::uno::Reference< css::media::XPlayerWindow >( window );
+    return css::uno::Reference< css::media::XPlayerWindow >( window );
 }
 
 uno::Reference< css::media::XFrameGrabber > SAL_CALL VLCPlayer::createFrameGrabber()
-     throw ( ::com::sun::star::uno::RuntimeException, std::exception )
+     throw ( css::uno::RuntimeException, std::exception )
 {
     ::osl::MutexGuard aGuard(m_aMutex);
 
     if ( !mrFrameGrabber.is() )
     {
         VLCFrameGrabber *frameGrabber = new VLCFrameGrabber( mEventHandler, mUrl );
-        mrFrameGrabber = uno::Reference< css::media::XFrameGrabber >( frameGrabber );
+        mrFrameGrabber.set( frameGrabber );
     }
 
     return mrFrameGrabber;
 }
 
 ::rtl::OUString SAL_CALL VLCPlayer::getImplementationName()
-     throw ( ::com::sun::star::uno::RuntimeException, std::exception )
+     throw ( css::uno::RuntimeException, std::exception )
 {
     return AVMEDIA_VLC_PLAYER_IMPLEMENTATIONNAME;
 }
 
 sal_Bool SAL_CALL VLCPlayer::supportsService( const ::rtl::OUString& serviceName )
-     throw ( ::com::sun::star::uno::RuntimeException, std::exception )
+     throw ( css::uno::RuntimeException, std::exception )
 {
     return cppu::supportsService(this, serviceName);
 }
 
 ::uno::Sequence< ::rtl::OUString > SAL_CALL VLCPlayer::getSupportedServiceNames()
-     throw ( ::com::sun::star::uno::RuntimeException, std::exception )
+     throw ( css::uno::RuntimeException, std::exception )
 {
-    uno::Sequence< OUString > aRet(1);
-    aRet[0] = AVMEDIA_VLC_PLAYER_SERVICENAME;
+    uno::Sequence< OUString > aRet { AVMEDIA_VLC_PLAYER_SERVICENAME };
     return aRet;
 }
 
