@@ -30,6 +30,7 @@
 #pragma warning(pop)
 #endif
 #include <com/sun/star/awt/SystemPointer.hpp>
+#include <cppuhelper/supportsservice.hxx>
 
 #include "window.hxx"
 #include "player.hxx"
@@ -61,7 +62,7 @@ static ::osl::Mutex& ImplGetOwnStaticMutex()
 
 LRESULT CALLBACK MediaPlayerWndProc( HWND hWnd,UINT nMsg, WPARAM nPar1, LPARAM nPar2 )
 {
-    Window* pWindow = (Window*) ::GetWindowLong( hWnd, 0 );
+    Window* pWindow = (Window*) ::GetWindowLongPtr( hWnd, 0 );
     bool    bProcessed = true;
 
     if( pWindow )
@@ -194,7 +195,7 @@ Window::Window( const uno::Reference< lang::XMultiServiceFactory >& rxMgr, Playe
 Window::~Window()
 {
     if( mnFrameWnd )
-        ::DestroyWindow( (HWND) mnFrameWnd );
+        ::DestroyWindow( mnFrameWnd );
 }
 
 void Window::ImplLayoutVideoWindow()
@@ -295,27 +296,16 @@ bool Window::create( const uno::Sequence< uno::Any >& rArguments )
         rArguments[ 0 ] >>= nWnd;
         rArguments[ 1 ] >>= aRect;
 
-        mnParentWnd = static_cast<int>(nWnd);
+        mnParentWnd = reinterpret_cast<HWND>(nWnd);
 
-        mnFrameWnd = (int) ::CreateWindow( mpWndClass->lpszClassName, NULL,
+        mnFrameWnd = ::CreateWindow( mpWndClass->lpszClassName, NULL,
                                            WS_VISIBLE | WS_CHILD | WS_CLIPSIBLINGS | WS_CLIPCHILDREN,
                                            aRect.X, aRect.Y, aRect.Width, aRect.Height,
-                                           (HWND) mnParentWnd, NULL, mpWndClass->hInstance, 0 );
-
-        // if the last CreateWindow failed...
-        if( mnFrameWnd == 0 )
-        {
-            // try again and this time assume that mnParent is indeed a dc
-            mnParentWnd = reinterpret_cast<int>(::WindowFromDC( (HDC)mnParentWnd ));
-            mnFrameWnd = (int) ::CreateWindow( mpWndClass->lpszClassName, NULL,
-                                           WS_VISIBLE | WS_CHILD | WS_CLIPSIBLINGS | WS_CLIPCHILDREN,
-                                           aRect.X, aRect.Y, aRect.Width, aRect.Height,
-                                           (HWND)mnParentWnd , NULL, mpWndClass->hInstance, 0 );
-        }
+                                           mnParentWnd, NULL, mpWndClass->hInstance, 0 );
 
         if( mnFrameWnd )
         {
-            ::SetWindowLong( (HWND) mnFrameWnd, 0, (DWORD) this );
+            ::SetWindowLongPtr( mnFrameWnd, 0, (LONG_PTR) this );
 
                         pVideoWindow->put_Owner( (OAHWND) mnFrameWnd );
                         pVideoWindow->put_MessageDrain( (OAHWND) mnFrameWnd );
@@ -397,7 +387,7 @@ void SAL_CALL Window::setPosSize( sal_Int32 X, sal_Int32 Y, sal_Int32 Width, sal
 {
     if( mnFrameWnd )
     {
-        ::SetWindowPos( (HWND) mnFrameWnd, HWND_TOP, X, Y, Width, Height, 0 );
+        ::SetWindowPos( mnFrameWnd, HWND_TOP, X, Y, Width, Height, 0 );
         ImplLayoutVideoWindow();
     }
 }
@@ -411,7 +401,7 @@ awt::Rectangle SAL_CALL Window::getPosSize()
     {
         ::RECT  aWndRect;
 
-        if( ::GetClientRect( (HWND) mnFrameWnd, &aWndRect ) )
+        if( ::GetClientRect( mnFrameWnd, &aWndRect ) )
         {
             aRet.X = aWndRect.left;
             aRet.Y = aWndRect.top;
@@ -433,7 +423,7 @@ void SAL_CALL Window::setVisible( sal_Bool bVisible )
         if( pVideoWindow )
             pVideoWindow->put_Visible( bVisible ? OATRUE : OAFALSE );
 
-        ::ShowWindow( (HWND) mnFrameWnd, bVisible ? SW_SHOW : SW_HIDE );
+        ::ShowWindow( mnFrameWnd, bVisible ? SW_SHOW : SW_HIDE );
     }
 }
 
@@ -441,86 +431,86 @@ void SAL_CALL Window::setEnable( sal_Bool bEnable )
     throw (uno::RuntimeException)
 {
     if( mnFrameWnd )
-        ::EnableWindow( (HWND) mnFrameWnd, bEnable );
+        ::EnableWindow( mnFrameWnd, bEnable );
 }
 
 void SAL_CALL Window::setFocus(  )
     throw (uno::RuntimeException)
 {
     if( mnFrameWnd )
-        ::SetFocus( (HWND) mnFrameWnd );
+        ::SetFocus( mnFrameWnd );
 }
 
 void SAL_CALL Window::addWindowListener( const uno::Reference< awt::XWindowListener >& xListener )
     throw (uno::RuntimeException)
 {
-    maListeners.addInterface( getCppuType( &xListener ), xListener );
+    maListeners.addInterface( cppu::UnoType<decltype(xListener)>::get(), xListener );
 }
 
 void SAL_CALL Window::removeWindowListener( const uno::Reference< awt::XWindowListener >& xListener )
     throw (uno::RuntimeException)
 {
-    maListeners.removeInterface( getCppuType( &xListener ), xListener );
+    maListeners.removeInterface( cppu::UnoType<decltype(xListener)>::get(), xListener );
 }
 
 void SAL_CALL Window::addFocusListener( const uno::Reference< awt::XFocusListener >& xListener )
     throw (uno::RuntimeException)
 {
-    maListeners.addInterface( getCppuType( &xListener ), xListener );
+    maListeners.addInterface( cppu::UnoType<decltype(xListener)>::get(), xListener );
 }
 
 void SAL_CALL Window::removeFocusListener( const uno::Reference< awt::XFocusListener >& xListener )
     throw (uno::RuntimeException)
 {
-    maListeners.removeInterface( getCppuType( &xListener ), xListener );
+    maListeners.removeInterface( cppu::UnoType<decltype(xListener)>::get(), xListener );
 }
 
 void SAL_CALL Window::addKeyListener( const uno::Reference< awt::XKeyListener >& xListener )
     throw (uno::RuntimeException)
 {
-    maListeners.addInterface( getCppuType( &xListener ), xListener );
+    maListeners.addInterface( cppu::UnoType<decltype(xListener)>::get(), xListener );
 }
 
 void SAL_CALL Window::removeKeyListener( const uno::Reference< awt::XKeyListener >& xListener )
     throw (uno::RuntimeException)
 {
-    maListeners.removeInterface( getCppuType( &xListener ), xListener );
+    maListeners.removeInterface( cppu::UnoType<decltype(xListener)>::get(), xListener );
 }
 
 void SAL_CALL Window::addMouseListener( const uno::Reference< awt::XMouseListener >& xListener )
     throw (uno::RuntimeException)
 {
-    maListeners.addInterface( getCppuType( &xListener ), xListener );
+    maListeners.addInterface( cppu::UnoType<decltype(xListener)>::get(), xListener );
 }
 
 void SAL_CALL Window::removeMouseListener( const uno::Reference< awt::XMouseListener >& xListener )
     throw (uno::RuntimeException)
 {
-    maListeners.removeInterface( getCppuType( &xListener ), xListener );
+    maListeners.removeInterface( cppu::UnoType<decltype(xListener)>::get(), xListener );
 }
 
 void SAL_CALL Window::addMouseMotionListener( const uno::Reference< awt::XMouseMotionListener >& xListener )
     throw (uno::RuntimeException)
 {
-    maListeners.addInterface( getCppuType( &xListener ), xListener );
+    maListeners.addInterface( cppu::UnoType<decltype(xListener)>::get(), xListener );
 }
 
 void SAL_CALL Window::removeMouseMotionListener( const uno::Reference< awt::XMouseMotionListener >& xListener )
     throw (uno::RuntimeException)
 {
-    maListeners.removeInterface( getCppuType( &xListener ), xListener );
+    maListeners.removeInterface( cppu::UnoType<decltype(xListener)>::get(), xListener );
 }
 
 void SAL_CALL Window::addPaintListener( const uno::Reference< awt::XPaintListener >& xListener )
     throw (uno::RuntimeException)
 {
-    maListeners.addInterface( getCppuType( &xListener ), xListener );
+    maListeners.addInterface( cppu::UnoType<decltype(xListener)>::get(), xListener );
 }
 
 void SAL_CALL Window::removePaintListener( const uno::Reference< awt::XPaintListener >& xListener )
     throw (uno::RuntimeException)
 {
-    maListeners.removeInterface( getCppuType( &xListener ), xListener );
+    maListeners.removeInterface( cppu::UnoType<decltype(xListener)>::get(), xListener );
 }
 
 void SAL_CALL Window::dispose(  )
@@ -531,18 +521,18 @@ void SAL_CALL Window::dispose(  )
 void SAL_CALL Window::addEventListener( const uno::Reference< lang::XEventListener >& xListener )
     throw (uno::RuntimeException)
 {
-    maListeners.addInterface( getCppuType( &xListener ), xListener );
+    maListeners.addInterface( cppu::UnoType<decltype(xListener)>::get(), xListener );
 }
 
 void SAL_CALL Window::removeEventListener( const uno::Reference< lang::XEventListener >& xListener )
     throw (uno::RuntimeException)
 {
-    maListeners.removeInterface( getCppuType( &xListener ), xListener );
+    maListeners.removeInterface( cppu::UnoType<decltype(xListener)>::get(), xListener );
 }
 
-void Window::fireMousePressedEvent( const ::com::sun::star::awt::MouseEvent& rEvt )
+void Window::fireMousePressedEvent( const css::awt::MouseEvent& rEvt )
 {
-    ::cppu::OInterfaceContainerHelper* pContainer = maListeners.getContainer( getCppuType( (uno::Reference< awt::XMouseListener >*) 0 ) );
+    ::cppu::OInterfaceContainerHelper* pContainer = maListeners.getContainer( cppu::UnoType<awt::XMouseListener>::get());
 
     if( pContainer )
     {
@@ -553,9 +543,9 @@ void Window::fireMousePressedEvent( const ::com::sun::star::awt::MouseEvent& rEv
     }
 }
 
-void Window::fireMouseReleasedEvent( const ::com::sun::star::awt::MouseEvent& rEvt )
+void Window::fireMouseReleasedEvent( const css::awt::MouseEvent& rEvt )
 {
-    ::cppu::OInterfaceContainerHelper* pContainer = maListeners.getContainer( getCppuType( (uno::Reference< awt::XMouseListener >*) 0 ) );
+    ::cppu::OInterfaceContainerHelper* pContainer = maListeners.getContainer( cppu::UnoType<awt::XMouseListener>::get());
 
     if( pContainer )
     {
@@ -566,9 +556,9 @@ void Window::fireMouseReleasedEvent( const ::com::sun::star::awt::MouseEvent& rE
     }
 }
 
-void Window::fireMouseMovedEvent( const ::com::sun::star::awt::MouseEvent& rEvt )
+void Window::fireMouseMovedEvent( const css::awt::MouseEvent& rEvt )
 {
-    ::cppu::OInterfaceContainerHelper* pContainer = maListeners.getContainer( getCppuType( (uno::Reference< awt::XMouseMotionListener >*) 0 ) );
+    ::cppu::OInterfaceContainerHelper* pContainer = maListeners.getContainer( cppu::UnoType<awt::XMouseMotionListener>::get());
 
     if( pContainer )
     {
@@ -579,9 +569,9 @@ void Window::fireMouseMovedEvent( const ::com::sun::star::awt::MouseEvent& rEvt
     }
 }
 
-void Window::fireSetFocusEvent( const ::com::sun::star::awt::FocusEvent& rEvt )
+void Window::fireSetFocusEvent( const css::awt::FocusEvent& rEvt )
 {
-    ::cppu::OInterfaceContainerHelper* pContainer = maListeners.getContainer( getCppuType( (uno::Reference< awt::XFocusListener >*) 0 ) );
+    ::cppu::OInterfaceContainerHelper* pContainer = maListeners.getContainer( cppu::UnoType<awt::XFocusListener>::get());
 
     if( pContainer )
     {
@@ -601,14 +591,13 @@ OUString SAL_CALL Window::getImplementationName(  )
 sal_Bool SAL_CALL Window::supportsService( const OUString& ServiceName )
     throw (uno::RuntimeException)
 {
-    return ServiceName == AVMEDIA_WIN_WINDOW_SERVICENAME;
+    return cppu::supportsService(this, ServiceName);
 }
 
 uno::Sequence< OUString > SAL_CALL Window::getSupportedServiceNames(  )
     throw (uno::RuntimeException)
 {
-    uno::Sequence< OUString > aRet(1);
-    aRet[0] = AVMEDIA_WIN_WINDOW_SERVICENAME ;
+    uno::Sequence<OUString> aRet { AVMEDIA_WIN_WINDOW_SERVICENAME };
 
     return aRet;
 }
