@@ -36,6 +36,7 @@
 #include <toolkit/helper/externallock.hxx>
 #include <toolkit/helper/convert.hxx>
 #include <vcl/svapp.hxx>
+#include <vcl/settings.hxx>
 
 namespace basctl
 {
@@ -46,26 +47,19 @@ using namespace ::com::sun::star::lang;
 using namespace ::com::sun::star::accessibility;
 using namespace ::comphelper;
 
-DBG_NAME( AccessibleDialogWindow )
-
-
-// -----------------------------------------------------------------------------
-// class ChildDescriptor
-// -----------------------------------------------------------------------------
-
 AccessibleDialogWindow::ChildDescriptor::ChildDescriptor( DlgEdObj* _pDlgEdObj )
     :pDlgEdObj( _pDlgEdObj )
-    ,rxAccessible( 0 )
+    ,rxAccessible( nullptr )
 {
 }
 
-// -----------------------------------------------------------------------------
+
 
 AccessibleDialogWindow::ChildDescriptor::~ChildDescriptor()
 {
 }
 
-// -----------------------------------------------------------------------------
+
 
 AccessibleDialogWindow::ChildDescriptor::ChildDescriptor( const ChildDescriptor& rDesc )
     :pDlgEdObj( rDesc.pDlgEdObj )
@@ -73,7 +67,7 @@ AccessibleDialogWindow::ChildDescriptor::ChildDescriptor( const ChildDescriptor&
 {
 }
 
-// -----------------------------------------------------------------------------
+
 
 AccessibleDialogWindow::ChildDescriptor& AccessibleDialogWindow::ChildDescriptor::operator=( const ChildDescriptor& rDesc )
 {
@@ -83,7 +77,7 @@ AccessibleDialogWindow::ChildDescriptor& AccessibleDialogWindow::ChildDescriptor
     return *this;
 }
 
-// -----------------------------------------------------------------------------
+
 
 bool AccessibleDialogWindow::ChildDescriptor::operator==( const ChildDescriptor& rDesc )
 {
@@ -94,7 +88,7 @@ bool AccessibleDialogWindow::ChildDescriptor::operator==( const ChildDescriptor&
     return bRet;
 }
 
-// -----------------------------------------------------------------------------
+
 
 bool AccessibleDialogWindow::ChildDescriptor::operator<( const ChildDescriptor& rDesc ) const
 {
@@ -105,25 +99,24 @@ bool AccessibleDialogWindow::ChildDescriptor::operator<( const ChildDescriptor&
     return bRet;
 }
 
-// -----------------------------------------------------------------------------
+
 // class AccessibleDialogWindow
-// -----------------------------------------------------------------------------
+
 
 AccessibleDialogWindow::AccessibleDialogWindow (basctl::DialogWindow* pDialogWindow)
     : AccessibleExtendedComponentHelper_BASE( new VCLExternalSolarLock() )
     , m_pDialogWindow(pDialogWindow)
-    , m_pDlgEditor(NULL)
-    , m_pDlgEdModel(NULL)
+    , m_pDlgEditor(nullptr)
+    , m_pDlgEdModel(nullptr)
 {
-    DBG_CTOR( AccessibleDialogWindow, NULL );
     m_pExternalLock = static_cast< VCLExternalSolarLock* >( getExternalLock() );
 
     if ( m_pDialogWindow )
     {
         SdrPage& rPage = m_pDialogWindow->GetPage();
-        sal_uLong nCount = rPage.GetObjCount();
+        const size_t nCount = rPage.GetObjCount();
 
-        for ( sal_uLong i = 0; i < nCount; ++i )
+        for ( size_t i = 0; i < nCount; ++i )
         {
             if (DlgEdObj* pDlgEdObj = dynamic_cast<DlgEdObj*>(rPage.GetObj(i)))
             {
@@ -142,11 +135,10 @@ AccessibleDialogWindow::AccessibleDialogWindow (basctl::DialogWindow* pDialogWin
     }
 }
 
-// -----------------------------------------------------------------------------
+
 
 AccessibleDialogWindow::~AccessibleDialogWindow()
 {
-    DBG_DTOR( AccessibleDialogWindow, NULL );
     if ( m_pDialogWindow )
         m_pDialogWindow->RemoveEventListener( LINK( this, AccessibleDialogWindow, WindowEventListener ) );
 
@@ -157,14 +149,14 @@ AccessibleDialogWindow::~AccessibleDialogWindow()
         EndListening( *m_pDlgEdModel );
 
     delete m_pExternalLock;
-    m_pExternalLock = NULL;
+    m_pExternalLock = nullptr;
 }
 
-// -----------------------------------------------------------------------------
+
 
 void AccessibleDialogWindow::UpdateFocused()
 {
-    for ( sal_uInt32 i = 0; i < m_aAccessibleChildren.size(); ++i )
+    for ( size_t i = 0; i < m_aAccessibleChildren.size(); ++i )
     {
         Reference< XAccessible > xChild( m_aAccessibleChildren[i].rxAccessible );
         if ( xChild.is() )
@@ -176,13 +168,13 @@ void AccessibleDialogWindow::UpdateFocused()
     }
 }
 
-// -----------------------------------------------------------------------------
+
 
 void AccessibleDialogWindow::UpdateSelected()
 {
     NotifyAccessibleEvent( AccessibleEventId::SELECTION_CHANGED, Any(), Any() );
 
-    for ( sal_uInt32 i = 0; i < m_aAccessibleChildren.size(); ++i )
+    for ( size_t i = 0; i < m_aAccessibleChildren.size(); ++i )
     {
         Reference< XAccessible > xChild( m_aAccessibleChildren[i].rxAccessible );
         if ( xChild.is() )
@@ -194,11 +186,11 @@ void AccessibleDialogWindow::UpdateSelected()
     }
 }
 
-// -----------------------------------------------------------------------------
+
 
 void AccessibleDialogWindow::UpdateBounds()
 {
-    for ( sal_uInt32 i = 0; i < m_aAccessibleChildren.size(); ++i )
+    for ( size_t i = 0; i < m_aAccessibleChildren.size(); ++i )
     {
         Reference< XAccessible > xChild( m_aAccessibleChildren[i].rxAccessible );
         if ( xChild.is() )
@@ -210,7 +202,7 @@ void AccessibleDialogWindow::UpdateBounds()
     }
 }
 
-// -----------------------------------------------------------------------------
+
 
 bool AccessibleDialogWindow::IsChildVisible( const ChildDescriptor& rDesc )
 {
@@ -254,7 +246,7 @@ bool AccessibleDialogWindow::IsChildVisible( const ChildDescriptor& rDesc )
     return bVisible;
 }
 
-// -----------------------------------------------------------------------------
+
 
 void AccessibleDialogWindow::InsertChild( const ChildDescriptor& rDesc )
 {
@@ -283,7 +275,7 @@ void AccessibleDialogWindow::InsertChild( const ChildDescriptor& rDesc )
     }
 }
 
-// -----------------------------------------------------------------------------
+
 
 void AccessibleDialogWindow::RemoveChild( const ChildDescriptor& rDesc )
 {
@@ -313,7 +305,7 @@ void AccessibleDialogWindow::RemoveChild( const ChildDescriptor& rDesc )
     }
 }
 
-// -----------------------------------------------------------------------------
+
 
 void AccessibleDialogWindow::UpdateChild( const ChildDescriptor& rDesc )
 {
@@ -329,20 +321,20 @@ void AccessibleDialogWindow::UpdateChild( const ChildDescriptor& rDesc )
     }
 }
 
-// -----------------------------------------------------------------------------
+
 
 void AccessibleDialogWindow::UpdateChildren()
 {
     if ( m_pDialogWindow )
     {
         SdrPage& rPage = m_pDialogWindow->GetPage();
-        for ( sal_uLong i = 0, nCount = rPage.GetObjCount(); i < nCount; ++i )
+        for ( size_t i = 0, nCount = rPage.GetObjCount(); i < nCount; ++i )
             if (DlgEdObj* pDlgEdObj = dynamic_cast<DlgEdObj*>(rPage.GetObj(i)))
                 UpdateChild( ChildDescriptor( pDlgEdObj ) );
     }
 }
 
-// -----------------------------------------------------------------------------
+
 
 void AccessibleDialogWindow::SortChildren()
 {
@@ -350,24 +342,16 @@ void AccessibleDialogWindow::SortChildren()
     ::std::sort( m_aAccessibleChildren.begin(), m_aAccessibleChildren.end() );
 }
 
-// -----------------------------------------------------------------------------
 
-IMPL_LINK( AccessibleDialogWindow, WindowEventListener, VclSimpleEvent*, pEvent )
+
+IMPL_LINK_TYPED( AccessibleDialogWindow, WindowEventListener, VclWindowEvent&, rEvent, void )
 {
-    DBG_CHKTHIS( AccessibleDialogWindow, 0 );
-
-    if (VclWindowEvent* pWinEvent = dynamic_cast<VclWindowEvent*>(pEvent))
-    {
-        DBG_ASSERT(pWinEvent->GetWindow(), "AccessibleDialogWindow::WindowEventListener: no window!");
-        if (!pWinEvent->GetWindow()->IsAccessibilityEventsSuppressed() || pEvent->GetId() == VCLEVENT_OBJECT_DYING)
-            ProcessWindowEvent(*pWinEvent);
-    }
-    else
-        DBG_ASSERT(false, "AccessibleDialogWindow::WindowEventListener: unknown window event!");
-    return 0;
+    DBG_ASSERT(rEvent.GetWindow(), "AccessibleDialogWindow::WindowEventListener: no window!");
+    if (!rEvent.GetWindow()->IsAccessibilityEventsSuppressed() || rEvent.GetId() == VCLEVENT_OBJECT_DYING)
+        ProcessWindowEvent(rEvent);
 }
 
-// -----------------------------------------------------------------------------
+
 
 void AccessibleDialogWindow::ProcessWindowEvent( const VclWindowEvent& rVclWindowEvent )
 {
@@ -435,18 +419,18 @@ void AccessibleDialogWindow::ProcessWindowEvent( const VclWindowEvent& rVclWindo
             if ( m_pDialogWindow )
             {
                 m_pDialogWindow->RemoveEventListener( LINK( this, AccessibleDialogWindow, WindowEventListener ) );
-                m_pDialogWindow = NULL;
+                m_pDialogWindow = nullptr;
 
                 if ( m_pDlgEditor )
                     EndListening( *m_pDlgEditor );
-                m_pDlgEditor = NULL;
+                m_pDlgEditor = nullptr;
 
                 if ( m_pDlgEdModel )
                     EndListening( *m_pDlgEdModel );
-                m_pDlgEdModel = NULL;
+                m_pDlgEdModel = nullptr;
 
                 // dispose all children
-                for ( sal_uInt32 i = 0; i < m_aAccessibleChildren.size(); ++i )
+                for ( size_t i = 0; i < m_aAccessibleChildren.size(); ++i )
                 {
                     Reference< XComponent > xComponent( m_aAccessibleChildren[i].rxAccessible, UNO_QUERY );
                     if ( xComponent.is() )
@@ -463,7 +447,7 @@ void AccessibleDialogWindow::ProcessWindowEvent( const VclWindowEvent& rVclWindo
     }
 }
 
-// -----------------------------------------------------------------------------
+
 
 void AccessibleDialogWindow::FillAccessibleStateSet( utl::AccessibleStateSetHelper& rStateSet )
 {
@@ -488,9 +472,9 @@ void AccessibleDialogWindow::FillAccessibleStateSet( utl::AccessibleStateSetHelp
     }
 }
 
-// -----------------------------------------------------------------------------
+
 // OCommonAccessibleComponent
-// -----------------------------------------------------------------------------
+
 
 awt::Rectangle AccessibleDialogWindow::implGetBounds() throw (RuntimeException)
 {
@@ -501,9 +485,9 @@ awt::Rectangle AccessibleDialogWindow::implGetBounds() throw (RuntimeException)
     return aBounds;
 }
 
-// -----------------------------------------------------------------------------
+
 // SfxListener
-// -----------------------------------------------------------------------------
+
 
 void AccessibleDialogWindow::Notify( SfxBroadcaster&, const SfxHint& rHint )
 {
@@ -562,21 +546,21 @@ void AccessibleDialogWindow::Notify( SfxBroadcaster&, const SfxHint& rHint )
     }
 }
 
-// -----------------------------------------------------------------------------
+
 // XInterface
-// -----------------------------------------------------------------------------
+
 
 IMPLEMENT_FORWARD_XINTERFACE2( AccessibleDialogWindow, AccessibleExtendedComponentHelper_BASE, AccessibleDialogWindow_BASE )
 
-// -----------------------------------------------------------------------------
+
 // XTypeProvider
-// -----------------------------------------------------------------------------
+
 
 IMPLEMENT_FORWARD_XTYPEPROVIDER2( AccessibleDialogWindow, AccessibleExtendedComponentHelper_BASE, AccessibleDialogWindow_BASE )
 
-// -----------------------------------------------------------------------------
+
 // XComponent
-// -----------------------------------------------------------------------------
+
 
 void AccessibleDialogWindow::disposing()
 {
@@ -585,18 +569,18 @@ void AccessibleDialogWindow::disposing()
     if ( m_pDialogWindow )
     {
         m_pDialogWindow->RemoveEventListener( LINK( this, AccessibleDialogWindow, WindowEventListener ) );
-        m_pDialogWindow = NULL;
+        m_pDialogWindow = nullptr;
 
         if ( m_pDlgEditor )
             EndListening( *m_pDlgEditor );
-        m_pDlgEditor = NULL;
+        m_pDlgEditor = nullptr;
 
         if ( m_pDlgEdModel )
             EndListening( *m_pDlgEdModel );
-        m_pDlgEdModel = NULL;
+        m_pDlgEdModel = nullptr;
 
         // dispose all children
-        for ( sal_uInt32 i = 0; i < m_aAccessibleChildren.size(); ++i )
+        for ( size_t i = 0; i < m_aAccessibleChildren.size(); ++i )
         {
             Reference< XComponent > xComponent( m_aAccessibleChildren[i].rxAccessible, UNO_QUERY );
             if ( xComponent.is() )
@@ -607,25 +591,24 @@ void AccessibleDialogWindow::disposing()
 }
 
 // XServiceInfo
-OUString AccessibleDialogWindow::getImplementationName() throw (RuntimeException)
+OUString AccessibleDialogWindow::getImplementationName() throw (RuntimeException, std::exception)
 {
     return OUString( "com.sun.star.comp.basctl.AccessibleWindow" );
 }
 
-sal_Bool AccessibleDialogWindow::supportsService( const OUString& rServiceName ) throw (RuntimeException)
+sal_Bool AccessibleDialogWindow::supportsService( const OUString& rServiceName ) throw (RuntimeException, std::exception)
 {
     return cppu::supportsService(this, rServiceName);
 }
 
-Sequence< OUString > AccessibleDialogWindow::getSupportedServiceNames() throw (RuntimeException)
+Sequence< OUString > AccessibleDialogWindow::getSupportedServiceNames() throw (RuntimeException, std::exception)
 {
-    Sequence< OUString > aNames(1);
-    aNames[0] = "com.sun.star.awt.AccessibleWindow" ;
+    Sequence<OUString> aNames { "com.sun.star.awt.AccessibleWindow" };
     return aNames;
 }
 
 // XAccessible
-Reference< XAccessibleContext > AccessibleDialogWindow::getAccessibleContext(  ) throw (RuntimeException)
+Reference< XAccessibleContext > AccessibleDialogWindow::getAccessibleContext(  ) throw (RuntimeException, std::exception)
 {
     OExternalLockGuard aGuard( this );
 
@@ -633,16 +616,16 @@ Reference< XAccessibleContext > AccessibleDialogWindow::getAccessibleContext(  )
 }
 
 // XAccessibleContext
-sal_Int32 AccessibleDialogWindow::getAccessibleChildCount() throw (RuntimeException)
+sal_Int32 AccessibleDialogWindow::getAccessibleChildCount() throw (RuntimeException, std::exception)
 {
     OExternalLockGuard aGuard( this );
 
     return m_aAccessibleChildren.size();
 }
 
-// -----------------------------------------------------------------------------
 
-Reference< XAccessible > AccessibleDialogWindow::getAccessibleChild( sal_Int32 i ) throw (IndexOutOfBoundsException, RuntimeException)
+
+Reference< XAccessible > AccessibleDialogWindow::getAccessibleChild( sal_Int32 i ) throw (IndexOutOfBoundsException, RuntimeException, std::exception)
 {
     OExternalLockGuard aGuard( this );
 
@@ -668,16 +651,16 @@ Reference< XAccessible > AccessibleDialogWindow::getAccessibleChild( sal_Int32 i
     return xChild;
 }
 
-// -----------------------------------------------------------------------------
 
-Reference< XAccessible > AccessibleDialogWindow::getAccessibleParent(  ) throw (RuntimeException)
+
+Reference< XAccessible > AccessibleDialogWindow::getAccessibleParent(  ) throw (RuntimeException, std::exception)
 {
     OExternalLockGuard aGuard( this );
 
     Reference< XAccessible > xParent;
     if ( m_pDialogWindow )
     {
-        Window* pParent = m_pDialogWindow->GetAccessibleParentWindow();
+        vcl::Window* pParent = m_pDialogWindow->GetAccessibleParentWindow();
         if ( pParent )
             xParent = pParent->GetAccessible();
     }
@@ -685,22 +668,22 @@ Reference< XAccessible > AccessibleDialogWindow::getAccessibleParent(  ) throw (
     return xParent;
 }
 
-// -----------------------------------------------------------------------------
 
-sal_Int32 AccessibleDialogWindow::getAccessibleIndexInParent(  ) throw (RuntimeException)
+
+sal_Int32 AccessibleDialogWindow::getAccessibleIndexInParent(  ) throw (RuntimeException, std::exception)
 {
     OExternalLockGuard aGuard( this );
 
     sal_Int32 nIndexInParent = -1;
     if ( m_pDialogWindow )
     {
-        Window* pParent = m_pDialogWindow->GetAccessibleParentWindow();
+        vcl::Window* pParent = m_pDialogWindow->GetAccessibleParentWindow();
         if ( pParent )
         {
             for ( sal_uInt16 i = 0, nCount = pParent->GetAccessibleChildWindowCount(); i < nCount; ++i )
             {
-                Window* pChild = pParent->GetAccessibleChildWindow( i );
-                if ( pChild == static_cast< Window* >( m_pDialogWindow ) )
+                vcl::Window* pChild = pParent->GetAccessibleChildWindow( i );
+                if ( pChild == static_cast< vcl::Window* >( m_pDialogWindow ) )
                 {
                     nIndexInParent = i;
                     break;
@@ -712,18 +695,18 @@ sal_Int32 AccessibleDialogWindow::getAccessibleIndexInParent(  ) throw (RuntimeE
     return nIndexInParent;
 }
 
-// -----------------------------------------------------------------------------
 
-sal_Int16 AccessibleDialogWindow::getAccessibleRole(  ) throw (RuntimeException)
+
+sal_Int16 AccessibleDialogWindow::getAccessibleRole(  ) throw (RuntimeException, std::exception)
 {
     OExternalLockGuard aGuard( this );
 
     return AccessibleRole::PANEL;
 }
 
-// -----------------------------------------------------------------------------
 
-OUString AccessibleDialogWindow::getAccessibleDescription(  ) throw (RuntimeException)
+
+OUString AccessibleDialogWindow::getAccessibleDescription(  ) throw (RuntimeException, std::exception)
 {
     OExternalLockGuard aGuard( this );
 
@@ -734,9 +717,9 @@ OUString AccessibleDialogWindow::getAccessibleDescription(  ) throw (RuntimeExce
     return sDescription;
 }
 
-// -----------------------------------------------------------------------------
 
-OUString AccessibleDialogWindow::getAccessibleName(  ) throw (RuntimeException)
+
+OUString AccessibleDialogWindow::getAccessibleName(  ) throw (RuntimeException, std::exception)
 {
     OExternalLockGuard aGuard( this );
 
@@ -747,9 +730,9 @@ OUString AccessibleDialogWindow::getAccessibleName(  ) throw (RuntimeException)
     return sName;
 }
 
-// -----------------------------------------------------------------------------
 
-Reference< XAccessibleRelationSet > AccessibleDialogWindow::getAccessibleRelationSet(  ) throw (RuntimeException)
+
+Reference< XAccessibleRelationSet > AccessibleDialogWindow::getAccessibleRelationSet(  ) throw (RuntimeException, std::exception)
 {
     OExternalLockGuard aGuard( this );
 
@@ -758,9 +741,9 @@ Reference< XAccessibleRelationSet > AccessibleDialogWindow::getAccessibleRelatio
     return xSet;
 }
 
-// -----------------------------------------------------------------------------
 
-Reference< XAccessibleStateSet > AccessibleDialogWindow::getAccessibleStateSet(  ) throw (RuntimeException)
+
+Reference< XAccessibleStateSet > AccessibleDialogWindow::getAccessibleStateSet(  ) throw (RuntimeException, std::exception)
 {
     OExternalLockGuard aGuard( this );
 
@@ -779,25 +762,25 @@ Reference< XAccessibleStateSet > AccessibleDialogWindow::getAccessibleStateSet(
     return xSet;
 }
 
-// -----------------------------------------------------------------------------
 
-Locale AccessibleDialogWindow::getLocale(  ) throw (IllegalAccessibleComponentStateException, RuntimeException)
+
+Locale AccessibleDialogWindow::getLocale(  ) throw (IllegalAccessibleComponentStateException, RuntimeException, std::exception)
 {
     OExternalLockGuard aGuard( this );
 
     return Application::GetSettings().GetLanguageTag().getLocale();
 }
 
-// -----------------------------------------------------------------------------
-// XAccessibleComponent
-// -----------------------------------------------------------------------------
 
-Reference< XAccessible > AccessibleDialogWindow::getAccessibleAtPoint( const awt::Point& rPoint ) throw (RuntimeException)
+// XAccessibleComponent
+
+
+Reference< XAccessible > AccessibleDialogWindow::getAccessibleAtPoint( const awt::Point& rPoint ) throw (RuntimeException, std::exception)
 {
     OExternalLockGuard aGuard( this );
 
     Reference< XAccessible > xChild;
-    for ( sal_uInt32 i = 0; i < m_aAccessibleChildren.size(); ++i )
+    for ( size_t i = 0; i < m_aAccessibleChildren.size(); ++i )
     {
         Reference< XAccessible > xAcc = getAccessibleChild( i );
         if ( xAcc.is() )
@@ -819,9 +802,9 @@ Reference< XAccessible > AccessibleDialogWindow::getAccessibleAtPoint( const awt
     return xChild;
 }
 
-// -----------------------------------------------------------------------------
 
-void AccessibleDialogWindow::grabFocus(  ) throw (RuntimeException)
+
+void AccessibleDialogWindow::grabFocus(  ) throw (RuntimeException, std::exception)
 {
     OExternalLockGuard aGuard( this );
 
@@ -829,9 +812,9 @@ void AccessibleDialogWindow::grabFocus(  ) throw (RuntimeException)
         m_pDialogWindow->GrabFocus();
 }
 
-// -----------------------------------------------------------------------------
 
-sal_Int32 AccessibleDialogWindow::getForeground(  ) throw (RuntimeException)
+
+sal_Int32 AccessibleDialogWindow::getForeground(  ) throw (RuntimeException, std::exception)
 {
     OExternalLockGuard aGuard( this );
 
@@ -842,7 +825,7 @@ sal_Int32 AccessibleDialogWindow::getForeground(  ) throw (RuntimeException)
             nColor = m_pDialogWindow->GetControlForeground().GetColor();
         else
         {
-            Font aFont;
+            vcl::Font aFont;
             if ( m_pDialogWindow->IsControlFont() )
                 aFont = m_pDialogWindow->GetControlFont();
             else
@@ -854,9 +837,9 @@ sal_Int32 AccessibleDialogWindow::getForeground(  ) throw (RuntimeException)
     return nColor;
 }
 
-// -----------------------------------------------------------------------------
 
-sal_Int32 AccessibleDialogWindow::getBackground(  ) throw (RuntimeException)
+
+sal_Int32 AccessibleDialogWindow::getBackground(  ) throw (RuntimeException, std::exception)
 {
     OExternalLockGuard aGuard( this );
 
@@ -872,11 +855,11 @@ sal_Int32 AccessibleDialogWindow::getBackground(  ) throw (RuntimeException)
     return nColor;
 }
 
-// -----------------------------------------------------------------------------
-// XAccessibleExtendedComponent
-// -----------------------------------------------------------------------------
 
-Reference< awt::XFont > AccessibleDialogWindow::getFont(  ) throw (RuntimeException)
+// XAccessibleExtendedComponent
+
+
+Reference< awt::XFont > AccessibleDialogWindow::getFont(  ) throw (RuntimeException, std::exception)
 {
     OExternalLockGuard aGuard( this );
 
@@ -886,7 +869,7 @@ Reference< awt::XFont > AccessibleDialogWindow::getFont(  ) throw (RuntimeExcept
         Reference< awt::XDevice > xDev( m_pDialogWindow->GetComponentInterface(), UNO_QUERY );
         if ( xDev.is() )
         {
-            Font aFont;
+            vcl::Font aFont;
             if ( m_pDialogWindow->IsControlFont() )
                 aFont = m_pDialogWindow->GetControlFont();
             else
@@ -900,18 +883,18 @@ Reference< awt::XFont > AccessibleDialogWindow::getFont(  ) throw (RuntimeExcept
     return xFont;
 }
 
-// -----------------------------------------------------------------------------
 
-OUString AccessibleDialogWindow::getTitledBorderText(  ) throw (RuntimeException)
+
+OUString AccessibleDialogWindow::getTitledBorderText(  ) throw (RuntimeException, std::exception)
 {
     OExternalLockGuard aGuard( this );
 
     return OUString();
 }
 
-// -----------------------------------------------------------------------------
 
-OUString AccessibleDialogWindow::getToolTipText(  ) throw (RuntimeException)
+
+OUString AccessibleDialogWindow::getToolTipText(  ) throw (RuntimeException, std::exception)
 {
     OExternalLockGuard aGuard( this );
 
@@ -922,11 +905,11 @@ OUString AccessibleDialogWindow::getToolTipText(  ) throw (RuntimeException)
     return sText;
 }
 
-// -----------------------------------------------------------------------------
-// XAccessibleSelection
-// -----------------------------------------------------------------------------
 
-void AccessibleDialogWindow::selectAccessibleChild( sal_Int32 nChildIndex ) throw (IndexOutOfBoundsException, RuntimeException)
+// XAccessibleSelection
+
+
+void AccessibleDialogWindow::selectAccessibleChild( sal_Int32 nChildIndex ) throw (IndexOutOfBoundsException, RuntimeException, std::exception)
 {
     OExternalLockGuard aGuard( this );
 
@@ -944,9 +927,9 @@ void AccessibleDialogWindow::selectAccessibleChild( sal_Int32 nChildIndex ) thro
     }
 }
 
-// -----------------------------------------------------------------------------
 
-sal_Bool AccessibleDialogWindow::isAccessibleChildSelected( sal_Int32 nChildIndex ) throw (IndexOutOfBoundsException, RuntimeException)
+
+sal_Bool AccessibleDialogWindow::isAccessibleChildSelected( sal_Int32 nChildIndex ) throw (IndexOutOfBoundsException, RuntimeException, std::exception)
 {
     OExternalLockGuard aGuard( this );
 
@@ -959,9 +942,10 @@ sal_Bool AccessibleDialogWindow::isAccessibleChildSelected( sal_Int32 nChildInde
     return false;
 }
 
-// -----------------------------------------------------------------------------
 
-void AccessibleDialogWindow::clearAccessibleSelection(  ) throw (RuntimeException)
+
+void AccessibleDialogWindow::clearAccessibleSelection()
+    throw (RuntimeException, std::exception)
 {
     OExternalLockGuard aGuard( this );
 
@@ -969,9 +953,9 @@ void AccessibleDialogWindow::clearAccessibleSelection(  ) throw (RuntimeExceptio
         m_pDialogWindow->GetView().UnmarkAll();
 }
 
-// -----------------------------------------------------------------------------
 
-void AccessibleDialogWindow::selectAllAccessibleChildren(  ) throw (RuntimeException)
+
+void AccessibleDialogWindow::selectAllAccessibleChildren(  ) throw (RuntimeException, std::exception)
 {
     OExternalLockGuard aGuard( this );
 
@@ -979,9 +963,9 @@ void AccessibleDialogWindow::selectAllAccessibleChildren(  ) throw (RuntimeExcep
         m_pDialogWindow->GetView().MarkAll();
 }
 
-// -----------------------------------------------------------------------------
 
-sal_Int32 AccessibleDialogWindow::getSelectedAccessibleChildCount(  ) throw (RuntimeException)
+
+sal_Int32 AccessibleDialogWindow::getSelectedAccessibleChildCount(  ) throw (RuntimeException, std::exception)
 {
     OExternalLockGuard aGuard( this );
 
@@ -996,9 +980,9 @@ sal_Int32 AccessibleDialogWindow::getSelectedAccessibleChildCount(  ) throw (Run
     return nRet;
 }
 
-// -----------------------------------------------------------------------------
 
-Reference< XAccessible > AccessibleDialogWindow::getSelectedAccessibleChild( sal_Int32 nSelectedChildIndex ) throw (IndexOutOfBoundsException, RuntimeException)
+
+Reference< XAccessible > AccessibleDialogWindow::getSelectedAccessibleChild( sal_Int32 nSelectedChildIndex ) throw (IndexOutOfBoundsException, RuntimeException, std::exception)
 {
     OExternalLockGuard aGuard( this );
 
@@ -1019,9 +1003,9 @@ Reference< XAccessible > AccessibleDialogWindow::getSelectedAccessibleChild( sal
     return xChild;
 }
 
-// -----------------------------------------------------------------------------
 
-void AccessibleDialogWindow::deselectAccessibleChild( sal_Int32 nChildIndex ) throw (IndexOutOfBoundsException, RuntimeException)
+
+void AccessibleDialogWindow::deselectAccessibleChild( sal_Int32 nChildIndex ) throw (IndexOutOfBoundsException, RuntimeException, std::exception)
 {
     OExternalLockGuard aGuard( this );
 
@@ -1040,7 +1024,7 @@ void AccessibleDialogWindow::deselectAccessibleChild( sal_Int32 nChildIndex ) th
     }
 }
 
-// -----------------------------------------------------------------------------
+
 
 } // namespace basctl
 
