@@ -75,7 +75,7 @@ void LocalizationMgr::handleTranslationbar ()
         ( m_pShell->GetViewFrame()->GetFrame().GetFrameInterface(), uno::UNO_QUERY );
     if ( xFrameProps.is() )
     {
-        Reference< ::com::sun::star::frame::XLayoutManager > xLayoutManager;
+        Reference< css::frame::XLayoutManager > xLayoutManager;
         uno::Any a = xFrameProps->getPropertyValue( aLayoutManagerName );
         a >>= xLayoutManager;
         if ( xLayoutManager.is() )
@@ -117,7 +117,7 @@ bool isLanguageDependentProperty( const OUString& aName )
         { "HelpText",        8 },
         { "CurrencySymbol", 14 },
         { "StringItemList", 14 },
-        { 0, 0                 }
+        { nullptr, 0                 }
     };
 
     for (Prop const* pProp = vProp; pProp->sName; ++pProp)
@@ -810,7 +810,7 @@ DialogWindow* FindDialogWindowForEditor( DlgEditor* pEditor )
                     return pDlgWin;
             }
     }
-    return 0;
+    return nullptr;
 }
 
 
