@@ -27,26 +27,20 @@
 namespace basctl
 {
 
-//----------------------------------------------------------------------------
-
-IMPL_LINK_INLINE_START( DlgEdFunc, ScrollTimeout, Timer *, pTimer )
+IMPL_LINK_TYPED( DlgEdFunc, ScrollTimeout, Timer *, pTimer, void )
 {
     (void)pTimer;
-    Window& rWindow = rParent.GetWindow();
+    vcl::Window& rWindow = rParent.GetWindow();
     Point aPos = rWindow.ScreenToOutputPixel( rWindow.GetPointerPosPixel() );
     aPos = rWindow.PixelToLogic( aPos );
     ForceScroll( aPos );
-    return 0;
 }
-IMPL_LINK_INLINE_END( DlgEdFunc, ScrollTimeout, Timer *, pTimer )
-
-//----------------------------------------------------------------------------
 
 void DlgEdFunc::ForceScroll( const Point& rPos )
 {
     aScrollTimer.Stop();
 
-    Window& rWindow  = rParent.GetWindow();
+    vcl::Window& rWindow  = rParent.GetWindow();
 
     static Point aDefPoint;
     Rectangle aOutRect( aDefPoint, rWindow.GetOutputSizePixel() );
@@ -83,8 +77,6 @@ void DlgEdFunc::ForceScroll( const Point& rPos )
     aScrollTimer.Start();
 }
 
-//----------------------------------------------------------------------------
-
 DlgEdFunc::DlgEdFunc (DlgEditor& rParent_) :
     rParent(rParent_)
 {
@@ -92,44 +84,34 @@ DlgEdFunc::DlgEdFunc (DlgEditor& rParent_) :
     aScrollTimer.SetTimeout( SELENG_AUTOREPEAT_INTERVAL );
 }
 
-//----------------------------------------------------------------------------
-
 DlgEdFunc::~DlgEdFunc()
 {
 }
 
-//----------------------------------------------------------------------------
-
 bool DlgEdFunc::MouseButtonDown( const MouseEvent& )
 {
     return true;
 }
 
-//----------------------------------------------------------------------------
-
 bool DlgEdFunc::MouseButtonUp( const MouseEvent& )
 {
     aScrollTimer.Stop();
     return true;
 }
 
-//----------------------------------------------------------------------------
-
 bool DlgEdFunc::MouseMove( const MouseEvent& )
 {
     return true;
 }
 
-//----------------------------------------------------------------------------
-
 bool DlgEdFunc::KeyInput( const KeyEvent& rKEvt )
 {
     bool bReturn = false;
 
     SdrView& rView = rParent.GetView();
-    Window& rWindow = rParent.GetWindow();
+    vcl::Window& rWindow = rParent.GetWindow();
 
-    KeyCode aCode = rKEvt.GetKeyCode();
+    vcl::KeyCode aCode = rKEvt.GetKeyCode();
     sal_uInt16 nCode = aCode.GetCode();
 
     switch ( nCode )
@@ -241,7 +223,7 @@ bool DlgEdFunc::KeyInput( const KeyEvent& rKEvt )
                 const SdrHdlList& rHdlList = rView.GetHdlList();
                 SdrHdl* pHdl = rHdlList.GetFocusHdl();
 
-                if ( pHdl == 0 )
+                if ( pHdl == nullptr )
                 {
                     // no handle selected
                     if ( rView.IsMoveAllowed() )
@@ -287,7 +269,7 @@ bool DlgEdFunc::KeyInput( const KeyEvent& rKEvt )
                         const SdrDragStat& rDragStat = rView.GetDragStat();
 
                         // start dragging
-                        rView.BegDragObj( aStartPoint, 0, pHdl, 0 );
+                        rView.BegDragObj( aStartPoint, nullptr, pHdl, 0 );
 
                         if ( rView.IsDragObj() )
                         {
@@ -296,7 +278,7 @@ bool DlgEdFunc::KeyInput( const KeyEvent& rKEvt )
 
                             // switch snapping off
                             if ( !bWasNoSnap )
-                                const_cast<SdrDragStat&>(rDragStat).SetNoSnap(true);
+                                const_cast<SdrDragStat&>(rDragStat).SetNoSnap();
                             if ( bWasSnapEnabled )
                                 rView.SetSnapEnabled(false);
 
@@ -349,30 +331,24 @@ bool DlgEdFunc::KeyInput( const KeyEvent& rKEvt )
     return bReturn;
 }
 
-//----------------------------------------------------------------------------
-
 DlgEdFuncInsert::DlgEdFuncInsert (DlgEditor& rParent_) :
     DlgEdFunc(rParent_)
 {
-    rParent.GetView().SetCreateMode(true);
+    rParent.GetView().SetCreateMode();
 }
 
-//----------------------------------------------------------------------------
-
 DlgEdFuncInsert::~DlgEdFuncInsert()
 {
-    rParent.GetView().SetEditMode( true );
+    rParent.GetView().SetEditMode();
 }
 
-//----------------------------------------------------------------------------
-
 bool DlgEdFuncInsert::MouseButtonDown( const MouseEvent& rMEvt )
 {
     if( !rMEvt.IsLeft() )
         return true;
 
     SdrView& rView  = rParent.GetView();
-    Window& rWindow = rParent.GetWindow();
+    vcl::Window& rWindow = rParent.GetWindow();
     rView.SetActualWin(&rWindow);
 
     Point aPos = rWindow.PixelToLogic( rMEvt.GetPosPixel() );
@@ -386,8 +362,8 @@ bool DlgEdFuncInsert::MouseButtonDown( const MouseEvent& rMEvt )
         SdrHdl* pHdl = rView.PickHandle(aPos);
 
         // if selected object was hit, drag object
-        if ( pHdl!=NULL || rView.IsMarkedHit(aPos, nHitLog) )
-            rView.BegDragObj(aPos, (OutputDevice*) NULL, pHdl, nDrgLog);
+        if ( pHdl!=nullptr || rView.IsMarkedHit(aPos, nHitLog) )
+            rView.BegDragObj(aPos, nullptr, pHdl, nDrgLog);
         else if ( rView.AreObjectsMarked() )
             rView.UnmarkAll();
 
@@ -405,14 +381,12 @@ bool DlgEdFuncInsert::MouseButtonDown( const MouseEvent& rMEvt )
     return true;
 }
 
-//----------------------------------------------------------------------------
-
 bool DlgEdFuncInsert::MouseButtonUp( const MouseEvent& rMEvt )
 {
     DlgEdFunc::MouseButtonUp( rMEvt );
 
     SdrView& rView  = rParent.GetView();
-    Window& rWindow = rParent.GetWindow();
+    vcl::Window& rWindow = rParent.GetWindow();
     rView.SetActualWin(&rWindow);
 
     rWindow.ReleaseMouse();
@@ -439,12 +413,10 @@ bool DlgEdFuncInsert::MouseButtonUp( const MouseEvent& rMEvt )
     }
 }
 
-//----------------------------------------------------------------------------
-
 bool DlgEdFuncInsert::MouseMove( const MouseEvent& rMEvt )
 {
     SdrView& rView  = rParent.GetView();
-    Window& rWindow = rParent.GetWindow();
+    vcl::Window& rWindow = rParent.GetWindow();
     rView.SetActualWin(&rWindow);
 
     Point aPos = rWindow.PixelToLogic(rMEvt.GetPosPixel());
@@ -456,32 +428,26 @@ bool DlgEdFuncInsert::MouseMove( const MouseEvent& rMEvt )
         rView.MovAction(aPos);
     }
 
-    rWindow.SetPointer( rView.GetPreferedPointer( aPos, &rWindow, nHitLog ) );
+    rWindow.SetPointer( rView.GetPreferredPointer( aPos, &rWindow, nHitLog ) );
 
     return true;
 }
 
-//----------------------------------------------------------------------------
-
 DlgEdFuncSelect::DlgEdFuncSelect (DlgEditor& rParent_) :
     DlgEdFunc(rParent_),
     bMarkAction(false)
 {
 }
 
-//----------------------------------------------------------------------------
-
 DlgEdFuncSelect::~DlgEdFuncSelect()
 {
 }
 
-//----------------------------------------------------------------------------
-
 bool DlgEdFuncSelect::MouseButtonDown( const MouseEvent& rMEvt )
 {
     // get view from parent
     SdrView& rView  = rParent.GetView();
-    Window& rWindow = rParent.GetWindow();
+    vcl::Window& rWindow = rParent.GetWindow();
     rView.SetActualWin(&rWindow);
 
     sal_uInt16 nDrgLog = static_cast<sal_uInt16>(rWindow.PixelToLogic(Size(3, 0)).Width());
@@ -491,13 +457,11 @@ bool DlgEdFuncSelect::MouseButtonDown( const MouseEvent& rMEvt )
     if ( rMEvt.IsLeft() && rMEvt.GetClicks() == 1 )
     {
         SdrHdl* pHdl = rView.PickHandle(aMDPos);
-        SdrObject* pObj;
-        SdrPageView* pPV;
 
         // hit selected object?
-        if ( pHdl!=NULL || rView.IsMarkedHit(aMDPos, nHitLog) )
+        if ( pHdl!=nullptr || rView.IsMarkedHit(aMDPos, nHitLog) )
         {
-            rView.BegDragObj(aMDPos, (OutputDevice*) NULL, pHdl, nDrgLog);
+            rView.BegDragObj(aMDPos, nullptr, pHdl, nDrgLog);
         }
         else
         {
@@ -506,6 +470,8 @@ bool DlgEdFuncSelect::MouseButtonDown( const MouseEvent& rMEvt )
                 rView.UnmarkAll();
             else
             {
+                SdrObject* pObj;
+                SdrPageView* pPV;
                 if( rView.PickObj( aMDPos, nHitLog, pObj, pPV ) )
                 {
                     //if (dynamic_cast<DlgEdForm*>(pObj))
@@ -519,7 +485,7 @@ bool DlgEdFuncSelect::MouseButtonDown( const MouseEvent& rMEvt )
             {
                 // drag object
                 pHdl = rView.PickHandle(aMDPos);
-                rView.BegDragObj(aMDPos, (OutputDevice*) NULL, pHdl, nDrgLog);
+                rView.BegDragObj(aMDPos, nullptr, pHdl, nDrgLog);
             }
             else
             {
@@ -539,15 +505,13 @@ bool DlgEdFuncSelect::MouseButtonDown( const MouseEvent& rMEvt )
     return true;
 }
 
-//----------------------------------------------------------------------------
-
 bool DlgEdFuncSelect::MouseButtonUp( const MouseEvent& rMEvt )
 {
     DlgEdFunc::MouseButtonUp( rMEvt );
 
     // get view from parent
     SdrView& rView  = rParent.GetView();
-    Window& rWindow = rParent.GetWindow();
+    vcl::Window& rWindow = rParent.GetWindow();
     rView.SetActualWin(&rWindow);
 
     Point aPnt = rWindow.PixelToLogic(rMEvt.GetPosPixel());
@@ -569,18 +533,16 @@ bool DlgEdFuncSelect::MouseButtonUp( const MouseEvent& rMEvt )
 
     bMarkAction = false;
 
-    rWindow.SetPointer( rView.GetPreferedPointer( aPnt, &rWindow, nHitLog ) );
+    rWindow.SetPointer( rView.GetPreferredPointer( aPnt, &rWindow, nHitLog ) );
     rWindow.ReleaseMouse();
 
     return true;
 }
 
-//----------------------------------------------------------------------------
-
 bool DlgEdFuncSelect::MouseMove( const MouseEvent& rMEvt )
 {
     SdrView& rView  = rParent.GetView();
-    Window& rWindow = rParent.GetWindow();
+    vcl::Window& rWindow = rParent.GetWindow();
     rView.SetActualWin(&rWindow);
 
     Point aPnt = rWindow.PixelToLogic(rMEvt.GetPosPixel());
@@ -595,13 +557,11 @@ bool DlgEdFuncSelect::MouseMove( const MouseEvent& rMEvt )
         rView.MovAction(aPnt_);
     }
 
-    rWindow.SetPointer( rView.GetPreferedPointer( aPnt, &rWindow, nHitLog ) );
+    rWindow.SetPointer( rView.GetPreferredPointer( aPnt, &rWindow, nHitLog ) );
 
     return true;
 }
 
-//----------------------------------------------------------------------------
-
 } // namespace basctl
 
 /* vim:set shiftwidth=4 softtabstop=4 expandtab: */
