@@ -24,36 +24,37 @@
 
 #include <basebmp/bitmapdevice.hxx>
 
-#include <basebmp/compositeiterator.hxx>
-#include <basebmp/iteratortraits.hxx>
+#include <compositeiterator.hxx>
+#include <iteratortraits.hxx>
 
-#include <basebmp/accessor.hxx>
-#include <basebmp/accessortraits.hxx>
-#include <basebmp/accessoradapters.hxx>
-#include <basebmp/colorblendaccessoradapter.hxx>
+#include <accessor.hxx>
+#include <accessortraits.hxx>
+#include <accessoradapters.hxx>
+#include <colorblendaccessoradapter.hxx>
 
 #include <basebmp/color.hxx>
-#include <basebmp/colormisc.hxx>
-#include <basebmp/colortraits.hxx>
+#include <colormisc.hxx>
+#include <colortraits.hxx>
 
-#include <basebmp/greylevelformats.hxx>
-#include <basebmp/paletteformats.hxx>
-#include <basebmp/rgbmaskpixelformats.hxx>
-#include <basebmp/rgb24pixelformats.hxx>
+#include <greylevelformats.hxx>
+#include <paletteformats.hxx>
+#include <rgbmaskpixelformats.hxx>
+#include <rgb24pixelformats.hxx>
 
 #include <basebmp/scanlineformats.hxx>
-#include <basebmp/fillimage.hxx>
-#include <basebmp/scaleimage.hxx>
-#include <basebmp/clippedlinerenderer.hxx>
-#include <basebmp/polypolygonrenderer.hxx>
-#include <basebmp/genericcolorimageaccessor.hxx>
+#include <fillimage.hxx>
+#include <scaleimage.hxx>
+#include <clippedlinerenderer.hxx>
+#include <polypolygonrenderer.hxx>
+#include <genericcolorimageaccessor.hxx>
 
-#include <basebmp/tools.hxx>
+#include <tools.hxx>
 #include "intconversion.hxx"
 
 #include <rtl/alloc.h>
 #include <sal/log.hxx>
 #include <osl/diagnose.h>
+#include <o3tl/enumarray.hxx>
 
 #include <basegfx/tools/tools.hxx>
 #include <basegfx/tools/canvastools.hxx>
@@ -92,7 +93,7 @@ operator^( RGBValue<Value, RedIndex, GreenIndex, BlueIndex> const& lhs,
 namespace basebmp
 {
 
-static const sal_uInt8 bitsPerPixel[] =
+static const o3tl::enumarray<Format,sal_uInt8> bitsPerPixel =
 {
     0,  // NONE
     1,  // ONE_BIT_MSB_GREY
@@ -108,7 +109,6 @@ static const sal_uInt8 bitsPerPixel[] =
     16, // SIXTEEN_BIT_LSB_TC_MASK
     16, // SIXTEEN_BIT_MSB_TC_MASK
     24, // TWENTYFOUR_BIT_TC_MASK
-    32, // TWENTYFOUR_BIT_TC_MASK_BGRX
     32, // THIRTYTWO_BIT_TC_MASK_BGRA
     32, // THIRTYTWO_BIT_TC_MASK_ARGB
     32, // THIRTYTWO_BIT_TC_MASK_ABGR
@@ -374,21 +374,21 @@ namespace
             damaged( basegfx::B2IBox( rDamagePoint, aEnd ) );
         }
 
-        static boost::shared_ptr<BitmapRenderer> getCompatibleBitmap( const BitmapDeviceSharedPtr& bmp )
+        static std::shared_ptr<BitmapRenderer> getCompatibleBitmap( const BitmapDeviceSharedPtr& bmp )
         {
-            return boost::dynamic_pointer_cast< BitmapRenderer >( bmp );
+            return std::dynamic_pointer_cast< BitmapRenderer >( bmp );
         }
 
-        virtual bool isCompatibleBitmap( const BitmapDeviceSharedPtr& bmp ) const SAL_OVERRIDE
+        virtual bool isCompatibleBitmap( const BitmapDeviceSharedPtr& bmp ) const override
         {
             // TODO(P1): dynamic_cast usually called twice for
             // compatible formats
             return getCompatibleBitmap(bmp).get() != NULL;
         }
 
-        boost::shared_ptr<mask_bitmap_type> getCompatibleClipMask( const BitmapDeviceSharedPtr& bmp ) const
+        std::shared_ptr<mask_bitmap_type> getCompatibleClipMask( const BitmapDeviceSharedPtr& bmp ) const
         {
-            boost::shared_ptr<mask_bitmap_type> pMask( boost::dynamic_pointer_cast<mask_bitmap_type>( bmp ));
+            std::shared_ptr<mask_bitmap_type> pMask( std::dynamic_pointer_cast<mask_bitmap_type>( bmp ));
 
             if( !pMask )
                 return pMask;
@@ -399,27 +399,20 @@ namespace
             return pMask;
         }
 
-        virtual bool isCompatibleClipMask( const BitmapDeviceSharedPtr& bmp ) const SAL_OVERRIDE
+        virtual bool isCompatibleClipMask( const BitmapDeviceSharedPtr& bmp ) const override
         {
             // TODO(P1): dynamic_cast usually called twice for
             // compatible formats
-            return boost::dynamic_pointer_cast<mask_bitmap_type>( bmp ).get() != NULL;
+            return std::dynamic_pointer_cast<mask_bitmap_type>( bmp ).get() != NULL;
         }
 
-        static boost::shared_ptr<alphamask_bitmap_type> getCompatibleAlphaMask( const BitmapDeviceSharedPtr& bmp )
+        static std::shared_ptr<alphamask_bitmap_type> getCompatibleAlphaMask( const BitmapDeviceSharedPtr& bmp )
         {
-            return boost::dynamic_pointer_cast<alphamask_bitmap_type>( bmp );
-        }
-
-        virtual bool isCompatibleAlphaMask( const BitmapDeviceSharedPtr& bmp ) const SAL_OVERRIDE
-        {
-            // TODO(P1): dynamic_cast usually called twice for
-            // compatible formats
-            return getCompatibleAlphaMask( bmp ).get() != NULL;
+            return std::dynamic_pointer_cast<alphamask_bitmap_type>( bmp );
         }
 
         virtual void clear_i( Color                   fillColor,
-                              const basegfx::B2IBox&  rBounds ) SAL_OVERRIDE
+                              const basegfx::B2IBox&  rBounds ) override
         {
             fillImage(destIterRange(maBegin,
                                     maRawAccessor,
@@ -432,12 +425,12 @@ namespace
 
         virtual void setPixel_i( const basegfx::B2IPoint& rPt,
                                  Color                    pixelColor,
-                                 DrawMode                 drawMode ) SAL_OVERRIDE
+                                 DrawMode                 drawMode ) override
         {
             const DestIterator pixel( maBegin +
                                       vigra::Diff2D(rPt.getX(),
                                                     rPt.getY()) );
-            if( drawMode == DrawMode_XOR )
+            if( drawMode == DrawMode::XOR )
                 maXorAccessor.set( pixelColor,
                                    pixel );
             else
@@ -449,9 +442,9 @@ namespace
         virtual void setPixel_i( const basegfx::B2IPoint&     rPt,
                                  Color                        pixelColor,
                                  DrawMode                     drawMode,
-                                 const BitmapDeviceSharedPtr& rClip ) SAL_OVERRIDE
+                                 const BitmapDeviceSharedPtr& rClip ) override
         {
-            boost::shared_ptr<mask_bitmap_type> pMask( getCompatibleClipMask(rClip) );
+            std::shared_ptr<mask_bitmap_type> pMask( getCompatibleClipMask(rClip) );
             OSL_ASSERT( pMask );
 
             const vigra::Diff2D offset(rPt.getX(),
@@ -461,7 +454,7 @@ namespace
                 maBegin + offset,
                 pMask->maBegin + offset );
 
-            if( drawMode == DrawMode_XOR )
+            if( drawMode == DrawMode::XOR )
                 maMaskedXorAccessor.set( pixelColor,
                                          aIter );
             else
@@ -470,7 +463,7 @@ namespace
             damagedPixel(rPt);
         }
 
-        virtual Color getPixel_i(const basegfx::B2IPoint& rPt ) SAL_OVERRIDE
+        virtual Color getPixel_i(const basegfx::B2IPoint& rPt ) override
         {
             const DestIterator pixel( maBegin +
                                       vigra::Diff2D(rPt.getX(),
@@ -478,7 +471,7 @@ namespace
             return maAccessor(pixel);
         }
 
-        virtual sal_uInt32 getPixelData_i( const basegfx::B2IPoint& rPt ) SAL_OVERRIDE
+        virtual sal_uInt32 getPixelData_i( const basegfx::B2IPoint& rPt ) override
         {
             const DestIterator pixel( maBegin +
                                       vigra::Diff2D(rPt.getX(),
@@ -547,7 +540,7 @@ namespace
                            const XorAcc&            xorAcc,
                            DrawMode                 drawMode )
         {
-            if( drawMode == DrawMode_XOR )
+            if( drawMode == DrawMode::XOR )
                 implRenderLine( rPt1, rPt2, rBounds, col,
                                 begin, maAccessor, xorAcc );
             else
@@ -559,7 +552,7 @@ namespace
                                 const basegfx::B2IPoint& rPt2,
                                 const basegfx::B2IBox&   rBounds,
                                 Color                    lineColor,
-                                DrawMode                 drawMode ) SAL_OVERRIDE
+                                DrawMode                 drawMode ) override
         {
             implDrawLine(rPt1,rPt2,rBounds,lineColor,
                          maBegin,
@@ -568,7 +561,7 @@ namespace
 
         composite_iterator_type getMaskedIter( const BitmapDeviceSharedPtr& rClip ) const
         {
-            boost::shared_ptr<mask_bitmap_type> pMask( getCompatibleClipMask(rClip) );
+            std::shared_ptr<mask_bitmap_type> pMask( getCompatibleClipMask(rClip) );
             OSL_ASSERT( pMask );
 
             return composite_iterator_type( maBegin,
@@ -580,7 +573,7 @@ namespace
                                 const basegfx::B2IBox&       rBounds,
                                 Color                        lineColor,
                                 DrawMode                     drawMode,
-                                const BitmapDeviceSharedPtr& rClip ) SAL_OVERRIDE
+                                const BitmapDeviceSharedPtr& rClip ) override
         {
             implDrawLine(rPt1,rPt2,rBounds,lineColor,
                          getMaskedIter(rClip),
@@ -623,9 +616,9 @@ namespace
         virtual void drawPolygon_i(const basegfx::B2DPolygon& rPoly,
                                    const basegfx::B2IBox&     rBounds,
                                    Color                      lineColor,
-                                   DrawMode                   drawMode ) SAL_OVERRIDE
+                                   DrawMode                   drawMode ) override
         {
-            if( drawMode == DrawMode_XOR )
+            if( drawMode == DrawMode::XOR )
                 implDrawPolygon( rPoly, rBounds, lineColor,
                                  maBegin,
                                  maRawXorAccessor );
@@ -639,9 +632,9 @@ namespace
                                    const basegfx::B2IBox&       rBounds,
                                    Color                        lineColor,
                                    DrawMode                     drawMode,
-                                   const BitmapDeviceSharedPtr& rClip ) SAL_OVERRIDE
+                                   const BitmapDeviceSharedPtr& rClip ) override
         {
-            if( drawMode == DrawMode_XOR )
+            if( drawMode == DrawMode::XOR )
                 implDrawPolygon( rPoly, rBounds, lineColor,
                                  getMaskedIter(rClip),
                                  maRawMaskedXorAccessor );
@@ -668,7 +661,7 @@ namespace
                                                      col),
                                       rBounds,
                                       aPoly,
-                                      basegfx::FillRule_EVEN_ODD );
+                                      basegfx::FillRule::EvenOdd );
 
             if( mpDamage )
             {
@@ -680,9 +673,9 @@ namespace
         virtual void fillPolyPolygon_i(const basegfx::B2DPolyPolygon& rPoly,
                                        Color                          fillColor,
                                        DrawMode                       drawMode,
-                                       const basegfx::B2IBox&         rBounds ) SAL_OVERRIDE
+                                       const basegfx::B2IBox&         rBounds ) override
         {
-            if( drawMode == DrawMode_XOR )
+            if( drawMode == DrawMode::XOR )
                 implFillPolyPolygon( rPoly, fillColor,
                                      maBegin,
                                      maRawXorAccessor,
@@ -698,9 +691,9 @@ namespace
                                        Color                          fillColor,
                                        DrawMode                       drawMode,
                                        const basegfx::B2IBox&         rBounds,
-                                       const BitmapDeviceSharedPtr&   rClip ) SAL_OVERRIDE
+                                       const BitmapDeviceSharedPtr&   rClip ) override
         {
-            if( drawMode == DrawMode_XOR )
+            if( drawMode == DrawMode::XOR )
                 implFillPolyPolygon( rPoly, fillColor,
                                      getMaskedIter(rClip),
                                      maRawMaskedXorAccessor,
@@ -719,7 +712,7 @@ namespace
                             const Iterator&              begin,
                             const RawAcc&                acc)
         {
-            boost::shared_ptr<BitmapRenderer> pSrcBmp( getCompatibleBitmap(rSrcBitmap) );
+            std::shared_ptr<BitmapRenderer> pSrcBmp( getCompatibleBitmap(rSrcBitmap) );
             OSL_ASSERT( pSrcBmp );
 
             scaleImage(
@@ -806,11 +799,11 @@ namespace
         virtual void drawBitmap_i(const BitmapDeviceSharedPtr& rSrcBitmap,
                                   const basegfx::B2IBox&       rSrcRect,
                                   const basegfx::B2IBox&       rDstRect,
-                                  DrawMode                     drawMode ) SAL_OVERRIDE
+                                  DrawMode                     drawMode ) override
         {
             if( isCompatibleBitmap( rSrcBitmap ) )
             {
-                if( drawMode == DrawMode_XOR )
+                if( drawMode == DrawMode::XOR )
                     implDrawBitmap(rSrcBitmap, rSrcRect, rDstRect,
                                    maBegin,
                                    maRawXorAccessor);
@@ -825,7 +818,7 @@ namespace
             }
             else
             {
-                if( drawMode == DrawMode_XOR )
+                if( drawMode == DrawMode::XOR )
                     implDrawBitmapGeneric(rSrcBitmap, rSrcRect, rDstRect,
                                           maBegin,
                                           maXorAccessor);
@@ -841,11 +834,11 @@ namespace
                                   const basegfx::B2IBox&       rSrcRect,
                                   const basegfx::B2IBox&       rDstRect,
                                   DrawMode                     drawMode,
-                                  const BitmapDeviceSharedPtr& rClip ) SAL_OVERRIDE
+                                  const BitmapDeviceSharedPtr& rClip ) override
         {
             if( isCompatibleBitmap( rSrcBitmap ) )
             {
-                if( drawMode == DrawMode_XOR )
+                if( drawMode == DrawMode::XOR )
                     implDrawBitmap(rSrcBitmap, rSrcRect, rDstRect,
                                    getMaskedIter(rClip),
                                    maRawMaskedXorAccessor);
@@ -856,7 +849,7 @@ namespace
             }
             else
             {
-                if( drawMode == DrawMode_XOR )
+                if( drawMode == DrawMode::XOR )
                     implDrawBitmapGeneric(rSrcBitmap, rSrcRect, rDstRect,
                                           getMaskedIter(rClip),
                                           maMaskedXorAccessor);
@@ -871,10 +864,10 @@ namespace
         virtual void drawMaskedColor_i(Color                        aSrcColor,
                                        const BitmapDeviceSharedPtr& rAlphaMask,
                                        const basegfx::B2IBox&       rSrcRect,
-                                       const basegfx::B2IPoint&     rDstPoint ) SAL_OVERRIDE
+                                       const basegfx::B2IPoint&     rDstPoint ) override
         {
-            boost::shared_ptr<mask_bitmap_type>      pMask( getCompatibleClipMask(rAlphaMask) );
-            boost::shared_ptr<alphamask_bitmap_type> pAlpha( getCompatibleAlphaMask(rAlphaMask) );
+            std::shared_ptr<mask_bitmap_type>      pMask( getCompatibleClipMask(rAlphaMask) );
+            std::shared_ptr<alphamask_bitmap_type> pAlpha( getCompatibleAlphaMask(rAlphaMask) );
 
             if( pAlpha )
             {
@@ -921,10 +914,10 @@ namespace
                                        const BitmapDeviceSharedPtr& rAlphaMask,
                                        const basegfx::B2IBox&       rSrcRect,
                                        const basegfx::B2IPoint&     rDstPoint,
-                                       const BitmapDeviceSharedPtr& rClip ) SAL_OVERRIDE
+                                       const BitmapDeviceSharedPtr& rClip ) override
         {
-            boost::shared_ptr<mask_bitmap_type>      pMask( getCompatibleClipMask(rAlphaMask) );
-            boost::shared_ptr<alphamask_bitmap_type> pAlpha( getCompatibleAlphaMask(rAlphaMask) );
+            std::shared_ptr<mask_bitmap_type>      pMask( getCompatibleClipMask(rAlphaMask) );
+            std::shared_ptr<alphamask_bitmap_type> pAlpha( getCompatibleAlphaMask(rAlphaMask) );
 
             if( pAlpha )
             {
@@ -941,7 +934,7 @@ namespace
             }
             else if( pMask )
             {
-                boost::shared_ptr<mask_bitmap_type> pClipMask( getCompatibleClipMask(rClip) );
+                std::shared_ptr<mask_bitmap_type> pClipMask( getCompatibleClipMask(rClip) );
                 OSL_ASSERT( pClipMask );
 
                 // setup a ((iter,mask),clipMask) composite composite
@@ -988,8 +981,8 @@ namespace
                                   const Iterator&              begin,
                                   const Acc&                   acc)
         {
-            boost::shared_ptr<BitmapRenderer>   pSrcBmp( getCompatibleBitmap(rSrcBitmap) );
-            boost::shared_ptr<mask_bitmap_type> pMask( getCompatibleClipMask(rMask) );
+            std::shared_ptr<BitmapRenderer>   pSrcBmp( getCompatibleBitmap(rSrcBitmap) );
+            std::shared_ptr<mask_bitmap_type> pMask( getCompatibleClipMask(rMask) );
             OSL_ASSERT( pMask && pSrcBmp );
 
             scaleImage(
@@ -1049,12 +1042,12 @@ namespace
                                         const BitmapDeviceSharedPtr& rMask,
                                         const basegfx::B2IBox&       rSrcRect,
                                         const basegfx::B2IBox&       rDstRect,
-                                        DrawMode                     drawMode ) SAL_OVERRIDE
+                                        DrawMode                     drawMode ) override
         {
             if( isCompatibleClipMask(rMask) &&
                 isCompatibleBitmap(rSrcBitmap) )
             {
-                if( drawMode == DrawMode_XOR )
+                if( drawMode == DrawMode::XOR )
                     implDrawMaskedBitmap(rSrcBitmap, rMask,
                                          rSrcRect, rDstRect,
                                          maBegin,
@@ -1067,7 +1060,7 @@ namespace
             }
             else
             {
-                if( drawMode == DrawMode_XOR )
+                if( drawMode == DrawMode::XOR )
                     implDrawMaskedBitmapGeneric(rSrcBitmap, rMask,
                                                 rSrcRect, rDstRect,
                                                 maBegin,
@@ -1086,12 +1079,12 @@ namespace
                                         const basegfx::B2IBox&       rSrcRect,
                                         const basegfx::B2IBox&       rDstRect,
                                         DrawMode                     drawMode,
-                                        const BitmapDeviceSharedPtr& rClip ) SAL_OVERRIDE
+                                        const BitmapDeviceSharedPtr& rClip ) override
         {
             if( isCompatibleClipMask(rMask) &&
                 isCompatibleBitmap(rSrcBitmap) )
             {
-                if( drawMode == DrawMode_XOR )
+                if( drawMode == DrawMode::XOR )
                     implDrawMaskedBitmap(rSrcBitmap, rMask,
                                          rSrcRect, rDstRect,
                                          getMaskedIter(rClip),
@@ -1104,7 +1097,7 @@ namespace
             }
             else
             {
-                if( drawMode == DrawMode_XOR )
+                if( drawMode == DrawMode::XOR )
                     implDrawMaskedBitmapGeneric(rSrcBitmap, rMask,
                                                 rSrcRect, rDstRect,
                                                 getMaskedIter(rClip),
@@ -1118,11 +1111,11 @@ namespace
             damaged( rDstRect );
         }
 
-        IBitmapDeviceDamageTrackerSharedPtr getDamageTracker_i() const SAL_OVERRIDE
+        IBitmapDeviceDamageTrackerSharedPtr getDamageTracker_i() const override
         {
             return mpDamage;
         }
-        void setDamageTracker_i( const IBitmapDeviceDamageTrackerSharedPtr& rDamage ) SAL_OVERRIDE
+        void setDamageTracker_i( const IBitmapDeviceDamageTrackerSharedPtr& rDamage ) override
         {
             mpDamage = rDamage;
         }
@@ -1639,7 +1632,7 @@ void BitmapDevice::drawMaskedColor( Color                        aSrcColor,
             pAlphaCopy->drawBitmap(rAlphaMask,
                                    aSrcRange,
                                    aAlphaRange,
-                                   DrawMode_PAINT);
+                                   DrawMode::Paint);
             drawMaskedColor_i( aSrcColor, pAlphaCopy, aAlphaRange, aDestPoint );
         }
         else
@@ -1691,7 +1684,7 @@ void BitmapDevice::drawMaskedColor( Color                        aSrcColor,
                 pAlphaCopy->drawBitmap(rAlphaMask,
                                        aSrcRange,
                                        aAlphaRange,
-                                       DrawMode_PAINT);
+                                       DrawMode::Paint);
                 drawMaskedColor_i( aSrcColor, pAlphaCopy, aAlphaRange, aDestPoint, rClip );
             }
             else
@@ -1789,11 +1782,6 @@ struct StdMasks
 };
 
 
-// Some compilers don't like the nested template wrap_accessor
-// reference in the parameter list - being slightly less type safe,
-// then.
-#ifndef BASEBMP_NO_NESTED_TEMPLATE_PARAMETER
-
 /// Produces a specialized renderer for the given pixel format
 template< class FormatTraits, class MaskTraits >
 BitmapDeviceSharedPtr createRenderer(
@@ -1808,22 +1796,6 @@ BitmapDeviceSharedPtr createRenderer(
     boost::shared_array< sal_uInt8 >                             pMem,
     const PaletteMemorySharedVector&                             pPal,
     const IBitmapDeviceDamageTrackerSharedPtr&                   pDamage )
-#else
-
-template< class FormatTraits, class MaskTraits, class Accessor >
-BitmapDeviceSharedPtr createRenderer(
-    const basegfx::B2IBox&                                       rBounds,
-    const basegfx::B2IVector&                                    rBufferSize,
-    Format                                                       nScanlineFormat,
-    sal_Int32                                                    nScanlineStride,
-    sal_uInt8*                                                   pFirstScanline,
-    typename FormatTraits::raw_accessor_type const&              rRawAccessor,
-    Accessor const&                                              rAccessor,
-    boost::shared_array< sal_uInt8 >                             pMem,
-    const PaletteMemorySharedVector&                             pPal,
-    const IBitmapDeviceDamageTrackerSharedPtr&                   pDamage )
-
-#endif
 {
     typedef typename FormatTraits::iterator_type                Iterator;
     typedef BitmapRenderer< Iterator,
@@ -1856,7 +1828,7 @@ PaletteMemorySharedVector createStandardPalette(
     if( pPal || nNumEntries <= 0 )
         return pPal;
 
-    boost::shared_ptr< std::vector<Color> > pLocalPal(
+    std::shared_ptr< std::vector<Color> > pLocalPal(
         new std::vector<Color>(nNumEntries) );
 
     const sal_Int32 nIncrement( 0x00FFFFFF/nNumEntries );
@@ -1928,35 +1900,11 @@ BitmapDeviceSharedPtr createRenderer(
                                       pDamage);
 }
 
-
-// TODO(Q3): consolidate with canvas/canvastools.hxx! Best move this
-// to o3tl or sal/bithacks.hxx ...
-
-/** Compute the next highest power of 2 of a 32-bit value
-
-    Code devised by Sean Anderson, in good ole HAKMEM
-    tradition.
-
-    @return 1 << (lg(x - 1) + 1)
-*/
-inline sal_uInt32 nextPow2( sal_uInt32 x )
-{
-    --x;
-    x |= x >> 1;
-    x |= x >> 2;
-    x |= x >> 4;
-    x |= x >> 8;
-    x |= x >> 16;
-
-    return ++x;
-}
-
 namespace
 {
 BitmapDeviceSharedPtr createBitmapDeviceImplInner( const basegfx::B2IVector&                  rSize,
                                                    bool                                       bTopDown,
                                                    Format                                     nScanlineFormat,
-                                                   sal_Int32                                  nScanlineStride,
                                                    boost::shared_array< sal_uInt8 >           pMem,
                                                    PaletteMemorySharedVector                  pPal,
                                                    const basegfx::B2IBox*                     pSubset,
@@ -1965,8 +1913,8 @@ BitmapDeviceSharedPtr createBitmapDeviceImplInner( const basegfx::B2IVector&
 {
     OSL_ASSERT(rSize.getX() > 0 && rSize.getY() > 0);
 
-    if( nScanlineFormat <= FORMAT_NONE ||
-        nScanlineFormat >  FORMAT_MAX )
+    if( nScanlineFormat <= Format::NONE ||
+        nScanlineFormat >  Format::LAST )
         return BitmapDeviceSharedPtr();
 
     sal_uInt8 nBitsPerPixel = bitsPerPixel[nScanlineFormat];
@@ -1977,6 +1925,8 @@ BitmapDeviceSharedPtr createBitmapDeviceImplInner( const basegfx::B2IVector&
         return BitmapDeviceSharedPtr();
     }
 
+    sal_Int32 nScanlineStride = getBitmapDeviceStrideForWidth(nScanlineFormat, rSize.getX());
+
     // factor in bottom-up scanline order case
     nScanlineStride *= bTopDown ? 1 : -1;
 
@@ -1996,7 +1946,7 @@ BitmapDeviceSharedPtr createBitmapDeviceImplInner( const basegfx::B2IVector&
         pMem.reset(
             static_cast<sal_uInt8*>(rtl_allocateMemory( nMemSize )),
             &rtl_freeMemory );
-        if (pMem.get() == 0 && nMemSize != 0)
+        if (pMem.get() == nullptr && nMemSize != 0)
             return BitmapDeviceSharedPtr();
         if (bBlack)
             memset(pMem.get(), 0, nMemSize);
@@ -2017,23 +1967,23 @@ BitmapDeviceSharedPtr createBitmapDeviceImplInner( const basegfx::B2IVector&
 
         // one bit formats
 
-        case FORMAT_ONE_BIT_MSB_GREY:
+        case Format::OneBitMsbGrey:
             return createRenderer<PixelFormatTraits_GREY1_MSB,StdMasks>(
                 aBounds, rSize, nScanlineFormat, nScanlineStride,
                 pFirstScanline, pMem, pPal, rDamage );
 
-        case FORMAT_ONE_BIT_LSB_GREY:
+        case Format::OneBitLsbGrey:
             return createRenderer<PixelFormatTraits_GREY1_LSB,StdMasks>(
                 aBounds, rSize, nScanlineFormat, nScanlineStride,
                 pFirstScanline, pMem, pPal, rDamage );
 
-        case FORMAT_ONE_BIT_MSB_PAL:
+        case Format::OneBitMsbPal:
             return createRenderer<PixelFormatTraits_PAL1_MSB,StdMasks>(
                 aBounds, rSize, nScanlineFormat, nScanlineStride,
                 pFirstScanline, pMem, pPal,
                 bitsPerPixel[nScanlineFormat], rDamage );
 
-        case FORMAT_ONE_BIT_LSB_PAL:
+        case Format::OneBitLsbPal:
             return createRenderer<PixelFormatTraits_PAL1_LSB,StdMasks>(
                 aBounds, rSize, nScanlineFormat, nScanlineStride,
                 pFirstScanline, pMem, pPal,
@@ -2043,23 +1993,23 @@ BitmapDeviceSharedPtr createBitmapDeviceImplInner( const basegfx::B2IVector&
 
         // four bit formats
 
-        case FORMAT_FOUR_BIT_MSB_GREY:
+        case Format::FourBitMsbGrey:
             return createRenderer<PixelFormatTraits_GREY4_MSB,StdMasks>(
                 aBounds, rSize, nScanlineFormat, nScanlineStride,
                 pFirstScanline, pMem, pPal, rDamage );
 
-        case FORMAT_FOUR_BIT_LSB_GREY:
+        case Format::FourBitLsbGrey:
             return createRenderer<PixelFormatTraits_GREY4_LSB,StdMasks>(
                 aBounds, rSize, nScanlineFormat, nScanlineStride,
                 pFirstScanline, pMem, pPal, rDamage );
 
-        case FORMAT_FOUR_BIT_MSB_PAL:
+        case Format::FourBitMsbPal:
             return createRenderer<PixelFormatTraits_PAL4_MSB,StdMasks>(
                 aBounds, rSize, nScanlineFormat, nScanlineStride,
                 pFirstScanline, pMem, pPal,
                 bitsPerPixel[nScanlineFormat], rDamage );
 
-        case FORMAT_FOUR_BIT_LSB_PAL:
+        case Format::FourBitLsbPal:
             return createRenderer<PixelFormatTraits_PAL4_LSB,StdMasks>(
                 aBounds, rSize, nScanlineFormat, nScanlineStride,
                 pFirstScanline, pMem, pPal,
@@ -2069,12 +2019,12 @@ BitmapDeviceSharedPtr createBitmapDeviceImplInner( const basegfx::B2IVector&
 
         // eight bit formats
 
-        case FORMAT_EIGHT_BIT_GREY:
+        case Format::EightBitGrey:
             return createRenderer<PixelFormatTraits_GREY8,StdMasks>(
                 aBounds, rSize, nScanlineFormat, nScanlineStride,
                 pFirstScanline, pMem, pPal, rDamage );
 
-        case FORMAT_EIGHT_BIT_PAL:
+        case Format::EightBitPal:
             return createRenderer<PixelFormatTraits_PAL8,StdMasks>(
                 aBounds, rSize, nScanlineFormat, nScanlineStride,
                 pFirstScanline, pMem, pPal,
@@ -2084,46 +2034,40 @@ BitmapDeviceSharedPtr createBitmapDeviceImplInner( const basegfx::B2IVector&
 
         // sixteen bit formats
 
-        case FORMAT_SIXTEEN_BIT_LSB_TC_MASK:
+        case Format::SixteenBitLsbTcMask:
             return createRenderer<PixelFormatTraits_RGB16_565_LSB,StdMasks>(
                 aBounds, rSize, nScanlineFormat, nScanlineStride,
                 pFirstScanline, pMem, pPal, rDamage );
 
-        case FORMAT_SIXTEEN_BIT_MSB_TC_MASK:
+        case Format::SixteenBitMsbTcMask:
             return createRenderer<PixelFormatTraits_RGB16_565_MSB,StdMasks>(
                 aBounds, rSize, nScanlineFormat, nScanlineStride,
                 pFirstScanline, pMem, pPal, rDamage );
 
         // twentyfour bit formats
-        case FORMAT_TWENTYFOUR_BIT_TC_MASK:
+        case Format::TwentyFourBitTcMask:
             return createRenderer<PixelFormatTraits_BGR24,StdMasks>(
                 aBounds, rSize, nScanlineFormat, nScanlineStride,
                 pFirstScanline, pMem, pPal, rDamage );
 
         // thirtytwo bit formats
 
-        // 8 red bits, 8 green bits, 8 blue bits, and 8 ignored bits like CAIRO_FORMAT_RGB24
-        case FORMAT_THIRTYTWO_BIT_TC_MASK_BGRX:
-            return createRenderer<PixelFormatTraits_BGRX32_8888,StdMasks>(
-                aBounds, rSize, nScanlineFormat, nScanlineStride,
-                pFirstScanline, pMem, pPal, rDamage );
-
-        case FORMAT_THIRTYTWO_BIT_TC_MASK_BGRA:
+        case Format::ThirtyTwoBitTcMaskBGRA:
             return createRenderer<PixelFormatTraits_BGRA32_8888,StdMasks>(
                 aBounds, rSize, nScanlineFormat, nScanlineStride,
                 pFirstScanline, pMem, pPal, rDamage );
 
-        case FORMAT_THIRTYTWO_BIT_TC_MASK_ARGB:
+        case Format::ThirtyTwoBitTcMaskARGB:
             return createRenderer<PixelFormatTraits_ARGB32_8888,StdMasks>(
                 aBounds, rSize, nScanlineFormat, nScanlineStride,
                 pFirstScanline, pMem, pPal, rDamage );
 
-        case FORMAT_THIRTYTWO_BIT_TC_MASK_ABGR:
+        case Format::ThirtyTwoBitTcMaskABGR:
             return createRenderer<PixelFormatTraits_ABGR32_8888,StdMasks>(
                 aBounds, rSize, nScanlineFormat, nScanlineStride,
                 pFirstScanline, pMem, pPal, rDamage );
 
-        case FORMAT_THIRTYTWO_BIT_TC_MASK_RGBA:
+        case Format::ThirtyTwoBitTcMaskRGBA:
             return createRenderer<PixelFormatTraits_RGBA32_8888,StdMasks>(
                 aBounds, rSize, nScanlineFormat, nScanlineStride,
                 pFirstScanline, pMem, pPal, rDamage );
@@ -2139,14 +2083,13 @@ BitmapDeviceSharedPtr createBitmapDeviceImplInner( const basegfx::B2IVector&
 BitmapDeviceSharedPtr createBitmapDeviceImpl( const basegfx::B2IVector&                  rSize,
                                               bool                                       bTopDown,
                                               Format                                     nScanlineFormat,
-                                              sal_Int32                                  nScanlineStride,
                                               boost::shared_array< sal_uInt8 >           pMem,
                                               PaletteMemorySharedVector                  pPal,
                                               const basegfx::B2IBox*                     pSubset,
                                               const IBitmapDeviceDamageTrackerSharedPtr& rDamage,
                                               bool bBlack = true)
 {
-    BitmapDeviceSharedPtr result( createBitmapDeviceImplInner( rSize, bTopDown, nScanlineFormat, nScanlineStride, pMem, pPal, pSubset, rDamage, bBlack ) );
+    BitmapDeviceSharedPtr result( createBitmapDeviceImplInner( rSize, bTopDown, nScanlineFormat, pMem, pPal, pSubset, rDamage, bBlack ) );
 
 #ifdef SAL_LOG_INFO
     std::ostringstream subset;
@@ -2172,60 +2115,52 @@ sal_Int32 getBitmapDeviceStrideForWidth(Format nScanlineFormat, sal_Int32 nWidth
     // round up to full 8 bit, divide by 8
     sal_Int32 nScanlineStride = (nWidth*nBitsPerPixel + 7) >> 3;
 
-    // rounded up to next full power-of-two number of bytes
-    const sal_uInt32 bytesPerPixel = nextPow2(
-        (bitsPerPixel[nScanlineFormat] + 7) >> 3);
+    // pixman (cairo) and GDI (windows) pad to multiples of 32bits
+    // so do the same to be easily compatible
+    nScanlineStride = (nScanlineStride + 3) & ~0x3;
 
-    // now make nScanlineStride a multiple of bytesPerPixel
-    nScanlineStride = (nScanlineStride + bytesPerPixel - 1) / bytesPerPixel * bytesPerPixel;
     return nScanlineStride;
 }
 
 BitmapDeviceSharedPtr createBitmapDevice( const basegfx::B2IVector& rSize,
                                           bool                      bTopDown,
-                                          Format                    nScanlineFormat,
-                                          sal_Int32                 nScanlineStride )
+                                          Format                    nScanlineFormat )
 {
     return createBitmapDeviceImpl( rSize,
                                    bTopDown,
                                    nScanlineFormat,
-                                   nScanlineStride,
                                    boost::shared_array< sal_uInt8 >(),
                                    PaletteMemorySharedVector(),
-                                   NULL,
+                                   nullptr,
                                    IBitmapDeviceDamageTrackerSharedPtr() );
 }
 
 BitmapDeviceSharedPtr createBitmapDevice( const basegfx::B2IVector&        rSize,
                                           bool                             bTopDown,
                                           Format                           nScanlineFormat,
-                                          sal_Int32                        nScanlineStride,
                                           const PaletteMemorySharedVector& rPalette )
 {
     return createBitmapDeviceImpl( rSize,
                                    bTopDown,
                                    nScanlineFormat,
-                                   nScanlineStride,
                                    boost::shared_array< sal_uInt8 >(),
                                    rPalette,
-                                   NULL,
+                                   nullptr,
                                    IBitmapDeviceDamageTrackerSharedPtr() );
 }
 
 BitmapDeviceSharedPtr createBitmapDevice( const basegfx::B2IVector&        rSize,
                                           bool                             bTopDown,
                                           Format                           nScanlineFormat,
-                                          sal_Int32                        nScanlineStride,
                                           const RawMemorySharedArray&      rMem,
                                           const PaletteMemorySharedVector& rPalette )
 {
     return createBitmapDeviceImpl( rSize,
                                    bTopDown,
                                    nScanlineFormat,
-                                   nScanlineStride,
                                    rMem,
                                    rPalette,
-                                   NULL,
+                                   nullptr,
                                    IBitmapDeviceDamageTrackerSharedPtr() );
 }
 
@@ -2234,11 +2169,10 @@ BitmapDeviceSharedPtr createClipDevice( const basegfx::B2IVector&        rSize )
     BitmapDeviceSharedPtr xClip(
              createBitmapDeviceImpl( rSize,
                                      false, /* bTopDown */
-                                     basebmp::FORMAT_ONE_BIT_MSB_GREY,
-                                     getBitmapDeviceStrideForWidth(basebmp::FORMAT_ONE_BIT_MSB_GREY, rSize.getX()),
+                                     basebmp::Format::OneBitMsbGrey,
                                      boost::shared_array< sal_uInt8 >(),
                                      PaletteMemorySharedVector(),
-                                     NULL,
+                                     nullptr,
                                      IBitmapDeviceDamageTrackerSharedPtr(),
                                      false /* white */) );
     return xClip;
@@ -2251,7 +2185,6 @@ BitmapDeviceSharedPtr subsetBitmapDevice( const BitmapDeviceSharedPtr& rProto,
     return createBitmapDeviceImpl( rProto->getSize(),
                                    rProto->isTopDown(),
                                    rProto->getScanlineFormat(),
-                                   rProto->getScanlineStride(),
                                    rProto->getBuffer(),
                                    rProto->getPalette(),
                                    &rSubset,
@@ -2264,10 +2197,9 @@ BitmapDeviceSharedPtr cloneBitmapDevice( const basegfx::B2IVector&    rSize,
     return createBitmapDeviceImpl( rSize,
                                    rProto->isTopDown(),
                                    rProto->getScanlineFormat(),
-                                   rProto->getScanlineStride(),
                                    boost::shared_array< sal_uInt8 >(),
                                    rProto->getPalette(),
-                                   NULL,
+                                   nullptr,
                                    rProto->getDamageTracker() );
 }
 
