@@ -53,22 +53,22 @@ private:
 
         const basegfx::B2IPoint aPt(0,0);
         const Color aCol(0xFFFFFFFF);
-        rDevice->setPixel( aPt, aCol, DrawMode_PAINT, mpClipMask );
+        rDevice->setPixel( aPt, aCol, DrawMode::Paint, mpClipMask );
         CPPUNIT_ASSERT_MESSAGE("get/setPixel clip #1",
                                rDevice->getPixel(aPt) == aBgCol);
 
         const basegfx::B2IPoint aPt2(10,10);
-        rDevice->setPixel( aPt2, aCol, DrawMode_PAINT, mpClipMask );
+        rDevice->setPixel( aPt2, aCol, DrawMode::Paint, mpClipMask );
         CPPUNIT_ASSERT_MESSAGE("get/setPixel clip #2",
                                rDevice->getPixel(aPt2) == aBgCol);
 
         const basegfx::B2IPoint aPt1(10,0);
-        rDevice->setPixel( aPt1, aCol, DrawMode_PAINT, mpClipMask );
+        rDevice->setPixel( aPt1, aCol, DrawMode::Paint, mpClipMask );
         CPPUNIT_ASSERT_MESSAGE("get/setPixel clip #3",
                                rDevice->getPixel(aPt1) != aBgCol);
 
         const basegfx::B2IPoint aPt3(0,10);
-        rDevice->setPixel( aPt3, aCol, DrawMode_PAINT, mpClipMask );
+        rDevice->setPixel( aPt3, aCol, DrawMode::Paint, mpClipMask );
         CPPUNIT_ASSERT_MESSAGE("get/setPixel clip #4",
                                rDevice->getPixel(aPt3) != aBgCol);
     }
@@ -81,7 +81,7 @@ private:
         const basegfx::B2IPoint aPt1(0,0);
         const basegfx::B2IPoint aPt2(1,9);
         const Color aCol(0xFFFFFFFF);
-        rDevice->drawLine( aPt1, aPt2, aCol, DrawMode_PAINT, mpClipMask );
+        rDevice->drawLine( aPt1, aPt2, aCol, DrawMode::Paint, mpClipMask );
 
         const basegfx::B2IPoint aPt3(1,5);
         CPPUNIT_ASSERT_MESSAGE("get line pixel",
@@ -90,7 +90,7 @@ private:
                                countPixel( rDevice,
                                            rDevice->getPixel(aPt3) ) == 4);
 
-        rDevice->drawLine( aPt1, aPt2, aCol, DrawMode_XOR, mpClipMask );
+        rDevice->drawLine( aPt1, aPt2, aCol, DrawMode::XOR, mpClipMask );
         CPPUNIT_ASSERT_MESSAGE("number of xor-rendered line pixel is not 0",
                                countPixel( rDevice,
                                            rDevice->getPixel(aPt3) ) == 121);
@@ -105,7 +105,7 @@ private:
         rDevice->fillPolyPolygon( basegfx::B2DPolyPolygon(
                                       basegfx::tools::createPolygonFromRect(aAllOver)),
                                   aCol,
-                                  DrawMode_PAINT,
+                                  DrawMode::Paint,
                                   mpClipMask );
         const basegfx::B2IPoint aPt(0,10);
         CPPUNIT_ASSERT_MESSAGE("number of clipped pixel is not 30",
@@ -114,14 +114,14 @@ private:
         rDevice->fillPolyPolygon( basegfx::B2DPolyPolygon(
                                       basegfx::tools::createPolygonFromRect(aAllOver)),
                                   aCol,
-                                  DrawMode_PAINT );
+                                  DrawMode::Paint );
         CPPUNIT_ASSERT_MESSAGE("number of filled pixel is not 121",
                                countPixel( rDevice, rDevice->getPixel(aPt) ) == 121);
 
         rDevice->fillPolyPolygon( basegfx::B2DPolyPolygon(
                                       basegfx::tools::createPolygonFromRect(aAllOver)),
                                   aCol,
-                                  DrawMode_XOR,
+                                  DrawMode::XOR,
                                   mpClipMask );
         CPPUNIT_ASSERT_MESSAGE("number of xor-cleared pixel is not 91",
                                countPixel( rDevice, rDevice->getPixel(aPt) ) == 121-30);
@@ -135,15 +135,15 @@ private:
         Color aCol1(0);
         Color aCol2(0xFFFFFFFF);
         pBmp->clear(aCol1);
-        pBmp->setPixel(basegfx::B2IPoint(0,0),aCol2,DrawMode_PAINT);
-        pBmp->setPixel(basegfx::B2IPoint(1,1),aCol2,DrawMode_PAINT);
-        pBmp->setPixel(basegfx::B2IPoint(2,2),aCol2,basebmp::DrawMode_PAINT);
+        pBmp->setPixel(basegfx::B2IPoint(0,0),aCol2,DrawMode::Paint);
+        pBmp->setPixel(basegfx::B2IPoint(1,1),aCol2,DrawMode::Paint);
+        pBmp->setPixel(basegfx::B2IPoint(2,2),aCol2,basebmp::DrawMode::Paint);
 
         rDevice->clear(aCol1);
         rDevice->drawBitmap(pBmp,
                             basegfx::B2IBox(0,0,3,3),
                             basegfx::B2IBox(-1,-1,4,4),
-                            DrawMode_PAINT,
+                            DrawMode::Paint,
                             mpClipMask);
 
         const basegfx::B2IPoint aPt(1,1);
@@ -156,18 +156,18 @@ private:
     {
         BitmapDeviceSharedPtr pBmp( createBitmapDevice( rDevice->getSize(),
                                                         true,
-                                                        FORMAT_EIGHT_BIT_GREY ));
+                                                        Format::EightBitGrey ));
 
         OUString aSvg( "m 0 0h5v10h5v-5h-10z" );
 
         basegfx::B2DPolyPolygon aPoly;
-        basegfx::tools::importFromSvgD( aPoly, aSvg, false, NULL );
+        basegfx::tools::importFromSvgD( aPoly, aSvg, false, nullptr );
         const basebmp::Color aCol(0xFF);
         pBmp->clear( basebmp::Color(0) );
         pBmp->fillPolyPolygon(
             aPoly,
             aCol,
-            basebmp::DrawMode_PAINT );
+            basebmp::DrawMode::Paint );
 
         const basegfx::B2IBox aSourceRect(0,0,10,10);
         const basegfx::B2IPoint aDestLeftTop(0,0);
@@ -185,27 +185,27 @@ private:
     }
 
 public:
-    void setUp()
+    void setUp() override
     {
         const basegfx::B2ISize aSize(11,11);
         mpClipMask = createBitmapDevice( aSize,
                                          true,
-                                         FORMAT_ONE_BIT_MSB_GREY );
+                                         Format::OneBitMsbGrey );
         mpDevice1bpp = createBitmapDevice( aSize,
                                            true,
-                                           FORMAT_ONE_BIT_MSB_PAL );
+                                           Format::OneBitMsbPal );
         mpDevice32bpp = createBitmapDevice( aSize,
                                            true,
-                                           FORMAT_THIRTYTWO_BIT_TC_MASK_BGRA );
+                                           Format::ThirtyTwoBitTcMaskBGRA );
 
         OUString aSvg( "m 0 0 h5 l5 5 v5 h-5 l-5-5 z" );
         basegfx::B2DPolyPolygon aPoly;
-        basegfx::tools::importFromSvgD( aPoly, aSvg, false, NULL );
+        basegfx::tools::importFromSvgD( aPoly, aSvg, false, nullptr );
         mpClipMask->clear(Color(0));
         mpClipMask->drawPolygon(
             aPoly.getB2DPolygon(0),
             Color(0xFFFFFFFF),
-            DrawMode_PAINT );
+            DrawMode::Paint );
     }
 
     void testPixelClip()
