@@ -29,6 +29,7 @@
 
 #include <vector>
 #include <algorithm>
+#include <memory>
 
 #define SUBDIVIDE_FOR_CUT_TEST_COUNT        (50)
 
@@ -174,7 +175,7 @@ namespace basegfx
             const temporaryPointVector& rPointVector, const B2DPolygon& rPolygon,
             sal_uInt32 nInd, temporaryPointVector& rTempPoints)
         {
-            // assuming that the subdivision to create rPolygon used aequidistant pieces
+            // assuming that the subdivision to create rPolygon used equidistant pieces
             // (as in adaptiveSubdivideByCount) it is now possible to calculate back the
             // cut positions in the polygon to relative cut positions on the original bezier
             // segment.
@@ -229,7 +230,7 @@ namespace basegfx
                         const double fOne(1.0);
                         fCut = (aVecB.getY() * (rCurrB.getX() - rCurrA.getX()) + aVecB.getX() * (rCurrA.getY() - rCurrB.getY())) / fCut;
 
-                        if(fTools::moreOrEqual(fCut, fZero) && fTools::lessOrEqual(fCut, fOne))
+                        if (fTools::betweenOrEqualEither(fCut, fZero, fOne))
                         {
                             // it's a candidate, but also need to test parameter value of cut on line 2
                             double fCut2;
@@ -244,7 +245,7 @@ namespace basegfx
                                 fCut2 = (rCurrA.getY() + (fCut * aVecA.getY()) - rCurrB.getY()) / aVecB.getY();
                             }
 
-                            if(fTools::moreOrEqual(fCut2, fZero) && fTools::lessOrEqual(fCut2, fOne))
+                            if (fTools::betweenOrEqualEither(fCut2, fZero, fOne))
                             {
                                 // cut is in range, add point. Two edges can have only one cut, but
                                 // add a cut point to each list. The lists may be the same for
@@ -266,7 +267,7 @@ namespace basegfx
             // it is not sufficient to use findCuts() recursively. This will indeed find the cuts between the
             // segments of the two temporarily adaptive subdivided bezier segments, but not the touches or
             // equal points of them.
-            // It would be possible to find the toches using findTouches(), but at last with commpn points
+            // It would be possible to find the touches using findTouches(), but at last with common points
             // the adding of cut points (temporary points) would fail. But for these temporarily adaptive
             // subdivided bezier segments, common points may be not very likely, but the bug shows that it
             // happens.
@@ -411,7 +412,7 @@ namespace basegfx
             }
 
             // append remapped tempVector entries for edge to tempPoints for edge
-            for(sal_uInt32 a(0L); a < aTempPointVectorEdge.size(); a++)
+            for(size_t a(0L); a < aTempPointVectorEdge.size(); a++)
             {
                 const temporaryPoint& rTempPoint = aTempPointVectorEdge[a];
                 rTempPointsB.push_back(temporaryPoint(rTempPoint.getPoint(), nIndB, rTempPoint.getCut()));
@@ -887,7 +888,7 @@ namespace basegfx
                 else
                 {
                     // first solve self cuts and self touches for all contained single polygons
-                    temporaryPolygonData *pTempData = new temporaryPolygonData[nCount];
+                    std::unique_ptr<temporaryPolygonData[]> pTempData(new temporaryPolygonData[nCount]);
                     sal_uInt32 a, b;
 
                     for(a = 0L; a < nCount; a++)
@@ -934,8 +935,6 @@ namespace basegfx
                     {
                         aRetval.append(mergeTemporaryPointsAndPolygon(pTempData[a].getPolygon(), pTempData[a].getTemporaryPointVector()));
                     }
-
-                    delete[] pTempData;
                 }
 
                 return aRetval;
