@@ -137,7 +137,7 @@ namespace basegfx
                 }
             }
 
-            bool impLeftOfEdges(const B2DVector& rVecA, const B2DVector& rVecB, const B2DVector& rTest)
+            static bool impLeftOfEdges(const B2DVector& rVecA, const B2DVector& rVecB, const B2DVector& rTest)
             {
                 // tests if rTest is left of both directed line segments along the line -rVecA, rVecB. Test is
                 // with border.
@@ -494,7 +494,7 @@ namespace basegfx
 
                     const sal_uInt32 nPointCount(aGeometry.count());
 
-                    // If it's not a pezier polygon, at least four points are needed to create
+                    // If it's not a bezier polygon, at least four points are needed to create
                     // a self-intersection. If it's a bezier polygon, the minimum point number
                     // is two, since with a single point You get a curve, but no self-intersection
                     if(nPointCount > 3 || (nPointCount > 1 && mbIsCurve))
@@ -522,7 +522,7 @@ namespace basegfx
 
                 if(nOriginalCount)
                 {
-                    B2DPolyPolygon aGeometry(tools::addPointsAtCutsAndTouches(maOriginal, true));
+                    B2DPolyPolygon aGeometry(tools::addPointsAtCutsAndTouches(maOriginal));
                     aGeometry.removeDoublePoints();
                     aGeometry = tools::simplifyCurveSegments(aGeometry);
                     mbIsCurve = aGeometry.areControlPointsUsed();
@@ -713,7 +713,7 @@ namespace basegfx
             {
                 const B2DPolygon aCandidate(rCandidate.getB2DPolygon(a));
 
-                if(ORIENTATION_NEUTRAL != tools::getOrientation(aCandidate))
+                if(B2VectorOrientation::Neutral != tools::getOrientation(aCandidate))
                 {
                     aRetval.append(aCandidate);
                 }
@@ -756,7 +756,7 @@ namespace basegfx
                     pNewHelper->meOrinetation = tools::getOrientation(aCand);
 
                     // initialize with own orientation
-                    pNewHelper->mnDepth = (ORIENTATION_NEGATIVE == pNewHelper->meOrinetation ? -1 : 1);
+                    pNewHelper->mnDepth = (B2VectorOrientation::Negative == pNewHelper->meOrinetation ? -1 : 1);
                 }
 
                 for(a = 0; a < nCount - 1; a++)
@@ -773,7 +773,7 @@ namespace basegfx
                         if(bAInB)
                         {
                             // A is inside B, add orientation of B to A
-                            rHelperA.mnDepth += (ORIENTATION_NEGATIVE == rHelperB.meOrinetation ? -1 : 1);
+                            rHelperA.mnDepth += (B2VectorOrientation::Negative == rHelperB.meOrinetation ? -1 : 1);
                         }
 
                         const bool bBInA(rHelperA.maRange.isInside(rHelperB.maRange) && tools::isInside(aCandA, aCandB, true));
@@ -781,7 +781,7 @@ namespace basegfx
                         if(bBInA)
                         {
                             // B is inside A, add orientation of A to B
-                            rHelperB.mnDepth += (ORIENTATION_NEGATIVE == rHelperA.meOrinetation ? -1 : 1);
+                            rHelperB.mnDepth += (B2VectorOrientation::Negative == rHelperA.meOrinetation ? -1 : 1);
                         }
                     }
                 }
@@ -817,7 +817,7 @@ namespace basegfx
             {
                 if(nCount == 1L)
                 {
-                    if(!bKeepAboveZero && ORIENTATION_POSITIVE == tools::getOrientation(rCandidate.getB2DPolygon(0L)))
+                    if(!bKeepAboveZero && B2VectorOrientation::Positive == tools::getOrientation(rCandidate.getB2DPolygon(0L)))
                     {
                         aRetval = rCandidate;
                     }
@@ -834,7 +834,7 @@ namespace basegfx
                         StripHelper* pNewHelper = &(aHelpers[a]);
                         pNewHelper->maRange = tools::getRange(aCandidate);
                         pNewHelper->meOrinetation = tools::getOrientation(aCandidate);
-                        pNewHelper->mnDepth = (ORIENTATION_NEGATIVE == pNewHelper->meOrinetation ? -1L : 0L);
+                        pNewHelper->mnDepth = (B2VectorOrientation::Negative == pNewHelper->meOrinetation ? -1L : 0L);
                     }
 
                     for(a = 0L; a < nCount - 1L; a++)
@@ -870,7 +870,7 @@ namespace basegfx
                             {
                                 if(bAInB)
                                 {
-                                    if(ORIENTATION_NEGATIVE == rHelperB.meOrinetation)
+                                    if(B2VectorOrientation::Negative == rHelperB.meOrinetation)
                                     {
                                         rHelperA.mnDepth--;
                                     }
@@ -881,7 +881,7 @@ namespace basegfx
                                 }
                                 else if(bBInA)
                                 {
-                                    if(ORIENTATION_NEGATIVE == rHelperA.meOrinetation)
+                                    if(B2VectorOrientation::Negative == rHelperA.meOrinetation)
                                     {
                                         rHelperB.mnDepth--;
                                     }
@@ -946,7 +946,7 @@ namespace basegfx
                 aRetval = solveCrossovers(aRetval);
                 aRetval = stripNeutralPolygons(aRetval);
 
-                return stripDispensablePolygons(aRetval, false);
+                return stripDispensablePolygons(aRetval);
             }
         }
 
@@ -1023,7 +1023,7 @@ namespace basegfx
                 aRetval = basegfx::tools::solveCrossovers(aRetval);
                 aRetval = basegfx::tools::stripNeutralPolygons(aRetval);
 
-                return basegfx::tools::stripDispensablePolygons(aRetval, false);
+                return basegfx::tools::stripDispensablePolygons(aRetval);
             }
         }
 
@@ -1038,7 +1038,7 @@ namespace basegfx
                 B2DPolyPolygonVector aResult;
                 aResult.reserve(aInput.size());
 
-                for(sal_uInt32 a(0); a < aInput.size(); a++)
+                for(size_t a(0); a < aInput.size(); a++)
                 {
                     const basegfx::B2DPolyPolygon aCandidate(prepareForPolygonOperation(aInput[a]));
 
@@ -1080,7 +1080,7 @@ namespace basegfx
                 B2DPolyPolygonVector aResult;
                 aResult.reserve((aInput.size() / 2) + 1);
 
-                for(sal_uInt32 a(0); a < aInput.size(); a += 2)
+                for(size_t a(0); a < aInput.size(); a += 2)
                 {
                     if(a + 1 < aInput.size())
                     {
