@@ -758,7 +758,7 @@ namespace basegfx
                             // is necessary.
                             const bool bSymmetricAtEdgeStart(
                                 0 != nIndex
-                                && CONTINUITY_C2 == aPolygon.getContinuityInPoint(nIndex));
+                                && B2VectorContinuity::C2 == aPolygon.getContinuityInPoint(nIndex));
 
                             if(bDetectQuadraticBeziers)
                             {
@@ -784,7 +784,6 @@ namespace basegfx
                                     if(aLastSVGCommand != aCommand)
                                     {
                                         aResult.append(aCommand);
-                                        aLastSVGCommand = aCommand;
                                     }
 
                                     basegfx::internal::putNumberCharWithSpace(aResult, aEdgeEnd.getX(), aCurrentSVGPosition.getX(), bUseRelativeCoordinates);
@@ -799,7 +798,6 @@ namespace basegfx
                                     if(aLastSVGCommand != aCommand)
                                     {
                                         aResult.append(aCommand);
-                                        aLastSVGCommand = aCommand;
                                     }
 
                                     basegfx::internal::putNumberCharWithSpace(aResult, aLeft.getX(), aCurrentSVGPosition.getX(), bUseRelativeCoordinates);
@@ -820,7 +818,6 @@ namespace basegfx
                                     if(aLastSVGCommand != aCommand)
                                     {
                                         aResult.append(aCommand);
-                                        aLastSVGCommand = aCommand;
                                     }
 
                                     basegfx::internal::putNumberCharWithSpace(aResult, aControlEdgeEnd.getX(), aCurrentSVGPosition.getX(), bUseRelativeCoordinates);
@@ -837,7 +834,6 @@ namespace basegfx
                                     if(aLastSVGCommand != aCommand)
                                     {
                                         aResult.append(aCommand);
-                                        aLastSVGCommand = aCommand;
                                     }
 
                                     basegfx::internal::putNumberCharWithSpace(aResult, aControlEdgeStart.getX(), aCurrentSVGPosition.getX(), bUseRelativeCoordinates);
