@@ -19,7 +19,7 @@
 
 
 #include "basiccharclass.hxx"
-#include "sbcomp.hxx"
+#include "token.hxx"
 
 struct TokenTable { SbiToken t; const char *s; };
 
@@ -96,7 +96,7 @@ static const TokenTable aTokTable_Basic [] = {
     { ERASE,    "Erase" },
     { _ERROR_,  "Error" },
     { EXIT,     "Exit" },
-    { EXPLICIT, "Explicit" },
+    { BASIC_EXPLICIT, "Explicit" },
     { FOR,      "For" },
     { FUNCTION, "Function" },
     { GET,      "Get" },
@@ -183,7 +183,7 @@ static const TokenTable aTokTable_Basic [] = {
 
 
 // #i109076
-TokenLabelInfo::TokenLabelInfo( void )
+TokenLabelInfo::TokenLabelInfo()
 {
     m_pTokenCanBeLabelTab = new bool[VBASUPPORT+1];
     for( int i = 0 ; i <= VBASUPPORT ; ++i )
@@ -192,11 +192,10 @@ TokenLabelInfo::TokenLabelInfo( void )
     }
     // Token accepted as label by VBA
     SbiToken eLabelToken[] = { ACCESS, ALIAS, APPEND, BASE, BINARY, CLASSMODULE,
-                               COMPARE, COMPATIBLE, DEFERR, _ERROR_, EXPLICIT, LIB, LINE, LPRINT, NAME,
+                               COMPARE, COMPATIBLE, DEFERR, _ERROR_, BASIC_EXPLICIT, LIB, LINE, LPRINT, NAME,
                                TOBJECT, OUTPUT, PROPERTY, RANDOM, READ, STEP, STOP, TEXT, VBASUPPORT, NIL };
-    SbiToken* pTok = eLabelToken;
     SbiToken eTok;
-    for( pTok = eLabelToken ; (eTok = *pTok) != NIL ; ++pTok )
+    for( SbiToken* pTok = eLabelToken ; (eTok = *pTok) != NIL ; ++pTok )
     {
         m_pTokenCanBeLabelTab[eTok] = true;
     }
@@ -211,13 +210,19 @@ TokenLabelInfo::~TokenLabelInfo()
 // the constructor detects the length of the token table
 
 SbiTokenizer::SbiTokenizer( const OUString& rSrc, StarBASIC* pb )
-           : SbiScanner( rSrc, pb )
+    : SbiScanner(rSrc, pb)
+    , eCurTok(NIL)
+    , ePush(NIL)
+    , nPLine(0)
+    , nPCol1(0)
+    , nPCol2(0)
+    , bEof(false)
+    , bEos(true)
+    , bKeywords(true)
+    , bAs(false)
+    , bErrorIsSymbol(true)
 {
     pTokTable = aTokTable_Basic;
-    bEof = bAs = false;
-    eCurTok = NIL;
-    ePush = NIL;
-    bEos = bKeywords = bErrorIsSymbol = true;
     if( !nToken )
     {
         const TokenTable *tp;
@@ -234,7 +239,7 @@ SbiTokenizer::~SbiTokenizer()
 void SbiTokenizer::Push( SbiToken t )
 {
     if( ePush != NIL )
-        Error( SbERR_INTERNAL_ERROR, "PUSH" );
+        Error( ERRCODE_BASIC_INTERNAL_ERROR, "PUSH" );
     else ePush = t;
 }
 
@@ -420,7 +425,7 @@ SbiToken SbiTokenizer::Next()
         while( delta );
         // Symbol? if not >= token
         sal_Unicode ch = aSym[0];
-        if( !theBasicCharClass::get().isAlpha( ch, bCompatible ) && !bSymbol )
+        if( !BasicCharClass::isAlpha( ch, bCompatible ) && !bSymbol )
         {
             return eCurTok = (SbiToken) (ch & 0x00FF);
         }
@@ -544,7 +549,7 @@ bool SbiTokenizer::MayBeLabel( bool bNeedsColon )
 {
     if( eCurTok == SYMBOL || m_aTokenLabelInfo.canTokenBeLabel( eCurTok ) )
     {
-        return bNeedsColon ? DoesColonFollow() : true;
+        return !bNeedsColon || DoesColonFollow();
     }
     else
     {
