@@ -20,8 +20,8 @@
 #include <sal/config.h>
 
 #if defined(WNT)
-#include <windows.h>
-#undef GetObject
+#include <prewin.h>
+#include <postwin.h>
 #endif
 
 #include <algorithm>
@@ -38,6 +38,7 @@
 #include <rtl/string.hxx>
 #include <rtl/ustring.hxx>
 #include <salhelper/simplereferenceobject.hxx>
+#include <boost/noncopyable.hpp>
 
 #undef max
 
@@ -161,7 +162,7 @@ std::size_t alignment(SbxVariable * variable) {
         case SbxOBJECT:
             {
                 std::size_t n = 1;
-                SbxArray * props = PTR_CAST(SbxObject, variable->GetObject())->
+                SbxArray * props = dynamic_cast<SbxObject*>( variable->GetObject() )->
                     GetProperties();
                 for (sal_uInt16 i = 0; i < props->Count(); ++i) {
                     n = std::max(n, alignment(props->Get(i)));
@@ -176,7 +177,7 @@ std::size_t alignment(SbxVariable * variable) {
             return 1;
         }
     } else {
-        SbxDimArray * arr = PTR_CAST(SbxDimArray, variable->GetObject());
+        SbxDimArray * arr = dynamic_cast<SbxDimArray*>( variable->GetObject() );
         int dims = arr->GetDims();
         std::vector< sal_Int32 > low(dims);
         for (int i = 0; i < dims; ++i) {
@@ -213,7 +214,7 @@ SbError marshalStruct(
     MarshalData & data)
 {
     OSL_ASSERT(variable != 0);
-    SbxArray * props = PTR_CAST(SbxObject, variable->GetObject())->
+    SbxArray * props = dynamic_cast<SbxObject*>( variable->GetObject() )->
         GetProperties();
     for (sal_uInt16 i = 0; i < props->Count(); ++i) {
         SbError e = marshal(false, props->Get(i), false, blob, offset, data);
@@ -229,7 +230,7 @@ SbError marshalArray(
     MarshalData & data)
 {
     OSL_ASSERT(variable != 0);
-    SbxDimArray * arr = PTR_CAST(SbxDimArray, variable->GetObject());
+    SbxDimArray * arr = dynamic_cast<SbxDimArray*>( variable->GetObject() );
     int dims = arr->GetDims();
     std::vector< sal_Int32 > low(dims);
     std::vector< sal_Int32 > up(dims);
@@ -263,7 +264,7 @@ SbError marshal(
     OSL_ASSERT(variable != 0);
 
     SbxDataType eVarType = variable->GetType();
-    bool bByVal = (variable->GetFlags() & SBX_REFERENCE) == 0;
+    bool bByVal = !(variable->GetFlags() & SbxFlagBits::Reference);
     if( !bByVal && !SbiRuntime::isVBAEnabled() && eVarType == SbxSTRING )
         bByVal = true;
 
@@ -326,7 +327,7 @@ SbError marshal(
             case SbxDOUBLE:
             case SbxBOOL:
             case SbxBYTE:
-                add(blob, variable->data(), 4, offset);
+                add(blob, variable->GetValues_Impl(), 4, offset);
                 break;
             case SbxSTRING:
                 {
@@ -405,7 +406,7 @@ void const * unmarshal(SbxVariable * variable, void const * data) {
                     align(
                         reinterpret_cast< sal_uIntPtr >(data),
                         alignment(variable)));
-                SbxArray * props = PTR_CAST(SbxObject, variable->GetObject())->
+                SbxArray * props = dynamic_cast<SbxObject*>( variable->GetObject() )->
                     GetProperties();
                 for (sal_uInt16 i = 0; i < props->Count(); ++i) {
                     data = unmarshal(props->Get(i), data);
@@ -423,7 +424,7 @@ void const * unmarshal(SbxVariable * variable, void const * data) {
             break;
         }
     } else {
-        SbxDimArray * arr = PTR_CAST(SbxDimArray, variable->GetObject());
+        SbxDimArray * arr = dynamic_cast<SbxDimArray*>( variable->GetObject() );
         int dims = arr->GetDims();
         std::vector< sal_Int32 > low(dims);
         std::vector< sal_Int32 > up(dims);
@@ -550,7 +551,7 @@ SbError call(
         break;
     }
     for (sal_uInt16 i = 1; i < (arguments == 0 ? 0 : arguments->Count()); ++i) {
-        arguments->Get(i)->ResetFlag(SBX_REFERENCE);
+        arguments->Get(i)->ResetFlag(SbxFlagBits::Reference);
             //TODO: skipped for errors?!?
     }
     for (std::vector< UnmarshalData >::iterator i(data.unmarshal.begin());
@@ -572,7 +573,7 @@ SbError call(
 SbError getProcData(HMODULE handle, OUString const & name, ProcData * proc)
 {
     OSL_ASSERT(proc != 0);
-    if (name.getLength() != 0 && name[0] == '@') { //TODO: "@" vs. "#"???
+    if ( !name.isEmpty() && name[0] == '@' ) { //TODO: "@" vs. "#"???
         sal_Int32 n = name.copy(1).toInt32(); //TODO: handle bad input
         if (n <= 0 || n > 0xFFFF) {
             return ERRCODE_BASIC_BAD_ARGUMENT; //TODO: more specific errcode?
