@@ -30,11 +30,10 @@
 
 // AppData-Structure for SBX:
 
-TYPEINIT0(SbxBase)
 
 SbxAppData::SbxAppData()
-    : eSbxError(SbxERR_OK)
-    , pBasicFormater(0)
+    : eSbxError(ERRCODE_SBX_OK)
+    , pBasicFormater(nullptr)
     , eBasicFormaterLangType(LANGUAGE_DONTKNOW)
 {
 }
@@ -44,12 +43,12 @@ SbxAppData::~SbxAppData()
     SolarMutexGuard g;
 
     delete pBasicFormater;
-    aFacs.clear();
+    m_Factories.clear();
 }
 
 SbxBase::SbxBase()
 {
-    nFlags  = SBX_READWRITE;
+    nFlags  = SbxFlagBits::ReadWrite;
 }
 
 SbxBase::SbxBase( const SbxBase& r )
@@ -84,17 +83,17 @@ void SbxBase::Clear()
 
 bool SbxBase::IsFixed() const
 {
-    return IsSet( SBX_FIXED );
+    return IsSet( SbxFlagBits::Fixed );
 }
 
 void SbxBase::SetModified( bool b )
 {
-    if( IsSet( SBX_NO_MODIFY ) )
+    if( IsSet( SbxFlagBits::NoModify ) )
         return;
     if( b )
-        SetFlag( SBX_MODIFIED );
+        SetFlag( SbxFlagBits::Modified );
     else
-        ResetFlag( SBX_MODIFIED );
+        ResetFlag( SbxFlagBits::Modified );
 }
 
 SbxError SbxBase::GetError()
@@ -105,18 +104,18 @@ SbxError SbxBase::GetError()
 void SbxBase::SetError( SbxError e )
 {
     SbxAppData& r = GetSbxData_Impl();
-    if( e && r.eSbxError == SbxERR_OK )
+    if( e && r.eSbxError == ERRCODE_SBX_OK )
         r.eSbxError = e;
 }
 
 bool SbxBase::IsError()
 {
-    return GetSbxData_Impl().eSbxError != SbxERR_OK;
+    return GetSbxData_Impl().eSbxError != ERRCODE_SBX_OK;
 }
 
 void SbxBase::ResetError()
 {
-    GetSbxData_Impl().eSbxError = SbxERR_OK;
+    GetSbxData_Impl().eSbxError = ERRCODE_SBX_OK;
 }
 
 void SbxBase::AddFactory( SbxFactory* pFac )
@@ -124,25 +123,27 @@ void SbxBase::AddFactory( SbxFactory* pFac )
     SbxAppData& r = GetSbxData_Impl();
 
     // From 1996-03-06: take the HandleLast-Flag into account
-    sal_uInt16 nPos = r.aFacs.size(); // Insert position
+    sal_uInt16 nPos = r.m_Factories.size(); // Insert position
     if( !pFac->IsHandleLast() )         // Only if not self HandleLast
     {
         // Rank new factory in front of factories with HandleLast
-        while( nPos > 0 &&
-                r.aFacs[ nPos-1 ].IsHandleLast() )
+        while (nPos > 0 && r.m_Factories[ nPos-1 ]->IsHandleLast())
             nPos--;
     }
-    r.aFacs.insert( r.aFacs.begin() + nPos, pFac );
+    r.m_Factories.insert(r.m_Factories.begin() + nPos, std::unique_ptr<SbxFactory>(pFac));
 }
 
 void SbxBase::RemoveFactory( SbxFactory* pFac )
 {
     SbxAppData& r = GetSbxData_Impl();
-    for(SbxFacs::iterator it = r.aFacs.begin(); it != r.aFacs.end(); ++it)
+    for (auto it = r.m_Factories.begin(); it != r.m_Factories.end(); ++it)
     {
-        if( &(*it) == pFac )
+        if ((*it).get() == pFac)
         {
-            r.aFacs.release( it ).release(); break;
+            std::unique_ptr<SbxFactory> tmp(std::move(*it));
+            r.m_Factories.erase( it );
+            tmp.release();
+            break;
         }
     }
 }
@@ -156,7 +157,6 @@ SbxBase* SbxBase::Create( sal_uInt16 nSbxId, sal_uInt32 nCreator )
     if( nSbxId == 0x65 )    // Dialog Id
         return new SbxVariable;
 
-    OUString aEmptyStr;
     if( nCreator == SBXCR_SBX )
       switch( nSbxId )
     {
@@ -164,19 +164,19 @@ SbxBase* SbxBase::Create( sal_uInt16 nSbxId, sal_uInt32 nCreator )
         case SBXID_VARIABLE:    return new SbxVariable;
         case SBXID_ARRAY:       return new SbxArray;
         case SBXID_DIMARRAY:    return new SbxDimArray;
-        case SBXID_OBJECT:      return new SbxObject( aEmptyStr );
-        case SBXID_COLLECTION:  return new SbxCollection( aEmptyStr );
+        case SBXID_OBJECT:      return new SbxObject( "" );
+        case SBXID_COLLECTION:  return new SbxCollection( "" );
         case SBXID_FIXCOLLECTION:
-                                return new SbxStdCollection( aEmptyStr, aEmptyStr );
-        case SBXID_METHOD:      return new SbxMethod( aEmptyStr, SbxEMPTY );
-        case SBXID_PROPERTY:    return new SbxProperty( aEmptyStr, SbxEMPTY );
+                                return new SbxStdCollection( "", "" );
+        case SBXID_METHOD:      return new SbxMethod( "", SbxEMPTY );
+        case SBXID_PROPERTY:    return new SbxProperty( "", SbxEMPTY );
     }
     // Unknown type: go over the factories!
     SbxAppData& r = GetSbxData_Impl();
-    SbxBase* pNew = NULL;
-    for( SbxFactory& rFac : r.aFacs )
+    SbxBase* pNew = nullptr;
+    for (auto const& rpFac : r.m_Factories)
     {
-        pNew = rFac.Create( nSbxId, nCreator );
+        pNew = rpFac->Create( nSbxId, nCreator );
         if( pNew )
             break;
     }
@@ -187,10 +187,10 @@ SbxBase* SbxBase::Create( sal_uInt16 nSbxId, sal_uInt32 nCreator )
 SbxObject* SbxBase::CreateObject( const OUString& rClass )
 {
     SbxAppData& r = GetSbxData_Impl();
-    SbxObject* pNew = NULL;
-    for( SbxFactory& rFac : r.aFacs )
+    SbxObject* pNew = nullptr;
+    for (auto const& rpFac : r.m_Factories)
     {
-        pNew = rFac.CreateObject( rClass );
+        pNew = rpFac->CreateObject( rClass );
         if( pNew )
             break;
     }
@@ -206,8 +206,8 @@ SbxBase* SbxBase::Load( SvStream& rStrm )
     SbxFlagBits nFlags = static_cast<SbxFlagBits>(nFlagsTmp);
 
     // Correcting a foolishness of mine:
-    if( (nFlags & SBX_RESERVED) != SBX_NONE )
-        nFlags = ( nFlags & ~SBX_RESERVED ) | SBX_GBLSEARCH;
+    if( nFlags & SbxFlagBits::Reserved )
+        nFlags = ( nFlags & ~SbxFlagBits::Reserved ) | SbxFlagBits::GlobalSearch;
 
     sal_Size nOldPos = rStrm.Tell();
     rStrm.ReadUInt32( nSize );
@@ -226,7 +226,7 @@ SbxBase* SbxBase::Load( SvStream& rStrm )
             {
                 // Deleting of the object
                 SbxBaseRef aRef( p );
-                p = NULL;
+                p = nullptr;
             }
         }
         else
@@ -234,7 +234,7 @@ SbxBase* SbxBase::Load( SvStream& rStrm )
             rStrm.SetError( SVSTREAM_FILEFORMAT_ERROR );
             // Deleting of the object
             SbxBaseRef aRef( p );
-            p = NULL;
+            p = nullptr;
         }
     }
     else
@@ -257,11 +257,11 @@ void SbxBase::Skip( SvStream& rStrm )
 
 bool SbxBase::Store( SvStream& rStrm )
 {
-    if( ( nFlags & SBX_DONTSTORE ) == SBX_NONE )
+    if( ( nFlags & SbxFlagBits::DontStore ) == SbxFlagBits::NONE )
     {
         rStrm.WriteUInt32( GetCreator() )
              .WriteUInt16( GetSbxId() )
-             .WriteUInt16( GetFlags() )
+             .WriteUInt16( static_cast<sal_uInt16>(GetFlags()) )
              .WriteUInt16( GetVersion() );
         sal_Size nOldPos = rStrm.Tell();
         rStrm.WriteUInt32( 0L );
@@ -290,16 +290,6 @@ bool SbxBase::StoreData( SvStream& ) const
     return false;
 }
 
-bool SbxBase::LoadPrivateData( SvStream&, sal_uInt16 )
-{
-    return true;
-}
-
-bool SbxBase::StorePrivateData( SvStream& ) const
-{
-    return true;
-}
-
 bool SbxBase::LoadCompleted()
 {
     return true;
@@ -313,12 +303,12 @@ SbxFactory::~SbxFactory()
 
 SbxBase* SbxFactory::Create( sal_uInt16, sal_uInt32 )
 {
-    return NULL;
+    return nullptr;
 }
 
 SbxObject* SbxFactory::CreateObject( const OUString& )
 {
-    return NULL;
+    return nullptr;
 }
 
 ///////////////////////////////// SbxInfo
@@ -328,20 +318,20 @@ SbxInfo::~SbxInfo()
 
 void SbxInfo::AddParam(const OUString& rName, SbxDataType eType, SbxFlagBits nFlags)
 {
-    aParams.push_back(new SbxParamInfo(rName, eType, nFlags));
+    m_Params.push_back(std::unique_ptr<SbxParamInfo>(new SbxParamInfo(rName, eType, nFlags)));
 }
 
 const SbxParamInfo* SbxInfo::GetParam( sal_uInt16 n ) const
 {
-    if( n < 1 || n > aParams.size() )
-        return NULL;
+    if (n < 1 || n > m_Params.size())
+        return nullptr;
     else
-        return &(aParams[n - 1]);
+        return m_Params[n - 1].get();
 }
 
 bool SbxInfo::LoadData( SvStream& rStrm, sal_uInt16 nVer )
 {
-    aParams.clear();
+    m_Params.clear();
     sal_uInt16 nParam;
     aComment = read_uInt16_lenPrefixed_uInt8s_ToOUString(rStrm,
         RTL_TEXTENCODING_ASCII_US);
@@ -359,7 +349,7 @@ bool SbxInfo::LoadData( SvStream& rStrm, sal_uInt16 nVer )
         if( nVer > 1 )
             rStrm.ReadUInt32( nUserData );
         AddParam( aName, (SbxDataType) nType, nFlags );
-        SbxParamInfo& p(aParams.back());
+        SbxParamInfo& p(*m_Params.back());
         p.nUserData = nUserData;
     }
     return true;
@@ -371,13 +361,13 @@ bool SbxInfo::StoreData( SvStream& rStrm ) const
         RTL_TEXTENCODING_ASCII_US );
     write_uInt16_lenPrefixed_uInt8s_FromOUString(rStrm, aHelpFile,
         RTL_TEXTENCODING_ASCII_US);
-    rStrm.WriteUInt32( nHelpId ).WriteUInt16( aParams.size() );
-    for(SbxParams::const_iterator i = aParams.begin(); i != aParams.end(); ++i)
+    rStrm.WriteUInt32( nHelpId ).WriteUInt16( m_Params.size() );
+    for (auto const& i : m_Params)
     {
         write_uInt16_lenPrefixed_uInt8s_FromOUString(rStrm, i->aName,
             RTL_TEXTENCODING_ASCII_US);
         rStrm.WriteUInt16( i->eType )
-             .WriteUInt16( i->nFlags )
+             .WriteUInt16( static_cast<sal_uInt16>(i->nFlags) )
              .WriteUInt32( i->nUserData );
     }
     return true;
