@@ -36,7 +36,7 @@ public class CallWatchThread extends Thread
 
     public CallWatchThread(long nTimeout)
     {
-        this(nTimeout, "");
+        this(nTimeout, "CallWatchThread");
     }
 
     public CallWatchThread( long nTimeout, String aTag )
@@ -52,7 +52,7 @@ public class CallWatchThread extends Thread
     }
 
     public void cancel()
-        throws java.lang.InterruptedException
+        throws InterruptedException
     {
         dbgPrint( "CallWatchThread(" + this + ".cancel(" + aTag + ")" );
         if ( aWatchedThread != null && aWatchedThread != Thread.currentThread() )
@@ -63,7 +63,7 @@ public class CallWatchThread extends Thread
     }
 
     public synchronized void restart()
-        throws java.lang.InterruptedException
+        throws InterruptedException
     {
         dbgPrint( "CallWatchThread(" + this + ".restart(" + aTag + ")" );
         if ( aWatchedThread != null && aWatchedThread != Thread.currentThread() )
@@ -74,21 +74,22 @@ public class CallWatchThread extends Thread
         notify();
     }
 
+    @Override
     public void run()
     {
         dbgPrint( "CallWatchThread(" + this + ".run(" + aTag + ") ***** STARTED *****" );
         long n = 0;
-        while ( aWatchedThread != null )
+        synchronized(this)
         {
-            dbgPrint( "CallWatchThread(" + this + ").run(" + aTag + ") running #" + ++n );
-            synchronized(this)
+            while ( aWatchedThread != null )
             {
+                dbgPrint( "CallWatchThread(" + this + ").run(" + aTag + ") running #" + ++n );
                 bAlive = false;
                 try
                 {
                     wait( nTimeout );
                 }
-                catch ( java.lang.InterruptedException aExc )
+                catch ( InterruptedException aExc )
                 {
                     bAlive = false;
                 }
