@@ -23,11 +23,9 @@ import com.sun.star.uno.UnoRuntime;
 // @requirement FUNC.PERF.LRN/0.6
 // @requirement FUNC.PERF.LOC/0.6
 // @requirement FUNC.PERF.FIX/0.6
+// @requirement FUNC.RES.OTH/0.2
+// No other resources are needed yet.
 /** This is the basic JavaBean for all OOo application modules.
-
-    @requirement FUNC.RES.OTH/0.2
-        No other resources are needed yet.
-
     @since OOo 2.0.0
  */
 public class OOoBean
@@ -64,7 +62,6 @@ public class OOoBean
     private transient OfficeDocument aDocument;
 
     // slot command execution environment
-    private transient com.sun.star.frame.XDispatchProvider xDispatcher;
     private transient com.sun.star.util.XURLTransformer xURLTransformer;
 
     // properties
@@ -81,7 +78,8 @@ public class OOoBean
     }
 
     // @requirement FUNC.PER/0.2
-    /** @internal
+    // @internal
+    /**
      */
     @Deprecated
     public void writeExternal( java.io.ObjectOutput aObjOut )
@@ -90,7 +88,8 @@ public class OOoBean
     }
 
     // @requirement FUNC.PER/0.2
-    /** @internal
+    // @internal
+    /**
      */
     @Deprecated
     public void readExternal( java.io.ObjectInput aObjIn )
@@ -103,7 +102,9 @@ public class OOoBean
         Neither a connection is established nor any document loaded.
      */
     public OOoBean()
-    {}
+    {
+        setLayout(new java.awt.BorderLayout());
+    }
 
        // @requirement FUNC.CON.MULT/0.3
     /** Constructor for an OOoBean which uses a specific office connection.
@@ -121,6 +122,7 @@ public class OOoBean
     public OOoBean( OfficeConnection iConnection )
         throws NoConnectionException
     {
+        setLayout(new java.awt.BorderLayout());
         try { setOOoConnection( iConnection ); }
         catch ( HasConnectionException aExc )
         { /* impossible here */ }
@@ -153,9 +155,8 @@ public class OOoBean
         nOOoCheckCycle = nMilliSecs;
     }
 
+    // @internal
     /** Sets a connection to an OOo instance.
-
-        @internal
      */
     private synchronized void setOOoConnection(OfficeConnection iNewConnection)
             throws HasConnectionException, NoConnectionException {
@@ -183,7 +184,7 @@ public class OOoBean
     }
 
     // @requirement FUNC.CON.STRT/0.4
-    /** Starts a connection to an OOo instance which is lauched if not running.
+    /** Starts a connection to an OOo instance which is launched if not running.
 
         @throws HasConnectionException
             if a connection was already established.
@@ -389,7 +390,6 @@ public class OOoBean
             }
 
             aDocument = null;
-            xDispatcher = null;
             aFrame = null;
 
             // clear xFrameWindow
@@ -589,14 +589,14 @@ public class OOoBean
                         com.sun.star.util.XURLTransformer.class,
                         xServiceFactory.createInstance( "com.sun.star.util.URLTransformer") );
 
-                                        try
-                                        {
-                                            xDispatcher = UnoRuntime.queryInterface(com.sun.star.frame.XDispatchProvider.class, aFrame);
-                                        }
-                                        catch (Exception e)
-                                        {
-                                            /*ignore!*/
-                                        }
+                    try
+                    {
+                        UnoRuntime.queryInterface(com.sun.star.frame.XDispatchProvider.class, aFrame);
+                    }
+                    catch (Exception e)
+                    {
+                        /*ignore!*/
+                    }
 
                     // get XComponentLoader from frame
                     com.sun.star.frame.XComponentLoader xLoader = UnoRuntime.queryInterface( com.sun.star.frame.XComponentLoader.class, aFrame );
@@ -760,7 +760,7 @@ public class OOoBean
             com.sun.star.lang.IllegalArgumentException,
             com.sun.star.util.CloseVetoException
     {
-        // wrap byte arrray into UNO stream
+        // wrap byte array into UNO stream
         com.sun.star.io.XInputStream xStream =
                 new com.sun.star.lib.uno.adapter.ByteArrayToXInputStreamAdapter(
                     aInBuffer );
@@ -895,7 +895,7 @@ public class OOoBean
             java.io.IOException,
             com.sun.star.lang.IllegalArgumentException
  {
-        // wrap byte arrray into UNO stream
+        // wrap byte array into UNO stream
         com.sun.star.lib.uno.adapter.XOutputStreamToByteArrayAdapter aStream = new com.sun.star.lib.uno.adapter.XOutputStreamToByteArrayAdapter(
                 aOutBuffer);
 
@@ -926,7 +926,7 @@ public class OOoBean
     /** returns the <type scope="com::sun::star::frame">Frame</a>
         of the bean.
 
-        @returns
+        @return
             a Java class which implements all interfaces which the service
         <type scope="com::sun::star::frame">Frame</a> implements.
         Thus, methods can be called directly without queryInterface.
@@ -949,7 +949,7 @@ public class OOoBean
        // @requirement API.SIM.SEAP/0.2
     /** returns the <type scope="com::sun::star::frame::Controller"> of the bean.
 
-        @returns
+        @return
             a Java class which implements all interfaces which the service
         <type scope="com::sun::star::frame">Controller</a> implements.
         Thus, methods can be called directly without queryInterface.
@@ -977,7 +977,7 @@ public class OOoBean
        /** returns the <type scope="com::sun::star::document::OfficeDocument">
         of the bean.
 
-        @returns
+        @return
             a Java class which implements all interfaces which the service
         <type scope="com::sun::star::document">OfficeDocument</a>
         implements.
@@ -1307,11 +1307,6 @@ xLayoutManager.showElement("private:resource/menubar/menubar");
     // Helper Methods / Internal Methods
 
 
-    // general instance intializer
-    {
-        setLayout(new java.awt.BorderLayout());
-    }
-
     @Deprecated
     @Override
     public void paint( java.awt.Graphics aGraphics )
@@ -1354,8 +1349,7 @@ xLayoutManager.showElement("private:resource/menubar/menubar");
             new com.sun.star.beans.PropertyValue[ nNumArgs + 1 ];
 
         // copy current arguments
-        for ( int n = 0; n < nNumArgs; ++n )
-            aExtendedArguments[n] = aArguments[n];
+        System.arraycopy(aArguments, 0, aExtendedArguments, 0, nNumArgs);
 
         // add new argument
         aExtendedArguments[ nNumArgs ] = aArgument;
@@ -1367,10 +1361,9 @@ xLayoutManager.showElement("private:resource/menubar/menubar");
 
     // Helper Classes
 
-
+    // @internal
     /** Helper class to listen on the connection to learn when it dies.
 
-        @internal
      */
     private class EventListener
         extends Thread
