@@ -79,7 +79,7 @@ css::uno::Sequence< sal_Int8 > read(
 }
 
 extern "C" void SAL_CALL request(void * pThreadSpecificData) {
-    assert(pThreadSpecificData != 0);
+    assert(pThreadSpecificData != nullptr);
     std::unique_ptr< IncomingRequest >(
         static_cast< IncomingRequest * >(pThreadSpecificData))->
         execute();
@@ -231,14 +231,14 @@ void Reader::readMessage(Unmarshal & unmarshal) {
         ("superfluous MUSTREPLY/SYNCHRONOUS ignored in request message with"
          " non-oneway function ID"));
     bool synchronous = !oneWay || forceSynchronous;
-    bool setter = false;
+    bool bSetter = false;
     std::vector< BinaryAny > inArgs;
     switch (memberTd.get()->eTypeClass) {
     case typelib_TypeClass_INTERFACE_ATTRIBUTE:
-        setter = itd->pMapMemberIndexToFunctionIndex[memberId] != functionId;
+        bSetter = itd->pMapMemberIndexToFunctionIndex[memberId] != functionId;
             // pMapMemberIndexToFunctionIndex contains function index of
             // attribute getter
-        if (setter) {
+        if (bSetter) {
             inArgs.push_back(
                 unmarshal.readValue(
                     css::uno::TypeDescription(
@@ -309,8 +309,8 @@ void Reader::readMessage(Unmarshal & unmarshal) {
                                           css::uno::XInterface > >::get())))))
                 {
                     throw css::uno::RuntimeException(
-                        "URP: queryInterface request message with unknown OID"
-                        " received");
+                        "URP: queryInterface request message with unknown OID '"
+                        + oid + "' received");
                 }
             }
             break;
@@ -330,7 +330,7 @@ void Reader::readMessage(Unmarshal & unmarshal) {
         std::unique_ptr< IncomingRequest > req(
             new IncomingRequest(
                 bridge_, tid, oid, obj, type, functionId, synchronous, memberTd,
-                setter, inArgs, ccMode, cc));
+                bSetter, inArgs, ccMode, cc));
         if (synchronous) {
             bridge_->incrementActiveCalls();
         }
@@ -359,7 +359,7 @@ void Reader::readReplyMessage(Unmarshal & unmarshal, sal_uInt8 flags1) {
                 ret.getType().get()))
         {
             sal_Int32 n = 0;
-            typelib_TypeDescriptionReference ** p = 0;
+            typelib_TypeDescriptionReference ** p = nullptr;
             switch (req.member.get()->eTypeClass) {
             case typelib_TypeClass_INTERFACE_ATTRIBUTE:
                 {
@@ -386,18 +386,18 @@ void Reader::readReplyMessage(Unmarshal & unmarshal, sal_uInt8 flags1) {
                 assert(false); // this cannot happen
                 break;
             }
-            bool ok = false;
+            bool bOk = false;
             for (sal_Int32 i = 0; i != n; ++i) {
                 if (typelib_typedescriptionreference_isAssignableFrom(
                         p[i],
                         reinterpret_cast< typelib_TypeDescriptionReference * >(
                             ret.getType().get())))
                 {
-                    ok = true;
+                    bOk = true;
                     break;
                 }
             }
-            if (!ok) {
+            if (!bOk) {
                 throw css::uno::RuntimeException(
                     "URP: reply message with bad exception type received");
             }
@@ -443,7 +443,7 @@ void Reader::readReplyMessage(Unmarshal & unmarshal, sal_uInt8 flags1) {
             std::unique_ptr< IncomingReply > resp(
                 new IncomingReply(exc, ret, outArgs));
             uno_threadpool_putJob(
-                bridge_->getThreadPool(), tid.getHandle(), resp.get(), 0,
+                bridge_->getThreadPool(), tid.getHandle(), resp.get(), nullptr,
                 false);
             resp.release();
             break;
