@@ -18,6 +18,7 @@
  */
 
 #include <com/sun/star/uno/genfunc.hxx>
+#include <sal/log.hxx>
 #include <typelib/typedescription.hxx>
 #include <uno/data.h>
 #include "bridges/cpp_uno/shared/bridge.hxx"
@@ -69,7 +70,7 @@ static typelib_TypeClass cpp2uno_call(
     pCppStack += sizeof( void* );
 
     // stack space
-    OSL_ENSURE( sizeof(void *) == sizeof(sal_Int32), "### unexpected size!" );
+    static_assert(sizeof(void *) == sizeof(sal_Int32), "### unexpected size!");
     // parameters
     void ** pUnoArgs = (void **)alloca( 4 * sizeof(void *) * nParams );
     void ** pCppArgs = pUnoArgs + nParams;
@@ -97,7 +98,7 @@ static typelib_TypeClass cpp2uno_call(
                     {
             if ((reinterpret_cast< long >(pCppStack) & 7) != 0)
                       {
-                   OSL_ASSERT( sizeof (double) == sizeof (sal_Int64) );
+                   static_assert(sizeof (double) == sizeof (sal_Int64), "boo");
                            void * pDest = alloca( sizeof (sal_Int64) );
                            *reinterpret_cast< sal_Int32 * >(pDest) =
                            *reinterpret_cast< sal_Int32 const * >(pCppStack);
@@ -222,7 +223,7 @@ static typelib_TypeClass cpp_mediate(
     void ** pCallStack,
     sal_Int64 * pRegisterReturn /* space for register return */ )
 {
-    OSL_ENSURE( sizeof(sal_Int32)==sizeof(void *), "### unexpected!" );
+    static_assert( sizeof(sal_Int32)==sizeof(void *), "### unexpected!" );
 
     // pCallStack: this, params
     // eventual [ret*] lies at pCallStack -1
@@ -240,16 +241,23 @@ static typelib_TypeClass cpp_mediate(
 
     typelib_InterfaceTypeDescription * pTypeDescr = pCppI->getTypeDescr();
 
-    OSL_ENSURE( nFunctionIndex < pTypeDescr->nMapFunctionIndexToMemberIndex,
-                 "### illegal vtable index!" );
     if (nFunctionIndex >= pTypeDescr->nMapFunctionIndexToMemberIndex)
     {
-        throw RuntimeException("illegal vtable index!", (XInterface *)pCppI );
+        SAL_WARN(
+            "bridges",
+            "illegal " << OUString::unacquired(&pTypeDescr->aBase.pTypeName)
+                << " vtable index " << nFunctionIndex << "/"
+                << pTypeDescr->nMapFunctionIndexToMemberIndex);
+        throw RuntimeException(
+            ("illegal " + OUString::unacquired(&pTypeDescr->aBase.pTypeName)
+             + " vtable index " + OUString::number(nFunctionIndex) + "/"
+             + OUString::number(pTypeDescr->nMapFunctionIndexToMemberIndex)),
+            (XInterface *)pCppI);
     }
 
     // determine called method
     sal_Int32 nMemberPos = pTypeDescr->pMapFunctionIndexToMemberIndex[nFunctionIndex];
-    OSL_ENSURE( nMemberPos < pTypeDescr->nAllMembers, "### illegal member index!" );
+    assert(nMemberPos < pTypeDescr->nAllMembers);
 
     TypeDescription aMemberDescr( pTypeDescr->ppAllMembers[nMemberPos] );
 
@@ -433,7 +441,7 @@ unsigned char * codeSnippet(
         index |= 0x80000000;
     }
     unsigned int * p = reinterpret_cast< unsigned int * >(code);
-    OSL_ASSERT(sizeof (unsigned int) == 4);
+    static_assert(sizeof (unsigned int) == 4);
     // st %o0, [%sp+68]:
     *p++ = 0xD023A044;
     // st %o1, [%sp+72]:
@@ -462,8 +470,7 @@ unsigned char * codeSnippet(
     *p++ = 0x81C2C000;
     // mov %sp, %o1:
     *p++ = 0x9210000E;
-    OSL_ASSERT(
-        reinterpret_cast< unsigned char * >(p) - code <= codeSnippetSize);
+    assert(reinterpret_cast< unsigned char * >(p) - code <= codeSnippetSize);
     return code + codeSnippetSize;
 }
 
@@ -485,7 +492,8 @@ sal_Size bridges::cpp_uno::shared::VtableFactory::getBlockSize(
 
 bridges::cpp_uno::shared::VtableFactory::Slot *
 bridges::cpp_uno::shared::VtableFactory::initializeBlock(
-    void * block, sal_Int32 slotCount)
+    void * block, sal_Int32 slotCount, sal_Int32,
+    typelib_InterfaceTypeDescription *)
 {
     Slot * slots = mapBlockToVtable(block);
     slots[-2].fn = 0; //null
@@ -503,7 +511,7 @@ unsigned char * bridges::cpp_uno::shared::VtableFactory::addLocalFunctions(
     for (sal_Int32 i = 0; i < type->nMembers; ++i) {
         typelib_TypeDescription * member = 0;
         TYPELIB_DANGER_GET(&member, type->ppMembers[i]);
-        OSL_ASSERT(member != 0);
+        assert(member != 0);
         switch (member->eTypeClass) {
         case typelib_TypeClass_INTERFACE_ATTRIBUTE:
             // Getter:
@@ -535,7 +543,7 @@ unsigned char * bridges::cpp_uno::shared::VtableFactory::addLocalFunctions(
             break;
 
         default:
-            OSL_ASSERT(false);
+            assert(false);
             break;
         }
         TYPELIB_DANGER_RELEASE(member);
