@@ -34,7 +34,7 @@
 #include "com/sun/star/uno/XComponentContext.hpp"
 #include "com/sun/star/uno/XInterface.hpp"
 #include "cppuhelper/factory.hxx"
-#include "cppuhelper/implbase3.hxx"
+#include "cppuhelper/implbase.hxx"
 #include <cppuhelper/supportsservice.hxx>
 #include "cppuhelper/weak.hxx"
 #include "osl/conditn.hxx"
@@ -46,7 +46,6 @@
 #include "test/javauno/acquire/XDerived.hpp"
 #include "test/javauno/acquire/XTest.hpp"
 #include "uno/environment.h"
-#include "uno/lbnames.h"
 
 #include <iostream>
 #include <cstdlib>
@@ -177,7 +176,7 @@ css::uno::Any Derived::queryInterface(css::uno::Type const & type)
 
 namespace {
 
-class Service: public cppu::WeakImplHelper3<
+class Service: public cppu::WeakImplHelper<
     css::lang::XServiceInfo, css::lang::XMain, test::javauno::acquire::XTest >
 {
 public:
@@ -476,8 +475,7 @@ OUString Service::getImplementationName_static() {
 }
 
 css::uno::Sequence< OUString > Service::getSupportedServiceNames_static() {
-    css::uno::Sequence< OUString > names(1);
-    names[0] = "com.sun.star.test.bridges.testacquire";
+    css::uno::Sequence< OUString > names { "com.sun.star.test.bridges.testacquire" };
     return names;
 }
 
@@ -522,16 +520,16 @@ bool writeInfo(void * registryKey, OUString const & implementationName,
     if (!key.is()) {
         return false;
     }
-    bool success = true;
+    bool bSuccess = true;
     for (sal_Int32 i = 0; i < serviceNames.getLength(); ++i) {
         try {
             key->createKey(serviceNames[i]);
         } catch (css::registry::InvalidRegistryException &) {
-            success = false;
+            bSuccess = false;
             break;
         }
     }
-    return success;
+    return bSuccess;
 }
 
 }
