@@ -17,49 +17,43 @@
  *   the License at http://www.apache.org/licenses/LICENSE-2.0 .
  */
 
+#include <sal/config.h>
 
-#include <canvas/debug.hxx>
-#include <tools/diagnose_ex.h>
-
-#include <rtl/math.hxx>
-
-#include <com/sun/star/rendering/TextDirection.hpp>
-#include <com/sun/star/rendering/TexturingMode.hpp>
-#include <com/sun/star/rendering/PathCapType.hpp>
-#include <com/sun/star/rendering/PathJoinType.hpp>
-
-#include <tools/poly.hxx>
-#include <vcl/window.hxx>
-#include <vcl/bitmapex.hxx>
-#include <vcl/bmpacc.hxx>
-#include <vcl/virdev.hxx>
-#include <vcl/canvastools.hxx>
+#include <boost/tuple/tuple.hpp>
 
 #include <basegfx/matrix/b2dhommatrix.hxx>
-#include <basegfx/range/b2drectangle.hxx>
+#include <basegfx/numeric/ftools.hxx>
 #include <basegfx/point/b2dpoint.hxx>
-#include <basegfx/vector/b2dsize.hxx>
+#include <basegfx/polygon/b2dlinegeometry.hxx>
 #include <basegfx/polygon/b2dpolygon.hxx>
 #include <basegfx/polygon/b2dpolygontools.hxx>
 #include <basegfx/polygon/b2dpolypolygontools.hxx>
-#include <basegfx/polygon/b2dlinegeometry.hxx>
-#include <basegfx/tools/tools.hxx>
-#include <basegfx/tools/lerp.hxx>
-#include <basegfx/tools/keystoplerp.hxx>
+#include <basegfx/range/b2drectangle.hxx>
 #include <basegfx/tools/canvastools.hxx>
-#include <basegfx/numeric/ftools.hxx>
-
+#include <basegfx/tools/keystoplerp.hxx>
+#include <basegfx/tools/lerp.hxx>
+#include <basegfx/tools/tools.hxx>
+#include <basegfx/vector/b2dsize.hxx>
+#include <com/sun/star/rendering/PathCapType.hpp>
+#include <com/sun/star/rendering/PathJoinType.hpp>
+#include <com/sun/star/rendering/TextDirection.hpp>
+#include <com/sun/star/rendering/TexturingMode.hpp>
 #include <comphelper/sequence.hxx>
+#include <rtl/math.hxx>
+#include <tools/diagnose_ex.h>
+#include <tools/poly.hxx>
+#include <vcl/bitmapex.hxx>
+#include <vcl/bmpacc.hxx>
+#include <vcl/canvastools.hxx>
+#include <vcl/virdev.hxx>
+#include <vcl/window.hxx>
 
 #include <canvas/canvastools.hxx>
 #include <canvas/parametricpolypolygon.hxx>
 
-#include <boost/bind.hpp>
-#include <boost/tuple/tuple.hpp>
-
-#include "spritecanvas.hxx"
 #include "canvashelper.hxx"
 #include "impltools.hxx"
+#include "spritecanvas.hxx"
 
 
 using namespace ::com::sun::star;
@@ -91,10 +85,10 @@ namespace vclcanvas
                 {
                     // update return value. This method should return true, if
                     // at least one of the looped Draws succeeded.
-                    bRet |= ( sal_True == rGraphic.Draw( &rOutDev,
+                    bRet |= rGraphic.Draw( &rOutDev,
                                            aCurrPos,
                                            rTileSize,
-                                           &rAttr ) );
+                                           &rAttr );
 
                     aCurrPos.X() += rNextTileX.Width();
                     aCurrPos.Y() += rNextTileX.Height();
@@ -133,8 +127,8 @@ namespace vclcanvas
 
             // calc length of bound rect diagonal
             const ::basegfx::B2DVector aBoundRectDiagonal(
-                ::vcl::unotools::b2DPointFromPoint( rBounds.TopLeft() ) -
-                ::vcl::unotools::b2DPointFromPoint( rBounds.BottomRight() ) );
+                vcl::unotools::b2DPointFromPoint( rBounds.TopLeft() ) -
+                vcl::unotools::b2DPointFromPoint( rBounds.BottomRight() ) );
             const double nDiagonalLength( aBoundRectDiagonal.getLength() );
 
             // create direction of gradient:
@@ -153,7 +147,7 @@ namespace vclcanvas
                                                              aLeftBottom,
                                                              aRightTop,
                                                              aRightBottom,
-                                                             ::vcl::unotools::b2DRectangleFromRectangle( rBounds ) );
+                                                             vcl::unotools::b2DRectangleFromRectangle( rBounds ) );
 
 
             // render gradient
@@ -168,7 +162,7 @@ namespace vclcanvas
             // vertex values in the loop below (as ::Polygon is a
             // pimpl class, creating one every loop turn would really
             // stress the mem allocator)
-            ::Polygon aTempPoly( static_cast<sal_uInt16>(5) );
+            ::tools::Polygon aTempPoly( static_cast<sal_uInt16>(5) );
 
             OSL_ENSURE( nStepCount >= 3,
                         "fillLinearGradient(): stepcount smaller than 3" );
@@ -176,7 +170,7 @@ namespace vclcanvas
 
             // fill initial strip (extending two times the bound rect's
             // diagonal to the 'left'
-            // ------------------------------------------------------
+
 
             // calculate left edge, by moving left edge of the
             // gradient rect two times the bound rect's diagonal to
@@ -193,7 +187,7 @@ namespace vclcanvas
 
 
             // iteratively render all other strips
-            // -----------------------------------
+
 
             // ensure that nStepCount matches color stop parity, to
             // have a well-defined middle color e.g. for axial
@@ -245,7 +239,7 @@ namespace vclcanvas
 
             // fill final strip (extending two times the bound rect's
             // diagonal to the 'right'
-            // ------------------------------------------------------
+
 
             // copy right egde of polygon to left edge (and also
             // copy the closing point)
@@ -306,13 +300,13 @@ namespace vclcanvas
 
 
             // apply scaling (possibly anisotrophic) to inner polygon
-            // ------------------------------------------------------
+
 
             // scale inner polygon according to aspect ratio: for
             // wider-than-tall bounds (nAspectRatio > 1.0), the inner
             // polygon, representing the gradient focus, must have
             // non-zero width. Specifically, a bound rect twice as wide as
-            // tall has a focus polygon of half it's width.
+            // tall has a focus polygon of half its width.
             const double nAspectRatio( rValues.mnAspectRatio );
             if( nAspectRatio > 1.0 )
             {
@@ -340,19 +334,19 @@ namespace vclcanvas
 
 
             const sal_uInt32 nNumPoints( aOuterPoly.count() );
-            ::Polygon        aTempPoly( static_cast<sal_uInt16>(nNumPoints+1) );
+            ::tools::Polygon aTempPoly( static_cast<sal_uInt16>(nNumPoints+1) );
 
             // increase number of steps by one: polygonal gradients have
             // the outermost polygon rendered in rColor2, and the
             // innermost in rColor1. The innermost polygon will never
             // have zero area, thus, we must divide the interval into
             // nStepCount+1 steps. For example, to create 3 steps:
-            //
+
             // |                       |
             // |-------|-------|-------|
             // |                       |
             // 3       2       1       0
-            //
+
             // This yields 4 tick marks, where 0 is never attained (since
             // zero-area polygons typically don't display perceivable
             // color).
@@ -417,8 +411,8 @@ namespace vclcanvas
                 // here, keep it all the way and only change the vertex values
                 // in the loop below (as ::Polygon is a pimpl class, creating
                 // one every loop turn would really stress the mem allocator)
-                ::PolyPolygon           aTempPolyPoly;
-                ::Polygon               aTempPoly2( static_cast<sal_uInt16>(nNumPoints+1) );
+                ::tools::PolyPolygon aTempPolyPoly;
+                ::tools::Polygon aTempPoly2( static_cast<sal_uInt16>(nNumPoints+1) );
 
                 aTempPoly2[0] = rBounds.TopLeft();
                 aTempPoly2[1] = rBounds.TopRight();
@@ -540,7 +534,7 @@ namespace vclcanvas
                            OutputDevice*                                   p2ndOutDev,
                            const ::canvas::ParametricPolyPolygon::Values&  rValues,
                            const std::vector< ::Color >&                   rColors,
-                           const PolyPolygon&                              rPoly,
+                           const ::tools::PolyPolygon&                     rPoly,
                            const rendering::ViewState&                     viewState,
                            const rendering::RenderState&                   renderState,
                            const rendering::Texture&                       texture,
@@ -552,7 +546,7 @@ namespace vclcanvas
             // mutex.
 
             // calc step size
-            // --------------
+
             int nColorSteps = 0;
             for( size_t i=0; i<rColors.size()-1; ++i )
                 nColorSteps += numColorSteps(rColors[i],rColors[i+1]);
@@ -575,16 +569,16 @@ namespace vclcanvas
             if( tools::isRectangle( rPoly ) )
             {
                 // use optimized output path
-                // -------------------------
+
 
                 // this distinction really looks like a
-                // micro-optimisation, but in fact greatly speeds up
+                // micro-optimization, but in fact greatly speeds up
                 // especially complex gradients. That's because when using
                 // clipping, we can output polygons instead of
                 // poly-polygons, and don't have to output the gradient
                 // twice for XOR
 
-                rOutDev.Push( PUSH_CLIPREGION );
+                rOutDev.Push( PushFlags::CLIPREGION );
                 rOutDev.IntersectClipRegion( aPolygonDeviceRectOrig );
                 doGradientFill( rOutDev,
                                 rValues,
@@ -607,9 +601,9 @@ namespace vclcanvas
             }
             else
             {
-                const Region aPolyClipRegion( rPoly );
+                const vcl::Region aPolyClipRegion( rPoly );
 
-                rOutDev.Push( PUSH_CLIPREGION );
+                rOutDev.Push( PushFlags::CLIPREGION );
                 rOutDev.SetClipRegion( aPolyClipRegion );
 
                 doGradientFill( rOutDev,
@@ -643,14 +637,14 @@ namespace vclcanvas
                                                             aTextureTransform );
                 rOutDev.SetLineColor( COL_RED );
                 rOutDev.SetFillColor();
-                rOutDev.DrawRect( ::vcl::unotools::rectangleFromB2DRectangle( aTextureDeviceRect ) );
+                rOutDev.DrawRect( vcl::unotools::rectangleFromB2DRectangle( aTextureDeviceRect ) );
 
                 rOutDev.SetLineColor( COL_BLUE );
-                ::Polygon aPoly1(
-                    ::vcl::unotools::rectangleFromB2DRectangle( aRect ));
+                ::tools::Polygon aPoly1(
+                    vcl::unotools::rectangleFromB2DRectangle( aRect ));
                 ::basegfx::B2DPolygon aPoly2( aPoly1.getB2DPolygon() );
                 aPoly2.transform( aTextureTransform );
-                ::Polygon aPoly3( aPoly2 );
+                ::tools::Polygon aPoly3( aPoly2 );
                 rOutDev.DrawPolygon( aPoly3 );
             }
 #endif
@@ -675,7 +669,7 @@ namespace vclcanvas
             tools::OutDevStateKeeper aStateKeeper( mpProtectedOutDev );
 
             const int nTransparency( setupOutDevState( viewState, renderState, IGNORE_COLOR ) );
-            PolyPolygon aPolyPoly( tools::mapPolyPolygon(
+            ::tools::PolyPolygon aPolyPoly( tools::mapPolyPolygon(
                                        ::basegfx::unotools::b2DPolyPolygonFromXPolyPolygon2D(xPolyPolygon),
                                        viewState, renderState ) );
 
@@ -706,14 +700,14 @@ namespace vclcanvas
                         std::transform(&rValues.maColors[0],
                                        &rValues.maColors[0]+rValues.maColors.getLength(),
                                        aColors.begin(),
-                                       boost::bind(
-                                           &vcl::unotools::stdColorSpaceSequenceToColor,
-                                           _1));
+                                       [](const uno::Sequence< double >& aColor) {
+                                           return vcl::unotools::stdColorSpaceSequenceToColor( aColor );
+                                       } );
 
                         // TODO(E1): Return value
                         // TODO(F1): FillRule
                         gradientFill( mpOutDev->getOutDev(),
-                                      mp2ndOutDev.get() ? &mp2ndOutDev->getOutDev() : (OutputDevice*)NULL,
+                                      mp2ndOutDev.get() ? &mp2ndOutDev->getOutDev() : nullptr,
                                       rValues,
                                       aColors,
                                       aPolyPoly,
@@ -767,7 +761,7 @@ namespace vclcanvas
                                                             aTotalTransform );
 
                 const ::Rectangle aIntegerTextureDeviceRect(
-                    ::vcl::unotools::rectangleFromB2DRectangle( aTextureDeviceRect ) );
+                    vcl::unotools::rectangleFromB2DRectangle( aTextureDeviceRect ) );
 
                 if( bRectangularPolygon &&
                     aIntegerTextureDeviceRect == aPolygonDeviceRect )
@@ -852,8 +846,8 @@ namespace vclcanvas
 
                         // setup GraphicAttr
                         aGrfAttr.SetMirrorFlags(
-                            ( aScale.getX() < 0.0 ? BMP_MIRROR_HORZ : 0 ) |
-                            ( aScale.getY() < 0.0 ? BMP_MIRROR_VERT : 0 ) );
+                            ( aScale.getX() < 0.0 ? BmpMirrorFlags::Horizontal : BmpMirrorFlags::NONE ) |
+                            ( aScale.getY() < 0.0 ? BmpMirrorFlags::Vertical : BmpMirrorFlags::NONE ) );
                         aGrfAttr.SetRotation( static_cast< sal_uInt16 >(::basegfx::fround( nRotate*10.0 )) );
 
                         pGrfObj.reset( new GraphicObject( aBmpEx ) );
@@ -911,7 +905,7 @@ namespace vclcanvas
                     // start point from it.
                     ::basegfx::B2DRectangle aTextureSpacePolygonRect;
                     ::canvas::tools::calcTransformedRectBounds( aTextureSpacePolygonRect,
-                                                                ::vcl::unotools::b2DRectangleFromRectangle(
+                                                                vcl::unotools::b2DRectangleFromRectangle(
                                                                     aPolygonDeviceRect ),
                                                                 aInverseTextureTransform );
 
@@ -939,12 +933,12 @@ namespace vclcanvas
                                                                 aSingleTextureRect,
                                                                 aPureTotalTransform );
 
-                    const ::Point aPtRepeat( ::vcl::unotools::pointFromB2DPoint(
+                    const ::Point aPtRepeat( vcl::unotools::pointFromB2DPoint(
                                                  aSingleDeviceTextureRect.getMinimum() ) );
                     const ::Size  aSz( ::basegfx::fround( aScale.getX() * aBmpSize.Width ),
                                        ::basegfx::fround( aScale.getY() * aBmpSize.Height ) );
-                    const ::Size  aIntegerNextTileX( ::vcl::unotools::sizeFromB2DSize(aNextTileX) );
-                    const ::Size  aIntegerNextTileY( ::vcl::unotools::sizeFromB2DSize(aNextTileY) );
+                    const ::Size  aIntegerNextTileX( vcl::unotools::sizeFromB2DSize(aNextTileX) );
+                    const ::Size  aIntegerNextTileY( vcl::unotools::sizeFromB2DSize(aNextTileY) );
 
                     const ::Point aPt( textures[0].RepeatModeX == rendering::TexturingMode::NONE ?
                                        ::basegfx::fround( aOutputPos.getX() ) : aPtRepeat.X(),
@@ -960,10 +954,10 @@ namespace vclcanvas
                     if( bRectangularPolygon )
                     {
                         // use optimized output path
-                        // -------------------------
+
 
                         // this distinction really looks like a
-                        // micro-optimisation, but in fact greatly speeds up
+                        // micro-optimization, but in fact greatly speeds up
                         // especially complex fills. That's because when using
                         // clipping, we can output polygons instead of
                         // poly-polygons, and don't have to output the gradient
@@ -1026,18 +1020,18 @@ namespace vclcanvas
                             // cannot do direct XOR, but have to
                             // prepare the filled polygon within a
                             // VDev
-                            VirtualDevice aVDev( rOutDev );
-                            aVDev.SetOutputSizePixel( aPolygonDeviceRect.GetSize() );
+                            ScopedVclPtrInstance< VirtualDevice > pVDev( rOutDev );
+                            pVDev->SetOutputSizePixel( aPolygonDeviceRect.GetSize() );
 
                             // shift output to origin of VDev
                             const ::Point aOutPos( aPt - aPolygonDeviceRect.TopLeft() );
                             aPolyPoly.Translate( ::Point( -aPolygonDeviceRect.Left(),
                                                           -aPolygonDeviceRect.Top() ) );
 
-                            const Region aPolyClipRegion( aPolyPoly );
+                            const vcl::Region aPolyClipRegion( aPolyPoly );
 
-                            aVDev.SetClipRegion( aPolyClipRegion );
-                            textureFill( aVDev,
+                            pVDev->SetClipRegion( aPolyClipRegion );
+                            textureFill( *pVDev.get(),
                                          *pGrfObj,
                                          aOutPos,
                                          aIntegerNextTileX,
@@ -1051,12 +1045,12 @@ namespace vclcanvas
                             // target position.
                             const ::Point aEmptyPoint;
                             Bitmap aContentBmp(
-                                aVDev.GetBitmap( aEmptyPoint,
-                                                 aVDev.GetOutputSizePixel() ) );
+                                pVDev->GetBitmap( aEmptyPoint,
+                                                 pVDev->GetOutputSizePixel() ) );
 
                             sal_uInt8 nCol( static_cast< sal_uInt8 >(
                                            ::basegfx::fround( 255.0*( 1.0 - textures[0].Alpha ) ) ) );
-                            AlphaMask aAlpha( aVDev.GetOutputSizePixel(),
+                            AlphaMask aAlpha( pVDev->GetOutputSizePixel(),
                                               &nCol );
 
                             BitmapEx aOutputBmpEx( aContentBmp, aAlpha );
@@ -1069,9 +1063,9 @@ namespace vclcanvas
                         }
                         else
                         {
-                            const Region aPolyClipRegion( aPolyPoly );
+                            const vcl::Region aPolyClipRegion( aPolyPoly );
 
-                            rOutDev.Push( PUSH_CLIPREGION );
+                            rOutDev.Push( PushFlags::CLIPREGION );
                             rOutDev.SetClipRegion( aPolyClipRegion );
 
                             textureFill( rOutDev,
@@ -1088,7 +1082,7 @@ namespace vclcanvas
                             if( mp2ndOutDev )
                             {
                                 OutputDevice& r2ndOutDev( mp2ndOutDev->getOutDev() );
-                                r2ndOutDev.Push( PUSH_CLIPREGION );
+                                r2ndOutDev.Push( PushFlags::CLIPREGION );
 
                                 r2ndOutDev.SetClipRegion( aPolyClipRegion );
                                 textureFill( r2ndOutDev,
@@ -1109,7 +1103,7 @@ namespace vclcanvas
         }
 
         // TODO(P1): Provide caching here.
-        return uno::Reference< rendering::XCachedPrimitive >(NULL);
+        return uno::Reference< rendering::XCachedPrimitive >(nullptr);
     }
 
 }
