@@ -23,8 +23,10 @@
 #include "DiagramHelper.hxx"
 #include "servicenames_charttypes.hxx"
 #include "ContainerHelper.hxx"
+#include <cppuhelper/supportsservice.hxx>
 #include <com/sun/star/chart2/XChartType.hpp>
 #include <com/sun/star/chart2/XDataSeriesContainer.hpp>
+#include <comphelper/sequence.hxx>
 
 #include "LinePropertiesHelper.hxx"
 #include "FillProperties.hxx"
@@ -52,7 +54,7 @@ struct StaticUpDownBarWrapperPropertyArray_Initializer
     }
 
 private:
-    Sequence< Property > lcl_GetPropertySequence()
+    static Sequence< Property > lcl_GetPropertySequence()
     {
         ::std::vector< ::com::sun::star::beans::Property > aProperties;
 
@@ -63,7 +65,7 @@ private:
         ::std::sort( aProperties.begin(), aProperties.end(),
                      ::chart::PropertyNameLess() );
 
-        return ::chart::ContainerHelper::ContainerToSequence( aProperties );
+        return comphelper::containerToSequence( aProperties );
     }
 };
 
@@ -107,7 +109,7 @@ struct StaticUpDownBarWrapperDefaults_Initializer
         return &aStaticDefaults;
     }
 private:
-    void lcl_AddDefaultsToMap( ::chart::tPropertyValueMap & rOutMap )
+    static void lcl_AddDefaultsToMap( ::chart::tPropertyValueMap & rOutMap )
     {
         ::chart::LinePropertiesHelper::AddDefaultsToMap( rOutMap );
         ::chart::FillProperties::AddDefaultsToMap( rOutMap );
@@ -126,7 +128,7 @@ namespace wrapper
 {
 
 UpDownBarWrapper::UpDownBarWrapper(
-    bool bUp, ::boost::shared_ptr< Chart2ModelContact > spChart2ModelContact )
+    bool bUp, std::shared_ptr< Chart2ModelContact > spChart2ModelContact )
         : m_spChart2ModelContact( spChart2ModelContact )
         , m_aEventListenerContainer( m_aMutex )
         , m_aPropertySetName( bUp ? OUString( "WhiteDay" ) : OUString( "BlackDay" ))
@@ -173,14 +175,14 @@ uno::Reference< beans::XPropertySetInfo > SAL_CALL UpDownBarWrapper::getProperty
 void SAL_CALL UpDownBarWrapper::setPropertyValue( const OUString& rPropertyName, const uno::Any& rValue )
                     throw (beans::UnknownPropertyException, beans::PropertyVetoException, lang::IllegalArgumentException, lang::WrappedTargetException, uno::RuntimeException, std::exception)
 {
-    Reference< beans::XPropertySet > xPropSet(0);
+    Reference< beans::XPropertySet > xPropSet(nullptr);
 
     Sequence< Reference< chart2::XChartType > > aTypes(
             ::chart::DiagramHelper::getChartTypesFromDiagram( m_spChart2ModelContact->getChart2Diagram() ) );
     for( sal_Int32 nN = 0; nN < aTypes.getLength(); nN++ )
     {
         Reference< chart2::XChartType > xType( aTypes[nN] );
-        if( xType->getChartType().equals(CHART2_SERVICE_NAME_CHARTTYPE_CANDLESTICK) )
+        if( xType->getChartType() == CHART2_SERVICE_NAME_CHARTTYPE_CANDLESTICK )
         {
             Reference< beans::XPropertySet > xTypeProps( aTypes[nN], uno::UNO_QUERY );
             if(xTypeProps.is())
@@ -197,14 +199,14 @@ uno::Any SAL_CALL UpDownBarWrapper::getPropertyValue( const OUString& rPropertyN
 {
     Any aRet;
 
-    Reference< beans::XPropertySet > xPropSet(0);
+    Reference< beans::XPropertySet > xPropSet(nullptr);
 
     Sequence< Reference< chart2::XChartType > > aTypes(
             ::chart::DiagramHelper::getChartTypesFromDiagram( m_spChart2ModelContact->getChart2Diagram() ) );
     for( sal_Int32 nN = 0; nN < aTypes.getLength(); nN++ )
     {
         Reference< chart2::XChartType > xType( aTypes[nN] );
-        if( xType->getChartType().equals(CHART2_SERVICE_NAME_CHARTTYPE_CANDLESTICK) )
+        if( xType->getChartType() == CHART2_SERVICE_NAME_CHARTTYPE_CANDLESTICK )
         {
             Reference< beans::XPropertySet > xTypeProps( aTypes[nN], uno::UNO_QUERY );
             if(xTypeProps.is())
@@ -382,7 +384,28 @@ Sequence< OUString > UpDownBarWrapper::getSupportedServiceNames_Static()
 }
 
 // implement XServiceInfo methods basing upon getSupportedServiceNames_Static
-APPHELPER_XSERVICEINFO_IMPL( UpDownBarWrapper, OUString(lcl_aServiceName) );
+OUString SAL_CALL UpDownBarWrapper::getImplementationName()
+    throw( css::uno::RuntimeException, std::exception )
+{
+    return getImplementationName_Static();
+}
+
+OUString UpDownBarWrapper::getImplementationName_Static()
+{
+    return OUString(lcl_aServiceName);
+}
+
+sal_Bool SAL_CALL UpDownBarWrapper::supportsService( const OUString& rServiceName )
+    throw( css::uno::RuntimeException, std::exception )
+{
+    return cppu::supportsService(this, rServiceName);
+}
+
+css::uno::Sequence< OUString > SAL_CALL UpDownBarWrapper::getSupportedServiceNames()
+    throw( css::uno::RuntimeException, std::exception )
+{
+    return getSupportedServiceNames_Static();
+}
 
 } //  namespace wrapper
 } //  namespace chart
