@@ -32,6 +32,7 @@
 #include "ExplicitCategoriesProvider.hxx"
 
 #include "ChartModel.hxx"
+#include <unonames.hxx>
 
 #include <com/sun/star/container/XIndexReplace.hpp>
 #include <com/sun/star/chart2/XAxis.hpp>
@@ -59,8 +60,10 @@ using namespace ::com::sun::star;
 using ::com::sun::star::uno::Reference;
 using ::com::sun::star::uno::Sequence;
 
-namespace
-{
+namespace chart {
+
+namespace {
+
 OUString lcl_getRole(
     const Reference< chart2::data::XDataSequence > & xSeq )
 {
@@ -80,21 +83,12 @@ OUString lcl_getRole(
     return aResult;
 }
 
-OUString lcl_getRole(
-    const Reference< chart2::data::XLabeledDataSequence > & xLSeq )
-{
-    OUString aResult;
-    if( xLSeq.is())
-        aResult = lcl_getRole( xLSeq->getValues());
-    return aResult;
-}
-
 OUString lcl_getUIRoleName(
     const Reference< chart2::data::XLabeledDataSequence > & xLSeq )
 {
-    OUString aResult( lcl_getRole( xLSeq ));
+    OUString aResult = DataSeriesHelper::getRole(xLSeq);
     if( !aResult.isEmpty())
-        aResult = ::chart::DialogModel::ConvertRoleFromInternalToUI( aResult );
+        aResult = DialogModel::ConvertRoleFromInternalToUI(aResult);
     return aResult;
 }
 
@@ -121,8 +115,7 @@ bool lcl_SequenceOfSeriesIsShared(
         Reference< chart2::data::XDataSource > xSource( xSeries, uno::UNO_QUERY_THROW );
         Sequence< Reference< chart2::data::XLabeledDataSequence > > aLSeq( xSource->getDataSequences());
         for( sal_Int32 i=0; i<aLSeq.getLength(); ++i )
-            if( aLSeq[i].is() &&
-                lcl_getRole( aLSeq[i] ).equals( aValuesRole ))
+            if (aLSeq[i].is() && DataSeriesHelper::getRole(aLSeq[i]).equals(aValuesRole))
             {
                 // getValues().is(), because lcl_getRole checked that already
                 bResult = (aValuesRep == aLSeq[i]->getValues()->getSourceRangeRepresentation());
@@ -185,16 +178,17 @@ sal_Int32 lcl_getValuesRepresentationIndex(
 
 struct lcl_RepresentationsOfLSeqMatch : public ::std::unary_function< Reference< chart2::data::XLabeledDataSequence >, bool >
 {
-    lcl_RepresentationsOfLSeqMatch( const Reference< chart2::data::XLabeledDataSequence > & xLSeq ) :
+    explicit lcl_RepresentationsOfLSeqMatch( const Reference< chart2::data::XLabeledDataSequence > & xLSeq ) :
             m_aValuesRep( xLSeq.is() ?
                           (xLSeq->getValues().is() ? xLSeq->getValues()->getSourceRangeRepresentation() : OUString())
                           : OUString() )
     {}
     bool operator() ( const Reference< chart2::data::XLabeledDataSequence > & xLSeq )
     {
-        return (xLSeq.is() &&
-                xLSeq->getValues().is() &&
-                (xLSeq->getValues()->getSourceRangeRepresentation() == m_aValuesRep ));
+        if (!xLSeq.is() || !xLSeq->getValues().is())
+            return false;
+
+        return xLSeq->getValues()->getSourceRangeRepresentation() == m_aValuesRep;
     }
 private:
     OUString m_aValuesRep;
@@ -202,54 +196,41 @@ private:
 
 struct lcl_RolesOfLSeqMatch : public ::std::unary_function< Reference< chart2::data::XLabeledDataSequence >, bool >
 {
-    lcl_RolesOfLSeqMatch( const Reference< chart2::data::XLabeledDataSequence > & xLSeq ) :
-            m_aRole( lcl_getRole( xLSeq ))
-    {}
+    explicit lcl_RolesOfLSeqMatch( const Reference< chart2::data::XLabeledDataSequence > & xLSeq ) :
+        m_aRole(DataSeriesHelper::getRole(xLSeq)) {}
+
     bool operator() ( const Reference< chart2::data::XLabeledDataSequence > & xLSeq )
     {
-        return lcl_getRole( xLSeq ).equals( m_aRole );
+        return DataSeriesHelper::getRole(xLSeq).equals(m_aRole);
     }
 private:
     OUString m_aRole;
 };
 
-bool lcl_ShowCategories( const Reference< chart2::XDiagram > & /* xDiagram */ )
-{
-    // show categories for all charts
-    return true;
-}
-
 bool lcl_ShowCategoriesAsDataLabel( const Reference< chart2::XDiagram > & xDiagram )
 {
-    return ! ::chart::DiagramHelper::isCategoryDiagram( xDiagram );
+    return !DiagramHelper::isCategoryDiagram(xDiagram);
 }
 
 } // anonymous namespace
 
-namespace chart
-{
-
 struct DataBrowserModel::tDataColumn
 {
-    ::com::sun::star::uno::Reference<
-            ::com::sun::star::chart2::XDataSeries >                m_xDataSeries;
-    sal_Int32                                                      m_nIndexInDataSeries;
-    OUString                                                       m_aUIRoleName;
-    ::com::sun::star::uno::Reference<
-            ::com::sun::star::chart2::data::XLabeledDataSequence > m_xLabeledDataSequence;
-    eCellType                                                  m_eCellType;
-    sal_Int32                                                  m_nNumberFormatKey;
+    uno::Reference<chart2::XDataSeries>  m_xDataSeries;
+    sal_Int32                            m_nIndexInDataSeries;
+    OUString                             m_aUIRoleName;
+    uno::Reference<chart2::data::XLabeledDataSequence> m_xLabeledDataSequence;
+    eCellType                                          m_eCellType;
+    sal_Int32                                          m_nNumberFormatKey;
 
     // default CTOR
     tDataColumn() : m_nIndexInDataSeries( -1 ), m_eCellType( TEXT ), m_nNumberFormatKey( 0 ) {}
     // "full" CTOR
     tDataColumn(
-        const ::com::sun::star::uno::Reference<
-        ::com::sun::star::chart2::XDataSeries > & xDataSeries,
+        const uno::Reference<chart2::XDataSeries> & xDataSeries,
         sal_Int32 nIndexInDataSeries,
-        OUString aUIRoleName,
-        ::com::sun::star::uno::Reference<
-        ::com::sun::star::chart2::data::XLabeledDataSequence >  xLabeledDataSequence,
+        const OUString& aUIRoleName,
+        const uno::Reference<chart2::data::XLabeledDataSequence>& xLabeledDataSequence,
         eCellType aCellType,
         sal_Int32 nNumberFormatKey ) :
             m_xDataSeries( xDataSeries ),
@@ -268,8 +249,8 @@ struct DataBrowserModel::implColumnLess : public ::std::binary_function<
     {
         if( rLeft.m_xLabeledDataSequence.is() && rRight.m_xLabeledDataSequence.is())
         {
-            return DialogModel::GetRoleIndexForSorting( lcl_getRole( rLeft.m_xLabeledDataSequence )) <
-                DialogModel::GetRoleIndexForSorting( lcl_getRole( rRight.m_xLabeledDataSequence ));
+            return DialogModel::GetRoleIndexForSorting(DataSeriesHelper::getRole(rLeft.m_xLabeledDataSequence)) <
+                DialogModel::GetRoleIndexForSorting(DataSeriesHelper::getRole(rRight.m_xLabeledDataSequence));
         }
         return true;
     }
@@ -292,7 +273,7 @@ namespace
 {
 struct lcl_DataSeriesOfHeaderMatches : public ::std::unary_function< ::chart::DataBrowserModel::tDataHeader, bool >
 {
-    lcl_DataSeriesOfHeaderMatches(
+    explicit lcl_DataSeriesOfHeaderMatches(
         const Reference< chart2::XDataSeries > & xSeriesToCompareWith ) :
             m_xSeries( xSeriesToCompareWith )
     {}
@@ -310,106 +291,118 @@ void DataBrowserModel::insertDataSeries( sal_Int32 nAfterColumnIndex )
     OSL_ASSERT( m_apDialogModel.get());
     Reference< chart2::XInternalDataProvider > xDataProvider(
         m_apDialogModel->getDataProvider(), uno::UNO_QUERY );
-    if( xDataProvider.is())
+
+    if (!xDataProvider.is())
+        return;
+
+    if( isCategoriesColumn(nAfterColumnIndex) )
+        // Move to the last category column.
+        nAfterColumnIndex = getCategoryColumnCount()-1;
+
+    sal_Int32 nStartCol = 0;
+    Reference<chart2::XDiagram> xDiagram = ChartModelHelper::findDiagram(m_xChartDocument);
+    Reference<chart2::XChartType> xChartType;
+    Reference<chart2::XDataSeries> xSeries;
+    if (static_cast<size_t>(nAfterColumnIndex) < m_aColumns.size())
+        // Get the data series at specific column position (if available).
+        xSeries.set( m_aColumns[nAfterColumnIndex].m_xDataSeries );
+
+    sal_Int32 nSeriesNumberFormat = 0;
+    if( xSeries.is())
     {
-        if( isCategoriesColumn(nAfterColumnIndex) )
-            nAfterColumnIndex = getCategoryColumnCount()-1;
+        // Use the chart type of the currently selected data series.
+        xChartType.set( DiagramHelper::getChartTypeOfSeries( xDiagram, xSeries ));
 
-        sal_Int32 nStartCol = 0;
-        Reference< chart2::XDiagram > xDiagram( ChartModelHelper::findDiagram( m_xChartDocument ));
-        Reference< chart2::XChartType > xChartType;
-        Reference< chart2::XDataSeries > xSeries;
-        if( static_cast< tDataColumnVector::size_type >( nAfterColumnIndex ) <= m_aColumns.size())
-            xSeries.set( m_aColumns[nAfterColumnIndex].m_xDataSeries );
+        // Find the corresponding header and determine the last column of this
+        // data series.
+        tDataHeaderVector::const_iterator aIt(
+            ::std::find_if( m_aHeaders.begin(), m_aHeaders.end(),
+                            lcl_DataSeriesOfHeaderMatches( xSeries )));
+        if( aIt != m_aHeaders.end())
+            nStartCol = aIt->m_nEndColumn;
 
-        sal_Int32 nSeriesNumberFormat = 0;
-        if( xSeries.is())
+        // Get the number format too.
+        Reference< beans::XPropertySet > xSeriesProps( xSeries, uno::UNO_QUERY );
+        if( xSeriesProps.is() )
+            xSeriesProps->getPropertyValue(CHART_UNONAME_NUMFMT) >>= nSeriesNumberFormat;
+    }
+    else
+    {
+        // No data series at specified column position. Use the first chart type.
+        xChartType.set( DiagramHelper::getChartTypeByIndex( xDiagram, 0 ));
+        nStartCol = nAfterColumnIndex;
+    }
+
+    if (!xChartType.is())
+        return;
+
+    // Get shared sequences of current series.  Normally multiple data series
+    // only share "values-x" sequences. (TODO: simplify this logic).
+    Reference< chart2::XDataSeriesContainer > xSeriesCnt( xChartType, uno::UNO_QUERY );
+    lcl_tSharedSeqVec aSharedSequences;
+    if( xSeriesCnt.is())
+        aSharedSequences = lcl_getSharedSequences( xSeriesCnt->getDataSeries());
+
+    Reference<chart2::XDataSeries> xNewSeries =
+        m_apDialogModel->insertSeriesAfter(xSeries, xChartType, true);
+
+    if (!xNewSeries.is())
+        // Failed to insert new data series to the model. Bail out.
+        return;
+
+    Reference< chart2::data::XDataSource > xSource( xNewSeries, uno::UNO_QUERY );
+    if (xSource.is())
+    {
+        Sequence<Reference<chart2::data::XLabeledDataSequence> > aLSequences = xSource->getDataSequences();
+        sal_Int32 nSeqIdx = 0;
+        sal_Int32 nSeqSize = aLSequences.getLength();
+        for (sal_Int32 nIndex = nStartCol; nSeqIdx < nSeqSize; ++nSeqIdx)
         {
-            xChartType.set( DiagramHelper::getChartTypeOfSeries( xDiagram, xSeries ));
-            tDataHeaderVector::const_iterator aIt(
-                ::std::find_if( m_aHeaders.begin(), m_aHeaders.end(),
-                                lcl_DataSeriesOfHeaderMatches( xSeries )));
-            if( aIt != m_aHeaders.end())
-                nStartCol = aIt->m_nEndColumn;
+            lcl_tSharedSeqVec::const_iterator aSharedIt(
+                ::std::find_if( aSharedSequences.begin(), aSharedSequences.end(),
+                                lcl_RolesOfLSeqMatch( aLSequences[nSeqIdx] )));
 
-            Reference< beans::XPropertySet > xSeriesProps( xSeries, uno::UNO_QUERY );
-            if( xSeriesProps.is() )
-                xSeriesProps->getPropertyValue( "NumberFormat" ) >>= nSeriesNumberFormat;
-        }
-        else
-        {
-            xChartType.set( DiagramHelper::getChartTypeByIndex( xDiagram, 0 ));
-            nStartCol = nAfterColumnIndex;
-        }
-
-        if( xChartType.is())
-        {
-            // get shared sequences of current series
-            Reference< chart2::XDataSeriesContainer > xSeriesCnt( xChartType, uno::UNO_QUERY );
-            lcl_tSharedSeqVec aSharedSequences;
-            if( xSeriesCnt.is())
-                aSharedSequences = lcl_getSharedSequences( xSeriesCnt->getDataSeries());
-            Reference< chart2::XDataSeries > xNewSeries(
-                m_apDialogModel->insertSeriesAfter( xSeries, xChartType, true /* bCreateDataCachedSequences */ ));
-            if( xNewSeries.is())
+            if( aSharedIt != aSharedSequences.end())
             {
-                {
-                    Reference< chart2::data::XDataSource > xSource( xNewSeries, uno::UNO_QUERY );
-                    if( xSource.is())
-                    {
-                        Sequence< Reference< chart2::data::XLabeledDataSequence > > aLSequences(
-                            xSource->getDataSequences());
-                        sal_Int32 nSeqIdx = 0;
-                        sal_Int32 nSeqSize = aLSequences.getLength();
-                        for( sal_Int32 nIndex = nStartCol;
-                             (nSeqIdx < nSeqSize);
-                             ++nSeqIdx )
-                        {
-                            lcl_tSharedSeqVec::const_iterator aSharedIt(
-                                ::std::find_if( aSharedSequences.begin(), aSharedSequences.end(),
-                                                lcl_RolesOfLSeqMatch( aLSequences[nSeqIdx] )));
-                            if( aSharedIt != aSharedSequences.end())
-                            {
-                                aLSequences[nSeqIdx]->setValues( (*aSharedIt)->getValues());
-                                aLSequences[nSeqIdx]->setLabel( (*aSharedIt)->getLabel());
-                            }
-                            else
-                            {
-                                xDataProvider->insertSequence( nIndex - 1 );
+                // Shared sequence. Most likely "values-x" sequence.  Copy it from existing sequence.
+                aLSequences[nSeqIdx]->setValues( (*aSharedIt)->getValues());
+                aLSequences[nSeqIdx]->setLabel( (*aSharedIt)->getLabel());
+            }
+            else
+            {
+                // Insert a new column in the internal data for the new sequence.
+                xDataProvider->insertSequence( nIndex - 1 );
 
-                                // values
-                                Reference< chart2::data::XDataSequence > xNewSeq(
-                                    xDataProvider->createDataSequenceByRangeRepresentation(
-                                        OUString::number( nIndex )));
-                                lcl_copyDataSequenceProperties(
-                                    aLSequences[nSeqIdx]->getValues(), xNewSeq );
-                                aLSequences[nSeqIdx]->setValues( xNewSeq );
+                // values
+                Reference< chart2::data::XDataSequence > xNewSeq(
+                    xDataProvider->createDataSequenceByRangeRepresentation(
+                        OUString::number( nIndex )));
+                lcl_copyDataSequenceProperties(
+                    aLSequences[nSeqIdx]->getValues(), xNewSeq );
+                aLSequences[nSeqIdx]->setValues( xNewSeq );
 
-                                // labels
-                                Reference< chart2::data::XDataSequence > xNewLabelSeq(
-                                    xDataProvider->createDataSequenceByRangeRepresentation(
-                                        "label " +
-                                        OUString::number( nIndex )));
-                                lcl_copyDataSequenceProperties(
-                                    aLSequences[nSeqIdx]->getLabel(), xNewLabelSeq );
-                                aLSequences[nSeqIdx]->setLabel( xNewLabelSeq );
-                                ++nIndex;
-                            }
-                        }
-                    }
-                }
-                if( nSeriesNumberFormat != 0 )
-                {
-                    //give the new series the same number format as the former series especially for bubble charts thus the bubble size values can be edited with same format immidiately
-                    Reference< beans::XPropertySet > xNewSeriesProps( xNewSeries, uno::UNO_QUERY );
-                    if( xNewSeriesProps.is() )
-                        xNewSeriesProps->setPropertyValue( "NumberFormat" , uno::makeAny( nSeriesNumberFormat ) );
-                }
-
-                updateFromModel();
+                // labels
+                Reference< chart2::data::XDataSequence > xNewLabelSeq(
+                    xDataProvider->createDataSequenceByRangeRepresentation(
+                        "label " +
+                        OUString::number( nIndex )));
+                lcl_copyDataSequenceProperties(
+                    aLSequences[nSeqIdx]->getLabel(), xNewLabelSeq );
+                aLSequences[nSeqIdx]->setLabel( xNewLabelSeq );
+                ++nIndex;
             }
         }
     }
+
+    if( nSeriesNumberFormat != 0 )
+    {
+        //give the new series the same number format as the former series especially for bubble charts thus the bubble size values can be edited with same format immediately
+        Reference< beans::XPropertySet > xNewSeriesProps( xNewSeries, uno::UNO_QUERY );
+        if( xNewSeriesProps.is() )
+            xNewSeriesProps->setPropertyValue(CHART_UNONAME_NUMFMT , uno::makeAny(nSeriesNumberFormat));
+    }
+
+    updateFromModel();
 }
 
 void DataBrowserModel::insertComplexCategoryLevel( sal_Int32 nAfterColumnIndex )
@@ -418,90 +411,109 @@ void DataBrowserModel::insertComplexCategoryLevel( sal_Int32 nAfterColumnIndex )
 
     OSL_ASSERT( m_apDialogModel.get());
     Reference< chart2::XInternalDataProvider > xDataProvider( m_apDialogModel->getDataProvider(), uno::UNO_QUERY );
-    if( xDataProvider.is() )
+    if (!xDataProvider.is())
+        return;
+
+    if( !isCategoriesColumn(nAfterColumnIndex) )
+        nAfterColumnIndex = getCategoryColumnCount()-1;
+
+    if(nAfterColumnIndex<0)
     {
-        if( !isCategoriesColumn(nAfterColumnIndex) )
-            nAfterColumnIndex = getCategoryColumnCount()-1;
-
-        if(nAfterColumnIndex<0)
-        {
-            OSL_FAIL( "wrong index for category level insertion" );
-            return;
-        }
-
-        m_apDialogModel->startControllerLockTimer();
-        ControllerLockGuardUNO aLockedControllers( Reference< frame::XModel >( m_xChartDocument, uno::UNO_QUERY ) );
-        xDataProvider->insertComplexCategoryLevel( nAfterColumnIndex+1 );
-        updateFromModel();
+        OSL_FAIL( "wrong index for category level insertion" );
+        return;
     }
+
+    m_apDialogModel->startControllerLockTimer();
+    ControllerLockGuardUNO aLockedControllers( Reference< frame::XModel >( m_xChartDocument, uno::UNO_QUERY ) );
+    xDataProvider->insertComplexCategoryLevel( nAfterColumnIndex+1 );
+    updateFromModel();
+}
+
+void DataBrowserModel::removeComplexCategoryLevel( sal_Int32 nAtColumnIndex )
+{
+    //delete a category column if there is more than one level (in case of a single column we do not get here)
+    OSL_ENSURE(nAtColumnIndex>0, "wrong index for categories deletion" );
+
+    Reference< chart2::XInternalDataProvider > xDataProvider( m_apDialogModel->getDataProvider(), uno::UNO_QUERY );
+    if (!xDataProvider.is())
+        return;
+
+    m_apDialogModel->startControllerLockTimer();
+    ControllerLockGuardUNO aLockedControllers( Reference< frame::XModel >( m_xChartDocument, uno::UNO_QUERY ) );
+    xDataProvider->deleteComplexCategoryLevel( nAtColumnIndex );
+
+    updateFromModel();
 }
 
 void DataBrowserModel::removeDataSeriesOrComplexCategoryLevel( sal_Int32 nAtColumnIndex )
 {
     OSL_ASSERT( m_apDialogModel.get());
-    if( static_cast< tDataColumnVector::size_type >( nAtColumnIndex ) < m_aColumns.size())
+    if (nAtColumnIndex < 0 || static_cast<size_t>(nAtColumnIndex) >= m_aColumns.size())
+        // Out of bound.
+        return;
+
+    if (isCategoriesColumn(nAtColumnIndex))
     {
-        Reference< chart2::XDataSeries > xSeries( m_aColumns[nAtColumnIndex].m_xDataSeries );
-        if( xSeries.is())
-        {
-            m_apDialogModel->deleteSeries(
-                xSeries, getHeaderForSeries( xSeries ).m_xChartType );
-
-            //delete sequences from internal data provider that are not used anymore
-            //but do not delete sequences that are still in use by the remaining series
-            Reference< chart2::XInternalDataProvider > xDataProvider( m_apDialogModel->getDataProvider(), uno::UNO_QUERY );
-            Reference< chart2::data::XDataSource > xSourceOfDeletedSeries( xSeries, uno::UNO_QUERY );
-            if( xDataProvider.is() && xSourceOfDeletedSeries.is())
-            {
-                ::std::vector< sal_Int32 > aSequenceIndexesToDelete;
-                Sequence< Reference< chart2::data::XLabeledDataSequence > > aSequencesOfDeletedSeries( xSourceOfDeletedSeries->getDataSequences() );
-                Reference< chart2::XDataSeriesContainer > xSeriesCnt( getHeaderForSeries( xSeries ).m_xChartType, uno::UNO_QUERY );
-                if( xSeriesCnt.is())
-                {
-                    Reference< chart2::data::XDataSource > xRemainingDataSource( DataSeriesHelper::getDataSource( xSeriesCnt->getDataSeries() ) );
-                    if( xRemainingDataSource.is() )
-                    {
-                        ::std::vector< Reference< chart2::data::XLabeledDataSequence > > aRemainingSeq( ContainerHelper::SequenceToVector( xRemainingDataSource->getDataSequences() ) );
-                        for( sal_Int32 i=0; i<aSequencesOfDeletedSeries.getLength(); ++i )
-                        {
-                            ::std::vector< Reference< chart2::data::XLabeledDataSequence > >::const_iterator aHitIt(
-                                ::std::find_if( aRemainingSeq.begin(), aRemainingSeq.end(),
-                                    lcl_RepresentationsOfLSeqMatch( aSequencesOfDeletedSeries[i] )));
-                            // if not used by the remaining series this sequence can be deleted
-                            if( aHitIt == aRemainingSeq.end() )
-                                aSequenceIndexesToDelete.push_back( lcl_getValuesRepresentationIndex( aSequencesOfDeletedSeries[i] ) );
-                        }
-                    }
-                }
-
-                // delete unnecessary sequences of the internal data
-                // iterate using greatest index first, so that deletion does not
-                // shift other sequences that will be deleted later
-                ::std::sort( aSequenceIndexesToDelete.begin(), aSequenceIndexesToDelete.end());
-                for( ::std::vector< sal_Int32 >::reverse_iterator aIt(
-                         aSequenceIndexesToDelete.rbegin()); aIt != aSequenceIndexesToDelete.rend(); ++aIt )
-                {
-                    if( *aIt != -1 )
-                        xDataProvider->deleteSequence( *aIt );
-                }
-            }
-            updateFromModel();
-        }
-        else
-        {
-            //delete a category column if there is more than one level (in case of a single column we do not get here)
-            OSL_ENSURE(nAtColumnIndex>0, "wrong index for categories deletion" );
-
-            Reference< chart2::XInternalDataProvider > xDataProvider( m_apDialogModel->getDataProvider(), uno::UNO_QUERY );
-            if( xDataProvider.is() )
-            {
-                m_apDialogModel->startControllerLockTimer();
-                ControllerLockGuardUNO aLockedControllers( Reference< frame::XModel >( m_xChartDocument, uno::UNO_QUERY ) );
-                xDataProvider->deleteComplexCategoryLevel( nAtColumnIndex );
-                updateFromModel();
-            }
-        }
+        removeComplexCategoryLevel(nAtColumnIndex);
+        return;
     }
+
+    const Reference<chart2::XDataSeries>& xSeries = m_aColumns[nAtColumnIndex].m_xDataSeries;
+
+    m_apDialogModel->deleteSeries(xSeries, getHeaderForSeries(xSeries).m_xChartType);
+
+    //delete sequences from internal data provider that are not used anymore
+    //but do not delete sequences that are still in use by the remaining series
+
+    Reference< chart2::XInternalDataProvider > xDataProvider( m_apDialogModel->getDataProvider(), uno::UNO_QUERY );
+    Reference< chart2::data::XDataSource > xSourceOfDeleted( xSeries, uno::UNO_QUERY );
+    if (!xDataProvider.is() || !xSourceOfDeleted.is())
+    {
+        // Something went wrong.  Bail out.
+        updateFromModel();
+        return;
+    }
+
+    Reference<chart2::XDataSeriesContainer> xSeriesCnt(
+        getHeaderForSeries(xSeries).m_xChartType, uno::UNO_QUERY);
+    if (!xSeriesCnt.is())
+    {
+        // Unexpected happened.  Bail out.
+        updateFromModel();
+        return;
+    }
+
+    // Collect all the remaining data sequences in the same chart type. The
+    // deleted data series is already gone by this point.
+    std::vector<Reference<chart2::data::XLabeledDataSequence> > aAllDataSeqs =
+        DataSeriesHelper::getAllDataSequences(xSeriesCnt->getDataSeries());
+
+    // Check if the sequences to be deleted are still referenced by any of
+    // the other data series.  If not, mark them for deletion.
+    std::vector<sal_Int32> aSequenceIndexesToDelete;
+    Sequence<Reference<chart2::data::XLabeledDataSequence> > aSequencesOfDeleted = xSourceOfDeleted->getDataSequences();
+    for (sal_Int32 i = 0; i < aSequencesOfDeleted.getLength(); ++i)
+    {
+        std::vector<Reference<chart2::data::XLabeledDataSequence> >::const_iterator aHitIt(
+            ::std::find_if( aAllDataSeqs.begin(), aAllDataSeqs.end(),
+                lcl_RepresentationsOfLSeqMatch( aSequencesOfDeleted[i] )));
+        // if not used by the remaining series this sequence can be deleted
+        if( aHitIt == aAllDataSeqs.end() )
+            aSequenceIndexesToDelete.push_back( lcl_getValuesRepresentationIndex( aSequencesOfDeleted[i] ) );
+    }
+
+    // delete unnecessary sequences of the internal data
+    // iterate using greatest index first, so that deletion does not
+    // shift other sequences that will be deleted later
+    ::std::sort( aSequenceIndexesToDelete.begin(), aSequenceIndexesToDelete.end());
+    for( ::std::vector< sal_Int32 >::reverse_iterator aIt(
+             aSequenceIndexesToDelete.rbegin()); aIt != aSequenceIndexesToDelete.rend(); ++aIt )
+    {
+        if( *aIt != -1 )
+            xDataProvider->deleteSequence( *aIt );
+    }
+
+    updateFromModel();
 }
 
 void DataBrowserModel::swapDataSeries( sal_Int32 nFirstColumnIndex )
@@ -570,7 +582,7 @@ Reference< chart2::XDataSeries >
     tDataColumnVector::size_type nIndex( nColumn );
     if( nIndex < m_aColumns.size())
         return m_aColumns[nIndex].m_xDataSeries;
-    return 0;
+    return nullptr;
 }
 
 DataBrowserModel::eCellType DataBrowserModel::getCellType( sal_Int32 nAtColumn, sal_Int32 /* nAtRow */ ) const
@@ -740,10 +752,14 @@ OUString DataBrowserModel::getRoleOfColumn( sal_Int32 nColumnIndex ) const
 
 bool DataBrowserModel::isCategoriesColumn( sal_Int32 nColumnIndex ) const
 {
-    bool bIsCategories = false;
-    if( nColumnIndex>=0 && nColumnIndex<static_cast< sal_Int32 >(m_aColumns.size()) )
-        bIsCategories = !m_aColumns[ nColumnIndex ].m_xDataSeries.is();
-    return bIsCategories;
+    if (nColumnIndex < 0)
+        return false;
+
+    if (static_cast<size_t>(nColumnIndex) >= m_aColumns.size())
+        return false;
+
+    // A column is a category when it doesn't have an associated data series.
+    return !m_aColumns[nColumnIndex].m_xDataSeries.is();
 }
 
 sal_Int32 DataBrowserModel::getCategoryColumnCount()
@@ -760,11 +776,6 @@ sal_Int32 DataBrowserModel::getCategoryColumnCount()
     return nLastTextColumnIndex+1;
 }
 
-const DataBrowserModel::tDataHeaderVector& DataBrowserModel::getDataHeaders() const
-{
-    return m_aHeaders;
-}
-
 void DataBrowserModel::updateFromModel()
 {
     if( !m_xChartDocument.is())
@@ -785,10 +796,11 @@ void DataBrowserModel::updateFromModel()
 
     sal_Int32 nHeaderStart = 0;
     sal_Int32 nHeaderEnd   = 0;
-    if( lcl_ShowCategories( xDiagram ))
     {
         Reference< frame::XModel > xChartModel( m_xChartDocument, uno::UNO_QUERY );
         ChartModel* pModel = dynamic_cast<ChartModel*>(xChartModel.get());
+        if (!pModel)
+            return;
         ExplicitCategoriesProvider aExplicitCategoriesProvider( ChartModelHelper::getFirstCoordinateSystem(xChartModel), *pModel );
 
         const Sequence< Reference< chart2::data::XLabeledDataSequence> >& rSplitCategoriesList( aExplicitCategoriesProvider.getSplitCategoriesList() );
@@ -819,7 +831,7 @@ void DataBrowserModel::updateFromModel()
     {
         Reference< chart2::XChartTypeContainer > xCTCnt( aCooSysSeq[nCooSysIdx], uno::UNO_QUERY_THROW );
         Sequence< Reference< chart2::XChartType > > aChartTypes( xCTCnt->getChartTypes());
-        sal_Int32 nXAxisNumberFormat = DataSeriesHelper::getNumberFormatKeyFromAxis( 0, aCooSysSeq[nCooSysIdx], 0, 0 );
+        sal_Int32 nXAxisNumberFormat = DataSeriesHelper::getNumberFormatKeyFromAxis( nullptr, aCooSysSeq[nCooSysIdx], 0, 0 );
 
         for( sal_Int32 nCTIdx=0; nCTIdx<aChartTypes.getLength(); ++nCTIdx )
         {
@@ -865,14 +877,14 @@ void DataBrowserModel::updateFromModel()
                         for( ; nSeqIdx<aLSeqs.getLength(); ++nSeqIdx )
                         {
                             sal_Int32 nSequenceNumberFormatKey = nYAxisNumberFormatKey;
-                            OUString aRole = lcl_getRole( aLSeqs[nSeqIdx] );
+                            OUString aRole = DataSeriesHelper::getRole(aLSeqs[nSeqIdx]);
 
                             if( aRole.equals( aRoleForDataLabelNumberFormat ) )
                             {
                                 nSequenceNumberFormatKey = ExplicitValueProvider::getExplicitNumberFormatKeyForDataLabel(
                                     Reference< beans::XPropertySet >( xSeries, uno::UNO_QUERY ), xSeries, -1, xDiagram );
                             }
-                            else if( aRole.equals( "values-x" ) )
+                            else if( aRole == "values-x" )
                                 nSequenceNumberFormatKey = nXAxisNumberFormat;
 
                             if( ::std::find_if( aSharedSequences.begin(), aSharedSequences.end(),
@@ -903,7 +915,7 @@ void DataBrowserModel::updateFromModel()
                         }
 
                         // add ranges for error bars if present for a series
-                        if( StatisticsHelper::usesErrorBarRanges( aSeries[nSeriesIdx], /* bYError = */ true ))
+                        if( StatisticsHelper::usesErrorBarRanges( aSeries[nSeriesIdx] ))
                             addErrorBarRanges( aSeries[nSeriesIdx], nYAxisNumberFormatKey, nSeqIdx, nHeaderEnd, true );
 
                         if( StatisticsHelper::usesErrorBarRanges( aSeries[nSeriesIdx], /* bYError = */ false ))
