@@ -18,7 +18,6 @@
  */
 
 #include "dlg_CreationWizard.hxx"
-#include "dlg_CreationWizard.hrc"
 #include "ResId.hxx"
 #include "macros.hxx"
 #include "Strings.hrc"
@@ -31,6 +30,9 @@
 #include "ChartTypeTemplateProvider.hxx"
 #include "DialogModel.hxx"
 
+#define CHART_WIZARD_PAGEWIDTH  250
+#define CHART_WIZARD_PAGEHEIGHT 170
+
 namespace chart
 {
 using namespace ::com::sun::star;
@@ -48,29 +50,26 @@ namespace
     const sal_Int32 nPageCount = 4;
 }
 
-CreationWizard::CreationWizard( Window* pParent, const uno::Reference< frame::XModel >& xChartModel
+CreationWizard::CreationWizard( vcl::Window* pParent, const uno::Reference< frame::XModel >& xChartModel
                                , const uno::Reference< uno::XComponentContext >& xContext
                                , sal_Int32 nOnePageOnlyIndex )
-                : svt::RoadmapWizard( pParent, SchResId(DLG_CHART_WIZARD)
-                    , ( nOnePageOnlyIndex >= 0 && nOnePageOnlyIndex < nPageCount )
-                        ?  WZB_HELP | WZB_CANCEL | WZB_FINISH
-                        :  WZB_HELP | WZB_CANCEL | WZB_PREVIOUS | WZB_NEXT | WZB_FINISH
+                : svt::RoadmapWizard( pParent,
+                    (nOnePageOnlyIndex >= 0 && nOnePageOnlyIndex < nPageCount)
+                        ?  WizardButtonFlags::HELP | WizardButtonFlags::CANCEL | WizardButtonFlags::FINISH
+                        :  WizardButtonFlags::HELP | WizardButtonFlags::CANCEL | WizardButtonFlags::PREVIOUS | WizardButtonFlags::NEXT | WizardButtonFlags::FINISH
                   )
                 , m_xChartModel(xChartModel,uno::UNO_QUERY)
                 , m_xCC( xContext )
                 , m_bIsClosable(true)
                 , m_nOnePageOnlyIndex(nOnePageOnlyIndex)
-                , m_pTemplateProvider(0)
+                , m_pTemplateProvider(nullptr)
                 , m_nFirstState(STATE_FIRST)
                 , m_nLastState(STATE_LAST)
                 , m_aTimerTriggeredControllerLock( xChartModel )
                 , m_bCanTravel( true )
 {
-    m_apDialogModel.reset( new DialogModel( m_xChartModel, m_xCC ));
-    // Do not call FreeResource(), because there are no sub-elements defined in
-    // the dialog resource
-    ShowButtonFixedLine( sal_True );
-    defaultButton( WZB_FINISH );
+    m_pDialogModel.reset( new DialogModel( m_xChartModel, m_xCC ));
+    defaultButton( WizardButtonFlags::FINISH );
 
     if( m_nOnePageOnlyIndex < 0 || m_nOnePageOnlyIndex >= nPageCount )
     {
@@ -88,9 +87,9 @@ CreationWizard::CreationWizard( Window* pParent, const uno::Reference< frame::XM
         , WZS_INVALID_STATE
     );
     this->SetRoadmapHelpId( HID_SCH_WIZARD_ROADMAP );
-    this->SetRoadmapInteractive( sal_True );
+    this->SetRoadmapInteractive( true );
     Size aAdditionalRoadmapSize( LogicToPixel( Size( 85, 0 ), MAP_APPFONT ) );
-    Size aSize( this->GetSizePixel() );
+    Size aSize(LogicToPixel(Size(CHART_WIZARD_PAGEWIDTH, CHART_WIZARD_PAGEHEIGHT), MAP_APPFONT));
     aSize.Width() += aAdditionalRoadmapSize.Width();
     this->SetSizePixel( aSize );
 
@@ -106,13 +105,10 @@ CreationWizard::CreationWizard( Window* pParent, const uno::Reference< frame::XM
     // Call ActivatePage, to create and activate the first page
     ActivatePage();
 }
-CreationWizard::~CreationWizard()
-{
-}
 
-svt::OWizardPage* CreationWizard::createPage(WizardState nState)
+VclPtr<TabPage> CreationWizard::createPage(WizardState nState)
 {
-    svt::OWizardPage* pRet = 0;
+    VclPtr<svt::OWizardPage> pRet;
     if(m_nOnePageOnlyIndex!=-1 && m_nOnePageOnlyIndex!=nState)
         return pRet;
     bool bDoLiveUpdate = m_nOnePageOnlyIndex == -1;
@@ -121,29 +117,28 @@ svt::OWizardPage* CreationWizard::createPage(WizardState nState)
     case STATE_CHARTTYPE:
         {
         m_aTimerTriggeredControllerLock.startTimer();
-        ChartTypeTabPage* pChartTypeTabPage = new ChartTypeTabPage(this,m_xChartModel,m_xCC,bDoLiveUpdate);
+        VclPtrInstance<ChartTypeTabPage> pChartTypeTabPage(this,m_xChartModel,m_xCC,bDoLiveUpdate);
         pRet  = pChartTypeTabPage;
         m_pTemplateProvider = pChartTypeTabPage;
-        if( m_pTemplateProvider &&
-            m_apDialogModel.get() )
-            m_apDialogModel->setTemplate( m_pTemplateProvider->getCurrentTemplate());
+        if (m_pDialogModel)
+            m_pDialogModel->setTemplate( m_pTemplateProvider->getCurrentTemplate());
         }
         break;
     case STATE_SIMPLE_RANGE:
         {
         m_aTimerTriggeredControllerLock.startTimer();
-        pRet = new RangeChooserTabPage(this,*(m_apDialogModel.get()),m_pTemplateProvider,this);
+        pRet = VclPtr<RangeChooserTabPage>::Create(this, *m_pDialogModel, m_pTemplateProvider, this);
         }
         break;
     case STATE_DATA_SERIES:
         {
         m_aTimerTriggeredControllerLock.startTimer();
-        pRet = new DataSourceTabPage(this,*(m_apDialogModel.get()),m_pTemplateProvider,this);
+        pRet = VclPtr<DataSourceTabPage>::Create(this, *m_pDialogModel, m_pTemplateProvider, this);
         }
         break;
     case STATE_OBJECTS:
         {
-        pRet  = new TitlesAndObjectsTabPage(this,m_xChartModel,m_xCC);
+        pRet  = VclPtr<TitlesAndObjectsTabPage>::Create(this,m_xChartModel,m_xCC);
         m_aTimerTriggeredControllerLock.startTimer();
         }
         break;
@@ -155,7 +150,7 @@ svt::OWizardPage* CreationWizard::createPage(WizardState nState)
     return pRet;
 }
 
-sal_Bool CreationWizard::leaveState( WizardState /*_nState*/ )
+bool CreationWizard::leaveState( WizardState /*_nState*/ )
 {
     return m_bCanTravel;
 }
@@ -174,18 +169,12 @@ svt::WizardTypes::WizardState CreationWizard::determineNextState( WizardState nC
 void CreationWizard::enterState(WizardState nState)
 {
     m_aTimerTriggeredControllerLock.startTimer();
-    enableButtons( WZB_PREVIOUS, bool( nState > m_nFirstState ) );
-    enableButtons( WZB_NEXT, bool( nState < m_nLastState ) );
+    enableButtons( WizardButtonFlags::PREVIOUS, bool( nState > m_nFirstState ) );
+    enableButtons( WizardButtonFlags::NEXT, bool( nState < m_nLastState ) );
     if( isStateEnabled( nState ))
         svt::RoadmapWizard::enterState(nState);
 }
 
-bool CreationWizard::isClosable()
-{
-    //@todo
-    return m_bIsClosable;
-}
-
 void CreationWizard::setInvalidPage( TabPage * /* pTabPage */ )
 {
     m_bCanTravel = false;
