@@ -18,12 +18,9 @@
  */
 
 #include "res_ErrorBar.hxx"
-#include "res_ErrorBar_IDs.hrc"
 #include "ResId.hxx"
-#include "Strings.hrc"
 #include "Bitmaps.hrc"
 #include "RangeSelectionHelper.hxx"
-// for RANGE_SELECTION_INVALID_RANGE_BACKGROUND_COLOR
 #include "TabPageNotifiable.hxx"
 #include "macros.hxx"
 
@@ -31,6 +28,11 @@
 #include <vcl/dialog.hxx>
 #include <svl/stritem.hxx>
 
+#define CHART_LB_FUNCTION_STD_ERROR     0
+#define CHART_LB_FUNCTION_STD_DEV       1
+#define CHART_LB_FUNCTION_VARIANCE      2
+#define CHART_LB_FUNCTION_ERROR_MARGIN  3
+
 using namespace ::com::sun::star;
 
 namespace
@@ -39,8 +41,8 @@ void lcl_enableRangeChoosing( bool bEnable, Dialog * pDialog )
 {
     if( pDialog )
     {
-        pDialog->Show( bEnable ? sal_False : sal_True );
-        pDialog->SetModalInputMode( bEnable ? sal_False : sal_True );
+        pDialog->Show( !bEnable );
+        pDialog->SetModalInputMode( !bEnable );
     }
 }
 
@@ -76,37 +78,9 @@ sal_uInt16 lcl_getLbEntryPosByErrorKind( SvxChartKindError eErrorKind )
 namespace chart
 {
 
-ErrorBarResources::ErrorBarResources( Window* pParent, Dialog * pParentDialog,
+ErrorBarResources::ErrorBarResources( VclBuilderContainer* pParent, Dialog * pParentDialog,
                                       const SfxItemSet& rInAttrs, bool bNoneAvailable,
                                       tErrorBarType eType /* = ERROR_BAR_Y */ ) :
-
-        m_aFlErrorCategory( pParent, SchResId( FL_ERROR )),
-        m_aRbNone( pParent, SchResId( RB_NONE )),
-        m_aRbConst( pParent, SchResId( RB_CONST )),
-        m_aRbPercent( pParent, SchResId( RB_PERCENT )),
-        m_aRbFunction( pParent, SchResId( RB_FUNCTION )),
-        m_aRbRange( pParent, SchResId( RB_RANGE )),
-        m_aLbFunction( pParent, SchResId( LB_FUNCTION )),
-
-        m_aFlParameters( pParent, SchResId( FL_PARAMETERS )),
-        m_aFtPositive( pParent, SchResId( FT_POSITIVE )),
-        m_aMfPositive( pParent, SchResId( MF_POSITIVE )),
-        m_aEdRangePositive( pParent, SchResId( ED_RANGE_POSITIVE )),
-        m_aIbRangePositive( pParent, SchResId( IB_RANGE_POSITIVE )),
-        m_aFtNegative( pParent, SchResId( FT_NEGATIVE )),
-        m_aMfNegative( pParent, SchResId( MF_NEGATIVE )),
-        m_aEdRangeNegative( pParent, SchResId( ED_RANGE_NEGATIVE )),
-        m_aIbRangeNegative( pParent, SchResId( IB_RANGE_NEGATIVE )),
-        m_aCbSyncPosNeg( pParent, SchResId( CB_SYN_POS_NEG )),
-
-        m_aFlIndicate( pParent, SchResId( FL_INDICATE )),
-        m_aRbBoth( pParent, SchResId( RB_BOTH )),
-        m_aRbPositive( pParent, SchResId( RB_POSITIVE )),
-        m_aRbNegative( pParent, SchResId( RB_NEGATIVE )),
-        m_aFiBoth( pParent, SchResId( FI_BOTH )),
-        m_aFiPositive( pParent, SchResId( FI_POSITIVE )),
-        m_aFiNegative( pParent, SchResId( FI_NEGATIVE )),
-
         m_eErrorKind( CHERROR_NONE ),
         m_eIndicate( CHINDICATE_BOTH ),
         m_bErrorKindUnique( true ),
@@ -119,38 +93,66 @@ ErrorBarResources::ErrorBarResources( Window* pParent, Dialog * pParentDialog,
         m_eErrorBarType( eType ),
         m_nConstDecimalDigits( 1 ),
         m_nConstSpinSize( 1 ),
-        m_pParentWindow( pParent ),
+        m_fPlusValue(0.0),
+        m_fMinusValue(0.0),
         m_pParentDialog( pParentDialog ),
-        m_pCurrentRangeChoosingField( 0 ),
+        m_pCurrentRangeChoosingField( nullptr ),
         m_bHasInternalDataProvider( true ),
-        m_bDisableDataTableDialog( false )
+        m_bEnableDataTableDialog( true )
 {
+        pParent->get(m_pRbNone,"RB_NONE");
+        pParent->get(m_pRbConst, "RB_CONST");
+        pParent->get(m_pRbPercent, "RB_PERCENT");
+        pParent->get(m_pRbFunction, "RB_FUNCTION");
+        pParent->get(m_pRbRange, "RB_RANGE");
+        pParent->get(m_pLbFunction, "LB_FUNCTION");
+
+        pParent->get(m_pFlParameters, "framePARAMETERS");
+        pParent->get(m_pBxPositive, "boxPOSITIVE");
+        pParent->get(m_pMfPositive, "MF_POSITIVE");
+        pParent->get(m_pEdRangePositive, "ED_RANGE_POSITIVE");
+        pParent->get(m_pIbRangePositive, "IB_RANGE_POSITIVE");
+        pParent->get(m_pBxNegative, "boxNEGATIVE");
+        pParent->get(m_pMfNegative, "MF_NEGATIVE");
+        pParent->get(m_pEdRangeNegative, "ED_RANGE_NEGATIVE");
+        pParent->get(m_pIbRangeNegative, "IB_RANGE_NEGATIVE");
+        pParent->get(m_pCbSyncPosNeg, "CB_SYN_POS_NEG");
+
+        pParent->get(m_pRbBoth, "RB_BOTH");
+        pParent->get(m_pRbPositive, "RB_POSITIVE");
+        pParent->get(m_pRbNegative, "RB_NEGATIVE");
+        pParent->get(m_pFiBoth, "FI_BOTH");
+        pParent->get(m_pFiPositive, "FI_POSITIVE");
+        pParent->get(m_pFiNegative, "FI_NEGATIVE");
+
+        pParent->get(m_pUIStringPos, "STR_DATA_SELECT_RANGE_FOR_POSITIVE_ERRORBARS");
+        pParent->get(m_pUIStringNeg, "STR_DATA_SELECT_RANGE_FOR_NEGATIVE_ERRORBARS");
+        pParent->get(m_pUIStringRbRange, "STR_CONTROLTEXT_ERROR_BARS_FROM_DATA");
+
     if( m_bNoneAvailable )
-        m_aRbNone.SetClickHdl( LINK( this, ErrorBarResources, CategoryChosen ));
+        m_pRbNone->SetClickHdl( LINK( this, ErrorBarResources, CategoryChosen ));
     else
-        m_aRbNone.Hide();
+        m_pRbNone->Hide();
 
-    m_aRbConst.SetClickHdl( LINK( this, ErrorBarResources, CategoryChosen ));
-    m_aRbPercent.SetClickHdl( LINK( this, ErrorBarResources, CategoryChosen ));
-    m_aRbFunction.SetClickHdl( LINK( this, ErrorBarResources, CategoryChosen ));
-    m_aRbRange.SetClickHdl( LINK( this, ErrorBarResources, CategoryChosen ));
-    m_aLbFunction.SetSelectHdl( LINK( this, ErrorBarResources, CategoryChosen ));
+    m_pRbConst->SetClickHdl( LINK( this, ErrorBarResources, CategoryChosen ));
+    m_pRbPercent->SetClickHdl( LINK( this, ErrorBarResources, CategoryChosen ));
+    m_pRbFunction->SetClickHdl( LINK( this, ErrorBarResources, CategoryChosen ));
+    m_pRbRange->SetClickHdl( LINK( this, ErrorBarResources, CategoryChosen ));
+    m_pLbFunction->SetSelectHdl( LINK( this, ErrorBarResources, CategoryChosen2 ));
 
-    m_aCbSyncPosNeg.Check( sal_False );
-    m_aCbSyncPosNeg.SetToggleHdl( LINK( this, ErrorBarResources, SynchronizePosAndNeg ));
+    m_pCbSyncPosNeg->Check( false );
+    m_pCbSyncPosNeg->SetToggleHdl( LINK( this, ErrorBarResources, SynchronizePosAndNeg ));
 
-    m_aMfPositive.SetModifyHdl( LINK( this, ErrorBarResources, PosValueChanged ));
-    m_aEdRangePositive.SetModifyHdl( LINK( this, ErrorBarResources, RangeChanged ));
-    m_aEdRangeNegative.SetModifyHdl( LINK( this, ErrorBarResources, RangeChanged ));
+    m_pMfPositive->SetModifyHdl( LINK( this, ErrorBarResources, PosValueChanged ));
+    m_pEdRangePositive->SetModifyHdl( LINK( this, ErrorBarResources, RangeChanged ));
+    m_pEdRangeNegative->SetModifyHdl( LINK( this, ErrorBarResources, RangeChanged ));
 
-    m_aRbPositive.SetClickHdl( LINK( this, ErrorBarResources, IndicatorChanged ));
-    m_aRbNegative.SetClickHdl( LINK( this, ErrorBarResources, IndicatorChanged ));
-    m_aRbBoth.SetClickHdl( LINK( this, ErrorBarResources, IndicatorChanged ));
+    m_pRbPositive->SetClickHdl( LINK( this, ErrorBarResources, IndicatorChanged ));
+    m_pRbNegative->SetClickHdl( LINK( this, ErrorBarResources, IndicatorChanged ));
+    m_pRbBoth->SetClickHdl( LINK( this, ErrorBarResources, IndicatorChanged ));
 
-    m_aIbRangePositive.SetClickHdl( LINK( this, ErrorBarResources, ChooseRange ));
-    m_aIbRangeNegative.SetClickHdl( LINK( this, ErrorBarResources, ChooseRange ));
-    m_aIbRangePositive.SetQuickHelpText(SCH_RESSTR(STR_TIP_SELECT_RANGE));
-    m_aIbRangeNegative.SetQuickHelpText(SCH_RESSTR(STR_TIP_SELECT_RANGE));
+    m_pIbRangePositive->SetClickHdl( LINK( this, ErrorBarResources, ChooseRange ));
+    m_pIbRangeNegative->SetClickHdl( LINK( this, ErrorBarResources, ChooseRange ));
 
     FillValueSets();
     Reset( rInAttrs );
@@ -180,7 +182,7 @@ void ErrorBarResources::SetChartDocumentForRangeChoosing(
         {
             try
             {
-                xProps->getPropertyValue( "DisableDataTableDialog" ) >>= m_bDisableDataTableDialog;
+                xProps->getPropertyValue("EnableDataTableDialog") >>= m_bEnableDataTableDialog;
             }
             catch( const uno::Exception& e )
             {
@@ -194,13 +196,13 @@ void ErrorBarResources::SetChartDocumentForRangeChoosing(
     OSL_ASSERT( m_apRangeSelectionHelper.get());
     if( m_bHasInternalDataProvider )
     {
-        m_aRbRange.SetText(SCH_RESSTR(STR_CONTROLTEXT_ERROR_BARS_FROM_DATA));
+        m_pRbRange->SetText(m_pUIStringRbRange->GetText());
     }
 
-    if( m_aRbRange.IsChecked())
+    if( m_pRbRange->IsChecked())
     {
-        isRangeFieldContentValid( m_aEdRangePositive );
-        isRangeFieldContentValid( m_aEdRangeNegative );
+        isRangeFieldContentValid( *m_pEdRangePositive );
+        isRangeFieldContentValid( *m_pEdRangeNegative );
     }
 }
 
@@ -226,60 +228,64 @@ void ErrorBarResources::SetAxisMinorStepWidthForErrorBarDecimals( double fMinorS
 void ErrorBarResources::UpdateControlStates()
 {
     // function
-    bool bIsFunction = m_aRbFunction.IsChecked();
-    m_aLbFunction.Enable( bIsFunction );
+    bool bIsFunction = m_pRbFunction->IsChecked();
+    m_pLbFunction->Enable( bIsFunction );
 
     // range buttons
-    m_aRbRange.Enable( !m_bHasInternalDataProvider || !m_bDisableDataTableDialog );
-    bool bShowRange = ( m_aRbRange.IsChecked());
+    m_pRbRange->Enable( !m_bHasInternalDataProvider || m_bEnableDataTableDialog );
+    bool bShowRange = ( m_pRbRange->IsChecked());
     bool bCanChooseRange =
         ( bShowRange &&
           m_apRangeSelectionHelper.get() &&
           m_apRangeSelectionHelper->hasRangeSelection());
 
-    m_aMfPositive.Show( ! bShowRange );
-    m_aMfNegative.Show( ! bShowRange );
+    m_pMfPositive->Show( ! bShowRange );
+    m_pMfNegative->Show( ! bShowRange );
 
     // use range but without range chooser => hide controls
-    m_aEdRangePositive.Show( bShowRange && ! m_bHasInternalDataProvider );
-    m_aIbRangePositive.Show( bCanChooseRange );
-    m_aEdRangeNegative.Show( bShowRange && ! m_bHasInternalDataProvider );
-    m_aIbRangeNegative.Show( bCanChooseRange );
+    m_pEdRangePositive->Show( bShowRange && ! m_bHasInternalDataProvider );
+    m_pIbRangePositive->Show( bCanChooseRange );
+    m_pEdRangeNegative->Show( bShowRange && ! m_bHasInternalDataProvider );
+    m_pIbRangeNegative->Show( bCanChooseRange );
 
     bool bShowPosNegAndSync = ! (bShowRange && m_bHasInternalDataProvider);
-    m_aFtPositive.Show( bShowPosNegAndSync );
-    m_aFtNegative.Show( bShowPosNegAndSync );
-    m_aCbSyncPosNeg.Show( bShowPosNegAndSync );
-    m_aFlParameters.Show( bShowPosNegAndSync );
+    m_pFlParameters->Show( bShowPosNegAndSync );
 
     // unit for metric fields
     bool bIsErrorMargin(
-        ( m_aRbFunction.IsChecked()) &&
-        ( m_aLbFunction.GetSelectEntryPos() == CHART_LB_FUNCTION_ERROR_MARGIN ));
-    bool bIsPercentage( m_aRbPercent.IsChecked() || bIsErrorMargin );
+        ( m_pRbFunction->IsChecked()) &&
+        ( m_pLbFunction->GetSelectEntryPos() == CHART_LB_FUNCTION_ERROR_MARGIN ));
+    bool bIsPercentage( m_pRbPercent->IsChecked() || bIsErrorMargin );
     OUString aCustomUnit;
 
     if( bIsPercentage )
     {
         aCustomUnit = " %";
-        m_aMfPositive.SetDecimalDigits( 1 );
-        m_aMfPositive.SetSpinSize( 10 );
-        m_aMfNegative.SetDecimalDigits( 1 );
-        m_aMfNegative.SetSpinSize( 10 );
+        m_pMfPositive->SetDecimalDigits( 1 );
+        m_pMfPositive->SetSpinSize( 10 );
+        m_pMfNegative->SetDecimalDigits( 1 );
+        m_pMfNegative->SetSpinSize( 10 );
     }
     else
     {
-        m_aMfPositive.SetDecimalDigits( m_nConstDecimalDigits );
-        m_aMfPositive.SetSpinSize( m_nConstSpinSize );
-        m_aMfNegative.SetDecimalDigits( m_nConstDecimalDigits );
-        m_aMfNegative.SetSpinSize( m_nConstSpinSize );
+        m_pMfPositive->SetDecimalDigits( m_nConstDecimalDigits );
+        m_pMfPositive->SetSpinSize( m_nConstSpinSize );
+        m_pMfNegative->SetDecimalDigits( m_nConstDecimalDigits );
+        m_pMfNegative->SetSpinSize( m_nConstSpinSize );
     }
-    m_aMfPositive.SetCustomUnitText( aCustomUnit );
-    m_aMfNegative.SetCustomUnitText( aCustomUnit );
+
+    sal_Int32 nPlusValue = static_cast< sal_Int32 >( m_fPlusValue * pow(10.0,m_pMfPositive->GetDecimalDigits()) );
+    sal_Int32 nMinusValue = static_cast< sal_Int32 >( m_fMinusValue * pow(10.0,m_pMfNegative->GetDecimalDigits()) );
+
+    m_pMfPositive->SetValue( nPlusValue );
+    m_pMfNegative->SetValue( nMinusValue );
+
+    m_pMfPositive->SetCustomUnitText( aCustomUnit );
+    m_pMfNegative->SetCustomUnitText( aCustomUnit );
 
     // positive and negative value fields
-    bool bPosEnabled = ( m_aRbPositive.IsChecked() || m_aRbBoth.IsChecked());
-    bool bNegEnabled = ( m_aRbNegative.IsChecked() || m_aRbBoth.IsChecked());
+    bool bPosEnabled = ( m_pRbPositive->IsChecked() || m_pRbBoth->IsChecked());
+    bool bNegEnabled = ( m_pRbNegative->IsChecked() || m_pRbBoth->IsChecked());
     if( !( bPosEnabled || bNegEnabled ))
     {
         // all three controls are not checked -> ambiguous state
@@ -289,72 +295,74 @@ void ErrorBarResources::UpdateControlStates()
 
     // functions with only one parameter
     bool bOneParameterCategory =
-        bIsErrorMargin || m_aRbPercent.IsChecked();
+        bIsErrorMargin || m_pRbPercent->IsChecked();
     if( bOneParameterCategory )
     {
-        m_aCbSyncPosNeg.Check();
+        m_pCbSyncPosNeg->Check();
     }
 
-    if( m_aCbSyncPosNeg.IsChecked())
+    if( m_pCbSyncPosNeg->IsChecked())
     {
         bPosEnabled = true;
         bNegEnabled = false;
     }
 
     // all functions except error margin take no arguments
-    if( m_aRbFunction.IsChecked() &&
-        ( m_aLbFunction.GetSelectEntryPos() != CHART_LB_FUNCTION_ERROR_MARGIN ))
+    if( m_pRbFunction->IsChecked() &&  ( m_pLbFunction->GetSelectEntryPos() != CHART_LB_FUNCTION_ERROR_MARGIN ))
     {
         bPosEnabled = false;
         bNegEnabled = false;
     }
 
     // enable/disable pos/neg fields
-    m_aFtPositive.Enable( bPosEnabled );
-    m_aFtNegative.Enable( bNegEnabled );
+    m_pBxPositive->Enable( bPosEnabled );
+    m_pBxNegative->Enable( bNegEnabled );
     if( bShowRange )
     {
-        m_aEdRangePositive.Enable( bPosEnabled );
-        m_aIbRangePositive.Enable( bPosEnabled );
-        m_aEdRangeNegative.Enable( bNegEnabled );
-        m_aIbRangeNegative.Enable( bNegEnabled );
+        m_pEdRangePositive->Enable( bPosEnabled );
+        m_pIbRangePositive->Enable( bPosEnabled );
+        m_pEdRangeNegative->Enable( bNegEnabled );
+        m_pIbRangeNegative->Enable( bNegEnabled );
     }
     else
     {
-        m_aMfPositive.Enable( bPosEnabled );
-        m_aMfNegative.Enable( bNegEnabled );
+        m_pMfPositive->Enable( bPosEnabled );
+        m_pMfNegative->Enable( bNegEnabled );
     }
 
-    m_aCbSyncPosNeg.Enable(
-        !bOneParameterCategory &&
-        ( bPosEnabled || bNegEnabled ));
+    m_pCbSyncPosNeg->Enable( !bOneParameterCategory &&  ( bPosEnabled || bNegEnabled ));
 
     // mark invalid entries in the range fields
     if( bShowRange && ! m_bHasInternalDataProvider )
     {
-        isRangeFieldContentValid( m_aEdRangePositive );
-        isRangeFieldContentValid( m_aEdRangeNegative );
+        isRangeFieldContentValid( *m_pEdRangePositive );
+        isRangeFieldContentValid( *m_pEdRangeNegative );
     }
 }
 
-IMPL_LINK( ErrorBarResources, CategoryChosen, void *,  )
+IMPL_LINK_NOARG_TYPED( ErrorBarResources, CategoryChosen2, ListBox&, void )
+{
+   CategoryChosen(nullptr);
+}
+
+IMPL_LINK_NOARG_TYPED( ErrorBarResources, CategoryChosen, Button*, void )
 {
     m_bErrorKindUnique = true;
     SvxChartKindError eOldError = m_eErrorKind;
 
-    if( m_aRbNone.IsChecked())
+    if( m_pRbNone->IsChecked())
         m_eErrorKind = CHERROR_NONE;
-    else if( m_aRbConst.IsChecked())
+    else if( m_pRbConst->IsChecked())
         m_eErrorKind = CHERROR_CONST;
-    else if( m_aRbPercent.IsChecked())
+    else if( m_pRbPercent->IsChecked())
         m_eErrorKind = CHERROR_PERCENT;
-    else if( m_aRbRange.IsChecked())
+    else if( m_pRbRange->IsChecked())
         m_eErrorKind = CHERROR_RANGE;
-    else if( m_aRbFunction.IsChecked())
+    else if( m_pRbFunction->IsChecked())
     {
-        if( m_aLbFunction.GetSelectEntryCount() == 1 )
+        if( m_pLbFunction->GetSelectEntryCount() == 1 )
         {
-            switch( m_aLbFunction.GetSelectEntryPos())
+            switch( m_pLbFunction->GetSelectEntryPos())
             {
                 case CHART_LB_FUNCTION_STD_ERROR:
                     m_eErrorKind = CHERROR_STDERROR; break;
@@ -381,78 +389,73 @@ IMPL_LINK( ErrorBarResources, CategoryChosen, void *,  )
     if( m_eErrorKind == CHERROR_RANGE &&
         eOldError != CHERROR_RANGE )
     {
-        m_aCbSyncPosNeg.Check(
-            (!m_aEdRangePositive.GetText().isEmpty()) &&
-            m_aEdRangePositive.GetText() == m_aEdRangeNegative.GetText());
+        m_pCbSyncPosNeg->Check(
+            (!m_pEdRangePositive->GetText().isEmpty()) &&
+            m_pEdRangePositive->GetText() == m_pEdRangeNegative->GetText());
     }
     // changed from range
     else if( m_eErrorKind != CHERROR_RANGE &&
         eOldError == CHERROR_RANGE )
     {
-        m_aCbSyncPosNeg.Check(
-            m_aMfPositive.GetValue() == m_aMfNegative.GetValue());
+        m_pCbSyncPosNeg->Check( m_pMfPositive->GetValue() == m_pMfNegative->GetValue());
     }
 
     UpdateControlStates();
-    return 0;
 }
 
-IMPL_LINK_NOARG(ErrorBarResources, SynchronizePosAndNeg)
+IMPL_LINK_NOARG_TYPED(ErrorBarResources, SynchronizePosAndNeg, CheckBox&, void)
 {
     UpdateControlStates();
-    PosValueChanged( 0 );
-    return 0;
+    PosValueChanged( *m_pMfPositive );
 }
 
-IMPL_LINK_NOARG(ErrorBarResources, PosValueChanged)
+IMPL_LINK_NOARG_TYPED(ErrorBarResources, PosValueChanged, Edit&, void)
 {
-    if( m_aCbSyncPosNeg.IsChecked())
+    if( m_pCbSyncPosNeg->IsChecked())
     {
-        if( m_aRbRange.IsChecked())
+        if( m_pRbRange->IsChecked())
         {
-            m_aEdRangeNegative.SetText( m_aEdRangePositive.GetText());
+            m_pEdRangeNegative->SetText( m_pEdRangePositive->GetText());
             m_bRangeNegUnique = m_bRangePosUnique;
         }
         else
-            m_aMfNegative.SetValue( m_aMfPositive.GetValue());
+            m_pMfNegative->SetValue( m_pMfPositive->GetValue());
     }
-
-    return 0;
 }
 
-IMPL_LINK_NOARG(ErrorBarResources, IndicatorChanged)
+IMPL_LINK_NOARG_TYPED(ErrorBarResources, IndicatorChanged, Button*, void)
 {
     m_bIndicatorUnique = true;
-    if( m_aRbBoth.IsChecked())
+    if( m_pRbBoth->IsChecked())
         m_eIndicate = CHINDICATE_BOTH;
-    else if( m_aRbPositive.IsChecked())
+    else if( m_pRbPositive->IsChecked())
         m_eIndicate = CHINDICATE_UP;
-    else if( m_aRbNegative.IsChecked())
+    else if( m_pRbNegative->IsChecked())
         m_eIndicate = CHINDICATE_DOWN;
     else
         m_bIndicatorUnique = false;
 
     UpdateControlStates();
-    return 0;
 }
 
-IMPL_LINK( ErrorBarResources, ChooseRange, RangeSelectionButton *, pButton )
+IMPL_LINK_TYPED( ErrorBarResources, ChooseRange, Button*, pButton, void )
 {
     OSL_ASSERT( m_apRangeSelectionHelper.get());
     if( ! m_apRangeSelectionHelper.get())
-        return 0;
-    OSL_ASSERT( m_pCurrentRangeChoosingField == 0 );
+        return;
+    OSL_ASSERT( m_pCurrentRangeChoosingField == nullptr );
 
     OUString aUIString;
-    if( pButton == &m_aIbRangePositive )
+
+    if( pButton == m_pIbRangePositive )
     {
-        m_pCurrentRangeChoosingField = &m_aEdRangePositive;
-        aUIString = SCH_RESSTR( STR_DATA_SELECT_RANGE_FOR_POSITIVE_ERRORBARS );
+        m_pCurrentRangeChoosingField = m_pEdRangePositive;
+        aUIString = m_pUIStringPos->GetText();
     }
     else
     {
-        m_pCurrentRangeChoosingField = &m_aEdRangeNegative;
-        aUIString = SCH_RESSTR( STR_DATA_SELECT_RANGE_FOR_NEGATIVE_ERRORBARS );
+        m_pCurrentRangeChoosingField = m_pEdRangeNegative;
+        aUIString = m_pUIStringNeg->GetText();
     }
 
     assert( m_pParentDialog );
@@ -464,104 +467,94 @@ IMPL_LINK( ErrorBarResources, ChooseRange, RangeSelectionButton *, pButton )
             aUIString, *this );
     }
     else
-        m_pCurrentRangeChoosingField = 0;
-
-    return 0;
+        m_pCurrentRangeChoosingField = nullptr;
 }
 
-IMPL_LINK( ErrorBarResources, RangeChanged, Edit *, pEdit )
+IMPL_LINK_TYPED( ErrorBarResources, RangeChanged, Edit&, rEdit, void )
 {
-    if( pEdit == & m_aEdRangePositive )
+    if( &rEdit == m_pEdRangePositive )
     {
         m_bRangePosUnique = true;
-        PosValueChanged( 0 );
+        PosValueChanged( *m_pMfPositive );
     }
     else
     {
         m_bRangeNegUnique = true;
     }
 
-    isRangeFieldContentValid( *pEdit );
-
-    return 0;
+    isRangeFieldContentValid( rEdit );
 }
 
 void ErrorBarResources::Reset(const SfxItemSet& rInAttrs)
 {
-    const SfxPoolItem *pPoolItem = NULL;
-    SfxItemState aState = SFX_ITEM_UNKNOWN;
+    const SfxPoolItem *pPoolItem = nullptr;
 
     // category
-     m_eErrorKind = CHERROR_NONE;
-    aState = rInAttrs.GetItemState( SCHATTR_STAT_KIND_ERROR, sal_True, &pPoolItem );
-    m_bErrorKindUnique = ( aState != SFX_ITEM_DONTCARE );
+    m_eErrorKind = CHERROR_NONE;
+    SfxItemState aState = rInAttrs.GetItemState( SCHATTR_STAT_KIND_ERROR, true, &pPoolItem );
+    m_bErrorKindUnique = ( aState != SfxItemState::DONTCARE );
 
-    if( aState == SFX_ITEM_SET )
-        m_eErrorKind = ((const SvxChartKindErrorItem*) pPoolItem)->GetValue();
+    if( aState == SfxItemState::SET )
+        m_eErrorKind = static_cast<const SvxChartKindErrorItem*>(pPoolItem)->GetValue();
 
-    m_aLbFunction.SelectEntryPos( lcl_getLbEntryPosByErrorKind( m_eErrorKind ));
+    m_pLbFunction->SelectEntryPos( lcl_getLbEntryPosByErrorKind( m_eErrorKind ));
 
     if( m_bErrorKindUnique )
     {
         switch( m_eErrorKind )
         {
             case CHERROR_NONE:
-                m_aRbNone.Check();
+                m_pRbNone->Check();
                 break;
             case CHERROR_PERCENT:
-                m_aRbPercent.Check();
+                m_pRbPercent->Check();
                 break;
             case CHERROR_CONST:
-                m_aRbConst.Check();
+                m_pRbConst->Check();
                 break;
             case CHERROR_STDERROR:
             case CHERROR_VARIANT:
             case CHERROR_SIGMA:
             case CHERROR_BIGERROR:
-                m_aRbFunction.Check();
+                m_pRbFunction->Check();
                 break;
             case CHERROR_RANGE:
-                m_aRbRange.Check();
+                m_pRbRange->Check();
                 break;
         }
     }
     else
     {
-        m_aRbNone.Check( sal_False );
-        m_aRbConst.Check( sal_False );
-        m_aRbPercent.Check( sal_False );
-        m_aRbFunction.Check( sal_False );
+        m_pRbNone->Check( false );
+        m_pRbConst->Check( false );
+        m_pRbPercent->Check( false );
+        m_pRbFunction->Check( false );
     }
 
     // parameters
-    aState = rInAttrs.GetItemState( SCHATTR_STAT_CONSTPLUS, sal_True, &pPoolItem );
-    m_bPlusUnique = ( aState != SFX_ITEM_DONTCARE );
-    double fPlusValue = 0.0;
-    if( aState == SFX_ITEM_SET )
+    aState = rInAttrs.GetItemState( SCHATTR_STAT_CONSTPLUS, true, &pPoolItem );
+    m_bPlusUnique = ( aState != SfxItemState::DONTCARE );
+    if( aState == SfxItemState::SET )
     {
-        fPlusValue = ((const SvxDoubleItem*) pPoolItem)->GetValue();
-        sal_Int32 nPlusValue = static_cast< sal_Int32 >( fPlusValue * pow(10.0,m_aMfPositive.GetDecimalDigits()) );
-        m_aMfPositive.SetValue( nPlusValue );
+        m_fPlusValue = static_cast<const SvxDoubleItem*>(pPoolItem)->GetValue();
     }
 
-    aState = rInAttrs.GetItemState( SCHATTR_STAT_CONSTMINUS, sal_True, &pPoolItem );
-    m_bMinusUnique = ( aState != SFX_ITEM_DONTCARE );
-    if( aState == SFX_ITEM_SET )
+    aState = rInAttrs.GetItemState( SCHATTR_STAT_CONSTMINUS, true, &pPoolItem );
+    m_bMinusUnique = ( aState != SfxItemState::DONTCARE );
+    if( aState == SfxItemState::SET )
     {
-        double fMinusValue = ((const SvxDoubleItem*) pPoolItem)->GetValue();
-        sal_Int32 nMinusValue = static_cast< sal_Int32 >( fMinusValue * pow(10.0,m_aMfNegative.GetDecimalDigits()) );
-        m_aMfNegative.SetValue( nMinusValue );
+        m_fMinusValue = static_cast<const SvxDoubleItem*>(pPoolItem)->GetValue();
 
         if( m_eErrorKind != CHERROR_RANGE &&
-            fPlusValue == fMinusValue )
-            m_aCbSyncPosNeg.Check();
+            m_fPlusValue == m_fMinusValue )
+            m_pCbSyncPosNeg->Check();
     }
 
     // indicator
-    aState = rInAttrs.GetItemState( SCHATTR_STAT_INDICATE, sal_True, &pPoolItem );
-    m_bIndicatorUnique = ( aState != SFX_ITEM_DONTCARE );
-    if( aState == SFX_ITEM_SET)
-        m_eIndicate = ((const SvxChartIndicateItem * ) pPoolItem)->GetValue();
+    aState = rInAttrs.GetItemState( SCHATTR_STAT_INDICATE, true, &pPoolItem );
+    m_bIndicatorUnique = ( aState != SfxItemState::DONTCARE );
+    if( aState == SfxItemState::SET)
+        m_eIndicate = static_cast<const SvxChartIndicateItem *>(pPoolItem)->GetValue();
 
     if( m_bIndicatorUnique )
     {
@@ -572,45 +565,45 @@ void ErrorBarResources::Reset(const SfxItemSet& rInAttrs)
                 m_eIndicate = CHINDICATE_BOTH;
                 // fall-through intended to BOTH
             case CHINDICATE_BOTH :
-                m_aRbBoth.Check(); break;
+                m_pRbBoth->Check(); break;
             case CHINDICATE_UP :
-                m_aRbPositive.Check(); break;
+                m_pRbPositive->Check(); break;
             case CHINDICATE_DOWN :
-                m_aRbNegative.Check(); break;
+                m_pRbNegative->Check(); break;
         }
     }
     else
     {
-        m_aRbBoth.Check( sal_False );
-        m_aRbPositive.Check( sal_False );
-        m_aRbNegative.Check( sal_False );
+        m_pRbBoth->Check( false );
+        m_pRbPositive->Check( false );
+        m_pRbNegative->Check( false );
     }
 
     // ranges
-    aState = rInAttrs.GetItemState( SCHATTR_STAT_RANGE_POS, sal_True, &pPoolItem );
-    m_bRangePosUnique = ( aState != SFX_ITEM_DONTCARE );
-    if( aState == SFX_ITEM_SET )
+    aState = rInAttrs.GetItemState( SCHATTR_STAT_RANGE_POS, true, &pPoolItem );
+    m_bRangePosUnique = ( aState != SfxItemState::DONTCARE );
+    if( aState == SfxItemState::SET )
     {
         OUString sRangePositive = (static_cast< const SfxStringItem * >( pPoolItem ))->GetValue();
-        m_aEdRangePositive.SetText( sRangePositive );
+        m_pEdRangePositive->SetText( sRangePositive );
     }
 
-    aState = rInAttrs.GetItemState( SCHATTR_STAT_RANGE_NEG, sal_True, &pPoolItem );
-    m_bRangeNegUnique = ( aState != SFX_ITEM_DONTCARE );
-    if( aState == SFX_ITEM_SET )
+    aState = rInAttrs.GetItemState( SCHATTR_STAT_RANGE_NEG, true, &pPoolItem );
+    m_bRangeNegUnique = ( aState != SfxItemState::DONTCARE );
+    if( aState == SfxItemState::SET )
     {
         OUString sRangeNegative = (static_cast< const SfxStringItem * >( pPoolItem ))->GetValue();
-        m_aEdRangeNegative.SetText( sRangeNegative );
+        m_pEdRangeNegative->SetText( sRangeNegative );
         if( m_eErrorKind == CHERROR_RANGE &&
             !sRangeNegative.isEmpty() &&
-            sRangeNegative == m_aEdRangePositive.GetText() )
-            m_aCbSyncPosNeg.Check();
+            sRangeNegative == m_pEdRangePositive->GetText() )
+            m_pCbSyncPosNeg->Check();
     }
 
     UpdateControlStates();
 }
 
-sal_Bool ErrorBarResources::FillItemSet(SfxItemSet& rOutAttrs) const
+bool ErrorBarResources::FillItemSet(SfxItemSet& rOutAttrs) const
 {
     if( m_bErrorKindUnique )
         rOutAttrs.Put( SvxChartKindErrorItem( m_eErrorKind, SCHATTR_STAT_KIND_ERROR ));
@@ -632,11 +625,11 @@ sal_Bool ErrorBarResources::FillItemSet(SfxItemSet& rOutAttrs) const
             }
             else
             {
-                aPosRange = m_aEdRangePositive.GetText();
-                if( m_aCbSyncPosNeg.IsChecked())
+                aPosRange = m_pEdRangePositive->GetText();
+                if( m_pCbSyncPosNeg->IsChecked())
                     aNegRange = aPosRange;
                 else
-                    aNegRange = m_aEdRangeNegative.GetText();
+                    aNegRange = m_pEdRangeNegative->GetText();
             }
 
             if( m_bRangePosUnique )
@@ -648,15 +641,15 @@ sal_Bool ErrorBarResources::FillItemSet(SfxItemSet& rOutAttrs) const
                  m_eErrorKind == CHERROR_PERCENT ||
                  m_eErrorKind == CHERROR_BIGERROR )
         {
-            double fPosValue = static_cast< double >( m_aMfPositive.GetValue()) /
-                pow( 10.0, m_aMfPositive.GetDecimalDigits());
+            double fPosValue = static_cast< double >( m_pMfPositive->GetValue()) /
+                pow( 10.0, m_pMfPositive->GetDecimalDigits());
             double fNegValue = 0.0;
 
-            if( m_aCbSyncPosNeg.IsChecked())
+            if( m_pCbSyncPosNeg->IsChecked())
                 fNegValue = fPosValue;
             else
-                fNegValue = static_cast< double >( m_aMfNegative.GetValue()) /
-                    pow( 10.0, m_aMfNegative.GetDecimalDigits());
+                fNegValue = static_cast< double >( m_pMfNegative->GetValue()) /
+                    pow( 10.0, m_pMfNegative->GetDecimalDigits());
 
             rOutAttrs.Put( SvxDoubleItem( fPosValue, SCHATTR_STAT_CONSTPLUS ));
             rOutAttrs.Put( SvxDoubleItem( fNegValue, SCHATTR_STAT_CONSTMINUS ));
@@ -665,22 +658,22 @@ sal_Bool ErrorBarResources::FillItemSet(SfxItemSet& rOutAttrs) const
 
     rOutAttrs.Put( SfxBoolItem( SCHATTR_STAT_ERRORBAR_TYPE , m_eErrorBarType == ERROR_BAR_Y ));
 
-    return sal_True;
+    return true;
 }
 
 void ErrorBarResources::FillValueSets()
 {
     if( m_eErrorBarType == ERROR_BAR_Y )
     {
-        m_aFiNegative.SetImage( Image( SchResId( BMP_INDICATE_DOWN       ) ) );
-        m_aFiPositive.SetImage( Image( SchResId( BMP_INDICATE_UP         ) ) );
-        m_aFiBoth.SetImage(     Image( SchResId( BMP_INDICATE_BOTH_VERTI ) ) );
+        m_pFiNegative->SetImage( Image( SchResId( BMP_INDICATE_DOWN       ) ) );
+        m_pFiPositive->SetImage( Image( SchResId( BMP_INDICATE_UP         ) ) );
+        m_pFiBoth->SetImage(     Image( SchResId( BMP_INDICATE_BOTH_VERTI ) ) );
     }
     else if( m_eErrorBarType == ERROR_BAR_X )
     {
-        m_aFiNegative.SetImage( Image( SchResId( BMP_INDICATE_LEFT      ) ) );
-        m_aFiPositive.SetImage( Image( SchResId( BMP_INDICATE_RIGHT     ) ) );
-        m_aFiBoth.SetImage(     Image( SchResId( BMP_INDICATE_BOTH_HORI ) ) );
+        m_pFiNegative->SetImage( Image( SchResId( BMP_INDICATE_LEFT      ) ) );
+        m_pFiPositive->SetImage( Image( SchResId( BMP_INDICATE_RIGHT     ) ) );
+        m_pFiBoth->SetImage(     Image( SchResId( BMP_INDICATE_BOTH_HORI ) ) );
     }
 }
 
@@ -698,20 +691,20 @@ void ErrorBarResources::listeningFinished(
     m_apRangeSelectionHelper->stopRangeListening();
 
     // change edit field
-    if( m_pParentWindow )
-    {
-        m_pParentWindow->ToTop();
-        m_pParentWindow->GrabFocus();
-    }
+//     if( m_pParentWindow )
+//     {
+//         m_pParentWindow->ToTop();
+//         m_pParentWindow->GrabFocus();
+//     }
 
     if( m_pCurrentRangeChoosingField )
     {
         m_pCurrentRangeChoosingField->SetText( aRange );
         m_pCurrentRangeChoosingField->GrabFocus();
-        PosValueChanged( 0 );
+        PosValueChanged( *m_pMfPositive );
     }
 
-    m_pCurrentRangeChoosingField = 0;
+    m_pCurrentRangeChoosingField = nullptr;
 
     UpdateControlStates();
     OSL_ASSERT( m_pParentDialog );
