@@ -17,6 +17,8 @@
  *   the License at http://www.apache.org/licenses/LICENSE-2.0 .
  */
 
+#include <vcl/layout.hxx>
+#include <vcl/builderfactory.hxx>
 #include "tp_DataSourceControls.hxx"
 
 using namespace ::com::sun::star;
@@ -30,12 +32,18 @@ namespace chart
 SeriesEntry::~SeriesEntry()
 {}
 
-SeriesListBox::SeriesListBox( Window* pParent, const ResId & rResId ) :
-        SvTreeListBox( pParent, rResId )
+SeriesListBox::SeriesListBox(vcl::Window* pParent, WinBits nStyle)
+    : SvTreeListBox(pParent, nStyle)
 {}
 
-SeriesListBox::~SeriesListBox()
-{}
+VCL_BUILDER_DECL_FACTORY(SeriesListBox)
+{
+    WinBits nWinStyle = 0;
+    OString sBorder = VclBuilder::extractCustomProperty(rMap);
+    if (!sBorder.isEmpty())
+        nWinStyle |= WB_BORDER;
+    rRet = VclPtr<SeriesListBox>::Create(pParent, nWinStyle);
+}
 
 SvTreeListEntry* SeriesListBox::CreateEntry() const
 {
