@@ -48,14 +48,13 @@ using namespace ::com::sun::star;
 
 ViewElementListProvider::ViewElementListProvider( DrawModelWrapper* pDrawModelWrapper )
                         : m_pDrawModelWrapper( pDrawModelWrapper )
-                        , m_pFontList(NULL)
+                        , m_pFontList(nullptr)
 {
 }
 
 ViewElementListProvider::~ViewElementListProvider()
 {
-    if(m_pFontList)
-        delete m_pFontList;
+    delete m_pFontList;
 }
 
 XColorListRef   ViewElementListProvider::GetColorTable() const
@@ -89,7 +88,7 @@ XHatchListRef    ViewElementListProvider::GetHatchList() const
 {
     if(m_pDrawModelWrapper)
         return m_pDrawModelWrapper->GetHatchList();
-    return NULL;
+    return nullptr;
 }
 
 XBitmapListRef   ViewElementListProvider::GetBitmapList() const
@@ -102,8 +101,8 @@ XBitmapListRef   ViewElementListProvider::GetBitmapList() const
 //create chartspecific symbols for linecharts
 SdrObjList* ViewElementListProvider::GetSymbolList() const
 {
-    SdrObjList* m_pSymbolList = NULL;
-    uno::Reference< drawing::XShapes > m_xSymbols(NULL);//@todo this keeps the first drawinglayer alive ...
+    SdrObjList* m_pSymbolList = nullptr;
+    uno::Reference< drawing::XShapes > m_xSymbols(nullptr);//@todo this keeps the first drawinglayer alive ...
     try
     {
         if(!m_pSymbolList || !m_pSymbolList->GetObjCount())
@@ -143,14 +142,14 @@ Graphic ViewElementListProvider::GetSymbolGraphic( sal_Int32 nStandardSymbol, co
         nStandardSymbol %= pSymbolList->GetObjCount();
     SdrObject* pObj = pSymbolList->GetObj(nStandardSymbol);
 
-    VirtualDevice aVDev;
-    aVDev.SetMapMode(MapMode(MAP_100TH_MM));
+    ScopedVclPtrInstance< VirtualDevice > pVDev;
+    pVDev->SetMapMode(MapMode(MAP_100TH_MM));
     SdrModel* pModel = new SdrModel();
     pModel->GetItemPool().FreezeIdRanges();
     SdrPage* pPage = new SdrPage( *pModel, false );
     pPage->SetSize(Size(1000,1000));
     pModel->InsertPage( pPage, 0 );
-    SdrView* pView = new SdrView( pModel, &aVDev );
+    SdrView* pView = new SdrView( pModel, pVDev );
     pView->hideMarkHandles();
     SdrPageView* pPageView = pView->ShowSdrPage(pPage);
 
@@ -183,10 +182,10 @@ FontList* ViewElementListProvider::getFontList() const
 
     if(!m_pFontList)
     {
-        OutputDevice* pRefDev    = m_pDrawModelWrapper ? m_pDrawModelWrapper->getReferenceDevice() : NULL;
+        OutputDevice* pRefDev    = m_pDrawModelWrapper ? m_pDrawModelWrapper->getReferenceDevice() : nullptr;
         OutputDevice* pDefaultOut = Application::GetDefaultDevice();
         m_pFontList = new FontList( pRefDev ? pRefDev    : pDefaultOut
-                                , pRefDev ? pDefaultOut : NULL
+                                , pRefDev ? pDefaultOut : nullptr
                                 , false );
     }
     return m_pFontList;
