@@ -41,6 +41,7 @@
 #include <com/sun/star/chart/ChartDataRowSource.hpp>
 #include <rtl/ustrbuf.hxx>
 #include <unotools/charclass.hxx>
+#include <cppuhelper/supportsservice.hxx>
 #include <comphelper/sequenceashashmap.hxx>
 
 #include <vector>
@@ -59,14 +60,14 @@ namespace
 {
 
 // note: in xmloff this name is used to indicate usage of own data
-static const OUString lcl_aServiceName( "com.sun.star.comp.chart.InternalDataProvider" );
+static const char lcl_aServiceName[] = "com.sun.star.comp.chart.InternalDataProvider";
 
-static const OUString lcl_aCategoriesRangeName( "categories" );
-static const OUString lcl_aCategoriesLevelRangeNamePrefix( "categoriesL " ); //L <-> level
-static const OUString lcl_aCategoriesPointRangeNamePrefix( "categoriesP " ); //P <-> point
-static const OUString lcl_aCategoriesRoleName( "categories" );
-static const OUString lcl_aLabelRangePrefix( "label " );
-static const OUString lcl_aCompleteRange( "all" );
+static const char lcl_aCategoriesRangeName[] = "categories";
+static const char lcl_aCategoriesLevelRangeNamePrefix[] = "categoriesL "; //L <-> level
+static const char lcl_aCategoriesPointRangeNamePrefix[] = "categoriesP "; //P <-> point
+static const char lcl_aCategoriesRoleName[] = "categories";
+static const char lcl_aLabelRangePrefix[] = "label ";
+static const char lcl_aCompleteRange[] = "all";
 
 typedef ::std::multimap< OUString, uno::WeakReference< chart2::data::XDataSequence > >
     lcl_tSequenceMap;
@@ -160,15 +161,13 @@ struct lcl_internalizeSeries : public ::std::unary_function< Reference< chart2::
                         comphelper::copyProperties(
                             Reference< beans::XPropertySet >( xLabel, uno::UNO_QUERY ),
                             Reference< beans::XPropertySet >( xNewLabel, uno::UNO_QUERY ));
-                        aNewSeriesData[i] = Reference< chart2::data::XLabeledDataSequence >(
-                                new LabeledDataSequence( xNewValues, xNewLabel ));
+                        aNewSeriesData[i].set( new LabeledDataSequence( xNewValues, xNewLabel ) );
                     }
                 }
                 else
                 {
                     if( m_bConnectToModel )
-                        aNewSeriesData[i] = Reference< chart2::data::XLabeledDataSequence >(
-                            new LabeledDataSequence( xNewValues ));
+                        aNewSeriesData[i].set( new LabeledDataSequence( xNewValues ) );
                 }
             }
             if( m_bConnectToModel )
@@ -343,9 +342,8 @@ InternalDataProvider::InternalDataProvider(
             {
                 vector< vector< uno::Any > > aNewCategories;//inner count is level
                 {
-                    ChartModel* pModel = dynamic_cast<ChartModel*>(xChartModel.get());
-                    assert(pModel);
-                    ExplicitCategoriesProvider aExplicitCategoriesProvider( ChartModelHelper::getFirstCoordinateSystem(xChartModel), *pModel );
+                    ChartModel& rModel = dynamic_cast<ChartModel&>(*xChartModel.get());
+                    ExplicitCategoriesProvider aExplicitCategoriesProvider(ChartModelHelper::getFirstCoordinateSystem(xChartModel), rModel);
 
                     const Sequence< Reference< chart2::data::XLabeledDataSequence> >& rSplitCategoriesList( aExplicitCategoriesProvider.getSplitCategoriesList() );
                     sal_Int32 nLevelCount = rSplitCategoriesList.getLength();
@@ -392,7 +390,9 @@ InternalDataProvider::InternalDataProvider(
 
             // data series
             ::std::vector< Reference< chart2::XDataSeries > > aSeriesVector( ChartModelHelper::getDataSeries( xChartDoc ));
-            ::std::for_each( aSeriesVector.begin(), aSeriesVector.end(), lcl_internalizeSeries( m_aInternalData, *this, bConnectToModel, m_bDataInColumns ) );
+            lcl_internalizeSeries ftor( m_aInternalData, *this, bConnectToModel, m_bDataInColumns );
+            for( const auto& rxScreen : aSeriesVector )
+                ftor( rxScreen );
         }
     }
     catch( const uno::Exception & ex )
@@ -412,7 +412,7 @@ InternalDataProvider::InternalDataProvider( const InternalDataProvider & rOther
 InternalDataProvider::~InternalDataProvider()
 {}
 
-void InternalDataProvider::lcl_addDataSequenceToMap(
+void InternalDataProvider::addDataSequenceToMap(
     const OUString & rRangeRepresentation,
     const Reference< chart2::data::XDataSequence > & xSequence )
 {
@@ -422,7 +422,7 @@ void InternalDataProvider::lcl_addDataSequenceToMap(
             uno::WeakReference< chart2::data::XDataSequence >( xSequence )));
 }
 
-void InternalDataProvider::lcl_deleteMapReferences( const OUString & rRangeRepresentation )
+void InternalDataProvider::deleteMapReferences( const OUString & rRangeRepresentation )
 {
     // set sequence to deleted by setting its range to an empty string
     tSequenceMapRange aRange( m_aSequenceMap.equal_range( rRangeRepresentation ));
@@ -440,7 +440,7 @@ void InternalDataProvider::lcl_deleteMapReferences( const OUString & rRangeRepre
     m_aSequenceMap.erase( aRange.first, aRange.second );
 }
 
-void InternalDataProvider::lcl_adaptMapReferences(
+void InternalDataProvider::adaptMapReferences(
     const OUString & rOldRangeRepresentation,
     const OUString & rNewRangeRepresentation )
 {
@@ -465,31 +465,31 @@ void InternalDataProvider::lcl_adaptMapReferences(
                                   m_aSequenceMap.upper_bound( rNewRangeRepresentation )));
 }
 
-void InternalDataProvider::lcl_increaseMapReferences(
+void InternalDataProvider::increaseMapReferences(
     sal_Int32 nBegin, sal_Int32 nEnd )
 {
     for( sal_Int32 nIndex = nEnd - 1; nIndex >= nBegin; --nIndex )
     {
-        lcl_adaptMapReferences( OUString::number( nIndex ),
+        adaptMapReferences( OUString::number( nIndex ),
                             OUString::number( nIndex + 1 ));
-        lcl_adaptMapReferences( lcl_aLabelRangePrefix + OUString::number( nIndex ),
+        adaptMapReferences( lcl_aLabelRangePrefix + OUString::number( nIndex ),
                             lcl_aLabelRangePrefix + OUString::number( nIndex + 1 ));
     }
 }
 
-void InternalDataProvider::lcl_decreaseMapReferences(
+void InternalDataProvider::decreaseMapReferences(
     sal_Int32 nBegin, sal_Int32 nEnd )
 {
     for( sal_Int32 nIndex = nBegin; nIndex < nEnd; ++nIndex )
     {
-        lcl_adaptMapReferences( OUString::number( nIndex ),
+        adaptMapReferences( OUString::number( nIndex ),
                             OUString::number( nIndex - 1 ));
-        lcl_adaptMapReferences( lcl_aLabelRangePrefix + OUString::number( nIndex ),
+        adaptMapReferences( lcl_aLabelRangePrefix + OUString::number( nIndex ),
                             lcl_aLabelRangePrefix + OUString::number( nIndex - 1 ));
     }
 }
 
-Reference< chart2::data::XDataSequence > InternalDataProvider::lcl_createDataSequenceAndAddToMap(
+Reference< chart2::data::XDataSequence > InternalDataProvider::createDataSequenceAndAddToMap(
     const OUString & rRangeRepresentation )
 {
     Reference<chart2::data::XDataSequence> xSeq = createDataSequenceFromArray(rRangeRepresentation, OUString());
@@ -497,7 +497,7 @@ Reference< chart2::data::XDataSequence > InternalDataProvider::lcl_createDataSeq
         return xSeq;
 
     xSeq.set(new UncachedDataSequence(this, rRangeRepresentation));
-    lcl_addDataSequenceToMap(rRangeRepresentation, xSeq);
+    addDataSequenceToMap(rRangeRepresentation, xSeq);
     return xSeq;
 }
 
@@ -515,7 +515,7 @@ InternalDataProvider::createDataSequenceFromArray( const OUString& rArrayStr, co
 
     const sal_Unicode* p = rArrayStr.getStr();
     const sal_Unicode* pEnd = p + rArrayStr.getLength();
-    const sal_Unicode* pElem = NULL;
+    const sal_Unicode* pElem = nullptr;
     OUString aElem;
 
     std::vector<OUString> aRawElems;
@@ -542,8 +542,8 @@ InternalDataProvider::createDataSequenceFromArray( const OUString& rArrayStr, co
                 if (pElem)
                     aElem = OUString(pElem, p-pElem);
                 aRawElems.push_back(aElem);
-                pElem = NULL;
-                aElem = OUString();
+                pElem = nullptr;
+                aElem.clear();
 
                 ++p; // Skip '"'.
                 if (p == pEnd)
@@ -560,8 +560,8 @@ InternalDataProvider::createDataSequenceFromArray( const OUString& rArrayStr, co
             if (pElem)
                 aElem = OUString(pElem, p-pElem);
             aRawElems.push_back(aElem);
-            pElem = NULL;
-            aElem = OUString();
+            pElem = nullptr;
+            aElem.clear();
         }
         else if (!pElem)
             pElem = p;
@@ -588,7 +588,7 @@ InternalDataProvider::createDataSequenceFromArray( const OUString& rArrayStr, co
 
         OUString aRangeRep = OUString::number(n);
         xSeq.set(new UncachedDataSequence(this, aRangeRep));
-        lcl_addDataSequenceToMap(aRangeRep, xSeq);
+        addDataSequenceToMap(aRangeRep, xSeq);
     }
     else if (rRole == "values-x")
     {
@@ -610,7 +610,7 @@ InternalDataProvider::createDataSequenceFromArray( const OUString& rArrayStr, co
 
         OUString aRangeRep = OUString::number(n);
         xSeq.set(new UncachedDataSequence(this, aRangeRep));
-        lcl_addDataSequenceToMap(aRangeRep, xSeq);
+        addDataSequenceToMap(aRangeRep, xSeq);
     }
     else if (rRole == "categories")
     {
@@ -623,7 +623,7 @@ InternalDataProvider::createDataSequenceFromArray( const OUString& rArrayStr, co
         }
 
         xSeq.set(new UncachedDataSequence(this, lcl_aCategoriesRangeName));
-        lcl_addDataSequenceToMap(lcl_aCategoriesRangeName, xSeq);
+        addDataSequenceToMap(lcl_aCategoriesRangeName, xSeq);
     }
     else if (rRole == "label")
     {
@@ -637,20 +637,20 @@ InternalDataProvider::createDataSequenceFromArray( const OUString& rArrayStr, co
 
             OUString aRangeRep = lcl_aLabelRangePrefix + OUString::number(nColSize-1);
             xSeq.set(new UncachedDataSequence(this, aRangeRep));
-            lcl_addDataSequenceToMap(aRangeRep, xSeq);
+            addDataSequenceToMap(aRangeRep, xSeq);
         }
     }
 
     return xSeq;
 }
 
-Reference< chart2::data::XDataSequence > InternalDataProvider::lcl_createDataSequenceAndAddToMap(
+Reference< chart2::data::XDataSequence > InternalDataProvider::createDataSequenceAndAddToMap(
     const OUString & rRangeRepresentation,
     const OUString & rRole )
 {
     Reference< chart2::data::XDataSequence > xSeq(
         new UncachedDataSequence( this, rRangeRepresentation, rRole ));
-    lcl_addDataSequenceToMap( rRangeRepresentation, xSeq );
+    addDataSequenceToMap( rRangeRepresentation, xSeq );
     return xSeq;
 }
 
@@ -696,7 +696,7 @@ Reference< chart2::data::XDataSource > SAL_CALL InternalDataProvider::createData
     uno::Sequence< sal_Int32 > aSequenceMapping;
     DataSourceHelper::readArguments( aArguments, aRangeRepresentation, aSequenceMapping, bUseColumns, bFirstCellAsLabel, bHasCategories );
 
-    if( aRangeRepresentation.equals( lcl_aCategoriesRangeName ) )
+    if( aRangeRepresentation == lcl_aCategoriesRangeName )
     {
         //return split complex categories if we have any:
         ::std::vector< Reference< chart2::data::XLabeledDataSequence > > aComplexCategories;
@@ -720,17 +720,17 @@ Reference< chart2::data::XDataSource > SAL_CALL InternalDataProvider::createData
                         , lcl_aCategoriesRoleName ) ) );
         }
         //don't add the created sequences to the map as they are used temporarily only ...
-        return new DataSource( ContainerHelper::ContainerToSequence(aComplexCategories) );
+        return new DataSource( comphelper::containerToSequence(aComplexCategories) );
     }
 
-    OSL_ASSERT( aRangeRepresentation.equals( lcl_aCompleteRange ));
+    OSL_ASSERT( aRangeRepresentation == lcl_aCompleteRange );
 
     ::std::vector< Reference< chart2::data::XLabeledDataSequence > > aResultLSeqVec;
 
     // categories
     if( bHasCategories )
         aResultLSeqVec.push_back(
-            new LabeledDataSequence( lcl_createDataSequenceAndAddToMap( lcl_aCategoriesRangeName, lcl_aCategoriesRoleName ) ) );
+            new LabeledDataSequence( createDataSequenceAndAddToMap( lcl_aCategoriesRangeName, lcl_aCategoriesRoleName ) ) );
 
     // data with labels
     ::std::vector< Reference< chart2::data::XLabeledDataSequence > > aDataVec;
@@ -739,8 +739,8 @@ Reference< chart2::data::XDataSource > SAL_CALL InternalDataProvider::createData
     {
         aDataVec.push_back(
             new LabeledDataSequence(
-                lcl_createDataSequenceAndAddToMap( OUString::number( nIdx )),
-                lcl_createDataSequenceAndAddToMap( lcl_aLabelRangePrefix + OUString::number( nIdx ))));
+                createDataSequenceAndAddToMap( OUString::number( nIdx )),
+                createDataSequenceAndAddToMap( lcl_aLabelRangePrefix + OUString::number( nIdx ))));
     }
 
     // attention: this data provider has the limitation that it stores
@@ -758,7 +758,7 @@ Reference< chart2::data::XDataSource > SAL_CALL InternalDataProvider::createData
             if( aDataVec[nOldIndex].is() )
             {
                 aResultLSeqVec.push_back( aDataVec[nOldIndex] );
-                aDataVec[nOldIndex] = 0;
+                aDataVec[nOldIndex] = nullptr;
             }
         }
     }
@@ -772,7 +772,7 @@ Reference< chart2::data::XDataSource > SAL_CALL InternalDataProvider::createData
             aResultLSeqVec.push_back( *aIt );
     }
 
-    return new DataSource( ContainerHelper::ContainerToSequence(aResultLSeqVec) );
+    return new DataSource( comphelper::containerToSequence(aResultLSeqVec) );
 }
 
 Sequence< beans::PropertyValue > SAL_CALL InternalDataProvider::detectArguments(
@@ -781,7 +781,7 @@ Sequence< beans::PropertyValue > SAL_CALL InternalDataProvider::detectArguments(
 {
     Sequence< beans::PropertyValue > aArguments( 4 );
     aArguments[0] = beans::PropertyValue(
-        "CellRangeRepresentation", -1, uno::makeAny( lcl_aCompleteRange ),
+        "CellRangeRepresentation", -1, uno::makeAny( OUString(lcl_aCompleteRange) ),
         beans::PropertyState_DIRECT_VALUE );
     aArguments[1] = beans::PropertyValue(
         "DataRowSource", -1, uno::makeAny(
@@ -814,28 +814,28 @@ Reference< chart2::data::XDataSequence > SAL_CALL InternalDataProvider::createDa
 {
     if( aRangeRepresentation.match( lcl_aCategoriesRangeName ))
     {
-        OSL_ASSERT( aRangeRepresentation.equals( lcl_aCategoriesRangeName ) );//it is not expected nor implmented that only parts of the categories are really requested
+        OSL_ASSERT( aRangeRepresentation == lcl_aCategoriesRangeName );//it is not expected nor implemented that only parts of the categories are really requested
 
         // categories
-        return lcl_createDataSequenceAndAddToMap( lcl_aCategoriesRangeName, lcl_aCategoriesRoleName );
+        return createDataSequenceAndAddToMap( lcl_aCategoriesRangeName, lcl_aCategoriesRoleName );
     }
     else if( aRangeRepresentation.match( lcl_aLabelRangePrefix ))
     {
         // label
-        sal_Int32 nIndex = aRangeRepresentation.copy( lcl_aLabelRangePrefix.getLength()).toInt32();
-        return lcl_createDataSequenceAndAddToMap( lcl_aLabelRangePrefix + OUString::number( nIndex ));
+        sal_Int32 nIndex = aRangeRepresentation.copy( strlen(lcl_aLabelRangePrefix)).toInt32();
+        return createDataSequenceAndAddToMap( lcl_aLabelRangePrefix + OUString::number( nIndex ));
     }
     else if ( aRangeRepresentation == "last" )
     {
         sal_Int32 nIndex = (m_bDataInColumns
                             ? m_aInternalData.getColumnCount()
                             : m_aInternalData.getRowCount()) - 1;
-        return lcl_createDataSequenceAndAddToMap( OUString::number( nIndex ));
+        return createDataSequenceAndAddToMap( OUString::number( nIndex ));
     }
     else if( !aRangeRepresentation.isEmpty())
     {
         // data
-        return lcl_createDataSequenceAndAddToMap( aRangeRepresentation );
+        return createDataSequenceAndAddToMap( aRangeRepresentation );
     }
 
     return Reference< chart2::data::XDataSequence >();
@@ -864,12 +864,12 @@ sal_Bool SAL_CALL InternalDataProvider::hasDataByRangeRepresentation( const OUSt
 
     if( aRange.match( lcl_aCategoriesRangeName ))
     {
-        OSL_ASSERT( aRange.equals( lcl_aCategoriesRangeName ) );//it is not expected nor implmented that only parts of the categories are really requested
+        OSL_ASSERT( aRange == lcl_aCategoriesRangeName );//it is not expected nor implemented that only parts of the categories are really requested
         bResult = true;
     }
     else if( aRange.match( lcl_aLabelRangePrefix ))
     {
-        sal_Int32 nIndex = aRange.copy( lcl_aLabelRangePrefix.getLength()).toInt32();
+        sal_Int32 nIndex = aRange.copy( strlen(lcl_aLabelRangePrefix)).toInt32();
         bResult = (nIndex < (m_bDataInColumns ? m_aInternalData.getColumnCount(): m_aInternalData.getRowCount()));
     }
     else
@@ -888,25 +888,25 @@ Sequence< uno::Any > SAL_CALL InternalDataProvider::getDataByRangeRepresentation
 
     if( aRange.match( lcl_aLabelRangePrefix ) )
     {
-        sal_Int32 nIndex = aRange.copy( lcl_aLabelRangePrefix.getLength()).toInt32();
+        sal_Int32 nIndex = aRange.copy( strlen(lcl_aLabelRangePrefix)).toInt32();
         vector< uno::Any > aComplexLabel = m_bDataInColumns
             ? m_aInternalData.getComplexColumnLabel( nIndex )
             : m_aInternalData.getComplexRowLabel( nIndex );
         if( !aComplexLabel.empty() )
-            aResult = ContainerHelper::ContainerToSequence(aComplexLabel);
+            aResult = comphelper::containerToSequence(aComplexLabel);
     }
     else if( aRange.match( lcl_aCategoriesPointRangeNamePrefix ) )
     {
-        sal_Int32 nPointIndex = aRange.copy( lcl_aCategoriesPointRangeNamePrefix.getLength() ).toInt32();
+        sal_Int32 nPointIndex = aRange.copy( strlen(lcl_aCategoriesPointRangeNamePrefix) ).toInt32();
         vector< uno::Any > aComplexCategory = m_bDataInColumns
             ? m_aInternalData.getComplexRowLabel( nPointIndex )
             : m_aInternalData.getComplexColumnLabel( nPointIndex );
         if( !aComplexCategory.empty() )
-            aResult = ContainerHelper::ContainerToSequence(aComplexCategory);
+            aResult = comphelper::containerToSequence(aComplexCategory);
     }
     else if( aRange.match( lcl_aCategoriesLevelRangeNamePrefix ) )
     {
-        sal_Int32 nLevel = aRange.copy( lcl_aCategoriesLevelRangeNamePrefix.getLength() ).toInt32();
+        sal_Int32 nLevel = aRange.copy( strlen(lcl_aCategoriesLevelRangeNamePrefix) ).toInt32();
         vector< vector< uno::Any > > aCategories( m_bDataInColumns ? m_aInternalData.getComplexRowLabels() : m_aInternalData.getComplexColumnLabels());
         if( nLevel < lcl_getInnerLevelCount( aCategories ) )
         {
@@ -915,7 +915,7 @@ Sequence< uno::Any > SAL_CALL InternalDataProvider::getDataByRangeRepresentation
                        aResult.getArray(), lcl_copyFromLevel(nLevel) );
         }
     }
-    else if( aRange.equals( lcl_aCategoriesRangeName ) )
+    else if( aRange == lcl_aCategoriesRangeName )
     {
         vector< vector< uno::Any > > aCategories( m_bDataInColumns ? m_aInternalData.getComplexRowLabels() : m_aInternalData.getComplexColumnLabels());
         sal_Int32 nLevelCount = lcl_getInnerLevelCount( aCategories );
@@ -961,7 +961,7 @@ void SAL_CALL InternalDataProvider::setDataByRangeRepresentation(
     vector< uno::Any > aNewVector( ContainerHelper::SequenceToVector(aNewData) );
     if( aRange.match( lcl_aLabelRangePrefix ) )
     {
-        sal_uInt32 nIndex = aRange.copy( lcl_aLabelRangePrefix.getLength()).toInt32();
+        sal_uInt32 nIndex = aRange.copy( strlen(lcl_aLabelRangePrefix)).toInt32();
         if( m_bDataInColumns )
             m_aInternalData.setComplexColumnLabel( nIndex, aNewVector );
         else
@@ -969,7 +969,7 @@ void SAL_CALL InternalDataProvider::setDataByRangeRepresentation(
     }
     else if( aRange.match( lcl_aCategoriesPointRangeNamePrefix ) )
     {
-        sal_Int32 nPointIndex = aRange.copy( lcl_aCategoriesLevelRangeNamePrefix.getLength()).toInt32();
+        sal_Int32 nPointIndex = aRange.copy( strlen(lcl_aCategoriesLevelRangeNamePrefix)).toInt32();
         if( m_bDataInColumns )
             m_aInternalData.setComplexRowLabel( nPointIndex, aNewVector );
         else
@@ -977,7 +977,7 @@ void SAL_CALL InternalDataProvider::setDataByRangeRepresentation(
     }
     else if( aRange.match( lcl_aCategoriesLevelRangeNamePrefix ) )
     {
-        sal_Int32 nLevel = aRange.copy( lcl_aCategoriesLevelRangeNamePrefix.getLength()).toInt32();
+        sal_Int32 nLevel = aRange.copy( strlen(lcl_aCategoriesLevelRangeNamePrefix)).toInt32();
         vector< vector< uno::Any > > aComplexCategories = m_bDataInColumns ? m_aInternalData.getComplexRowLabels() : m_aInternalData.getComplexColumnLabels();
 
         //ensure equal length
@@ -994,7 +994,7 @@ void SAL_CALL InternalDataProvider::setDataByRangeRepresentation(
         else
             m_aInternalData.setComplexColumnLabels( aComplexCategories );
     }
-    else if( aRange.equals( lcl_aCategoriesRangeName ) )
+    else if( aRange == lcl_aCategoriesRangeName )
     {
         vector< vector< uno::Any > > aComplexCategories;
         aComplexCategories.resize( aNewVector.size() );
@@ -1026,12 +1026,12 @@ void SAL_CALL InternalDataProvider::insertSequence( ::sal_Int32 nAfterIndex )
 {
     if( m_bDataInColumns )
     {
-        lcl_increaseMapReferences( nAfterIndex + 1, m_aInternalData.getColumnCount());
+        increaseMapReferences( nAfterIndex + 1, m_aInternalData.getColumnCount());
         m_aInternalData.insertColumn( nAfterIndex );
     }
     else
     {
-        lcl_increaseMapReferences( nAfterIndex + 1, m_aInternalData.getRowCount());
+        increaseMapReferences( nAfterIndex + 1, m_aInternalData.getRowCount());
         m_aInternalData.insertRow( nAfterIndex );
     }
 }
@@ -1039,16 +1039,16 @@ void SAL_CALL InternalDataProvider::insertSequence( ::sal_Int32 nAfterIndex )
 void SAL_CALL InternalDataProvider::deleteSequence( ::sal_Int32 nAtIndex )
     throw (uno::RuntimeException, std::exception)
 {
-    lcl_deleteMapReferences( OUString::number( nAtIndex ));
-    lcl_deleteMapReferences( lcl_aLabelRangePrefix + OUString::number( nAtIndex ));
+    deleteMapReferences( OUString::number( nAtIndex ));
+    deleteMapReferences( lcl_aLabelRangePrefix + OUString::number( nAtIndex ));
     if( m_bDataInColumns )
     {
-        lcl_decreaseMapReferences( nAtIndex + 1, m_aInternalData.getColumnCount());
+        decreaseMapReferences( nAtIndex + 1, m_aInternalData.getColumnCount());
         m_aInternalData.deleteColumn( nAtIndex );
     }
     else
     {
-        lcl_decreaseMapReferences( nAtIndex + 1, m_aInternalData.getRowCount());
+        decreaseMapReferences( nAtIndex + 1, m_aInternalData.getRowCount());
         m_aInternalData.deleteRow( nAtIndex );
     }
 }
@@ -1169,7 +1169,7 @@ void SAL_CALL InternalDataProvider::registerDataSequenceForChanges( const Refere
     throw (uno::RuntimeException, std::exception)
 {
     if( xSeq.is())
-        lcl_addDataSequenceToMap( xSeq->getSourceRangeRepresentation(), xSeq );
+        addDataSequenceToMap( xSeq->getSourceRangeRepresentation(), xSeq );
 }
 
 // ____ XRangeXMLConversion ____
@@ -1186,7 +1186,7 @@ OUString SAL_CALL InternalDataProvider::convertRangeToXML( const OUString& aRang
     // @todo: add this information in the range representation strings
     if( aRangeRepresentation.match( lcl_aCategoriesRangeName ))
     {
-        OSL_ASSERT( aRangeRepresentation.equals( lcl_aCategoriesRangeName ) );//it is not expected nor implmented that only parts of the categories are really requested
+        OSL_ASSERT( aRangeRepresentation == lcl_aCategoriesRangeName );//it is not expected nor implemented that only parts of the categories are really requested
         aRange.aUpperLeft.bIsEmpty = false;
         if( m_bDataInColumns )
         {
@@ -1205,7 +1205,7 @@ OUString SAL_CALL InternalDataProvider::convertRangeToXML( const OUString& aRang
     }
     else if( aRangeRepresentation.match( lcl_aLabelRangePrefix ))
     {
-        sal_Int32 nIndex = aRangeRepresentation.copy( lcl_aLabelRangePrefix.getLength()).toInt32();
+        sal_Int32 nIndex = aRangeRepresentation.copy( strlen(lcl_aLabelRangePrefix)).toInt32();
         aRange.aUpperLeft.bIsEmpty = false;
         aRange.aLowerRight.bIsEmpty = true;
         if( m_bDataInColumns )
@@ -1219,7 +1219,7 @@ OUString SAL_CALL InternalDataProvider::convertRangeToXML( const OUString& aRang
             aRange.aUpperLeft.nRow = nIndex + 1;
         }
     }
-    else if( aRangeRepresentation.equals( lcl_aCompleteRange ))
+    else if( aRangeRepresentation == lcl_aCompleteRange )
     {
         aRange.aUpperLeft.bIsEmpty = false;
         aRange.aLowerRight.bIsEmpty = false;
@@ -1266,7 +1266,7 @@ OUString SAL_CALL InternalDataProvider::convertRangeFromXML( const OUString& aXM
     if( !aRange.aLowerRight.bIsEmpty &&
         ( aRange.aUpperLeft.nColumn != aRange.aLowerRight.nColumn ) &&
         ( aRange.aUpperLeft.nRow != aRange.aLowerRight.nRow ) )
-        return lcl_aCompleteRange;
+        return OUString(lcl_aCompleteRange);
 
     // attention: this data provider has the limitation that it stores
     // internally if data comes from columns or rows. It is intended for
@@ -1277,7 +1277,7 @@ OUString SAL_CALL InternalDataProvider::convertRangeFromXML( const OUString& aXM
     if( m_bDataInColumns )
     {
         if( aRange.aUpperLeft.nColumn == 0 )
-            return lcl_aCategoriesRangeName;
+            return OUString(lcl_aCategoriesRangeName);
         if( aRange.aUpperLeft.nRow == 0 )
             return lcl_aLabelRangePrefix + OUString::number( aRange.aUpperLeft.nColumn - 1 );
 
@@ -1286,7 +1286,7 @@ OUString SAL_CALL InternalDataProvider::convertRangeFromXML( const OUString& aXM
 
     // data in rows
     if( aRange.aUpperLeft.nRow == 0 )
-        return lcl_aCategoriesRangeName;
+        return OUString(lcl_aCategoriesRangeName);
     if( aRange.aUpperLeft.nColumn == 0 )
         return lcl_aLabelRangePrefix + OUString::number( aRange.aUpperLeft.nRow - 1 );
 
@@ -1305,7 +1305,7 @@ Sequence< Sequence< Type > > lcl_convertVectorVectorToSequenceSequence( const ve
     {
         aRet.realloc(nOuterCount);
         for( sal_Int32 nN=0; nN<nOuterCount; nN++)
-            aRet[nN]= ContainerHelper::ContainerToSequence( rIn[nN] );
+            aRet[nN]= comphelper::containerToSequence( rIn[nN] );
     }
     return aRet;
 }
@@ -1332,7 +1332,7 @@ Sequence< Sequence< OUString > > lcl_convertComplexAnyVectorToStringSequence( co
     {
         aRet.realloc(nOuterCount);
         for( sal_Int32 nN=0; nN<nOuterCount; nN++)
-            aRet[nN]= lcl_AnyToStringSequence( ContainerHelper::ContainerToSequence( rIn[nN] ) );
+            aRet[nN]= lcl_AnyToStringSequence( comphelper::containerToSequence( rIn[nN] ) );
     }
     return aRet;
 }
@@ -1356,8 +1356,8 @@ public:
     virtual ~SplitCategoriesProvider_ForComplexDescriptions()
     {}
 
-    virtual sal_Int32 getLevelCount() const SAL_OVERRIDE;
-    virtual uno::Sequence< OUString > getStringsForLevel( sal_Int32 nIndex ) const SAL_OVERRIDE;
+    virtual sal_Int32 getLevelCount() const override;
+    virtual uno::Sequence< OUString > getStringsForLevel( sal_Int32 nIndex ) const override;
 
 private:
     const ::std::vector< ::std::vector< uno::Any > >& m_rComplexDescriptions;
@@ -1533,7 +1533,7 @@ sal_Bool SAL_CALL InternalDataProvider::isNotANumber( double nNumber )
 void SAL_CALL InternalDataProvider::initialize(const uno::Sequence< uno::Any > & _aArguments) throw (uno::RuntimeException, uno::Exception, std::exception)
 {
     comphelper::SequenceAsHashMap aArgs(_aArguments);
-    if ( aArgs.getUnpackedValueOrDefault( "CreateDefaultData" ,sal_False) )
+    if ( aArgs.getUnpackedValueOrDefault( "CreateDefaultData", false ) )
         createDefaultData();
 }
 // ____ XCloneable ____
@@ -1545,13 +1545,40 @@ Reference< util::XCloneable > SAL_CALL InternalDataProvider::createClone()
 
 Sequence< OUString > InternalDataProvider::getSupportedServiceNames_Static()
 {
-    Sequence< OUString > aServices( 1 );
-    aServices[ 0 ] = "com.sun.star.chart2.data.DataProvider";
+    Sequence<OUString> aServices { "com.sun.star.chart2.data.DataProvider" };
     return aServices;
 }
 
-APPHELPER_XSERVICEINFO_IMPL( InternalDataProvider, lcl_aServiceName );
+OUString SAL_CALL InternalDataProvider::getImplementationName()
+    throw( css::uno::RuntimeException, std::exception )
+{
+    return getImplementationName_Static();
+}
+
+OUString InternalDataProvider::getImplementationName_Static()
+{
+    return OUString(lcl_aServiceName);
+}
+
+sal_Bool SAL_CALL InternalDataProvider::supportsService( const OUString& rServiceName )
+    throw( css::uno::RuntimeException, std::exception )
+{
+    return cppu::supportsService(this, rServiceName);
+}
+
+css::uno::Sequence< OUString > SAL_CALL InternalDataProvider::getSupportedServiceNames()
+    throw( css::uno::RuntimeException, std::exception )
+{
+    return getSupportedServiceNames_Static();
+}
 
 } //  namespace chart
 
+extern "C" SAL_DLLPUBLIC_EXPORT css::uno::XInterface * SAL_CALL
+com_sun_star_comp_chart_InternalDataProvider_get_implementation(css::uno::XComponentContext *context,
+        css::uno::Sequence<css::uno::Any> const &)
+{
+    return cppu::acquire(new ::chart::InternalDataProvider(context));
+}
+
 /* vim:set shiftwidth=4 softtabstop=4 expandtab: */
