@@ -19,10 +19,12 @@
 
 #include "Splines.hxx"
 #include <rtl/math.hxx>
+#include <osl/diagnose.h>
 
 #include <vector>
 #include <algorithm>
 #include <functional>
+#include <memory>
 
 #define MAX_BSPLINE_DEGREE 15
 
@@ -40,7 +42,7 @@ typedef tPointVecType::size_type        lcl_tSizeType;
 class lcl_SplineCalculation
 {
 public:
-    /** @descr creates an object that calculates cublic splines on construction
+    /** @descr creates an object that calculates cubic splines on construction
 
         @param rSortedPoints  the points for which splines shall be calculated, they need to be sorted in x values
         @param fY1FirstDerivation the resulting spline should have the first
@@ -55,13 +57,13 @@ public:
                            double fY1FirstDerivation,
                            double fYnFirstDerivation );
 
-    /** @descr creates an object that calculates cublic splines on construction
+    /** @descr creates an object that calculates cubic splines on construction
                for the special case of periodic cubic spline
 
         @param rSortedPoints  the points for which splines shall be calculated,
                they need to be sorted in x values. First and last y value must be equal
      */
-    lcl_SplineCalculation( const tPointVecType & rSortedPoints);
+    explicit lcl_SplineCalculation( const tPointVecType & rSortedPoints);
 
     /** @descr this function corresponds to the function splint in [1].
 
@@ -94,11 +96,11 @@ private:
     */
     void Calculate();
 
-    /** @descr this function corresponds to the algoritm 4.76 in [2] and
+    /** @descr this function corresponds to the algorithm 4.76 in [2] and
         theorem 5.3.7 in [3]
 
-        [2] Engeln-Mllges, Gisela: Numerik-Algorithmen: Verfahren, Beispiele, Anwendungen
-            Springer, Berlin; Auflage: 9., berarb. und erw. A. (8. Dezember 2004)
+        [2] Engeln-Müllges, Gisela: Numerik-Algorithmen: Verfahren, Beispiele, Anwendungen
+            Springer, Berlin; Auflage: 9., überarb. und erw. A. (8. Dezember 2004)
             Section 4.10.2, page 175
 
         [3] Hanrath, Wilhelm: Mathematik III / Numerik, Vorlesungsskript zur
@@ -122,7 +124,7 @@ lcl_SplineCalculation::lcl_SplineCalculation(
           m_nKHigh( rSortedPoints.size() - 1 ),
           m_fLastInterpolatedValue(0.0)
 {
-    ::rtl::math::setInf( &m_fLastInterpolatedValue, sal_False );
+    ::rtl::math::setInf( &m_fLastInterpolatedValue, false );
     Calculate();
 }
 
@@ -135,7 +137,7 @@ lcl_SplineCalculation::lcl_SplineCalculation(
           m_nKHigh( rSortedPoints.size() - 1 ),
           m_fLastInterpolatedValue(0.0)
 {
-    ::rtl::math::setInf( &m_fLastInterpolatedValue, sal_False );
+    ::rtl::math::setInf( &m_fLastInterpolatedValue, false );
     CalculatePeriodic();
 }
 
@@ -201,7 +203,7 @@ void lcl_SplineCalculation::Calculate()
     m_aSecDerivY[ n ] = ( un - qn * u[ n - 1 ] ) * ( qn * m_aSecDerivY[ n - 1 ] + 1.0 );
 
     // note: the algorithm in [1] iterates from n-1 to 0, but as size_type
-    // may be (usuall is) an unsigned type, we can not write k >= 0, as this
+    // may be (usually is) an unsigned type, we can not write k >= 0, as this
     // is always true.
     for( lcl_tSizeType k = n; k > 0; --k )
     {
@@ -405,11 +407,11 @@ double lcl_SplineCalculation::GetInterpolatedValue( double x )
 // helper methods for B-spline
 
 // Create parameter t_0 to t_n using the centripetal method with a power of 0.5
-bool createParameterT(const tPointVecType aUniquePoints, double* t)
+bool createParameterT(const tPointVecType& rUniquePoints, double* t)
 {   // precondition: no adjacent identical points
     // postcondition: 0 = t_0 < t_1 < ... < t_n = 1
     bool bIsSuccessful = true;
-    const lcl_tSizeType n = aUniquePoints.size() - 1;
+    const lcl_tSizeType n = rUniquePoints.size() - 1;
     t[0]=0.0;
     double dx = 0.0;
     double dy = 0.0;
@@ -417,8 +419,8 @@ bool createParameterT(const tPointVecType aUniquePoints, double* t)
     double fDenominator = 0.0; // initialized for summing up
     for (lcl_tSizeType i=1; i<=n ; ++i)
     {   // 4th root(dx^2+dy^2)
-        dx = aUniquePoints[i].first - aUniquePoints[i-1].first;
-        dy = aUniquePoints[i].second - aUniquePoints[i-1].second;
+        dx = rUniquePoints[i].first - rUniquePoints[i-1].first;
+        dy = rUniquePoints[i].second - rUniquePoints[i-1].second;
         // scaling to avoid underflow or overflow
         fDiffMax = (fabs(dx)>fabs(dy)) ? fabs(dx) : fabs(dy);
         if (fDiffMax == 0.0)
@@ -444,8 +446,8 @@ bool createParameterT(const tPointVecType aUniquePoints, double* t)
             double fNumerator = 0.0;
             for (lcl_tSizeType i=1; i<=j ; ++i)
             {
-                dx = aUniquePoints[i].first - aUniquePoints[i-1].first;
-                dy = aUniquePoints[i].second - aUniquePoints[i-1].second;
+                dx = rUniquePoints[i].first - rUniquePoints[i-1].first;
+                dy = rUniquePoints[i].second - rUniquePoints[i-1].second;
                 fDiffMax = (fabs(dx)>fabs(dy)) ? fabs(dx) : fabs(dy);
                 // same as above, so should not be zero
                 dx /= fDiffMax;
@@ -479,10 +481,9 @@ void createKnotVector(const lcl_tSizeType n, const sal_uInt32 p, double* t, doub
         {
             u[j] = 0.0;
         }
-        double fSum = 0.0;
         for (lcl_tSizeType j = 1; j <= n-p; ++j )
         {
-            fSum = 0.0;
+            double fSum = 0.0;
             for (lcl_tSizeType i = j; i <= j+p-1; ++i)
             {
                 fSum += t[i];
@@ -499,8 +500,6 @@ void createKnotVector(const lcl_tSizeType n, const sal_uInt32 p, double* t, doub
 void applyNtoParameterT(const lcl_tSizeType i,const double tk,const sal_uInt32 p,const double* u, double* rowN)
 {
     // get N_p(t_k) recursively, only N_(i-p) till N_(i) are relevant, all other N_# are zero
-    double fRightFactor = 0.0;
-    double fLeftFactor = 0.0;
 
     // initialize with indicator function degree 0
     rowN[p] = 1.0; // all others are zero
@@ -509,7 +508,8 @@ void applyNtoParameterT(const lcl_tSizeType i,const double tk,const sal_uInt32 p
     for (sal_uInt32 s = 1; s <= p; ++s)
     {
         // first element
-        fRightFactor = ( u[i+1] - tk ) / ( u[i+1]- u[i-s+1] );
+        double fLeftFactor = 0.0;
+        double fRightFactor = ( u[i+1] - tk ) / ( u[i+1]- u[i-s+1] );
         // i-s "true index" - (i-p)"shift" = p-s
         rowN[p-s] = fRightFactor * rowN[p-s+1];
 
@@ -588,8 +588,6 @@ void SplineCalculater::CalculateCubicSplines(
 
         // generate a spline for each coordinate. It holds the complete
         // information to calculate each point of the curve
-        double fXDerivation;
-        double fYDerivation;
         lcl_SplineCalculation* aSplineX;
         lcl_SplineCalculation* aSplineY;
         // lcl_SplineCalculation* aSplineZ; the z-coordinates of all points in
@@ -608,9 +606,9 @@ void SplineCalculater::CalculateCubicSplines(
         else // generate the kind "natural spline"
         {
             double fInfty;
-            ::rtl::math::setInf( &fInfty, sal_False );
-            fXDerivation = fInfty;
-            fYDerivation = fInfty;
+            ::rtl::math::setInf( &fInfty, false );
+            double fXDerivation = fInfty;
+            double fYDerivation = fInfty;
             aSplineX = new lcl_SplineCalculation( aInputX, fXDerivation, fXDerivation );
             aSplineY = new lcl_SplineCalculation( aInputY, fYDerivation, fYDerivation );
         }
@@ -625,10 +623,6 @@ void SplineCalculater::CalculateCubicSplines(
         double* pNewZ = rResult.SequenceZ[nOuter].getArray();
 
         sal_uInt32 nNewPointIndex = 0; // Index in result points
-        // needed for inner loop
-        double    fInc;   // step for intermediate points
-        sal_uInt32 nj;     // for loop
-        double    fParam; // a intermediate parameter value
 
         for( sal_uInt32 ni = 0; ni < nMaxIndexPoints; ni++ )
         {
@@ -639,10 +633,10 @@ void SplineCalculater::CalculateCubicSplines(
             nNewPointIndex++;
 
             // calculate intermediate points
-            fInc = ( aParameter[ ni+1 ] - aParameter[ni] ) / static_cast< double >( nGranularity );
-            for(nj = 1; nj < nGranularity; nj++)
+            double fInc = ( aParameter[ ni+1 ] - aParameter[ni] ) / static_cast< double >( nGranularity );
+            for(sal_uInt32 nj = 1; nj < nGranularity; nj++)
             {
-                fParam = aParameter[ni] + ( fInc * static_cast< double >( nj ) );
+                double fParam = aParameter[ni] + ( fInc * static_cast< double >( nj ) );
 
                 pNewX[nNewPointIndex]=aSplineX->GetInterpolatedValue( fParam );
                 pNewY[nNewPointIndex]=aSplineY->GetInterpolatedValue( fParam );
@@ -675,9 +669,9 @@ void SplineCalculater::CalculateBSplines(
             , sal_uInt32 nResolution
             , sal_uInt32 nDegree )
 {
-    // nResolution is ODF1.2 file format attribut chart:spline-resolution and
+    // nResolution is ODF1.2 file format attribute chart:spline-resolution and
     // ODF1.2 spec variable k. Causion, k is used as index in the spec in addition.
-    // nDegree is ODF1.2 file format attribut chart:spline-order and
+    // nDegree is ODF1.2 file format attribute chart:spline-order and
     // ODF1.2 spec variable p
     OSL_ASSERT( nResolution > 1 );
     OSL_ASSERT( nDegree >= 1 );
@@ -727,30 +721,29 @@ void SplineCalculater::CalculateBSplines(
             continue; // need at least 2 points, degree p needs at least n+1 points
                       // next piece of series
 
-        double* t = new double [n+1];
-        if (!createParameterT(aPointsIn, t))
+        std::unique_ptr<double[]> t(new double [n+1]);
+        if (!createParameterT(aPointsIn, t.get()))
         {
-            delete[] t;
             continue; // next piece of series
         }
 
         lcl_tSizeType m = n + p + 1;
-        double* u = new double [m+1];
-        createKnotVector(n, p, t, u);
+        std::unique_ptr<double[]> u(new double [m+1]);
+        createKnotVector(n, p, t.get(), u.get());
 
         // The matrix N contains the B-spline basis functions applied to parameters.
         // In each row only p+1 adjacent elements are non-zero. The starting
         // column in a higher row is equal or greater than in the lower row.
         // To store this matrix the non-zero elements are shifted to column 0
         // and the amount of shifting is remembered in an array.
-        double** aMatN = new double*[n+1];
+        std::unique_ptr<double*[]> aMatN(new double*[n+1]);
         for (lcl_tSizeType row = 0; row <=n; ++row)
         {
             aMatN[row] = new double[p+1];
             for (sal_uInt32 col = 0; col <= p; ++col)
             aMatN[row][col] = 0.0;
         }
-        lcl_tSizeType* aShift = new lcl_tSizeType[n+1];
+        std::unique_ptr<lcl_tSizeType[]> aShift(new lcl_tSizeType[n+1]);
         aMatN[0][0] = 1.0; //all others are zero
         aShift[0] = 0;
         aMatN[n][0] = 1.0;
@@ -770,7 +763,7 @@ void SplineCalculater::CalculateBSplines(
             // index in reduced matrix aMatN = (index in full matrix N) - (i-p)
             aShift[k] = i - p;
 
-            applyNtoParameterT(i, t[k], p, u, aMatN[k]);
+            applyNtoParameterT(i, t[k], p, u.get(), aMatN[k]);
         } // next row k
 
         // Get matrix C of control points from the matrix equation aMatN * C = aPointsIn
@@ -858,7 +851,7 @@ void SplineCalculater::CalculateBSplines(
                 while ( r !=0 && cc-r < p )
                 {
                     fEliminate = aMatN[r][ cc - aShift[r] ];
-                    if ( fEliminate != 0.0) // else element is accidentically zero, no action needed
+                    if ( fEliminate != 0.0) // else element is accidentally zero, no action needed
                     {
                         // row r -= fEliminate * row cc only relevant for right side
                         aMatN[r][cc - aShift[r]] = 0.0;
@@ -886,7 +879,7 @@ void SplineCalculater::CalculateBSplines(
             pNewX[nNewSize -1 ] = aPointsIn[n].first;
             pNewY[nNewSize -1 ] = aPointsIn[n].second;
             pNewZ[nNewSize -1 ] = fZCoordinate;
-            double* aP = new double[m+1];
+            std::unique_ptr<double[]> aP(new double[m+1]);
             lcl_tSizeType nLow = 0;
             for ( lcl_tSizeType nTIndex = 0; nTIndex <= n-1; ++nTIndex)
             {
@@ -912,10 +905,9 @@ void SplineCalculater::CalculateBSplines(
                     }
                     for (sal_uInt32 lcl_Degree = 1; lcl_Degree <= p; ++lcl_Degree)
                     {
-                        double fFactor = 0.0;
                         for (lcl_tSizeType i = nLow; i >= nLow + lcl_Degree - p; --i)
                         {
-                            fFactor = ( ux - u[i] ) / ( u[i+p+1-lcl_Degree] - u[i]);
+                            double fFactor = ( ux - u[i] ) / ( u[i+p+1-lcl_Degree] - u[i]);
                             aP[i] = (1 - fFactor)* aP[i-1] + fFactor * aP[i];
                         }
                     }
@@ -928,10 +920,9 @@ void SplineCalculater::CalculateBSplines(
                     }
                     for (sal_uInt32 lcl_Degree = 1; lcl_Degree <= p; ++lcl_Degree)
                     {
-                        double fFactor = 0.0;
                         for (lcl_tSizeType i = nLow; i >= nLow +lcl_Degree - p; --i)
                         {
-                            fFactor = ( ux - u[i] ) / ( u[i+p+1-lcl_Degree] - u[i]);
+                            double fFactor = ( ux - u[i] ) / ( u[i+p+1-lcl_Degree] - u[i]);
                             aP[i] = (1 - fFactor)* aP[i-1] + fFactor * aP[i];
                         }
                     }
@@ -939,17 +930,11 @@ void SplineCalculater::CalculateBSplines(
                     pNewZ[nNewIndex] = fZCoordinate;
                 }
             }
-            delete[] aP;
         }
-        delete[] aShift;
         for (lcl_tSizeType row = 0; row <=n; ++row)
         {
             delete[] aMatN[row];
         }
-        delete[] aMatN;
-        delete[] u;
-        delete[] t;
-
     } // next piece of the series
 }
 
