@@ -58,7 +58,7 @@ bool VDataSequence::is() const
 }
 void VDataSequence::clear()
 {
-    Model = NULL;
+    Model = nullptr;
     Doubles.realloc(0);
 }
 
@@ -146,12 +146,12 @@ VDataSeries::VDataSeries( const uno::Reference< XDataSeries >& xDataSeries )
     , m_fLogicMinX(0.0)
     , m_fLogicMaxX(0.0)
     , m_fLogicZPos(0.0)
-    , m_xGroupShape(NULL)
-    , m_xLabelsGroupShape(NULL)
-    , m_xErrorXBarsGroupShape(NULL)
-    , m_xErrorYBarsGroupShape(NULL)
-    , m_xFrontSubGroupShape(NULL)
-    , m_xBackSubGroupShape(NULL)
+    , m_xGroupShape(nullptr)
+    , m_xLabelsGroupShape(nullptr)
+    , m_xErrorXBarsGroupShape(nullptr)
+    , m_xErrorYBarsGroupShape(nullptr)
+    , m_xFrontSubGroupShape(nullptr)
+    , m_xBackSubGroupShape(nullptr)
     , m_xDataSeries(xDataSeries)
     , m_nPointCount(0)
 
@@ -170,20 +170,20 @@ VDataSeries::VDataSeries( const uno::Reference< XDataSeries >& xDataSeries )
 
     , m_nGlobalSeriesIndex(0)
 
-    , m_apLabel_Series(NULL)
-    , m_apLabelPropNames_Series(NULL)
-    , m_apLabelPropValues_Series(NULL)
-    , m_apSymbolProperties_Series(NULL)
+    , m_apLabel_Series(nullptr)
+    , m_apLabelPropNames_Series(nullptr)
+    , m_apLabelPropValues_Series(nullptr)
+    , m_apSymbolProperties_Series(nullptr)
 
-    , m_apLabel_AttributedPoint(NULL)
-    , m_apLabelPropNames_AttributedPoint(NULL)
-    , m_apLabelPropValues_AttributedPoint(NULL)
-    , m_apSymbolProperties_AttributedPoint(NULL)
-    , m_apSymbolProperties_InvisibleSymbolForSelection(NULL)
+    , m_apLabel_AttributedPoint(nullptr)
+    , m_apLabelPropNames_AttributedPoint(nullptr)
+    , m_apLabelPropValues_AttributedPoint(nullptr)
+    , m_apSymbolProperties_AttributedPoint(nullptr)
+    , m_apSymbolProperties_InvisibleSymbolForSelection(nullptr)
     , m_nCurrentAttributedPoint(-1)
     , m_nMissingValueTreatment(::com::sun::star::chart::MissingValueTreatment::LEAVE_GAP)
     , m_bAllowPercentValueInDataLabel(false)
-    , mpOldSeries(NULL)
+    , mpOldSeries(nullptr)
     , mnPercent(0.0)
 {
     ::rtl::math::setNan( & m_fXMeanValue );
@@ -286,7 +286,7 @@ void VDataSeries::doSortByXValues()
     if( m_aValues_X.is() && m_aValues_X.Doubles.getLength() )
     {
         //prepare a vector for sorting
-        std::vector< ::std::vector< double > > aTmp;//outer vector are points, inner vector are the different values of athe point
+        std::vector< ::std::vector< double > > aTmp;//outer vector are points, inner vector are the different values of the point
         double fNan;
         ::rtl::math::setNan( & fNan );
         sal_Int32 nPointIndex = 0;
@@ -315,12 +315,12 @@ void VDataSeries::doSortByXValues()
 
 void VDataSeries::releaseShapes()
 {
-    m_xGroupShape.set(0);
-    m_xLabelsGroupShape.set(0);
-    m_xErrorXBarsGroupShape.set(0);
-    m_xErrorYBarsGroupShape.set(0);
-    m_xFrontSubGroupShape.set(0);
-    m_xBackSubGroupShape.set(0);
+    m_xGroupShape.set(nullptr);
+    m_xLabelsGroupShape.set(nullptr);
+    m_xErrorXBarsGroupShape.set(nullptr);
+    m_xErrorYBarsGroupShape.set(nullptr);
+    m_xFrontSubGroupShape.set(nullptr);
+    m_xBackSubGroupShape.set(nullptr);
 
     m_aPolyPolygonShape3D.SequenceX.realloc(0);
     m_aPolyPolygonShape3D.SequenceY.realloc(0);
@@ -521,7 +521,7 @@ void VDataSeries::getMinMaxXValue(double& fMin, double& fMax) const
     if(aValuesX.getLength() > 0)
     {
         sal_Int32 i = 0;
-        while ( i < aValuesX.getLength() && ::rtl::math::isNan( aValuesX[i] ) )
+        while ( i < aValuesX.getLength() && ::rtl::math::isNan(aValuesX[i]) )
             i++;
         if ( i < aValuesX.getLength() )
             fMax = fMin = aValuesX[i++];
@@ -779,7 +779,7 @@ double VDataSeries::getYMeanValue() const
     return m_fYMeanValue;
 }
 
-Symbol* getSymbolPropertiesFromPropertySet( const uno::Reference< beans::XPropertySet >& xProp )
+std::unique_ptr<Symbol> getSymbolPropertiesFromPropertySet( const uno::Reference< beans::XPropertySet >& xProp )
 {
     ::std::unique_ptr< Symbol > apSymbolProps( new Symbol() );
     try
@@ -798,26 +798,26 @@ Symbol* getSymbolPropertiesFromPropertySet( const uno::Reference< beans::XProper
     {
         ASSERT_EXCEPTION( e );
     }
-    return apSymbolProps.release();
+    return apSymbolProps;
 }
 
 Symbol* VDataSeries::getSymbolProperties( sal_Int32 index ) const
 {
-    Symbol* pRet=NULL;
+    Symbol* pRet=nullptr;
     if( isAttributedDataPoint( index ) )
     {
         adaptPointCache( index );
         if (!m_apSymbolProperties_AttributedPoint)
-            m_apSymbolProperties_AttributedPoint.reset(
-                getSymbolPropertiesFromPropertySet(this->getPropertiesOfPoint(index)));
+            m_apSymbolProperties_AttributedPoint
+                = getSymbolPropertiesFromPropertySet(this->getPropertiesOfPoint(index));
         pRet = m_apSymbolProperties_AttributedPoint.get();
         //if a single data point does not have symbols but the dataseries itself has symbols
         //we create an invisible symbol shape to enable selection of that point
         if( !pRet || pRet->Style == SymbolStyle_NONE )
         {
             if (!m_apSymbolProperties_Series)
-                m_apSymbolProperties_Series.reset(
-                    getSymbolPropertiesFromPropertySet(this->getPropertiesOfSeries()));
+                m_apSymbolProperties_Series
+                    = getSymbolPropertiesFromPropertySet(this->getPropertiesOfSeries());
             if( m_apSymbolProperties_Series.get() && m_apSymbolProperties_Series->Style != SymbolStyle_NONE )
             {
                 if (!m_apSymbolProperties_InvisibleSymbolForSelection)
@@ -836,8 +836,8 @@ Symbol* VDataSeries::getSymbolProperties( sal_Int32 index ) const
     else
     {
         if (!m_apSymbolProperties_Series)
-            m_apSymbolProperties_Series.reset(
-                getSymbolPropertiesFromPropertySet(this->getPropertiesOfSeries()));
+            m_apSymbolProperties_Series
+                = getSymbolPropertiesFromPropertySet(this->getPropertiesOfSeries());
         pRet = m_apSymbolProperties_Series.get();
     }
 
@@ -925,7 +925,7 @@ uno::Reference<beans::XPropertySet> VDataSeries::getPropertiesOfSeries() const
     return uno::Reference<css::beans::XPropertySet>(m_xDataSeries, css::uno::UNO_QUERY);
 }
 
-DataPointLabel* getDataPointLabelFromPropertySet( const uno::Reference< beans::XPropertySet >& xProp )
+std::unique_ptr<DataPointLabel> getDataPointLabelFromPropertySet( const uno::Reference< beans::XPropertySet >& xProp )
 {
     ::std::unique_ptr< DataPointLabel > apLabel( new DataPointLabel() );
     try
@@ -937,7 +937,7 @@ DataPointLabel* getDataPointLabelFromPropertySet( const uno::Reference< beans::X
     {
         ASSERT_EXCEPTION( e );
     }
-    return apLabel.release();
+    return apLabel;
 }
 
 void VDataSeries::adaptPointCache( sal_Int32 nNewPointIndex ) const
@@ -954,20 +954,20 @@ void VDataSeries::adaptPointCache( sal_Int32 nNewPointIndex ) const
 
 DataPointLabel* VDataSeries::getDataPointLabel( sal_Int32 index ) const
 {
-    DataPointLabel* pRet = NULL;
+    DataPointLabel* pRet = nullptr;
     if( isAttributedDataPoint( index ) )
     {
         adaptPointCache( index );
         if( !m_apLabel_AttributedPoint.get() )
-            m_apLabel_AttributedPoint.reset(
-                getDataPointLabelFromPropertySet(this->getPropertiesOfPoint(index)));
+            m_apLabel_AttributedPoint
+                = getDataPointLabelFromPropertySet(this->getPropertiesOfPoint(index));
         pRet = m_apLabel_AttributedPoint.get();
     }
     else
     {
         if (!m_apLabel_Series)
-            m_apLabel_Series.reset(
-                getDataPointLabelFromPropertySet(this->getPropertiesOfPoint(index)));
+            m_apLabel_Series
+                = getDataPointLabelFromPropertySet(this->getPropertiesOfPoint(index));
         pRet = m_apLabel_Series.get();
     }
     if( !m_bAllowPercentValueInDataLabel )
@@ -983,7 +983,7 @@ DataPointLabel* VDataSeries::getDataPointLabelIfLabel( sal_Int32 index ) const
     DataPointLabel* pLabel = this->getDataPointLabel( index );
     if( !pLabel || (!pLabel->ShowNumber && !pLabel->ShowNumberInPercent
         && !pLabel->ShowCategoryName ) )
-        return 0;
+        return nullptr;
     return pLabel;
 }
 
@@ -991,7 +991,7 @@ bool VDataSeries::getTextLabelMultiPropertyLists( sal_Int32 index
     , tNameSequence*& pPropNames
     , tAnySequence*& pPropValues ) const
 {
-    pPropNames = NULL; pPropValues = NULL;
+    pPropNames = nullptr; pPropValues = nullptr;
     uno::Reference< beans::XPropertySet > xTextProp;
     bool bDoDynamicFontResize = false;
     if( isAttributedDataPoint( index ) )
@@ -1052,7 +1052,7 @@ VDataSeries::VDataSeries()
     , m_fLogicMaxX(0)
     , m_fLogicZPos(0)
     , m_nPointCount(0)
-    , m_pValueSequenceForDataLabelNumberFormatDetection(NULL)
+    , m_pValueSequenceForDataLabelNumberFormatDetection(nullptr)
     , m_fXMeanValue(0)
     , m_fYMeanValue(0)
     , m_eStackingDirection(chart2::StackingDirection_NO_STACKING)
@@ -1064,7 +1064,7 @@ VDataSeries::VDataSeries()
     , m_nCurrentAttributedPoint(0)
     , m_nMissingValueTreatment(0)
     , m_bAllowPercentValueInDataLabel(false)
-    , mpOldSeries(NULL)
+    , mpOldSeries(nullptr)
     , mnPercent(0)
 {
 }
@@ -1073,7 +1073,7 @@ void VDataSeries::setOldTimeBased( VDataSeries* pOldSeries, double nPercent )
 {
     mnPercent = nPercent;
     mpOldSeries = pOldSeries;
-    mpOldSeries->mpOldSeries = NULL;
+    mpOldSeries->mpOldSeries = nullptr;
 }
 
 VDataSeries* VDataSeries::createCopyForTimeBased() const
