@@ -49,9 +49,9 @@ OUString mapCliTypeName(System::String^ typeName);
 System::String^ mapCliPolymorphicName(System::String^ unoName);
 System::String^ mapPolymorphicName(System::String^ unoName, bool bCliToUno);
 
-inline auto_ptr< rtl_mem > seq_allocate( sal_Int32 nElements, sal_Int32 nSize )
+inline unique_ptr< rtl_mem > seq_allocate( sal_Int32 nElements, sal_Int32 nSize )
 {
-    auto_ptr< rtl_mem > seq(
+    unique_ptr< rtl_mem > seq(
         rtl_mem::allocate( SAL_SEQUENCE_HEADER_SIZE + (nElements * nSize) ) );
     uno_Sequence * p = (uno_Sequence *)seq.get();
     p->nRefCount = 1;
@@ -154,7 +154,7 @@ System::Type^ loadCliType(System::String ^ unoName)
             bIsPolymorphic = true;
         }
         System::AppDomain^  currentDomain = System::AppDomain::CurrentDomain;
-        array<sr::Assembly^>^  assems = currentDomain->GetAssemblies();
+        cli::array<sr::Assembly^>^  assems = currentDomain->GetAssemblies();
         for (int i = 0; i < assems->Length; i++)
         {
             retVal = assems[i]->GetType(loadName, false);
@@ -443,10 +443,7 @@ typelib_TypeDescriptionReference* mapCliType(System::Type^ cliType)
     }
     if (retVal == NULL)
     {
-        OUStringBuffer buf( 128 );
-        buf.append( "[cli_uno bridge] mapCliType():could not map type: " );
-        buf.append(mapCliString(cliType->FullName));
-        throw BridgeRuntimeError( buf.makeStringAndClear() );
+        throw BridgeRuntimeError("[cli_uno bridge] mapCliType():could not map type: " + mapCliString(cliType->FullName));
     }
     return retVal;
 }
@@ -515,7 +512,7 @@ System::String^ mapUnoTypeName(rtl_uString const * typeName)
         System::String ^ sName = mapUnoPolymorphicName(sUnoName);
         buf->Append(sName);
     }
-    // apend []
+    // append []
     for (;dims--;)
         buf->Append(const_cast<System::String^>(Constants::sBrackets));
 
@@ -575,7 +572,7 @@ System::String^ mapPolymorphicName(System::String^ unoName, bool bCliToUno)
             System::String ^ sParam = unoName->Substring(index, cur - index);
             //skip the comma
             cur++;
-            //the the index to the beginning of the next param
+            //the index to the beginning of the next param
             index = cur;
             if (bCliToUno)
             {
@@ -897,7 +894,7 @@ void Bridge::map_to_uno(void * uno_data, System::Object^ cli_data,
                     }
                     else
                     {
-                        auto_ptr< rtl_mem > mem( rtl_mem::allocate( sizeof (sal_Int64) ) );
+                        unique_ptr< rtl_mem > mem( rtl_mem::allocate( sizeof (sal_Int64) ) );
                         *(sal_Int64 *) mem.get()=  *safe_cast<System::Int64^>(aAny.Value);
                         pAny->pData = mem.release();
                     }
@@ -910,7 +907,7 @@ void Bridge::map_to_uno(void * uno_data, System::Object^ cli_data,
                     }
                     else
                     {
-                        auto_ptr< rtl_mem > mem( rtl_mem::allocate( sizeof (sal_uInt64) ) );
+                        unique_ptr< rtl_mem > mem( rtl_mem::allocate( sizeof (sal_uInt64) ) );
                         *(sal_uInt64 *) mem.get()=  *safe_cast<System::UInt64^>(aAny.Value);
                         pAny->pData = mem.release();
                     }
@@ -923,7 +920,7 @@ void Bridge::map_to_uno(void * uno_data, System::Object^ cli_data,
                     }
                     else
                     {
-                        auto_ptr< rtl_mem > mem( rtl_mem::allocate( sizeof (float) ) );
+                        unique_ptr< rtl_mem > mem( rtl_mem::allocate( sizeof (float) ) );
                         *(float*) mem.get() = *safe_cast<System::Single^>(aAny.Value);
                         pAny->pData = mem.release();
                     }
@@ -936,7 +933,7 @@ void Bridge::map_to_uno(void * uno_data, System::Object^ cli_data,
                     }
                     else
                     {
-                        auto_ptr< rtl_mem > mem( rtl_mem::allocate( sizeof (double) ) );
+                        unique_ptr< rtl_mem > mem( rtl_mem::allocate( sizeof (double) ) );
                         *(double*) mem.get()= *safe_cast<System::Double^>(aAny.Value);
                         pAny->pData= mem.release();
                     }
@@ -965,7 +962,7 @@ void Bridge::map_to_uno(void * uno_data, System::Object^ cli_data,
                     css::uno::Type anyType(value_td);
                     typelib_TypeDescription* td= NULL;
                     anyType.getDescription(&td);
-                    auto_ptr< rtl_mem > mem(rtl_mem::allocate(td->nSize));
+                    unique_ptr< rtl_mem > mem(rtl_mem::allocate(td->nSize));
                     typelib_typedescription_release(td);
                     map_to_uno(
                         mem.get(), aAny.Value, value_td.getTypeLibType(),
@@ -975,11 +972,7 @@ void Bridge::map_to_uno(void * uno_data, System::Object^ cli_data,
                 }
                 default:
                 {
-                    OUStringBuffer buf( 128 );
-                    buf.append( "[map_to_uno():" );
-                    buf.append(value_td.getTypeName());
-                    buf.append( "] unsupported value type of any!" );
-                    throw BridgeRuntimeError( buf.makeStringAndClear() );
+                    throw BridgeRuntimeError("[map_to_uno():" + value_td.getTypeName() + "] unsupported value type of any!");
                 }
                 }
             }
@@ -988,20 +981,15 @@ void Bridge::map_to_uno(void * uno_data, System::Object^ cli_data,
 // ToDo check this
                 if (assign)
                     uno_any_construct( pAny, 0, 0, 0 ); // restore some valid any
-                OUStringBuffer buf( 256 );
-                buf.append( "[map_to_uno():Any" );
-                buf.append(value_td.getTypeName());
-                buf.append( "]The Any type ");
-                buf.append(value_td.getTypeName());
-                buf.append( " does not correspond to its value type: " );
+                OUString str = "[map_to_uno():Any" + value_td.getTypeName() + "]The Any type " + value_td.getTypeName() + " does not correspond to its value type: ";
                 if(aAny.Value != nullptr)
                 {
                     css::uno::Type td(mapCliType(aAny.Value->GetType()), SAL_NO_ACQUIRE);
-                    buf.append(td.getTypeName());
+                    str += td.getTypeName();
                 }
                 if (assign)
                     uno_any_construct( pAny, 0, 0, 0 ); // restore some valid any
-                throw BridgeRuntimeError( buf.makeStringAndClear() );
+                throw BridgeRuntimeError(str);
             }
             catch (BridgeRuntimeError& )
             {
@@ -1058,18 +1046,10 @@ void Bridge::map_to_uno(void * uno_data, System::Object^ cli_data,
             sal_Int32 nPos = 0;
             try
             {
-                typelib_TypeDescriptionReference * member_type= NULL;
-
                 OUString usUnoException("com.sun.star.uno.Exception");
                 for (; nPos < nMembers; ++nPos)
                 {
-                    member_type= comp_td->ppTypeRefs[nPos];
-#if OSL_DEBUG_LEVEL >= 2
-                    System::String* __s;
-                    sr::FieldInfo* arFields[];
-                    __s = mapUnoString(comp_td->ppMemberNames[nPos]);
-                    arFields = cliType != NULL ? cliType->GetFields() : NULL;
-#endif
+                    typelib_TypeDescriptionReference * member_type= comp_td->ppTypeRefs[nPos];
                     System::Object^ val= nullptr;
                     if (cli_data != nullptr)
                     {
@@ -1089,10 +1069,7 @@ void Bridge::map_to_uno(void * uno_data, System::Object^ cli_data,
                             }
                             else
                             {
-                                OUStringBuffer buf(512);
-                                buf.append("[map_to_uno(): Member: ");
-                                buf.append(comp_td->ppMemberNames[nPos]);
-                                throw BridgeRuntimeError(buf.makeStringAndClear());
+                                throw BridgeRuntimeError("[map_to_uno(): Member: " + OUString::unacquired(&comp_td->ppMemberNames[nPos]));
                             }
                         }
                         else
@@ -1103,11 +1080,11 @@ void Bridge::map_to_uno(void * uno_data, System::Object^ cli_data,
                     void * p = (char *) uno_data + comp_td->pMemberOffsets[ nPos ];
                     //When using polymorphic structs then the parameterized members can be null.
                     //Then we set a default value.
-                    bool bDefault = ((struct_td != NULL
+                    bool bDefault = (struct_td != NULL
                                      && struct_td->pParameterizedTypes != NULL
                                      && struct_td->pParameterizedTypes[nPos] == sal_True
-                                      && val == nullptr)
-                                     || cli_data == nullptr) ? true : false;
+                                     && val == nullptr)
+                                    || cli_data == nullptr;
                     switch (member_type->eTypeClass)
                     {
                     case typelib_TypeClass_CHAR:
@@ -1187,31 +1164,24 @@ void Bridge::map_to_uno(void * uno_data, System::Object^ cli_data,
             catch (BridgeRuntimeError& e)
             {
                 bException= true;
-                OUStringBuffer buf(512);
-                buf.append("[map_to_uno():");
+                OUString str = "[map_to_uno():";
                 if (cliType)
                 {
-                    buf.append(mapCliString(cliType->FullName));
-                    buf.append(".");
-                    buf.append(comp_td->ppMemberNames[nPos]);
-                    buf.append(" ");
+                    str += mapCliString(cliType->FullName) + "." + OUString::unacquired(&comp_td->ppMemberNames[nPos]) + " ";
                 }
-                buf.append(e.m_message);
-                throw BridgeRuntimeError(buf.makeStringAndClear());
+                str += e.m_message;
+                throw BridgeRuntimeError(str);
             }
             catch (System::InvalidCastException^ )
             {
                 bException= true;
-                OUStringBuffer buf( 256 );
-                buf.append( "[map_to_uno():" );
+                OUString str = "[map_to_uno():";
                 if (cliType)
                 {
-                    buf.append(mapCliString(cliType->FullName));
-                    buf.append( "." );
-                    buf.append(comp_td->ppMemberNames[nPos]);
+                    str += mapCliString(cliType->FullName) + "." + OUString::unacquired(&comp_td->ppMemberNames[nPos]);
                 }
-                buf.append( "] Value has not the required type." );
-                throw BridgeRuntimeError(buf.makeStringAndClear());
+                str += "] Value has not the required type.";
+                throw BridgeRuntimeError(str);
             }
             catch (...)
             {
@@ -1244,7 +1214,7 @@ void Bridge::map_to_uno(void * uno_data, System::Object^ cli_data,
             typelib_TypeDescriptionReference * element_type =
                 ((typelib_IndirectTypeDescription *)td.get())->pType;
 
-            auto_ptr< rtl_mem > seq;
+            unique_ptr< rtl_mem > seq;
 
             System::Array^ ar = nullptr;
             if (cli_data != nullptr)
@@ -1258,66 +1228,66 @@ void Bridge::map_to_uno(void * uno_data, System::Object^ cli_data,
                     {
                     case typelib_TypeClass_CHAR:
                         seq = seq_allocate(nElements, sizeof (sal_Unicode));
-                        sri::Marshal::Copy(safe_cast<array<System::Char>^>(cli_data), 0,
+                        sri::Marshal::Copy(safe_cast<cli::array<System::Char>^>(cli_data), 0,
                                            IntPtr(& ((uno_Sequence*) seq.get())->elements), nElements);
                         break;
                     case typelib_TypeClass_BOOLEAN:
                         seq = seq_allocate(nElements, sizeof (sal_Bool));
-                        sri::Marshal::Copy(safe_cast<array<System::Char>^>(cli_data), 0,
+                        sri::Marshal::Copy(safe_cast<cli::array<System::Char>^>(cli_data), 0,
                                            IntPtr(& ((uno_Sequence*) seq.get())->elements), nElements);
                         break;
                     case typelib_TypeClass_BYTE:
                         seq = seq_allocate( nElements, sizeof (sal_Int8) );
-                    sri::Marshal::Copy(safe_cast<array<System::Byte>^>(cli_data), 0,
+                        sri::Marshal::Copy(safe_cast<cli::array<System::Byte>^>(cli_data), 0,
                                        IntPtr(& ((uno_Sequence*) seq.get())->elements), nElements);
                     break;
                     case typelib_TypeClass_SHORT:
                         seq = seq_allocate(nElements, sizeof (sal_Int16));
-                        sri::Marshal::Copy(safe_cast<array<System::Int16>^>(cli_data), 0,
+                        sri::Marshal::Copy(safe_cast<cli::array<System::Int16>^>(cli_data), 0,
                                            IntPtr(& ((uno_Sequence*) seq.get())->elements), nElements);
                         break;
                     case typelib_TypeClass_UNSIGNED_SHORT:
                         seq = seq_allocate( nElements, sizeof (sal_uInt16) );
-                        sri::Marshal::Copy(dynamic_cast<array<System::Int16>^>(
-                                               safe_cast<array<System::UInt16>^>(cli_data)), 0,
+                        sri::Marshal::Copy(dynamic_cast<cli::array<System::Int16>^>(
+                                           safe_cast<cli::array<System::UInt16>^>(cli_data)), 0,
                                            IntPtr(& ((uno_Sequence*) seq.get())->elements), nElements);
                         break;
                     case typelib_TypeClass_LONG:
                         seq = seq_allocate(nElements, sizeof (sal_Int32));
-                        sri::Marshal::Copy(safe_cast<array<System::Int32>^>(cli_data), 0,
+                        sri::Marshal::Copy(safe_cast<cli::array<System::Int32>^>(cli_data), 0,
                                            IntPtr(& ((uno_Sequence*) seq.get())->elements), nElements);
                         break;
                     case typelib_TypeClass_UNSIGNED_LONG:
                         seq = seq_allocate( nElements, sizeof (sal_uInt32) );
-                        sri::Marshal::Copy(dynamic_cast<array<System::Int32>^>(
-                                               safe_cast<array<System::UInt32>^>(cli_data)), 0,
+                        sri::Marshal::Copy(dynamic_cast<cli::array<System::Int32>^>(
+                                           safe_cast<cli::array<System::UInt32>^>(cli_data)), 0,
                                            IntPtr(& ((uno_Sequence*) seq.get())->elements), nElements);
                         break;
                     case typelib_TypeClass_HYPER:
                         seq = seq_allocate(nElements, sizeof (sal_Int64));
-                        sri::Marshal::Copy(safe_cast<array<System::Int64>^>(cli_data), 0,
+                        sri::Marshal::Copy(safe_cast<cli::array<System::Int64>^>(cli_data), 0,
                                            IntPtr(& ((uno_Sequence*) seq.get())->elements), nElements);
                         break;
                     case typelib_TypeClass_UNSIGNED_HYPER:
                         seq = seq_allocate(nElements, sizeof (sal_uInt64));
-                        sri::Marshal::Copy(dynamic_cast<array<System::Int64>^>(
-                                               safe_cast<array<System::UInt64>^>(cli_data)), 0,
+                        sri::Marshal::Copy(dynamic_cast<cli::array<System::Int64>^>(
+                                           safe_cast<cli::array<System::UInt64>^>(cli_data)), 0,
                                            IntPtr(& ((uno_Sequence*) seq.get())->elements), nElements);
                         break;
                     case typelib_TypeClass_FLOAT:
                         seq = seq_allocate(nElements, sizeof (float));
-                        sri::Marshal::Copy(safe_cast<array<System::Single>^>(cli_data), 0,
+                        sri::Marshal::Copy(safe_cast<cli::array<System::Single>^>(cli_data), 0,
                                            IntPtr(& ((uno_Sequence*) seq.get())->elements), nElements);
                         break;
                     case typelib_TypeClass_DOUBLE:
                         seq = seq_allocate(nElements, sizeof (double));
-                        sri::Marshal::Copy(safe_cast<array<System::Double>^>(cli_data), 0,
+                        sri::Marshal::Copy(safe_cast<cli::array<System::Double>^>(cli_data), 0,
                                            IntPtr(& ((uno_Sequence*) seq.get())->elements), nElements);
                         break;
                     case typelib_TypeClass_STRING:
                     {
                         seq = seq_allocate(nElements, sizeof (rtl_uString*));
-                        array<System::String^>^ arStr= safe_cast<array<System::String^>^>(cli_data);
+                        cli::array<System::String^>^ arStr= safe_cast<cli::array<System::String^>^>(cli_data);
                         for (int i= 0; i < nElements; i++)
                         {
                             pin_ptr<const wchar_t> pdata= PtrToStringChars(arStr[i]);
@@ -1375,33 +1345,20 @@ void Bridge::map_to_uno(void * uno_data, System::Object^ cli_data,
                     }
                     default:
                     {
-                        OUStringBuffer buf( 128 );
-                        buf.append( "[map_to_uno():" );
-                        buf.append( *reinterpret_cast< OUString const * >( &type->pTypeName ) );
-                        buf.append( "] unsupported sequence element type: " );
-                        buf.append( *reinterpret_cast< OUString const * >( &element_type->pTypeName ) );
-                        throw BridgeRuntimeError( buf.makeStringAndClear() );
+                        throw BridgeRuntimeError("[map_to_uno():" + OUString::unacquired( &type->pTypeName ) +
+                            "] unsupported sequence element type: " + OUString::unacquired( &element_type->pTypeName ));
                     }
                     }
                 }
                 catch (BridgeRuntimeError& e)
                 {
-                    OUStringBuffer buf( 128 );
-                    buf.append( "[map_to_uno():" );
-                    buf.append( *reinterpret_cast< OUString const * >( &type->pTypeName ));
-                    buf.append( "] conversion failed\n ");
-                    buf.append(e.m_message);
-                    throw BridgeRuntimeError(buf.makeStringAndClear());
+                    throw BridgeRuntimeError("[map_to_uno():" + OUString::unacquired( &type->pTypeName ) + "] conversion failed\n " + e.m_message);
                 }
                 catch (System::InvalidCastException^ )
                 {
                     // Ok, checked
-                    OUStringBuffer buf( 128 );
-                    buf.append( "[map_to_uno():" );
-                    buf.append( *reinterpret_cast< OUString const * >( &type->pTypeName) );
-                    buf.append( "] could not convert sequence element type: " );
-                    buf.append( *reinterpret_cast< OUString const * >( &element_type->pTypeName ) );
-                    throw BridgeRuntimeError( buf.makeStringAndClear() );
+                    throw BridgeRuntimeError("[map_to_uno():" + OUString::unacquired( &type->pTypeName) +
+                        "] could not convert sequence element type: " + OUString::unacquired( &element_type->pTypeName ));
                 }
                 catch (...)
                 {
@@ -1444,11 +1401,7 @@ void Bridge::map_to_uno(void * uno_data, System::Object^ cli_data,
         default:
         {
             //ToDo check
-            OUStringBuffer buf( 128 );
-            buf.append( "[map_to_uno():" );
-            buf.append( *reinterpret_cast< OUString const * >( &type->pTypeName ) );
-            buf.append( "] unsupported type!" );
-            throw BridgeRuntimeError( buf.makeStringAndClear() );
+            throw BridgeRuntimeError("[map_to_uno():" + OUString::unacquired( &type->pTypeName ) + "] unsupported type!");
         }
         }
     }
@@ -1456,18 +1409,11 @@ void Bridge::map_to_uno(void * uno_data, System::Object^ cli_data,
     catch (System::InvalidCastException^ )
     {
         //ToDo check
-        OUStringBuffer buf( 128 );
-        buf.append( "[map_to_uno():" );
-        buf.append( *reinterpret_cast< OUString const * >( &type->pTypeName ) );
-        buf.append( "] could not convert type!" );
-        throw BridgeRuntimeError( buf.makeStringAndClear() );
+        throw BridgeRuntimeError("[map_to_uno():" + OUString::unacquired( &type->pTypeName ) + "] could not convert type!");
     }
     catch (System::NullReferenceException ^ e)
     {
-        OUStringBuffer buf(512);
-        buf.append( "[map_to_uno()] Illegal null reference passed!\n" );
-        buf.append(mapCliString(e->StackTrace));
-        throw BridgeRuntimeError( buf.makeStringAndClear() );
+        throw BridgeRuntimeError("[map_to_uno()] Illegal null reference passed!\n" + mapCliString(e->StackTrace));
     }
     catch (BridgeRuntimeError& )
     {
@@ -1504,7 +1450,7 @@ void Bridge::map_to_cli(
         *cli_data= *(__wchar_t const*)uno_data;
         break;
     case typelib_TypeClass_BOOLEAN:
-        *cli_data = (*(bool const*)uno_data) == sal_True ? true : false;
+        *cli_data = (*(bool const*)uno_data) == sal_True;
         break;
     case typelib_TypeClass_BYTE:
         *cli_data = *(unsigned char const*) uno_data;
@@ -1614,10 +1560,6 @@ void Bridge::map_to_cli(
                 OUString usMessageMember("Message");
                 for (int i = 0; i < pCTD->nMembers; i ++)
                 {
-#if OSL_DEBUG_LEVEL >= 2
-                    System::String* sMember;
-                    sMember = mapUnoString(pCTD->ppMemberNames[i]);
-#endif
                     if (usMessageMember.equals(pCTD->ppMemberNames[i]))
                     {
                         nPos = i;
@@ -1631,12 +1573,12 @@ void Bridge::map_to_cli(
                                                         ((char*) uno_data + offset));
                 //We need to find a constructor for the exception that takes the message string
                 //We assume that the first argument is the message string
-                array<sr::ConstructorInfo^>^ arCtorInfo = cliType->GetConstructors();
+                cli::array<sr::ConstructorInfo^>^ arCtorInfo = cliType->GetConstructors();
                 sr::ConstructorInfo^ ctorInfo = nullptr;
                 int numCtors = arCtorInfo->Length;
                 //Constructor must at least have 2 params for the base
                 //unoidl.com.sun.star.uno.Exception (String, Object);
-                array<sr::ParameterInfo^>^ arParamInfo;
+                cli::array<sr::ParameterInfo^>^ arParamInfo;
                 for (int i = 0; i < numCtors; i++)
                 {
                     arParamInfo = arCtorInfo[i]->GetParameters();
@@ -1651,7 +1593,7 @@ void Bridge::map_to_cli(
                     && arParamInfo[1]->Position == 1);
                 //Prepare parameters for constructor
                 int numArgs = arParamInfo->Length;
-                array<System::Object^>^ args = gcnew array<System::Object^>(numArgs);
+                cli::array<System::Object^>^ args = gcnew cli::array<System::Object^>(numArgs);
                 //only initialize the first argument with the message
                 args[0] = sMessage;
                 cliObj = ctorInfo->Invoke(args);
@@ -1748,58 +1690,58 @@ void Bridge::map_to_cli(
         {
         case typelib_TypeClass_CHAR:
         {
-            array<System::Char>^ arChar= gcnew array<System::Char>(nElements);
+            cli::array<System::Char>^ arChar= gcnew cli::array<System::Char>(nElements);
             sri::Marshal::Copy( IntPtr((void*) &seq->elements), arChar, 0, nElements);
             *cli_data= arChar;
             break;
         }
         case typelib_TypeClass_BOOLEAN:
         {
-            array<System::Byte>^ arBool= gcnew array<System::Byte>(nElements);
+            cli::array<System::Byte>^ arBool= gcnew cli::array<System::Byte>(nElements);
             sri::Marshal::Copy( IntPtr((void*) &seq->elements), arBool, 0, nElements);
-            *cli_data= dynamic_cast<array<System::Boolean>^>(arBool);
+            *cli_data= dynamic_cast<cli::array<System::Boolean>^>(arBool);
             break;
         }
         case typelib_TypeClass_BYTE:
         {
-            array<System::Byte>^ arByte= gcnew array<System::Byte>(nElements);
+            cli::array<System::Byte>^ arByte= gcnew cli::array<System::Byte>(nElements);
             sri::Marshal::Copy( IntPtr((void*) &seq->elements), arByte, 0, nElements);
             *cli_data= arByte;
             break;
         }
         case typelib_TypeClass_SHORT:
         {
-            array<System::Int16>^ arShort= gcnew array<System::Int16>(nElements);
+            cli::array<System::Int16>^ arShort= gcnew cli::array<System::Int16>(nElements);
             sri::Marshal::Copy( IntPtr((void*) &seq->elements), arShort, 0, nElements);
             *cli_data= arShort;
             break;
         }
         case typelib_TypeClass_UNSIGNED_SHORT:
         {
-            array<System::UInt16>^ arUInt16= gcnew array<System::UInt16>(nElements);
-            sri::Marshal::Copy( IntPtr((void*) &seq->elements), dynamic_cast<array<System::Int16>^>(arUInt16),
+            cli::array<System::UInt16>^ arUInt16= gcnew cli::array<System::UInt16>(nElements);
+            sri::Marshal::Copy( IntPtr((void*) &seq->elements), dynamic_cast<cli::array<System::Int16>^>(arUInt16),
                                 0, nElements);
             *cli_data= arUInt16;
             break;
         }
         case typelib_TypeClass_LONG:
         {
-            array<System::Int32>^ arInt32= gcnew array<System::Int32>(nElements);
+            cli::array<System::Int32>^ arInt32= gcnew cli::array<System::Int32>(nElements);
             sri::Marshal::Copy( IntPtr((void*) &seq->elements), arInt32, 0, nElements);
             *cli_data= arInt32;
             break;
         }
         case typelib_TypeClass_UNSIGNED_LONG:
         {
-            array<System::UInt32>^ arUInt32= gcnew array<System::UInt32>(nElements);
-            sri::Marshal::Copy( IntPtr((void*) &seq->elements), dynamic_cast<array<System::Int32>^>(arUInt32),
+            cli::array<System::UInt32>^ arUInt32= gcnew cli::array<System::UInt32>(nElements);
+            sri::Marshal::Copy( IntPtr((void*) &seq->elements), dynamic_cast<cli::array<System::Int32>^>(arUInt32),
                                 0, nElements);
             *cli_data= arUInt32;
             break;
         }
         case typelib_TypeClass_HYPER:
         {
-            array<System::Int64>^ arInt64= gcnew array<System::Int64>(nElements);
+            cli::array<System::Int64>^ arInt64= gcnew cli::array<System::Int64>(nElements);
             sri::Marshal::Copy( IntPtr((void*) &seq->elements), arInt64, 0, nElements);
             *cli_data= arInt64;
             break;
@@ -1807,28 +1749,28 @@ void Bridge::map_to_cli(
         //FIXME: Marshal::Copy of UInt64?
         case typelib_TypeClass_UNSIGNED_HYPER:
         {
-            array<System::IntPtr>^ arUInt64= gcnew array<System::IntPtr>(nElements);
+            cli::array<System::IntPtr>^ arUInt64= gcnew cli::array<System::IntPtr>(nElements);
             sri::Marshal::Copy( IntPtr((void*) &seq->elements), arUInt64, 0, nElements);
-            *cli_data= dynamic_cast<array<System::UInt64>^>(arUInt64);
+            *cli_data= dynamic_cast<cli::array<System::UInt64>^>(arUInt64);
             break;
         }
         case typelib_TypeClass_FLOAT:
         {
-            array<System::Single>^ arSingle= gcnew array<System::Single>(nElements);
+            cli::array<System::Single>^ arSingle= gcnew cli::array<System::Single>(nElements);
             sri::Marshal::Copy( IntPtr((void*) &seq->elements), arSingle, 0, nElements);
             *cli_data= arSingle;
             break;
         }
         case typelib_TypeClass_DOUBLE:
         {
-            array<System::Double>^ arDouble= gcnew array<System::Double>(nElements);
+            cli::array<System::Double>^ arDouble= gcnew cli::array<System::Double>(nElements);
             sri::Marshal::Copy( IntPtr((void*) &seq->elements), arDouble, 0, nElements);
             *cli_data= arDouble;
             break;
         }
         case typelib_TypeClass_STRING:
         {
-            array<System::String^>^ arString= gcnew array<System::String^>(nElements);
+            cli::array<System::String^>^ arString= gcnew cli::array<System::String^>(nElements);
             for (int i= 0; i < nElements; i++)
             {
                 rtl_uString *aStr= ((rtl_uString**)(&seq->elements))[i];
@@ -1839,7 +1781,7 @@ void Bridge::map_to_cli(
         }
         case typelib_TypeClass_TYPE:
         {
-            array<System::Type^>^ arType= gcnew array<System::Type^>(nElements);
+            cli::array<System::Type^>^ arType= gcnew cli::array<System::Type^>(nElements);
             for (int i= 0; i < nElements; i++)
             {
                 arType[i]=
@@ -1850,7 +1792,7 @@ void Bridge::map_to_cli(
         }
         case typelib_TypeClass_ANY:
         {
-            array<uno::Any>^ arCli= gcnew array<uno::Any>(nElements);
+            cli::array<uno::Any>^ arCli= gcnew cli::array<uno::Any>(nElements);
             uno_Any const * p = (uno_Any const *)seq->elements;
             for (sal_Int32 nPos = 0; nPos < nElements; ++nPos )
             {
@@ -1950,12 +1892,8 @@ void Bridge::map_to_cli(
         }
         default:
         {
-            OUStringBuffer buf( 128 );
-            buf.append( "[map_to_cli():" );
-            buf.append( *reinterpret_cast< OUString const * >( &type->pTypeName ) );
-            buf.append( "] unsupported element type: " );
-            buf.append( *reinterpret_cast< OUString const * >( &element_type->pTypeName ) );
-            throw BridgeRuntimeError( buf.makeStringAndClear() );
+            throw BridgeRuntimeError("[map_to_cli():" + OUString::unacquired( &type->pTypeName ) +
+                "] unsupported element type: " + OUString::unacquired( &element_type->pTypeName ));
         }
         }
         break;
@@ -1976,11 +1914,7 @@ void Bridge::map_to_cli(
     default:
     {
         //ToDo check this exception. The String is probably crippled
-        OUStringBuffer buf( 128 );
-        buf.append( "[map_to_cli():" );
-        buf.append( *reinterpret_cast< OUString const * >( &type->pTypeName ) );
-        buf.append( "] unsupported type!" );
-        throw BridgeRuntimeError( buf.makeStringAndClear() );
+        throw BridgeRuntimeError("[map_to_cli():" + OUString::unacquired( &type->pTypeName ) + "] unsupported type!");
     }
     } //switch
 } // method
