@@ -132,11 +132,10 @@ uno::Reference< container::XNameAccess > MimeConfigurationHelper::GetConfigurati
         aPathProp.Value <<= aPath;
         aArgs[0] <<= aPathProp;
 
-        xConfig = uno::Reference< container::XNameAccess >(
-                            m_xConfigProvider->createInstanceWithArguments(
-                                OUString( "com.sun.star.configuration.ConfigurationAccess" ),
-                                aArgs ),
-                            uno::UNO_QUERY );
+        xConfig.set( m_xConfigProvider->createInstanceWithArguments(
+                        "com.sun.star.configuration.ConfigurationAccess",
+                        aArgs ),
+                     uno::UNO_QUERY );
     }
     catch( uno::Exception& )
     {}
@@ -151,7 +150,7 @@ uno::Reference< container::XNameAccess > MimeConfigurationHelper::GetObjConfigur
 
     if ( !m_xObjectConfig.is() )
         m_xObjectConfig = GetConfigurationByPath(
-                                         OUString( "/org.openoffice.Office.Embedding/Objects" ) );
+                                         "/org.openoffice.Office.Embedding/Objects" );
 
     return m_xObjectConfig;
 }
@@ -163,7 +162,7 @@ uno::Reference< container::XNameAccess > MimeConfigurationHelper::GetVerbsConfig
 
     if ( !m_xVerbsConfig.is() )
         m_xVerbsConfig = GetConfigurationByPath(
-                                        OUString( "/org.openoffice.Office.Embedding/Verbs" ));
+                                        "/org.openoffice.Office.Embedding/Verbs");
 
     return m_xVerbsConfig;
 }
@@ -175,7 +174,7 @@ uno::Reference< container::XNameAccess > MimeConfigurationHelper::GetMediaTypeCo
 
     if ( !m_xMediaTypeConfig.is() )
         m_xMediaTypeConfig = GetConfigurationByPath(
-                    OUString( "/org.openoffice.Office.Embedding/MimeTypeClassIDRelations" ));
+                    "/org.openoffice.Office.Embedding/MimeTypeClassIDRelations");
 
     return m_xMediaTypeConfig;
 }
@@ -231,9 +230,7 @@ OUString MimeConfigurationHelper::GetDocServiceNameFromMediaType( const OUString
         try
         {
             // make query for all types matching the properties
-            uno::Sequence < beans::NamedValue > aSeq( 1 );
-            aSeq[0].Name = "MediaType";
-            aSeq[0].Value <<= aMediaType;
+            uno::Sequence < beans::NamedValue > aSeq { { "MediaType", css::uno::makeAny(aMediaType) } };
 
             uno::Reference < container::XEnumeration > xEnum = xTypeCFG->createSubSetEnumerationByProperties( aSeq );
             while ( xEnum->hasMoreElements() )
@@ -535,8 +532,7 @@ OUString MimeConfigurationHelper::GetFactoryNameByDocumentName( const OUString&
                     OUString aEntryDocName;
 
                     if ( ( xObjConfig->getByName( aClassIDs[nInd] ) >>= xObjectProps ) && xObjectProps.is()
-                      && ( xObjectProps->getByName(
-                                  OUString( "ObjectDocumentServiceName" ) ) >>= aEntryDocName )
+                      && ( xObjectProps->getByName( "ObjectDocumentServiceName" ) >>= aEntryDocName )
                       && aEntryDocName == aDocName )
                     {
                         xObjectProps->getByName("ObjectFactory") >>= aResult;
@@ -671,9 +667,9 @@ OUString MimeConfigurationHelper::UpdateMediaDescriptorWithFilterName(
 
 #ifdef WNT
 
-sal_Int32 MimeConfigurationHelper::GetFilterFlags( const OUString& aFilterName )
+SfxFilterFlags MimeConfigurationHelper::GetFilterFlags( const OUString& aFilterName )
 {
-    sal_Int32 nFlags = 0;
+    SfxFilterFlags nFlags = SfxFilterFlags::NONE;
     try
     {
         if ( !aFilterName.isEmpty() )
@@ -687,7 +683,7 @@ sal_Int32 MimeConfigurationHelper::GetFilterFlags( const OUString& aFilterName )
             if ( aFilterAny >>= aData )
             {
                 SequenceAsHashMap aFilterHM( aData );
-                nFlags = aFilterHM.getUnpackedValueOrDefault( "Flags", (sal_Int32)0 );
+                nFlags = static_cast<SfxFilterFlags>(aFilterHM.getUnpackedValueOrDefault( "Flags", (sal_Int32)0 ));
             }
         }
     } catch( uno::Exception& )
@@ -696,23 +692,21 @@ sal_Int32 MimeConfigurationHelper::GetFilterFlags( const OUString& aFilterName )
     return nFlags;
 }
 
-sal_Bool MimeConfigurationHelper::AddFilterNameCheckOwnFile(
+bool MimeConfigurationHelper::AddFilterNameCheckOwnFile(
                         uno::Sequence< beans::PropertyValue >& aMediaDescr )
 {
-    sal_Bool bResult = sal_False;
-
     OUString aFilterName = UpdateMediaDescriptorWithFilterName( aMediaDescr, sal_False );
     if ( !aFilterName.isEmpty() )
     {
-        sal_Int32 nFlags = GetFilterFlags( aFilterName );
+        SfxFilterFlags nFlags = GetFilterFlags( aFilterName );
         // check the OWN flag
-        bResult = ( nFlags & SFX_FILTER_OWN );
+        return bool(nFlags & SfxFilterFlags::OWN);
     }
 
-    return bResult;
+    return false;
 }
-#endif
 
+#endif
 
 OUString MimeConfigurationHelper::GetDefaultFilterFromServiceName( const OUString& aServiceName, sal_Int32 nVersion )
 {
@@ -725,11 +719,11 @@ OUString MimeConfigurationHelper::GetDefaultFilterFromServiceName( const OUStrin
                 GetFilterFactory(),
                 uno::UNO_QUERY_THROW );
 
-            uno::Sequence< beans::NamedValue > aSearchRequest( 2 );
-            aSearchRequest[0].Name = "DocumentService";
-            aSearchRequest[0].Value <<= aServiceName;
-            aSearchRequest[1].Name = "FileFormatVersion";
-            aSearchRequest[1].Value <<= nVersion;
+            uno::Sequence< beans::NamedValue > aSearchRequest
+            {
+                { "DocumentService", css::uno::makeAny(aServiceName) },
+                { "FileFormatVersion", css::uno::makeAny(nVersion) }
+            };
 
             uno::Reference< container::XEnumeration > xFilterEnum =
                                             xFilterQuery->createSubSetEnumerationByProperties( aSearchRequest );
@@ -742,22 +736,22 @@ OUString MimeConfigurationHelper::GetDefaultFilterFromServiceName( const OUStrin
                     if ( xFilterEnum->nextElement() >>= aProps )
                     {
                         SequenceAsHashMap aPropsHM( aProps );
-                        sal_Int32 nFlags = aPropsHM.getUnpackedValueOrDefault( "Flags", (sal_Int32)0 );
+                        SfxFilterFlags nFlags = static_cast<SfxFilterFlags>(aPropsHM.getUnpackedValueOrDefault( "Flags", (sal_Int32)0 ));
 
                         // that should be import, export, own filter and not a template filter ( TemplatePath flag )
-                        sal_Int32 const nRequired = (SFX_FILTER_OWN
+                        SfxFilterFlags const nRequired = (SfxFilterFlags::OWN
                             // fdo#78159 for OOoXML, there is code to convert
                             // to ODF in OCommonEmbeddedObject::store*
                             // so accept it even though there's no export
-                            | (SOFFICE_FILEFORMAT_60 == nVersion ? 0 : SFX_FILTER_EXPORT)
-                            | SFX_FILTER_IMPORT );
-                        if ( ( ( nFlags & nRequired ) == nRequired ) && !( nFlags & SFX_FILTER_TEMPLATEPATH ) )
+                            | (SOFFICE_FILEFORMAT_60 == nVersion ? SfxFilterFlags::NONE : SfxFilterFlags::EXPORT)
+                            | SfxFilterFlags::IMPORT );
+                        if ( ( ( nFlags & nRequired ) == nRequired ) && !( nFlags & SfxFilterFlags::TEMPLATEPATH ) )
                         {
                             // if there are more than one filter the preffered one should be used
                             // if there is no preffered filter the first one will be used
-                            if ( aResult.isEmpty() || ( nFlags & SFX_FILTER_PREFERED ) )
+                            if ( aResult.isEmpty() || ( nFlags & SfxFilterFlags::PREFERED ) )
                                 aResult = aPropsHM.getUnpackedValueOrDefault( "Name", OUString() );
-                            if ( nFlags & SFX_FILTER_PREFERED )
+                            if ( nFlags & SfxFilterFlags::PREFERED )
                                 break; // the preferred filter was found
                         }
                     }
@@ -787,15 +781,15 @@ OUString MimeConfigurationHelper::GetExportFilterFromImportFilter( const OUStrin
             if ( aImpFilterAny >>= aImpData )
             {
                 SequenceAsHashMap aImpFilterHM( aImpData );
-                sal_Int32 nFlags = aImpFilterHM.getUnpackedValueOrDefault( "Flags", (sal_Int32)0 );
+                SfxFilterFlags nFlags = static_cast<SfxFilterFlags>(aImpFilterHM.getUnpackedValueOrDefault( "Flags", (sal_Int32)0 ));
 
-                if ( !( nFlags & SFX_FILTER_IMPORT ) )
+                if ( !( nFlags & SfxFilterFlags::IMPORT ) )
                 {
                     OSL_FAIL( "This is no import filter!" );
                     throw uno::Exception();
                 }
 
-                if ( nFlags & SFX_FILTER_EXPORT )
+                if ( nFlags & SfxFilterFlags::EXPORT )
                 {
                     aExportFilterName = aImportFilterName;
                 }
@@ -807,17 +801,17 @@ OUString MimeConfigurationHelper::GetExportFilterFromImportFilter( const OUStrin
                     OSL_ENSURE( !aDocumentServiceName.isEmpty() && !aTypeName.isEmpty(), "Incomplete filter data!" );
                     if ( !(aDocumentServiceName.isEmpty() || aTypeName.isEmpty()) )
                     {
-                        uno::Sequence< beans::NamedValue > aSearchRequest( 2 );
-                        aSearchRequest[0].Name = "Type";
-                        aSearchRequest[0].Value <<= aTypeName;
-                        aSearchRequest[1].Name = "DocumentService";
-                        aSearchRequest[1].Value <<= aDocumentServiceName;
+                        uno::Sequence< beans::NamedValue > aSearchRequest
+                        {
+                            { "Type", css::uno::makeAny(aTypeName) },
+                            { "DocumentService", css::uno::makeAny(aDocumentServiceName) }
+                        };
 
                         uno::Sequence< beans::PropertyValue > aExportFilterProps = SearchForFilter(
                             uno::Reference< container::XContainerQuery >( xFilterFactory, uno::UNO_QUERY_THROW ),
                             aSearchRequest,
-                            SFX_FILTER_EXPORT,
-                            SFX_FILTER_INTERNAL );
+                            SfxFilterFlags::EXPORT,
+                            SfxFilterFlags::INTERNAL );
 
                         if ( aExportFilterProps.getLength() )
                         {
@@ -840,8 +834,8 @@ OUString MimeConfigurationHelper::GetExportFilterFromImportFilter( const OUStrin
 uno::Sequence< beans::PropertyValue > MimeConfigurationHelper::SearchForFilter(
                                                         const uno::Reference< container::XContainerQuery >& xFilterQuery,
                                                         const uno::Sequence< beans::NamedValue >& aSearchRequest,
-                                                        sal_Int32 nMustFlags,
-                                                        sal_Int32 nDontFlags )
+                                                        SfxFilterFlags nMustFlags,
+                                                        SfxFilterFlags nDontFlags )
 {
     uno::Sequence< beans::PropertyValue > aFilterProps;
     uno::Reference< container::XEnumeration > xFilterEnum =
@@ -857,11 +851,11 @@ uno::Sequence< beans::PropertyValue > MimeConfigurationHelper::SearchForFilter(
             if ( xFilterEnum->nextElement() >>= aProps )
             {
                 SequenceAsHashMap aPropsHM( aProps );
-                sal_Int32 nFlags = aPropsHM.getUnpackedValueOrDefault("Flags",
-                                                                        (sal_Int32)0 );
+                SfxFilterFlags nFlags = static_cast<SfxFilterFlags>(aPropsHM.getUnpackedValueOrDefault("Flags",
+                                                                        (sal_Int32)0 ));
                 if ( ( ( nFlags & nMustFlags ) == nMustFlags ) && !( nFlags & nDontFlags ) )
                 {
-                    if ( ( nFlags & SFX_FILTER_DEFAULT ) == SFX_FILTER_DEFAULT )
+                    if ( ( nFlags & SfxFilterFlags::DEFAULT ) == SfxFilterFlags::DEFAULT )
                     {
                         aFilterProps = aProps;
                         break;
