@@ -17,19 +17,19 @@
  *   the License at http://www.apache.org/licenses/LICENSE-2.0 .
  */
 
-#include "connectivity/filtermanager.hxx"
+#include <connectivity/filtermanager.hxx>
 
 #include <com/sun/star/sdb/XSQLQueryComposerFactory.hpp>
 #include "TConnection.hxx"
 #include <osl/diagnose.h>
-#include "connectivity/dbtools.hxx"
+#include <connectivity/dbtools.hxx>
 #include <tools/diagnose_ex.h>
 #include <rtl/ustrbuf.hxx>
 
-//........................................................................
+
 namespace dbtools
 {
-//........................................................................
+
 
     using namespace ::com::sun::star::uno;
     using namespace ::com::sun::star::sdbc;
@@ -38,39 +38,35 @@ namespace dbtools
     using namespace ::com::sun::star::beans;
     using namespace connectivity;
 
-    //====================================================================
-    //= FilterManager
-    //====================================================================
-    //--------------------------------------------------------------------
     FilterManager::FilterManager( )
         :m_aFilterComponents( FC_COMPONENT_COUNT )
         ,m_bApplyPublicFilter( true )
     {
     }
 
-    //--------------------------------------------------------------------
+
     void FilterManager::initialize( const Reference< XPropertySet >& _rxComponentAggregate )
     {
         m_xComponentAggregate = _rxComponentAggregate;
         OSL_ENSURE( m_xComponentAggregate.is(), "FilterManager::initialize: invalid arguments!" );
 
         if ( m_xComponentAggregate.is() )
-            m_xComponentAggregate->setPropertyValue( OMetaConnection::getPropMap().getNameByIndex(PROPERTY_ID_APPLYFILTER), makeAny( (sal_Bool)sal_True ) );
+            m_xComponentAggregate->setPropertyValue( OMetaConnection::getPropMap().getNameByIndex(PROPERTY_ID_APPLYFILTER), makeAny( true ) );
     }
 
-    //--------------------------------------------------------------------
+
     void FilterManager::dispose( )
     {
         m_xComponentAggregate.clear();
     }
 
-    //--------------------------------------------------------------------
+
     const OUString& FilterManager::getFilterComponent( FilterComponent _eWhich ) const
     {
         return m_aFilterComponents[ _eWhich ];
     }
 
-    //--------------------------------------------------------------------
+
     void FilterManager::setFilterComponent( FilterComponent _eWhich, const OUString& _rComponent )
     {
         m_aFilterComponents[ _eWhich ]  = _rComponent;
@@ -85,8 +81,8 @@ namespace dbtools
         }
     }
 
-    //--------------------------------------------------------------------
-    void FilterManager::setApplyPublicFilter( sal_Bool _bApply )
+
+    void FilterManager::setApplyPublicFilter( bool _bApply )
     {
         if ( m_bApplyPublicFilter == _bApply )
             return;
@@ -106,22 +102,22 @@ namespace dbtools
         }
     }
 
-    //--------------------------------------------------------------------
-    void FilterManager::appendFilterComponent( OUStringBuffer& io_appendTo, const OUString& i_component ) const
+
+    void FilterManager::appendFilterComponent( OUStringBuffer& io_appendTo, const OUString& i_component )
     {
         if ( !io_appendTo.isEmpty() )
         {
             io_appendTo.insert( 0, '(' );
             io_appendTo.insert( 1, ' ' );
-            io_appendTo.appendAscii( " ) AND " );
+            io_appendTo.append( " ) AND " );
         }
 
-        io_appendTo.appendAscii( "( " );
+        io_appendTo.append( "( " );
         io_appendTo.append( i_component );
-        io_appendTo.appendAscii( " )" );
+        io_appendTo.append( " )" );
     }
 
-    //--------------------------------------------------------------------
+
     bool FilterManager::isThereAtMostOneComponent( OUStringBuffer& o_singleComponent ) const
     {
         sal_Int32 nOnlyNonEmpty = -1;
@@ -152,7 +148,7 @@ namespace dbtools
         return false;
     }
 
-    //--------------------------------------------------------------------
+
     OUString FilterManager::getComposedFilter( ) const
     {
         OUStringBuffer aComposedFilter;
@@ -168,8 +164,8 @@ namespace dbtools
         return aComposedFilter.makeStringAndClear();
     }
 
-//........................................................................
+
 }   // namespace dbtools
-//........................................................................
+
 
 /* vim:set shiftwidth=4 softtabstop=4 expandtab: */
