@@ -18,8 +18,8 @@
  */
 
 
-#include "connectivity/warningscontainer.hxx"
-#include "connectivity/dbexception.hxx"
+#include <connectivity/warningscontainer.hxx>
+#include <connectivity/dbexception.hxx>
 
 #include <osl/diagnose.h>
 
@@ -32,10 +32,6 @@ namespace dbtools
     using namespace ::com::sun::star::sdbc;
     using namespace ::com::sun::star::sdb;
 
-
-    //= WarningsContainer
-
-
     static void lcl_concatWarnings( Any& _rChainLeft, const Any& _rChainRight )
     {
         if ( !_rChainLeft.hasValue() )
@@ -59,11 +55,6 @@ namespace dbtools
     }
 
 
-    WarningsContainer::~WarningsContainer()
-    {
-    }
-
-
     void WarningsContainer::appendWarning(const SQLException& _rWarning)
     {
         lcl_concatWarnings( m_aOwnWarnings, makeAny( _rWarning ) );
