@@ -27,11 +27,10 @@
 #include <com/sun/star/frame/Desktop.hpp>
 #include <com/sun/star/reflection/ProxyFactory.hpp>
 #include <com/sun/star/sdbc/DriverManager.hpp>
-#include <comphelper/extract.hxx>
 #include <comphelper/processfactory.hxx>
 #include <cppuhelper/supportsservice.hxx>
 #include <com/sun/star/beans/XPropertySet.hpp>
-#include "diagnose_ex.h"
+#include <osl/diagnose.h>
 
 using namespace ::com::sun::star::uno;
 using namespace ::com::sun::star::lang;
@@ -42,38 +41,33 @@ using namespace ::com::sun::star::reflection;
 using namespace ::osl;
 using namespace connectivity;
 
-//--------------------------------------------------------------------
-static const OUString& getConnectionPoolNodeName()
+
+static OUString getConnectionPoolNodeName()
 {
-    static OUString s_sNodeName(  "org.openoffice.Office.DataAccess/ConnectionPool" );
-    return s_sNodeName;
-}
-//--------------------------------------------------------------------
-static const OUString& getEnablePoolingNodeName()
-{
-    static OUString s_sNodeName(  "EnablePooling" );
-    return s_sNodeName;
-}
-//--------------------------------------------------------------------
-static const OUString& getDriverNameNodeName()
-{
-    static OUString s_sNodeName(  "DriverName" );
-    return s_sNodeName;
-}
-// -----------------------------------------------------------------------------
-static const OUString& getDriverSettingsNodeName()
-{
-    static OUString s_sNodeName(  "DriverSettings" );
-    return s_sNodeName;
-}
-//--------------------------------------------------------------------------
-static const OUString& getEnableNodeName()
-{
-    static OUString s_sNodeName(  "Enable" );
-    return s_sNodeName;
+    return OUString(  "org.openoffice.Office.DataAccess/ConnectionPool" );
 }
 
-//--------------------------------------------------------------------
+static OUString getEnablePoolingNodeName()
+{
+    return OUString(  "EnablePooling" );
+}
+
+static OUString getDriverNameNodeName()
+{
+    return OUString(  "DriverName" );
+}
+
+static OUString getDriverSettingsNodeName()
+{
+    return OUString(  "DriverSettings" );
+}
+
+static OUString getEnableNodeName()
+{
+    return OUString(  "Enable" );
+}
+
+
 OPoolCollection::OPoolCollection(const Reference< XComponentContext >& _rxContext)
     :m_xContext(_rxContext)
 {
@@ -95,18 +89,18 @@ OPoolCollection::OPoolCollection(const Reference< XComponentContext >& _rxContex
     }
     osl_atomic_decrement( &m_refCount );
 }
-// -----------------------------------------------------------------------------
+
 OPoolCollection::~OPoolCollection()
 {
-    clearConnectionPools(sal_False);
+    clearConnectionPools(false);
 }
-// -----------------------------------------------------------------------------
-Reference< XConnection > SAL_CALL OPoolCollection::getConnection( const OUString& _rURL ) throw(SQLException, RuntimeException)
+
+Reference< XConnection > SAL_CALL OPoolCollection::getConnection( const OUString& _rURL ) throw(SQLException, RuntimeException, std::exception)
 {
     return getConnectionWithInfo(_rURL,Sequence< PropertyValue >());
 }
-// -----------------------------------------------------------------------------
-Reference< XConnection > SAL_CALL OPoolCollection::getConnectionWithInfo( const OUString& _rURL, const Sequence< PropertyValue >& _rInfo ) throw(SQLException, RuntimeException)
+
+Reference< XConnection > SAL_CALL OPoolCollection::getConnectionWithInfo( const OUString& _rURL, const Sequence< PropertyValue >& _rInfo ) throw(SQLException, RuntimeException, std::exception)
 {
     MutexGuard aGuard(m_aMutex);
     Reference< XConnection > xConnection;
@@ -125,32 +119,31 @@ Reference< XConnection > SAL_CALL OPoolCollection::getConnectionWithInfo( const
 
     return xConnection;
 }
-// -----------------------------------------------------------------------------
-void SAL_CALL OPoolCollection::setLoginTimeout( sal_Int32 seconds ) throw(RuntimeException)
+
+void SAL_CALL OPoolCollection::setLoginTimeout( sal_Int32 seconds ) throw(RuntimeException, std::exception)
 {
     MutexGuard aGuard(m_aMutex);
     m_xManager->setLoginTimeout(seconds);
 }
-// -----------------------------------------------------------------------------
-sal_Int32 SAL_CALL OPoolCollection::getLoginTimeout(  ) throw(RuntimeException)
+
+sal_Int32 SAL_CALL OPoolCollection::getLoginTimeout(  ) throw(RuntimeException, std::exception)
 {
     MutexGuard aGuard(m_aMutex);
     return m_xManager->getLoginTimeout();
 }
-// -----------------------------------------------------------------------------
-OUString SAL_CALL OPoolCollection::getImplementationName(  ) throw(RuntimeException)
+
+OUString SAL_CALL OPoolCollection::getImplementationName(  ) throw(RuntimeException, std::exception)
 {
-    MutexGuard aGuard(m_aMutex);
     return getImplementationName_Static();
 }
 
-sal_Bool SAL_CALL OPoolCollection::supportsService( const OUString& _rServiceName ) throw(RuntimeException)
+sal_Bool SAL_CALL OPoolCollection::supportsService( const OUString& _rServiceName ) throw(RuntimeException, std::exception)
 {
     return cppu::supportsService(this, _rServiceName);
 }
 
-//--------------------------------------------------------------------------
-Sequence< OUString > SAL_CALL OPoolCollection::getSupportedServiceNames(  ) throw(RuntimeException)
+
+Sequence< OUString > SAL_CALL OPoolCollection::getSupportedServiceNames(  ) throw(RuntimeException, std::exception)
 {
     return getSupportedServiceNames_Static();
 }
@@ -161,21 +154,20 @@ Reference< XInterface > SAL_CALL OPoolCollection::CreateInstance(const Reference
     return static_cast<XDriverManager*>(new OPoolCollection(comphelper::getComponentContext(_rxFactory)));
 }
 
-//--------------------------------------------------------------------------
+
 OUString SAL_CALL OPoolCollection::getImplementationName_Static(  ) throw(RuntimeException)
 {
     return OUString("com.sun.star.sdbc.OConnectionPool");
 }
 
-//--------------------------------------------------------------------------
+
 Sequence< OUString > SAL_CALL OPoolCollection::getSupportedServiceNames_Static(  ) throw(RuntimeException)
 {
-    Sequence< OUString > aSupported(1);
-    aSupported[0] = "com.sun.star.sdbc.ConnectionPool";
+    Sequence< OUString > aSupported { "com.sun.star.sdbc.ConnectionPool" };
     return aSupported;
 }
-// -----------------------------------------------------------------------------
-Reference< XDriver > SAL_CALL OPoolCollection::getDriverByURL( const OUString& _rURL ) throw(RuntimeException)
+
+Reference< XDriver > SAL_CALL OPoolCollection::getDriverByURL( const OUString& _rURL ) throw(RuntimeException, std::exception)
 {
     // returns the original driver when no connection pooling is enabled else it returns the proxy
     MutexGuard aGuard(m_aMutex);
@@ -187,7 +179,7 @@ Reference< XDriver > SAL_CALL OPoolCollection::getDriverByURL( const OUString& _
     {
         Reference< XDriver > xExistentProxy;
         // look if we already have a proxy for this driver
-        for (   ConstMapDriver2DriverRefIterator aLookup = m_aDriverProxies.begin();
+        for (   MapDriver2DriverRef::const_iterator aLookup = m_aDriverProxies.begin();
                 aLookup != m_aDriverProxies.end();
                 ++aLookup
             )
@@ -216,11 +208,11 @@ Reference< XDriver > SAL_CALL OPoolCollection::getDriverByURL( const OUString& _
 
     return xDriver;
 }
-// -----------------------------------------------------------------------------
-sal_Bool OPoolCollection::isDriverPoolingEnabled(const OUString& _sDriverImplName,
+
+bool OPoolCollection::isDriverPoolingEnabled(const OUString& _sDriverImplName,
                                                  Reference< XInterface >& _rxDriverNode)
 {
-    sal_Bool bEnabled = sal_False;
+    bool bEnabled = false;
     Reference<XInterface> xConnectionPoolRoot = getConfigPoolRoot();
     // then look for which of them settings are stored in the configuration
     Reference< XNameAccess > xDirectAccess(openNode(getDriverSettingsNodeName(),xConnectionPoolRoot),UNO_QUERY);
@@ -244,32 +236,32 @@ sal_Bool OPoolCollection::isDriverPoolingEnabled(const OUString& _sDriverImplNam
     }
     return bEnabled;
 }
-// -----------------------------------------------------------------------------
-sal_Bool OPoolCollection::isPoolingEnabled()
+
+bool OPoolCollection::isPoolingEnabled()
 {
     // the config node where all pooling relevant info are stored under
     Reference<XInterface> xConnectionPoolRoot = getConfigPoolRoot();
 
     // the global "enabled" flag
-    sal_Bool bEnabled = sal_False;
+    bool bEnabled = false;
     if(xConnectionPoolRoot.is())
         getNodeValue(getEnablePoolingNodeName(),xConnectionPoolRoot) >>= bEnabled;
     return bEnabled;
 }
-// -----------------------------------------------------------------------------
+
 Reference<XInterface> OPoolCollection::getConfigPoolRoot()
 {
     if(!m_xConfigNode.is())
         m_xConfigNode = createWithServiceFactory(getConnectionPoolNodeName());
     return m_xConfigNode;
 }
-// -----------------------------------------------------------------------------
-sal_Bool OPoolCollection::isPoolingEnabledByUrl(const OUString& _sUrl,
+
+bool OPoolCollection::isPoolingEnabledByUrl(const OUString& _sUrl,
                                                 Reference< XDriver >& _rxDriver,
                                                 OUString& _rsImplName,
                                                 Reference< XInterface >& _rxDriverNode)
 {
-    sal_Bool bEnabled = sal_False;
+    bool bEnabled = false;
     _rxDriver = m_xManager->getDriverByURL(_sUrl);
     if (_rxDriver.is() && isPoolingEnabled())
     {
@@ -285,8 +277,8 @@ sal_Bool OPoolCollection::isPoolingEnabledByUrl(const OUString& _sUrl,
     }
     return bEnabled;
 }
-// -----------------------------------------------------------------------------
-void OPoolCollection::clearConnectionPools(sal_Bool _bDispose)
+
+void OPoolCollection::clearConnectionPools(bool _bDispose)
 {
     OConnectionPools::const_iterator aIter = m_aPools.begin();
     while(aIter != m_aPools.end())
@@ -298,12 +290,12 @@ void OPoolCollection::clearConnectionPools(sal_Bool _bDispose)
         m_aPools.erase(sKeyValue);
     }
 }
-// -----------------------------------------------------------------------------
+
 OConnectionPool* OPoolCollection::getConnectionPool(const OUString& _sImplName,
                                                     const Reference< XDriver >& _xDriver,
                                                     const Reference< XInterface >& _xDriverNode)
 {
-    OConnectionPool *pRet = 0;
+    OConnectionPool *pRet = nullptr;
     OConnectionPools::const_iterator aFind = m_aPools.find(_sImplName);
     if (aFind != m_aPools.end())
         pRet = aFind->second;
@@ -322,16 +314,16 @@ OConnectionPool* OPoolCollection::getConnectionPool(const OUString& _sImplName,
 
     return pRet;
 }
-// -----------------------------------------------------------------------------
+
 Reference< XInterface > OPoolCollection::createWithServiceFactory(const OUString& _rPath) const
 {
     return createWithProvider(
         com::sun::star::configuration::theDefaultProvider::get(m_xContext),
         _rPath);
 }
-//------------------------------------------------------------------------
+
 Reference< XInterface > OPoolCollection::createWithProvider(const Reference< XMultiServiceFactory >& _rxConfProvider,
-                            const OUString& _rPath) const
+                            const OUString& _rPath)
 {
     OSL_ASSERT(_rxConfProvider.is());
     Sequence< Any > args(1);
@@ -341,15 +333,15 @@ Reference< XInterface > OPoolCollection::createWithProvider(const Reference< XMu
             makeAny(_rPath)));
     Reference< XInterface > xInterface(
         _rxConfProvider->createInstanceWithArguments(
-            OUString( "com.sun.star.configuration.ConfigurationAccess"),
+            "com.sun.star.configuration.ConfigurationAccess",
             args));
     OSL_ENSURE(
         xInterface.is(),
         "::createWithProvider: could not create the node access!");
     return xInterface;
 }
-// -----------------------------------------------------------------------------
-Reference<XInterface> OPoolCollection::openNode(const OUString& _rPath,const Reference<XInterface>& _xTreeNode) const throw()
+
+Reference<XInterface> OPoolCollection::openNode(const OUString& _rPath,const Reference<XInterface>& _xTreeNode) throw()
 {
     Reference< XHierarchicalNameAccess > xHierarchyAccess(_xTreeNode, UNO_QUERY);
     Reference< XNameAccess > xDirectAccess(_xTreeNode, UNO_QUERY);
@@ -359,13 +351,19 @@ Reference<XInterface> OPoolCollection::openNode(const OUString& _rPath,const Ref
     {
         if (xDirectAccess.is() && xDirectAccess->hasByName(_rPath))
         {
-            if (!::cppu::extractInterface(xNode, xDirectAccess->getByName(_rPath)))
-                SAL_WARN("connectivity.cpool", "OConfigurationNode::openNode: could not open the node!");
+            xNode.set(xDirectAccess->getByName(_rPath), css::uno::UNO_QUERY);
+            SAL_WARN_IF(
+                !xNode.is(), "connectivity.cpool",
+                "OConfigurationNode::openNode: could not open the node!");
         }
         else if (xHierarchyAccess.is())
         {
-            if (!::cppu::extractInterface(xNode, xHierarchyAccess->getByHierarchicalName(_rPath)))
-                SAL_WARN("connectivity.cpool", "OConfigurationNode::openNode: could not open the node!");
+            xNode.set(
+                xHierarchyAccess->getByHierarchicalName(_rPath),
+                css::uno::UNO_QUERY);
+            SAL_WARN_IF(
+                !xNode.is(), "connectivity.cpool",
+                "OConfigurationNode::openNode: could not open the node!");
         }
 
     }
@@ -380,7 +378,7 @@ Reference<XInterface> OPoolCollection::openNode(const OUString& _rPath,const Ref
     }
     return xNode;
 }
-// -----------------------------------------------------------------------------
+
 Any OPoolCollection::getNodeValue(const OUString& _rPath,const Reference<XInterface>& _xTreeNode) throw()
 {
     Reference< XHierarchicalNameAccess > xHierarchyAccess(_xTreeNode, UNO_QUERY);
@@ -399,23 +397,23 @@ Any OPoolCollection::getNodeValue(const OUString& _rPath,const Reference<XInterf
     }
     catch(NoSuchElementException& e)
     {
-        SAL_WARN("connectivity.cpool", "::getNodeValue: caught a " <<
+        SAL_WARN("connectivity.cpool", "::getNodeValue: caught a "
                  "NoSuchElementException while trying to open " <<
                  e.Message << "!" );
     }
     return aReturn;
 }
-// -----------------------------------------------------------------------------
-void SAL_CALL OPoolCollection::queryTermination( const EventObject& /*Event*/ ) throw (::com::sun::star::frame::TerminationVetoException, RuntimeException)
+
+void SAL_CALL OPoolCollection::queryTermination( const EventObject& /*Event*/ ) throw (::com::sun::star::frame::TerminationVetoException, RuntimeException, std::exception)
 {
 }
-// -----------------------------------------------------------------------------
-void SAL_CALL OPoolCollection::notifyTermination( const EventObject& /*Event*/ ) throw (RuntimeException)
+
+void SAL_CALL OPoolCollection::notifyTermination( const EventObject& /*Event*/ ) throw (RuntimeException, std::exception)
 {
     clearDesktop();
 }
-// -----------------------------------------------------------------------------
-void SAL_CALL OPoolCollection::disposing( const EventObject& Source ) throw (RuntimeException)
+
+void SAL_CALL OPoolCollection::disposing( const EventObject& Source ) throw (RuntimeException, std::exception)
 {
     MutexGuard aGuard(m_aMutex);
     if ( m_xDesktop == Source.Source )
@@ -442,13 +440,13 @@ void SAL_CALL OPoolCollection::disposing( const EventObject& Source ) throw (Run
         }
     }
 }
-// -----------------------------------------------------------------------------
-void SAL_CALL OPoolCollection::propertyChange( const ::com::sun::star::beans::PropertyChangeEvent& evt ) throw (RuntimeException)
+
+void SAL_CALL OPoolCollection::propertyChange( const ::com::sun::star::beans::PropertyChangeEvent& evt ) throw (RuntimeException, std::exception)
 {
     MutexGuard aGuard(m_aMutex);
     if(evt.Source == m_xConfigNode)
     {
-        sal_Bool bEnabled = sal_True;
+        bool bEnabled = true;
         evt.NewValue >>= bEnabled;
         if(!bEnabled )
         {
@@ -457,7 +455,7 @@ void SAL_CALL OPoolCollection::propertyChange( const ::com::sun::star::beans::Pr
             OConnectionPools::iterator aIter = m_aPools.begin();
             for(;aIter != m_aPools.end();++aIter)
             {
-                aIter->second->clear(sal_False);
+                aIter->second->clear(false);
                 aIter->second->release();
             }
             m_aPools.clear();
@@ -466,7 +464,7 @@ void SAL_CALL OPoolCollection::propertyChange( const ::com::sun::star::beans::Pr
     }
     else if(evt.Source.is())
     {
-        sal_Bool bEnabled = sal_True;
+        bool bEnabled = true;
         evt.NewValue >>= bEnabled;
         if(!bEnabled)
         {
@@ -474,10 +472,10 @@ void SAL_CALL OPoolCollection::propertyChange( const ::com::sun::star::beans::Pr
             getNodeValue(getDriverNameNodeName(),evt.Source) >>= sThisDriverName;
             // 1nd relase the driver
             // look if we already have a proxy for this driver
-            MapDriver2DriverRefIterator aLookup = m_aDriverProxies.begin();
+            MapDriver2DriverRef::iterator aLookup = m_aDriverProxies.begin();
             while(  aLookup != m_aDriverProxies.end())
             {
-                MapDriver2DriverRefIterator aFind = aLookup;
+                MapDriver2DriverRef::iterator aFind = aLookup;
                 Reference<XServiceInfo> xInfo(aLookup->first,UNO_QUERY);
                 ++aLookup;
                 if(xInfo.is() && xInfo->getImplementationName() == sThisDriverName)
@@ -488,22 +486,22 @@ void SAL_CALL OPoolCollection::propertyChange( const ::com::sun::star::beans::Pr
             OConnectionPools::iterator aFind = m_aPools.find(sThisDriverName);
             if(aFind != m_aPools.end() && aFind->second)
             {
-                aFind->second->clear(sal_False);
+                aFind->second->clear(false);
                 aFind->second->release();
                 m_aPools.erase(aFind);
             }
         }
     }
 }
-// -----------------------------------------------------------------------------
+
 void OPoolCollection::clearDesktop()
 {
-    clearConnectionPools(sal_True);
+    clearConnectionPools(true);
     if ( m_xDesktop.is() )
         m_xDesktop->removeTerminateListener(this);
 m_xDesktop.clear();
 }
-// -----------------------------------------------------------------------------
+
 
 
 /* vim:set shiftwidth=4 softtabstop=4 expandtab: */
