@@ -26,7 +26,7 @@
 #include <comphelper/types.hxx>
 
 
-// -------------------------------------------------------------------------
+
 using namespace connectivity;
 using namespace connectivity::mysql;
 using namespace connectivity::sdbcx;
@@ -36,27 +36,27 @@ using namespace ::com::sun::star::sdbcx;
 using namespace ::com::sun::star::sdbc;
 using namespace ::com::sun::star::container;
 using namespace ::com::sun::star::lang;
-// -------------------------------------------------------------------------
+
 OMySQLCatalog::OMySQLCatalog(const Reference< XConnection >& _xConnection) : OCatalog(_xConnection)
                 ,m_xConnection(_xConnection)
 {
 }
-// -----------------------------------------------------------------------------
+
 void OMySQLCatalog::refreshObjects(const Sequence< OUString >& _sKindOfObject,TStringVector& _rNames)
 {
     Reference< XResultSet > xResult = m_xMetaData->getTables(Any(),
-                                                            OUString("%"),
-                                                            OUString("%"),
+                                                            "%",
+                                                            "%",
                                                             _sKindOfObject);
     fillNames(xResult,_rNames);
 }
-// -------------------------------------------------------------------------
+
 void OMySQLCatalog::refreshTables()
 {
     TStringVector aVector;
-    static const OUString s_sTableTypeView("VIEW");
-    static const OUString s_sTableTypeTable("TABLE");
-    static const OUString s_sAll("%");
+    static const char s_sTableTypeView[] = "VIEW";
+    static const char s_sTableTypeTable[] = "TABLE";
+    static const char s_sAll[] = "%";
 
     Sequence< OUString > sTableTypes(3);
     sTableTypes[0] = s_sTableTypeView;
@@ -70,17 +70,16 @@ void OMySQLCatalog::refreshTables()
     else
         m_pTables = new OTables(m_xMetaData,*this,m_aMutex,aVector);
 }
-// -------------------------------------------------------------------------
+
 void OMySQLCatalog::refreshViews()
 {
-    Sequence< OUString > aTypes(1);
-    aTypes[0] = "VIEW";
+    Sequence< OUString > aTypes { "VIEW" };
 
     // let's simply assume the server is new enough to support views. Current drivers
     // as of this writing might not return the proper information in getTableTypes, so
     // don't rely on it.
     // during #73245# / 2007-10-26 / frank.schoenheit@sun.com
-    bool bSupportsViews = sal_True;
+    bool bSupportsViews = true;
 
     TStringVector aVector;
     if ( bSupportsViews )
@@ -91,16 +90,16 @@ void OMySQLCatalog::refreshViews()
     else
         m_pViews = new OViews(m_xMetaData,*this,m_aMutex,aVector);
 }
-// -------------------------------------------------------------------------
+
 void OMySQLCatalog::refreshGroups()
 {
 }
-// -------------------------------------------------------------------------
+
 void OMySQLCatalog::refreshUsers()
 {
     TStringVector aVector;
     Reference< XStatement > xStmt = m_xConnection->createStatement(  );
-    Reference< XResultSet >  xResult = xStmt->executeQuery(OUString("select User from mysql.user group by User"));
+    Reference< XResultSet >  xResult = xStmt->executeQuery("SELECT grantee FROM information_schema.user_privileges GROUP BY grantee");
     if ( xResult.is() )
     {
         Reference< XRow > xRow(xResult,UNO_QUERY);
@@ -116,17 +115,17 @@ void OMySQLCatalog::refreshUsers()
     else
         m_pUsers = new OUsers(*this,m_aMutex,aVector,m_xConnection,this);
 }
-// -----------------------------------------------------------------------------
-Any SAL_CALL OMySQLCatalog::queryInterface( const Type & rType ) throw(RuntimeException)
+
+Any SAL_CALL OMySQLCatalog::queryInterface( const Type & rType ) throw(RuntimeException, std::exception)
 {
-    if ( rType == ::getCppuType((const Reference<XGroupsSupplier>*)0) )
+    if ( rType == cppu::UnoType<XGroupsSupplier>::get())
         return Any();
 
 
     return OCatalog::queryInterface(rType);
 }
-// -----------------------------------------------------------------------------
-Sequence< Type > SAL_CALL OMySQLCatalog::getTypes(  ) throw(RuntimeException)
+
+Sequence< Type > SAL_CALL OMySQLCatalog::getTypes(  ) throw(RuntimeException, std::exception)
 {
     Sequence< Type > aTypes = OCatalog::getTypes();
     ::std::vector<Type> aOwnTypes;
@@ -135,15 +134,14 @@ Sequence< Type > SAL_CALL OMySQLCatalog::getTypes(  ) throw(RuntimeException)
     const Type* pEnd = pBegin + aTypes.getLength();
     for(;pBegin != pEnd;++pBegin)
     {
-        if ( !(*pBegin == ::getCppuType((const Reference<XGroupsSupplier>*)0)))
+        if ( !(*pBegin == cppu::UnoType<XGroupsSupplier>::get()))
         {
             aOwnTypes.push_back(*pBegin);
         }
     }
-    const Type* pTypes = aOwnTypes.empty() ? 0 : &aOwnTypes[0];
-    return Sequence< Type >(pTypes, aOwnTypes.size());
+    return Sequence< Type >(aOwnTypes.data(), aOwnTypes.size());
 }
-// -----------------------------------------------------------------------------
+
 
 
 /* vim:set shiftwidth=4 softtabstop=4 expandtab: */
