@@ -42,18 +42,18 @@ extern "C" SAL_DLLPUBLIC_EXPORT void* SAL_CALL mysql_component_getFactory(
 {
     if (!pServiceManager)
     {
-        return 0;
+        return nullptr;
     }
 
     Reference< XSingleServiceFactory > xRet;
-    const Reference< XMultiServiceFactory > xServiceManager( reinterpret_cast<XMultiServiceFactory*>(pServiceManager) );
+    const Reference< XMultiServiceFactory > xServiceManager( static_cast<XMultiServiceFactory*>(pServiceManager) );
     const OUString sImplementationName( OUString::createFromAscii(pImplementationName) );
 
     if( ODriverDelegator::getImplementationName_Static() == sImplementationName )
         try
         {
             xRet = ::cppu::createSingleFactory( xServiceManager, sImplementationName, ODriverDelegator_CreateInstance,
-                       ODriverDelegator::getSupportedServiceNames_Static(), 0);
+                       ODriverDelegator::getSupportedServiceNames_Static());
         }
         catch(...)
         {
