@@ -92,12 +92,12 @@ OUString concatQualified( const OUString & a, const OUString &b)
     return buf.makeStringAndClear();
 }
 
-static inline OString iOUStringToOString( const OUString str, ConnectionSettings *settings) {
+static inline OString iOUStringToOString( const OUString& str, ConnectionSettings *settings) {
     OSL_ENSURE(settings, "pgsql-sdbc: OUStringToOString got NULL settings");
     return OUStringToOString( str, settings->encoding );
 }
 
-OString OUStringToOString( const OUString str, ConnectionSettings *settings) {
+OString OUStringToOString( const OUString& str, ConnectionSettings *settings) {
     return iOUStringToOString( str, settings );
 }
 
@@ -107,7 +107,7 @@ void bufferEscapeConstant( OUStringBuffer & buf, const OUString & value, Connect
     OString y = iOUStringToOString( value, settings );
     OStringBuffer strbuf( y.getLength() * 2 + 2 );
     int error;
-    int len = PQescapeStringConn(settings->pConnection, ((char*)strbuf.getStr()), y.getStr() , y.getLength(), &error );
+    int len = PQescapeStringConn(settings->pConnection, const_cast<char*>(strbuf.getStr()), y.getStr() , y.getLength(), &error );
     if ( error )
     {
         char *errstr = PQerrorMessage(settings->pConnection);
@@ -117,7 +117,7 @@ void bufferEscapeConstant( OUStringBuffer & buf, const OUString & value, Connect
         // 22018 is for "Invalid character value" and seems to be the best match.
         // We have no good XInterface Reference to pass here, so just give NULL
         throw SQLException(OUString(errstr, strlen(errstr), settings->encoding),
-                           NULL,
+                           nullptr,
                            OUString("22018"),
                            -1,
                            Any());
@@ -158,12 +158,12 @@ static inline void ibufferQuoteIdentifier( OUStringBuffer & buf, const OUString
 
     OString y = iOUStringToOString( toQuote, settings );
     char *cstr = PQescapeIdentifier(settings->pConnection, y.getStr(), y.getLength());
-    if ( cstr == NULL )
+    if ( cstr == nullptr )
     {
         char *errstr = PQerrorMessage(settings->pConnection);
         // Implementation-defined SQLACCESS error
         throw SQLException(OUString(errstr, strlen(errstr), settings->encoding),
-                           NULL,
+                           nullptr,
                            OUString("22018"),
                            -1,
                            Any());
@@ -209,10 +209,10 @@ OUString extractStringProperty(
     return value;
 }
 
-sal_Bool extractBoolProperty(
+bool extractBoolProperty(
     const Reference< XPropertySet > & descriptor, const OUString &name )
 {
-    sal_Bool value = sal_False;
+    bool value = false;
     descriptor->getPropertyValue( name ) >>= value;
     return value;
 }
@@ -278,7 +278,7 @@ DisposeGuard::~DisposeGuard()
 
 TransactionGuard::TransactionGuard( const Reference< XStatement > &stmt )
     : m_stmt( stmt ),
-      m_commited( sal_False )
+      m_commited( false )
 {
     m_stmt->executeUpdate( getStatics().BEGIN );
 }
@@ -286,7 +286,7 @@ TransactionGuard::TransactionGuard( const Reference< XStatement > &stmt )
 void TransactionGuard::commit()
 {
     m_stmt->executeUpdate( getStatics().COMMIT );
-    m_commited = sal_True;
+    m_commited = true;
 }
 
 void TransactionGuard::executeUpdate( const OUString & sql )
@@ -321,13 +321,11 @@ OUString extractTableFromInsert( const OUString & sql )
     int i = 0;
     while (i < sql.getLength() && isWhitespace(sql[i])) { i++; }
 
-    if( 0 == rtl_ustr_ascii_shortenedCompareIgnoreAsciiCase_WithLength(
-            &sql.getStr()[i], sql.getLength() - i, "insert" , 6 ) )
+    if( sql.matchIgnoreAsciiCase("insert", i) )
     {
         i += 6;
         while (i < sql.getLength() && isWhitespace(sql[i])) { i++; }
-        if( 0 == rtl_ustr_ascii_shortenedCompareIgnoreAsciiCase_WithLength(
-            &sql.getStr()[i], sql.getLength() - i, "into" , 4 ) )
+        if( sql.matchIgnoreAsciiCase("into", i) )
         {
             i +=4;
             while (i < sql.getLength() && isWhitespace(sql[i])) { i++; }
@@ -345,7 +343,7 @@ OUString extractTableFromInsert( const OUString & sql )
                         {
                             // the second part of the table name does not use quotes
                             // parse on
-                            quote = 0;
+                            quote = false;
                         }
                     }
                     else
@@ -425,7 +423,7 @@ void splitSQL( const OString & sql, OStringVector &vec )
         }
         else if( singleQuote )
         {
-            if( '\'' == c && '\'' == sql[i+1] )
+            if( '\'' == c && (i+1) < length && '\'' == sql[i+1] )
             {
                 // two subsequent single quotes within a quoted string
                 // mean a single quote within the string
@@ -554,7 +552,7 @@ void splitConcatenatedIdentifier( const OUString & source, OUString *first, OUSt
     switch (vec.size())
     {
     case 1:
-        *first  = OUString();
+        first->clear();
         *second = OStringToOUString( vec[0], RTL_TEXTENCODING_UTF8 );
         break;
     case 3:
@@ -568,7 +566,7 @@ void splitConcatenatedIdentifier( const OUString & source, OUString *first, OUSt
     }
 }
 
-typedef std::vector< sal_Int32 , Allocator< sal_Int32 > > IntVector;
+typedef std::vector< sal_Int32 > IntVector;
 
 
 OUString array2String( const com::sun::star::uno::Sequence< Any > &seq )
@@ -603,8 +601,7 @@ OUString array2String( const com::sun::star::uno::Sequence< Any > &seq )
 typedef
 std::vector
 <
-    com::sun::star::uno::Any,
-    Allocator< com::sun::star::uno::Any >
+    com::sun::star::uno::Any
 > AnyVector;
 
 com::sun::star::uno::Sequence< Any > parseArray( const OUString & str ) throw( SQLException )
@@ -649,11 +646,11 @@ com::sun::star::uno::Sequence< Any > parseArray( const OUString & str ) throw( S
             {
 
                 OUStringBuffer buf;
-                buf.appendAscii( "error during array parsing, didn't expect a } at position " );
+                buf.append( "error during array parsing, didn't expect a } at position " );
                 buf.append( (sal_Int32) i );
-                buf.appendAscii( " ('" );
+                buf.append( " ('" );
                 buf.append( str );
-                buf.appendAscii( "')" );
+                buf.append( "')" );
                 throw SQLException(
                     buf.makeStringAndClear(),
                     Reference< XInterface > (), OUString(), 1, Any() );
@@ -772,9 +769,7 @@ OString extractSingleTableFromSelect( const OStringVector &vec )
             token ++;
         }
 
-        if( token < vec.size() && rtl_str_compare_WithLength(
-                vec[token].getStr(), vec[token].getLength(),
-                RTL_CONSTASCII_STRINGPARAM("(") ) )
+        if( token < vec.size() && vec[token] != "(" )
         {
             // it is a table or a function name
             OStringBuffer buf(128);
@@ -786,9 +781,7 @@ OString extractSingleTableFromSelect( const OStringVector &vec )
 
             if( token < vec.size() )
             {
-                if( rtl_str_compare_WithLength(
-                        vec[token].getStr(), vec[token].getLength(),
-                        RTL_CONSTASCII_STRINGPARAM( "." ) ) == 0 )
+                if( vec[token] == "." )
                 {
                     buf.append( vec[token] );
                     token ++;
@@ -806,12 +799,10 @@ OString extractSingleTableFromSelect( const OStringVector &vec )
             ret = buf.makeStringAndClear();
             // now got my table candidate
 
-            if( token < vec.size() && rtl_str_compare_WithLength(
-                    vec[token].getStr(), vec[token].getLength(),
-                    RTL_CONSTASCII_STRINGPARAM( "(" ) ) == 0 )
+            if( token < vec.size() && vec[token] == "(" )
             {
                 // whoops, it is a function
-                ret = OString();
+                ret.clear();
             }
             else
             {
@@ -826,26 +817,25 @@ OString extractSingleTableFromSelect( const OStringVector &vec )
 
                 if( token < vec.size() )
                 {
-                    if( rtl_str_compare_WithLength(
-                            vec[token].getStr(), vec[token].getLength(),
-                            RTL_CONSTASCII_STRINGPARAM( "," ) ) == 0 )
+                    if( vec[token] == "," )
                     {
                         // whoops, multiple tables are used
-                        ret = OString();
+                        ret.clear();
                     }
                     else
                     {
                         static const char * forbiddenKeywords[] =
-                            { "join", "natural", "outer", "inner", "left", "right", "full" , 0 };
+                            { "join", "natural", "outer", "inner", "left", "right", "full" , nullptr };
                         for( int i = 0 ; forbiddenKeywords[i] ; i ++ )
                         {
+                            size_t nKeywordLen = strlen(forbiddenKeywords[i]);
                             if( 0 == rtl_str_shortenedCompareIgnoreAsciiCase_WithLength(
                                  vec[token].pData->buffer, vec[token].pData->length,
-                                 forbiddenKeywords[i], strlen(forbiddenKeywords[i]),
-                                 strlen(forbiddenKeywords[i]) ) )
+                                 forbiddenKeywords[i], nKeywordLen,
+                                 nKeywordLen ) )
                             {
                                 // whoops, it is a join
-                                ret = OString();
+                                ret.clear();
                             }
                         }
                     }
@@ -864,33 +854,46 @@ com::sun::star::uno::Sequence< sal_Int32 > string2intarray( const OUString & str
     if( str.getLength() > 1 )
     {
         sal_Int32 start = 0;
-        while ( iswspace( str.iterateCodePoints(&start) ) )
+        sal_uInt32 c;
+        while ( iswspace( (c=str.iterateCodePoints(&start)) ) )
             if ( start == strlen)
                 return ret;
-        if ( str.iterateCodePoints(&start) != L'{' )
+        if ( c != L'{' )
             return ret;
-        while ( iswspace( str.iterateCodePoints(&start) ) )
+        while ( iswspace( c=str.iterateCodePoints(&start) ) )
             if ( start == strlen)
                 return ret;
-        if ( str.iterateCodePoints(&start, 0) == L'}' )
+        if ( c == L'}' )
             return ret;
 
-        std::vector< sal_Int32, Allocator< sal_Int32 > > vec;
+        std::vector< sal_Int32 > vec;
         do
         {
             OUString digits;
-            sal_Int32 c;
-            while ( isdigit( c = str.iterateCodePoints(&start) ) )
+            do
             {
+                if(!iswspace(c))
+                    break;
                 if ( start == strlen)
                     return ret;
-                digits += OUString(c);
-            }
+            } while ( (c=str.iterateCodePoints(&start)) );
+            do
+            {
+                if (!iswdigit(c))
+                    break;
+                if ( start == strlen)
+                    return ret;
+                digits += OUString(&c, 1);
+            } while ( (c = str.iterateCodePoints(&start)) );
             vec.push_back( digits.toInt32() );
-            while ( iswspace( str.iterateCodePoints(&start) ) )
+            do
+            {
+                if(!iswspace(c))
+                    break;
                 if ( start == strlen)
                     return ret;
-            if ( str.iterateCodePoints(&start, 0) == L'}' )
+            } while ( (c=str.iterateCodePoints(&start)) );
+            if ( c == L'}' )
                 break;
             if ( str.iterateCodePoints(&start) != L',' )
                 return ret;
@@ -898,6 +901,7 @@ com::sun::star::uno::Sequence< sal_Int32 > string2intarray( const OUString & str
                 return ret;
         } while( true );
         // vec is guaranteed non-empty
+        assert(vec.size() > 0);
         ret = com::sun::star::uno::Sequence< sal_Int32 > ( &vec[0] , vec.size() );
     }
     return ret;
@@ -1070,12 +1074,6 @@ void bufferKey2TableConstraint(
 
 }
 
-static bool equalsIgnoreCase( const OString & str, const char *str2, int length2 )
-{
-    return 0 == rtl_str_compareIgnoreAsciiCase_WithLength(
-        str.pData->buffer, str.pData->length, str2, length2 );
-}
-
 void extractNameValuePairsFromInsert( String2StringMap & map, const OString & lastQuery )
 {
     OStringVector vec;
@@ -1084,15 +1082,15 @@ void extractNameValuePairsFromInsert( String2StringMap & map, const OString & la
     int nSize = vec.size();
 //     printf( "1 %d\n", nSize );
     if( nSize > 6  &&
-        equalsIgnoreCase( vec[0] , RTL_CONSTASCII_STRINGPARAM( "insert" ) ) &&
-        equalsIgnoreCase( vec[1] , RTL_CONSTASCII_STRINGPARAM( "into" ) ) )
+        vec[0].equalsIgnoreAsciiCase( "insert" ) &&
+        vec[1].equalsIgnoreAsciiCase( "into" ) )
     {
         int n = 2;
 
 //         printf( "1a\n" );
         // extract table name
         OString tableName;
-        if( equalsIgnoreCase( vec[n+1], RTL_CONSTASCII_STRINGPARAM( "." ) ) )
+        if( vec[n+1].equalsIgnoreAsciiCase( "." ) )
         {
             tableName = vec[n];
             tableName += vec[n+1];
@@ -1106,15 +1104,15 @@ void extractNameValuePairsFromInsert( String2StringMap & map, const OString & la
 
         OStringVector names;
         n ++;
-        if( equalsIgnoreCase( vec[n], RTL_CONSTASCII_STRINGPARAM( "(" ) ) )
+        if( vec[n].equalsIgnoreAsciiCase( "(" ) )
         {
 //             printf( "2\n" );
             // extract names
             n++;
-            while( nSize > n && ! equalsIgnoreCase(vec[n] , RTL_CONSTASCII_STRINGPARAM( ")" ) ) )
+            while( nSize > n && ! vec[n].equalsIgnoreAsciiCase( ")" ) )
             {
                 names.push_back( vec[n] );
-                if( nSize > n+1 && equalsIgnoreCase( vec[n+1] , RTL_CONSTASCII_STRINGPARAM( "," ) ) )
+                if( nSize > n+1 && vec[n+1].equalsIgnoreAsciiCase( "," ) )
                 {
                     n ++;
                 }
@@ -1123,15 +1121,15 @@ void extractNameValuePairsFromInsert( String2StringMap & map, const OString & la
             n++;
 
             // now read the values
-            if( nSize > n +1 && equalsIgnoreCase( vec[n], RTL_CONSTASCII_STRINGPARAM("VALUES") ) &&
-                equalsIgnoreCase(vec[n+1], RTL_CONSTASCII_STRINGPARAM( "(" ) ) )
+            if( nSize > n +1 && vec[n].equalsIgnoreAsciiCase("VALUES") &&
+                vec[n+1].equalsIgnoreAsciiCase( "(" ) )
             {
                 n +=2;
 //                 printf( "3\n" );
                 for ( OStringVector::size_type i = 0 ; i < names.size() && nSize > n ; i ++ )
                 {
                     map[names[i]] = vec[n];
-                    if( nSize > n+1 && equalsIgnoreCase( vec[n+1] , RTL_CONSTASCII_STRINGPARAM(",") ) )
+                    if( nSize > n+1 && vec[n+1].equalsIgnoreAsciiCase(",") )
                     {
                         n ++;
                     }
@@ -1161,7 +1159,7 @@ OUString querySingleValue(
 bool implSetObject(	const Reference< XParameters >& _rxParameters,
                         const sal_Int32 _nColumnIndex, const Any& _rValue)
 {
-    sal_Bool bSuccessfullyReRouted = sal_True;
+    bool bSuccessfullyReRouted = true;
     switch (_rValue.getValueTypeClass())
     {
         case typelib_TypeClass_HYPER:
@@ -1176,56 +1174,56 @@ bool implSetObject(	const Reference< XParameters >& _rxParameters,
             break;
 
         case typelib_TypeClass_STRING:
-            _rxParameters->setString(_nColumnIndex, *(OUString*)_rValue.getValue());
+            _rxParameters->setString(_nColumnIndex, *static_cast<OUString const *>(_rValue.getValue()));
             break;
 
         case typelib_TypeClass_BOOLEAN:
-            _rxParameters->setBoolean(_nColumnIndex, *(sal_Bool *)_rValue.getValue());
+            _rxParameters->setBoolean(_nColumnIndex, *static_cast<sal_Bool const *>(_rValue.getValue()));
             break;
 
         case typelib_TypeClass_BYTE:
-            _rxParameters->setByte(_nColumnIndex, *(sal_Int8 *)_rValue.getValue());
+            _rxParameters->setByte(_nColumnIndex, *static_cast<sal_Int8 const *>(_rValue.getValue()));
             break;
 
         case typelib_TypeClass_UNSIGNED_SHORT:
         case typelib_TypeClass_SHORT:
-            _rxParameters->setShort(_nColumnIndex, *(sal_Int16*)_rValue.getValue());
+            _rxParameters->setShort(_nColumnIndex, *static_cast<sal_Int16 const *>(_rValue.getValue()));
             break;
 
         case typelib_TypeClass_CHAR:
-            _rxParameters->setString(_nColumnIndex, OUString((sal_Unicode *)_rValue.getValue(),1));
+            _rxParameters->setString(_nColumnIndex, OUString(static_cast<sal_Unicode const *>(_rValue.getValue()),1));
             break;
 
         case typelib_TypeClass_UNSIGNED_LONG:
         case typelib_TypeClass_LONG:
-            _rxParameters->setInt(_nColumnIndex, *(sal_Int32*)_rValue.getValue());
+            _rxParameters->setInt(_nColumnIndex, *static_cast<sal_Int32 const *>(_rValue.getValue()));
             break;
 
         case typelib_TypeClass_FLOAT:
-            _rxParameters->setFloat(_nColumnIndex, *(float*)_rValue.getValue());
+            _rxParameters->setFloat(_nColumnIndex, *static_cast<float const *>(_rValue.getValue()));
             break;
 
         case typelib_TypeClass_DOUBLE:
-            _rxParameters->setDouble(_nColumnIndex, *(double*)_rValue.getValue());
+            _rxParameters->setDouble(_nColumnIndex, *static_cast<double const *>(_rValue.getValue()));
             break;
 
         case typelib_TypeClass_SEQUENCE:
-            if (_rValue.getValueType() == ::getCppuType((const Sequence< sal_Int8 > *)0))
+            if (_rValue.getValueType() == cppu::UnoType<Sequence< sal_Int8 >>::get())
             {
-                _rxParameters->setBytes(_nColumnIndex, *(Sequence<sal_Int8>*)_rValue.getValue());
+                _rxParameters->setBytes(_nColumnIndex, *static_cast<Sequence<sal_Int8> const *>(_rValue.getValue()));
             }
             else
-                bSuccessfullyReRouted = sal_False;
+                bSuccessfullyReRouted = false;
             break;
         case typelib_TypeClass_STRUCT:
-            if (_rValue.getValueType() == ::getCppuType((const com::sun::star::util::DateTime*)0))
-                _rxParameters->setTimestamp(_nColumnIndex, *(com::sun::star::util::DateTime*)_rValue.getValue());
-            else if (_rValue.getValueType() == ::getCppuType((const com::sun::star::util::Date*)0))
-                _rxParameters->setDate(_nColumnIndex, *(com::sun::star::util::Date*)_rValue.getValue());
-            else if (_rValue.getValueType() == ::getCppuType((const com::sun::star::util::Time*)0))
-                _rxParameters->setTime(_nColumnIndex, *(com::sun::star::util::Time*)_rValue.getValue());
+            if (_rValue.getValueType() == cppu::UnoType<com::sun::star::util::DateTime>::get())
+                _rxParameters->setTimestamp(_nColumnIndex, *static_cast<com::sun::star::util::DateTime const *>(_rValue.getValue()));
+            else if (_rValue.getValueType() == cppu::UnoType<com::sun::star::util::Date>::get())
+                _rxParameters->setDate(_nColumnIndex, *static_cast<com::sun::star::util::Date const *>(_rValue.getValue()));
+            else if (_rValue.getValueType() == cppu::UnoType<com::sun::star::util::Time>::get())
+                _rxParameters->setTime(_nColumnIndex, *static_cast<com::sun::star::util::Time const *>(_rValue.getValue()));
             else
-                bSuccessfullyReRouted = sal_False;
+                bSuccessfullyReRouted = false;
             break;
 
         case typelib_TypeClass_INTERFACE:
@@ -1240,7 +1238,7 @@ bool implSetObject(	const Reference< XParameters >& _rxParameters,
         }
             // run through
         default:
-            bSuccessfullyReRouted = sal_False;
+            bSuccessfullyReRouted = false;
 
     }
 
@@ -1248,3 +1246,5 @@ bool implSetObject(	const Reference< XParameters >& _rxParameters,
 }
 
 }
+
+/* vim:set shiftwidth=4 softtabstop=4 expandtab: */
