@@ -18,19 +18,20 @@
  */
 
 
-#include "sal/main.h"
-#include "osl/file.hxx"
+#include <sal/main.h>
+#include <osl/file.hxx>
 
-#include "typelib/typedescription.hxx"
+#include <typelib/typedescription.hxx>
 
-#include "cppuhelper/bootstrap.hxx"
-#include "cppuhelper/shlib.hxx"
+#include <cppuhelper/bootstrap.hxx>
+#include <cppuhelper/shlib.hxx>
 
 #include <com/sun/star/lang/XComponent.hpp>
 
-#include "uno/environment.hxx"
-#include "cppu/EnvDcp.hxx"
-#include "cppu/EnvGuards.hxx"
+#include <uno/environment.hxx>
+#include <uno/lbnames.h>
+#include <cppu/EnvDcp.hxx>
+#include <cppu/EnvGuards.hxx>
 
 #include <iostream>
 
@@ -143,7 +144,7 @@ static void s_test__loadSharedLibComponentFactory__purpose_purpose()
     s_test__loadSharedLibComponentFactory(":testenv", ":testenv");
 }
 
-static rtl::OUString s_getSDrive(void)
+static rtl::OUString s_getSDrive()
 {
     rtl::OUString path;//("file://");
 
@@ -179,14 +180,14 @@ static void s_test__createSimpleRegistry(rtl::OUString const & clientPurpose)
     }
 }
 
-static void s_test__createSimpleRegistry__free(void)
+static void s_test__createSimpleRegistry__free()
 {
     s_comment += "\ts_test__createSimpleRegistry__free\n";
 
     s_test__createSimpleRegistry(rtl::OUString());
 }
 
-static void s_test__createSimpleRegistry__purpose(void)
+static void s_test__createSimpleRegistry__purpose()
 {
     s_comment += "\ts_test__createSimpleRegistry__purpose\n";
 
@@ -225,14 +226,14 @@ static void s_test__bootstrap_InitialComponentContext(rtl::OUString const & clie
     xComponent->dispose();
 }
 
-static void s_test__bootstrap_InitialComponentContext__free(void)
+static void s_test__bootstrap_InitialComponentContext__free()
 {
     s_comment += "\ts_test__bootstrap_InitialComponentContext__free\n";
 
     s_test__bootstrap_InitialComponentContext(rtl::OUString());
 }
 
-static void s_test__bootstrap_InitialComponentContext__purpose(void)
+static void s_test__bootstrap_InitialComponentContext__purpose()
 {
     s_comment += "\ts_test__bootstrap_InitialComponentContext__purpose\n";
 
