@@ -17,7 +17,7 @@
  *   the License at http://www.apache.org/licenses/LICENSE-2.0 .
  */
 
-#include <vcl/builder.hxx>
+#include <vcl/builderfactory.hxx>
 #include <vcl/msgbox.hxx>
 #include <sfx2/viewfrm.hxx>
 #include <sfx2/viewsh.hxx>
@@ -31,13 +31,13 @@
 GraphicPreviewWindow::GraphicPreviewWindow(vcl::Window* pParent,
     const WinBits nStyle)
     : Control(pParent, nStyle)
-    , mpOrigGraphic(NULL)
+    , mpOrigGraphic(nullptr)
     , mfScaleX(0.0)
     , mfScaleY(0.0)
 {
 }
 
-extern "C" SAL_DLLPUBLIC_EXPORT vcl::Window* SAL_CALL makeGraphicPreviewWindow(vcl::Window *pParent, VclBuilder::stringmap &rMap)
+VCL_BUILDER_DECL_FACTORY(GraphicPreviewWindow)
 {
     WinBits nWinBits = WB_TABSTOP;
 
@@ -45,7 +45,7 @@ extern "C" SAL_DLLPUBLIC_EXPORT vcl::Window* SAL_CALL makeGraphicPreviewWindow(v
     if (!sBorder.isEmpty())
        nWinBits |= WB_BORDER;
 
-    return new GraphicPreviewWindow(pParent, nWinBits);
+    rRet = VclPtr<GraphicPreviewWindow>::Create(pParent, nWinBits);
 }
 
 Size GraphicPreviewWindow::GetOptimalSize() const
@@ -53,33 +53,29 @@ Size GraphicPreviewWindow::GetOptimalSize() const
     return LogicToPixel(Size(81, 73), MAP_APPFONT);
 }
 
-
-
-void GraphicPreviewWindow::Paint( const Rectangle& rRect )
+void GraphicPreviewWindow::Paint(vcl::RenderContext& rRenderContext, const Rectangle& rRect)
 {
-    Control::Paint( rRect );
+    Control::Paint(rRenderContext, rRect);
 
-    const Size  aOutputSize( GetOutputSizePixel() );
+    const Size aOutputSize(GetOutputSizePixel());
 
-    if( maPreview.IsAnimated() )
+    if (maPreview.IsAnimated())
     {
-        const Size  aGraphicSize( LogicToPixel( maPreview.GetPrefSize(), maPreview.GetPrefMapMode() ) );
-        const Point aGraphicPosition( ( aOutputSize.Width()  - aGraphicSize.Width()  ) >> 1,
-                                      ( aOutputSize.Height() - aGraphicSize.Height() ) >> 1 );
-        maPreview.StartAnimation( this, aGraphicPosition, aGraphicSize );
+        const Size aGraphicSize(rRenderContext.LogicToPixel(maPreview.GetPrefSize(), maPreview.GetPrefMapMode()));
+        const Point aGraphicPosition((aOutputSize.Width()  - aGraphicSize.Width()  ) >> 1,
+                                     (aOutputSize.Height() - aGraphicSize.Height() ) >> 1);
+        maPreview.StartAnimation(&rRenderContext, aGraphicPosition, aGraphicSize);
     }
     else
     {
-        const Size  aGraphicSize( maPreview.GetSizePixel() );
-        const Point aGraphicPosition( ( aOutputSize.Width()  - aGraphicSize.Width()  ) >> 1,
-                                      ( aOutputSize.Height() - aGraphicSize.Height() ) >> 1 );
-        maPreview.Draw( this, aGraphicPosition, aGraphicSize );
+        const Size  aGraphicSize(maPreview.GetSizePixel());
+        const Point aGraphicPosition((aOutputSize.Width()  - aGraphicSize.Width())  >> 1,
+                                     (aOutputSize.Height() - aGraphicSize.Height()) >> 1);
+        maPreview.Draw(&rRenderContext, aGraphicPosition, aGraphicSize);
     }
 }
 
-
-
-void GraphicPreviewWindow::SetPreview( const Graphic& rGraphic )
+void GraphicPreviewWindow::SetPreview(const Graphic& rGraphic)
 {
     maPreview = rGraphic;
     Invalidate();
@@ -122,12 +118,12 @@ void GraphicPreviewWindow::ScaleImageToFit()
         {
             BitmapEx aBmpEx( mpOrigGraphic->GetBitmapEx() );
 
-            if( aBmpEx.Scale( aGrfSize, BMP_SCALE_DEFAULT ) )
+            if( aBmpEx.Scale( aGrfSize ) )
                 maScaledOrig = aBmpEx;
         }
     }
 
-    maModifyHdl.Call(this);
+    maModifyHdl.Call(nullptr);
 }
 
 void GraphicPreviewWindow::Resize()
@@ -153,28 +149,34 @@ GraphicFilterDialog::GraphicFilterDialog(vcl::Window* pParent,
     mpPreview->init(&rGraphic, maModifyHdl);
 }
 
+GraphicFilterDialog::~GraphicFilterDialog()
+{
+    disposeOnce();
+}
+
+void GraphicFilterDialog::dispose()
+{
+    mpPreview.clear();
+    ModalDialog::dispose();
+}
 
 
-IMPL_LINK_NOARG(GraphicFilterDialog, ImplPreviewTimeoutHdl)
+IMPL_LINK_NOARG_TYPED(GraphicFilterDialog, ImplPreviewTimeoutHdl, Timer *, void)
 {
     maTimer.Stop();
     mpPreview->SetPreview(GetFilteredGraphic(mpPreview->GetScaledOriginal(),
         mpPreview->GetScaleX(), mpPreview->GetScaleY()));
-
-    return 0;
 }
 
 
 
-IMPL_LINK_NOARG(GraphicFilterDialog, ImplModifyHdl)
+IMPL_LINK_NOARG_TYPED(GraphicFilterDialog, ImplModifyHdl, LinkParamNone*, void)
 {
     if (bIsBitmap)
     {
         maTimer.Stop();
         maTimer.Start();
     }
-
-    return 0;
 }
 
 
@@ -192,19 +194,40 @@ GraphicFilterMosaic::GraphicFilterMosaic( vcl::Window* pParent, const Graphic& r
 
     mpMtrWidth->SetValue( nTileWidth );
     mpMtrWidth->SetLast( GetGraphicSizePixel().Width() );
-    mpMtrWidth->SetModifyHdl( GetModifyHdl() );
+    mpMtrWidth->SetModifyHdl( LINK(this, GraphicFilterMosaic, EditModifyHdl) );
 
     mpMtrHeight->SetValue( nTileHeight );
     mpMtrHeight->SetLast( GetGraphicSizePixel().Height() );
-    mpMtrHeight->SetModifyHdl( GetModifyHdl() );
+    mpMtrHeight->SetModifyHdl( LINK(this, GraphicFilterMosaic, EditModifyHdl) );
 
     mpCbxEdges->Check( bEnhanceEdges );
-    mpCbxEdges->SetToggleHdl( GetModifyHdl() );
+    mpCbxEdges->SetToggleHdl( LINK(this, GraphicFilterMosaic, CheckBoxModifyHdl) );
 
     mpMtrWidth->GrabFocus();
 }
 
+IMPL_LINK_NOARG_TYPED(GraphicFilterMosaic, CheckBoxModifyHdl, CheckBox&, void)
+{
+    GetModifyHdl().Call(nullptr);
+}
 
+IMPL_LINK_NOARG_TYPED(GraphicFilterMosaic, EditModifyHdl, Edit&, void)
+{
+    GetModifyHdl().Call(nullptr);
+}
+
+GraphicFilterMosaic::~GraphicFilterMosaic()
+{
+    disposeOnce();
+}
+
+void GraphicFilterMosaic::dispose()
+{
+    mpMtrWidth.clear();
+    mpMtrHeight.clear();
+    mpCbxEdges.clear();
+    GraphicFilterDialog::dispose();
+}
 
 Graphic GraphicFilterMosaic::GetFilteredGraphic( const Graphic& rGraphic,
                                                  double fScaleX, double fScaleY )
@@ -253,10 +276,25 @@ GraphicFilterSmooth::GraphicFilterSmooth( vcl::Window* pParent, const Graphic& r
     get(mpMtrRadius, "radius");
 
     mpMtrRadius->SetValue( nRadius* 10  );
-    mpMtrRadius->SetModifyHdl( GetModifyHdl() );
+    mpMtrRadius->SetModifyHdl( LINK(this, GraphicFilterSmooth, EditModifyHdl) );
     mpMtrRadius->GrabFocus();
 }
 
+IMPL_LINK_NOARG_TYPED(GraphicFilterSmooth, EditModifyHdl, Edit&, void)
+{
+    GetModifyHdl().Call(nullptr);
+}
+
+GraphicFilterSmooth::~GraphicFilterSmooth()
+{
+    disposeOnce();
+}
+
+void GraphicFilterSmooth::dispose()
+{
+    mpMtrRadius.clear();
+    GraphicFilterDialog::dispose();
+}
 
 
 Graphic GraphicFilterSmooth::GetFilteredGraphic( const Graphic& rGraphic, double /*fScaleX*/, double /*fScaleY*/ )
@@ -299,12 +337,32 @@ GraphicFilterSolarize::GraphicFilterSolarize( vcl::Window* pParent, const Graphi
     get(mpCbxInvert, "invert");
 
     mpMtrThreshold->SetValue( FRound( cGreyThreshold / 2.55 ) );
-    mpMtrThreshold->SetModifyHdl( GetModifyHdl() );
+    mpMtrThreshold->SetModifyHdl( LINK(this, GraphicFilterSolarize, EditModifyHdl) );
 
     mpCbxInvert->Check( bInvert );
-    mpCbxInvert->SetToggleHdl( GetModifyHdl() );
+    mpCbxInvert->SetToggleHdl( LINK(this, GraphicFilterSolarize, CheckBoxModifyHdl) );
 }
 
+IMPL_LINK_NOARG_TYPED(GraphicFilterSolarize, CheckBoxModifyHdl, CheckBox&, void)
+{
+    GetModifyHdl().Call(nullptr);
+}
+IMPL_LINK_NOARG_TYPED(GraphicFilterSolarize, EditModifyHdl, Edit&, void)
+{
+    GetModifyHdl().Call(nullptr);
+}
+
+GraphicFilterSolarize::~GraphicFilterSolarize()
+{
+    disposeOnce();
+}
+
+void GraphicFilterSolarize::dispose()
+{
+    mpMtrThreshold.clear();
+    mpCbxInvert.clear();
+    GraphicFilterDialog::dispose();
+}
 
 
 Graphic GraphicFilterSolarize::GetFilteredGraphic( const Graphic& rGraphic,
@@ -353,9 +411,24 @@ GraphicFilterSepia::GraphicFilterSepia( vcl::Window* pParent, const Graphic& rGr
     get(mpMtrSepia, "value");
 
     mpMtrSepia->SetValue( nSepiaPercent );
-    mpMtrSepia->SetModifyHdl( GetModifyHdl() );
+    mpMtrSepia->SetModifyHdl( LINK(this, GraphicFilterSepia, EditModifyHdl) );
 }
 
+IMPL_LINK_NOARG_TYPED(GraphicFilterSepia, EditModifyHdl, Edit&, void)
+{
+    GetModifyHdl().Call(nullptr);
+}
+
+GraphicFilterSepia::~GraphicFilterSepia()
+{
+    disposeOnce();
+}
+
+void GraphicFilterSepia::dispose()
+{
+    mpMtrSepia.clear();
+    GraphicFilterDialog::dispose();
+}
 
 
 Graphic GraphicFilterSepia::GetFilteredGraphic( const Graphic& rGraphic,
@@ -396,9 +469,24 @@ GraphicFilterPoster::GraphicFilterPoster(vcl::Window* pParent, const Graphic& rG
     mpNumPoster->SetFirst( 2 );
     mpNumPoster->SetLast( rGraphic.GetBitmapEx().GetBitCount() );
     mpNumPoster->SetValue( nPosterCount );
-    mpNumPoster->SetModifyHdl( GetModifyHdl() );
+    mpNumPoster->SetModifyHdl( LINK(this, GraphicFilterPoster, EditModifyHdl) );
 }
 
+IMPL_LINK_NOARG_TYPED(GraphicFilterPoster, EditModifyHdl, Edit&, void)
+{
+    GetModifyHdl().Call(nullptr);
+}
+
+GraphicFilterPoster::~GraphicFilterPoster()
+{
+    disposeOnce();
+}
+
+void GraphicFilterPoster::dispose()
+{
+    mpNumPoster.clear();
+    GraphicFilterDialog::dispose();
+}
 
 
 Graphic GraphicFilterPoster::GetFilteredGraphic( const Graphic& rGraphic,
@@ -436,7 +524,7 @@ void EmbossControl::MouseButtonDown( const MouseEvent& rEvt )
     SvxRectCtl::MouseButtonDown( rEvt );
 
     if( GetActualRP() != eOldRP )
-        maModifyHdl.Call( this );
+        maModifyHdl.Call( nullptr );
 }
 
 Size EmbossControl::GetOptimalSize() const
@@ -444,12 +532,7 @@ Size EmbossControl::GetOptimalSize() const
     return LogicToPixel(Size(77, 60), MAP_APPFONT);
 }
 
-extern "C" SAL_DLLPUBLIC_EXPORT vcl::Window* SAL_CALL makeEmbossControl(vcl::Window *pParent, VclBuilder::stringmap &)
-{
-    return new EmbossControl(pParent);
-}
-
-
+VCL_BUILDER_FACTORY(EmbossControl)
 
 GraphicFilterEmboss::GraphicFilterEmboss(vcl::Window* pParent,
     const Graphic& rGraphic, RECT_POINT eLightSource)
@@ -462,6 +545,16 @@ GraphicFilterEmboss::GraphicFilterEmboss(vcl::Window* pParent,
     mpCtlLight->GrabFocus();
 }
 
+GraphicFilterEmboss::~GraphicFilterEmboss()
+{
+    disposeOnce();
+}
+
+void GraphicFilterEmboss::dispose()
+{
+    mpCtlLight.clear();
+    GraphicFilterDialog::dispose();
+}
 
 
 Graphic GraphicFilterEmboss::GetFilteredGraphic( const Graphic& rGraphic,
