@@ -42,7 +42,7 @@ SvxPostItDialog::SvxPostItDialog(vcl::Window* pParent, const SfxItemSet& rCoreSe
     bool bPrevNext)
     : SfxModalDialog(pParent, "CommentDialog", "cui/ui/comment.ui")
     , rSet(rCoreSet)
-    , pOutSet(0)
+    , pOutSet(nullptr)
 {
     get(m_pLastEditFT, "lastedit");
     get(m_pInsertAuthor, "insertauthor");
@@ -73,7 +73,7 @@ SvxPostItDialog::SvxPostItDialog(vcl::Window* pParent, const SfxItemSet& rCoreSe
     nWhich = rSet.GetPool()->GetWhich( SID_ATTR_POSTIT_AUTHOR );
     OUString aAuthorStr, aDateStr;
 
-    if ( rSet.GetItemState( nWhich, true ) >= SfxItemState::DEFAULT )
+    if ( rSet.GetItemState( nWhich ) >= SfxItemState::DEFAULT )
     {
         bNew = false;
         const SvxPostItAuthorItem& rAuthor =
@@ -85,7 +85,7 @@ SvxPostItDialog::SvxPostItDialog(vcl::Window* pParent, const SfxItemSet& rCoreSe
 
     nWhich = rSet.GetPool()->GetWhich( SID_ATTR_POSTIT_DATE );
 
-    if ( rSet.GetItemState( nWhich, true ) >= SfxItemState::DEFAULT )
+    if ( rSet.GetItemState( nWhich ) >= SfxItemState::DEFAULT )
     {
         const SvxPostItDateItem& rDate =
             static_cast<const SvxPostItDateItem&>(rSet.Get( nWhich ));
@@ -100,7 +100,7 @@ SvxPostItDialog::SvxPostItDialog(vcl::Window* pParent, const SfxItemSet& rCoreSe
     nWhich = rSet.GetPool()->GetWhich( SID_ATTR_POSTIT_TEXT );
 
     OUString aTextStr;
-    if ( rSet.GetItemState( nWhich, true ) >= SfxItemState::DEFAULT )
+    if ( rSet.GetItemState( nWhich ) >= SfxItemState::DEFAULT )
     {
         const SvxPostItTextItem& rText =
             static_cast<const SvxPostItTextItem&>(rSet.Get( nWhich ));
@@ -109,10 +109,9 @@ SvxPostItDialog::SvxPostItDialog(vcl::Window* pParent, const SfxItemSet& rCoreSe
 
     ShowLastAuthor(aAuthorStr, aDateStr);
 
-    //lock to initial .ui placeholder size before replacing contents
-    Size aSize(m_pEditED->get_preferred_size());
-    m_pEditED->set_width_request(aSize.Width());
-    m_pEditED->set_height_request(aSize.Height());
+    //lock to an initial size before replacing contents
+    m_pEditED->set_width_request(m_pEditED->approximate_char_width() * 40);
+    m_pEditED->set_height_request(m_pEditED->GetTextHeight() * 10);
 
     m_pEditED->SetText(convertLineEnd(aTextStr, GetSystemLineEnd()));
 
@@ -130,7 +129,7 @@ SvxPostItDialog::~SvxPostItDialog()
 void SvxPostItDialog::dispose()
 {
     delete pOutSet;
-    pOutSet = 0;
+    pOutSet = nullptr;
     m_pLastEditFT.clear();
     m_pEditED.clear();
     m_pInsertAuthor.clear();
@@ -174,19 +173,17 @@ void SvxPostItDialog::EnableTravel(bool bNext, bool bPrev)
 
 
 
-IMPL_LINK_NOARG(SvxPostItDialog, PrevHdl)
+IMPL_LINK_NOARG_TYPED(SvxPostItDialog, PrevHdl, Button*, void)
 {
-    aPrevHdlLink.Call( this );
-    return 0;
+    aPrevHdlLink.Call( *this );
 }
 
-IMPL_LINK_NOARG(SvxPostItDialog, NextHdl)
+IMPL_LINK_NOARG_TYPED(SvxPostItDialog, NextHdl, Button*, void)
 {
-    aNextHdlLink.Call( this );
-    return 0;
+    aNextHdlLink.Call( *this );
 }
 
-IMPL_LINK_NOARG(SvxPostItDialog, Stamp)
+IMPL_LINK_NOARG_TYPED(SvxPostItDialog, Stamp, Button*, void)
 {
     Date aDate( Date::SYSTEM );
     tools::Time aTime( tools::Time::SYSTEM );
@@ -202,7 +199,7 @@ IMPL_LINK_NOARG(SvxPostItDialog, Stamp)
     }
     aStr += rLocaleWrapper.getDate(aDate);
     aStr += ", ";
-    aStr += rLocaleWrapper.getTime(aTime, false, false);
+    aStr += rLocaleWrapper.getTime(aTime, false);
     aStr += " ----\n";
 
     aStr = convertLineEnd(aStr, GetSystemLineEnd());
@@ -211,12 +208,11 @@ IMPL_LINK_NOARG(SvxPostItDialog, Stamp)
     sal_Int32 nLen = aStr.getLength();
     m_pEditED->GrabFocus();
     m_pEditED->SetSelection( Selection( nLen, nLen ) );
-    return 0;
 }
 
 
 
-IMPL_LINK_NOARG(SvxPostItDialog, OKHdl)
+IMPL_LINK_NOARG_TYPED(SvxPostItDialog, OKHdl, Button*, void)
 {
     const LocaleDataWrapper& rLocaleWrapper( Application::GetSettings().GetLocaleDataWrapper() );
     pOutSet = new SfxItemSet( rSet );
@@ -227,7 +223,6 @@ IMPL_LINK_NOARG(SvxPostItDialog, OKHdl)
     pOutSet->Put( SvxPostItTextItem( m_pEditED->GetText(),
                                      rSet.GetPool()->GetWhich( SID_ATTR_POSTIT_TEXT ) ) );
     EndDialog( RET_OK );
-    return 0;
 }
 
 /* vim:set shiftwidth=4 softtabstop=4 expandtab: */
