@@ -407,7 +407,7 @@ static std::size_t lcl_GetFrmMapCount(const FrmMap* pMap)
 }
 
 static SvxSwFramePosString::StringId lcl_ChangeResIdToVerticalOrRTL(
-            SvxSwFramePosString::StringId eStringId, sal_Bool bVertical, sal_Bool bRTL)
+            SvxSwFramePosString::StringId eStringId, bool bVertical, bool bRTL)
 {
     //special handling of STR_FROMLEFT
     if(SwFPos::FROMLEFT == eStringId)
@@ -501,17 +501,16 @@ static sal_uLong lcl_GetLBRelationsForStrID( const FrmMap* _pMap,
     return nLBRelations;
 }
 
-SvxSwPosSizeTabPage::SvxSwPosSizeTabPage(Window* pParent, const SfxItemSet& rInAttrs)
-    : SfxTabPage(pParent, "SwPosSizePage", "cui/ui/swpossizepage.ui", rInAttrs)
-    , m_pVMap(0)
-    , m_pHMap(0)
-    , m_pSdrView(0)
+SvxSwPosSizeTabPage::SvxSwPosSizeTabPage(vcl::Window* pParent, const SfxItemSet& rInAttrs)
+    : SfxTabPage(pParent, "SwPosSizePage", "cui/ui/swpossizepage.ui", &rInAttrs)
+    , m_pVMap(nullptr)
+    , m_pHMap(nullptr)
+    , m_pSdrView(nullptr)
     , m_nOldH(HoriOrientation::CENTER)
     , m_nOldHRel(RelOrientation::FRAME)
     , m_nOldV(VertOrientation::TOP)
     , m_nOldVRel(RelOrientation::PRINT_AREA)
     , m_fWidthHeightRatio(1.0)
-    , m_nHtmlMode(0)
     , m_bHtmlMode(false)
     , m_bAtHoriPosModified(false)
     , m_bAtVertPosModified(false)
@@ -551,32 +550,32 @@ SvxSwPosSizeTabPage::SvxSwPosSizeTabPage(Window* pParent, const SfxItemSet& rInA
     setOptimalRelWidth();
 
     FieldUnit eDlgUnit = GetModuleFieldUnit( rInAttrs );
-    SetFieldUnit( *m_pHoriByMF, eDlgUnit, sal_True );
-    SetFieldUnit( *m_pVertByMF, eDlgUnit, sal_True );
-    SetFieldUnit( *m_pWidthMF , eDlgUnit, sal_True );
-    SetFieldUnit( *m_pHeightMF, eDlgUnit, sal_True );
+    SetFieldUnit( *m_pHoriByMF, eDlgUnit, true );
+    SetFieldUnit( *m_pVertByMF, eDlgUnit, true );
+    SetFieldUnit( *m_pWidthMF , eDlgUnit, true );
+    SetFieldUnit( *m_pHeightMF, eDlgUnit, true );
 
     SetExchangeSupport();
 
-    Link aLk = LINK(this, SvxSwPosSizeTabPage, RangeModifyHdl);
-    m_pWidthMF->SetLoseFocusHdl( aLk );
-    m_pHeightMF->SetLoseFocusHdl( aLk );
-    m_pHoriByMF->SetLoseFocusHdl( aLk );
-    m_pVertByMF->SetLoseFocusHdl( aLk );
-    m_pFollowCB->SetClickHdl( aLk );
+    Link<Control&,void> aLk3 = LINK(this, SvxSwPosSizeTabPage, RangeModifyHdl);
+    m_pWidthMF->SetLoseFocusHdl( aLk3 );
+    m_pHeightMF->SetLoseFocusHdl( aLk3 );
+    m_pHoriByMF->SetLoseFocusHdl( aLk3 );
+    m_pVertByMF->SetLoseFocusHdl( aLk3 );
+    m_pFollowCB->SetClickHdl( LINK(this, SvxSwPosSizeTabPage, RangeModifyClickHdl) );
 
-    aLk = LINK(this, SvxSwPosSizeTabPage, ModifyHdl);
+    Link<Edit&,void> aLk = LINK(this, SvxSwPosSizeTabPage, ModifyHdl);
     m_pWidthMF->SetModifyHdl( aLk );
     m_pHeightMF->SetModifyHdl( aLk );
     m_pHoriByMF->SetModifyHdl( aLk );
     m_pVertByMF->SetModifyHdl( aLk );
 
-    aLk = LINK(this, SvxSwPosSizeTabPage, AnchorTypeHdl);
-    m_pToPageRB->SetClickHdl( aLk );
-    m_pToParaRB->SetClickHdl( aLk );
-    m_pToCharRB->SetClickHdl( aLk );
-    m_pAsCharRB->SetClickHdl( aLk );
-    m_pToFrameRB->SetClickHdl( aLk );
+    Link<Button*,void> aLk2 = LINK(this, SvxSwPosSizeTabPage, AnchorTypeHdl);
+    m_pToPageRB->SetClickHdl( aLk2 );
+    m_pToParaRB->SetClickHdl( aLk2 );
+    m_pToCharRB->SetClickHdl( aLk2 );
+    m_pAsCharRB->SetClickHdl( aLk2 );
+    m_pToFrameRB->SetClickHdl( aLk2 );
 
     m_pHoriLB->SetSelectHdl(LINK(this, SvxSwPosSizeTabPage, PosHdl));
     m_pVertLB->SetSelectHdl(LINK(this, SvxSwPosSizeTabPage, PosHdl));
@@ -588,6 +587,43 @@ SvxSwPosSizeTabPage::SvxSwPosSizeTabPage(Window* pParent, const SfxItemSet& rInA
     m_pPositionCB->SetClickHdl(LINK(this, SvxSwPosSizeTabPage, ProtectHdl));
 }
 
+SvxSwPosSizeTabPage::~SvxSwPosSizeTabPage()
+{
+    disposeOnce();
+}
+
+void SvxSwPosSizeTabPage::dispose()
+{
+    m_pWidthMF.clear();
+    m_pHeightMF.clear();
+    m_pKeepRatioCB.clear();
+    m_pToPageRB.clear();
+    m_pToParaRB.clear();
+    m_pToCharRB.clear();
+    m_pAsCharRB.clear();
+    m_pToFrameRB.clear();
+    m_pPositionCB.clear();
+    m_pSizeCB.clear();
+    m_pPosFrame.clear();
+    m_pHoriFT.clear();
+    m_pHoriLB.clear();
+    m_pHoriByFT.clear();
+    m_pHoriByMF.clear();
+    m_pHoriToFT.clear();
+    m_pHoriToLB.clear();
+    m_pHoriMirrorCB.clear();
+    m_pVertFT.clear();
+    m_pVertLB.clear();
+    m_pVertByFT.clear();
+    m_pVertByMF.clear();
+    m_pVertToFT.clear();
+    m_pVertToLB.clear();
+    m_pFollowCB.clear();
+    m_pExampleWN.clear();
+    SfxTabPage::dispose();
+}
+
+
 namespace
 {
     struct FrmMaps
@@ -689,18 +725,14 @@ void SvxSwPosSizeTabPage::setOptimalRelWidth()
     m_pHoriLB->Clear();
 }
 
-SvxSwPosSizeTabPage::~SvxSwPosSizeTabPage()
+VclPtr<SfxTabPage> SvxSwPosSizeTabPage::Create( vcl::Window* pParent, const SfxItemSet* rSet)
 {
+    return VclPtr<SvxSwPosSizeTabPage>::Create(pParent, *rSet);
 }
 
-SfxTabPage* SvxSwPosSizeTabPage::Create( Window* pParent, const SfxItemSet& rSet)
+const sal_uInt16* SvxSwPosSizeTabPage::GetRanges()
 {
-    return new SvxSwPosSizeTabPage(pParent, rSet);
-}
-
-sal_uInt16* SvxSwPosSizeTabPage::GetRanges()
-{
-    static sal_uInt16 pSwPosRanges[] =
+    static const sal_uInt16 pSwPosRanges[] =
     {
         SID_ATTR_TRANSFORM_POS_X,
         SID_ATTR_TRANSFORM_POS_Y,
@@ -727,36 +759,36 @@ sal_uInt16* SvxSwPosSizeTabPage::GetRanges()
     return pSwPosRanges;
 }
 
-sal_Bool SvxSwPosSizeTabPage::FillItemSet( SfxItemSet& rSet)
+bool SvxSwPosSizeTabPage::FillItemSet( SfxItemSet* rSet)
 {
     bool bAnchorChanged = false;
     short nAnchor = GetAnchorType(&bAnchorChanged);
-    sal_Bool bModified = sal_False;
+    bool bModified = false;
     if(bAnchorChanged)
     {
-        rSet.Put(SfxInt16Item(SID_ATTR_TRANSFORM_ANCHOR, nAnchor));
-        bModified |= sal_True;
+        rSet->Put(SfxInt16Item(SID_ATTR_TRANSFORM_ANCHOR, nAnchor));
+        bModified = true;
     }
-    if ( m_pPositionCB->GetState() != m_pPositionCB->GetSavedValue() )
+    if ( m_pPositionCB->IsValueChangedFromSaved() )
     {
-        if( m_pPositionCB->GetState() == STATE_DONTKNOW )
-            rSet.InvalidateItem( SID_ATTR_TRANSFORM_PROTECT_POS );
+        if( m_pPositionCB->GetState() == TRISTATE_INDET )
+            rSet->InvalidateItem( SID_ATTR_TRANSFORM_PROTECT_POS );
         else
-            rSet.Put(
+            rSet->Put(
                 SfxBoolItem( GetWhich( SID_ATTR_TRANSFORM_PROTECT_POS ),
-                m_pPositionCB->GetState() == STATE_CHECK ? sal_True : sal_False ) );
-        bModified |= sal_True;
+                m_pPositionCB->GetState() == TRISTATE_TRUE ) );
+        bModified = true;
     }
 
-    if ( m_pSizeCB->GetState() != m_pSizeCB->GetSavedValue() )
+    if ( m_pSizeCB->IsValueChangedFromSaved() )
     {
-        if ( m_pSizeCB->GetState() == STATE_DONTKNOW )
-            rSet.InvalidateItem( SID_ATTR_TRANSFORM_PROTECT_SIZE );
+        if ( m_pSizeCB->GetState() == TRISTATE_INDET )
+            rSet->InvalidateItem( SID_ATTR_TRANSFORM_PROTECT_SIZE );
         else
-            rSet.Put(
+            rSet->Put(
                 SfxBoolItem( GetWhich( SID_ATTR_TRANSFORM_PROTECT_SIZE ),
-                m_pSizeCB->GetState() == STATE_CHECK ? sal_True : sal_False ) );
-        bModified |= sal_True;
+                m_pSizeCB->GetState() == TRISTATE_TRUE ) );
+        bModified = true;
     }
 
     const SfxItemSet& rOldSet = GetItemSet();
@@ -780,10 +812,10 @@ sal_Bool SvxSwPosSizeTabPage::FillItemSet( SfxItemSet& rSet)
                 nHoriByPos += m_aAnchorPos.X();
                 nVertByPos += m_aAnchorPos.Y();
 
-                rSet.Put( SfxInt32Item( GetWhich( SID_ATTR_TRANSFORM_POS_X ), nHoriByPos ) );
-                rSet.Put( SfxInt32Item( GetWhich( SID_ATTR_TRANSFORM_POS_Y ), nVertByPos ) );
+                rSet->Put( SfxInt32Item( GetWhich( SID_ATTR_TRANSFORM_POS_X ), nHoriByPos ) );
+                rSet->Put( SfxInt32Item( GetWhich( SID_ATTR_TRANSFORM_POS_Y ), nVertByPos ) );
 
-                bModified |= sal_True;
+                bModified = true;
             }
         }
         else
@@ -808,15 +840,15 @@ sal_Bool SvxSwPosSizeTabPage::FillItemSet( SfxItemSet& rSet)
                     (m_pHoriByMF->IsEnabled() && nHoriByPos != rHoriPosition.GetValue())
                    )
                 {
-                    rSet.Put(SfxInt16Item(SID_ATTR_TRANSFORM_HORI_ORIENT, nAlign));
-                    rSet.Put(SfxInt16Item(SID_ATTR_TRANSFORM_HORI_RELATION, nRel));
+                    rSet->Put(SfxInt16Item(SID_ATTR_TRANSFORM_HORI_ORIENT, nAlign));
+                    rSet->Put(SfxInt16Item(SID_ATTR_TRANSFORM_HORI_RELATION, nRel));
                     if(m_pHoriByMF->IsEnabled())
-                        rSet.Put(SfxInt32Item(SID_ATTR_TRANSFORM_HORI_POSITION, nHoriByPos));
-                    bModified |= sal_True;
+                        rSet->Put(SfxInt32Item(SID_ATTR_TRANSFORM_HORI_POSITION, nHoriByPos));
+                    bModified = true;
                 }
             }
-            if(m_pHoriMirrorCB->IsEnabled() && m_pHoriMirrorCB->IsChecked() != m_pHoriMirrorCB->GetSavedValue())
-                bModified |= 0 != rSet.Put(SfxBoolItem(SID_ATTR_TRANSFORM_HORI_MIRROR, m_pHoriMirrorCB->IsChecked()));
+            if(m_pHoriMirrorCB->IsEnabled() && m_pHoriMirrorCB->IsValueChangedFromSaved())
+                bModified |= nullptr != rSet->Put(SfxBoolItem(SID_ATTR_TRANSFORM_HORI_MIRROR, m_pHoriMirrorCB->IsChecked()));
 
             if ( m_pVMap )
             {
@@ -843,25 +875,24 @@ sal_Bool SvxSwPosSizeTabPage::FillItemSet( SfxItemSet& rSet)
                      ( m_pVertByMF->IsEnabled() &&
                        nVertByPos != rVertPosition.GetValue() ) )
                 {
-                    rSet.Put(SfxInt16Item(SID_ATTR_TRANSFORM_VERT_ORIENT, nAlign));
-                    rSet.Put(SfxInt16Item(SID_ATTR_TRANSFORM_VERT_RELATION, nRel));
+                    rSet->Put(SfxInt16Item(SID_ATTR_TRANSFORM_VERT_ORIENT, nAlign));
+                    rSet->Put(SfxInt16Item(SID_ATTR_TRANSFORM_VERT_RELATION, nRel));
                     if(m_pVertByMF->IsEnabled())
-                        rSet.Put(SfxInt32Item(SID_ATTR_TRANSFORM_VERT_POSITION, nVertByPos));
-                    bModified |= sal_True;
+                        rSet->Put(SfxInt32Item(SID_ATTR_TRANSFORM_VERT_POSITION, nVertByPos));
+                    bModified = true;
                 }
             }
 
             // #i18732#
-            if(m_pFollowCB->IsChecked() != m_pFollowCB->GetSavedValue())
+            if(m_pFollowCB->IsValueChangedFromSaved())
             {
                 //Writer internal type - based on SfxBoolItem
                 const SfxPoolItem* pItem = GetItem( rOldSet, SID_SW_FOLLOW_TEXT_FLOW);
                 if(pItem)
                 {
-                    SfxBoolItem* pFollow = static_cast<SfxBoolItem*>(pItem->Clone());
+                    std::unique_ptr<SfxBoolItem> pFollow(static_cast<SfxBoolItem*>(pItem->Clone()));
                     pFollow->SetValue(m_pFollowCB->IsChecked());
-                    bModified |= 0 != rSet.Put(*pFollow);
-                    delete pFollow;
+                    bModified |= nullptr != rSet->Put(*pFollow);
                 }
             }
         }
@@ -870,22 +901,22 @@ sal_Bool SvxSwPosSizeTabPage::FillItemSet( SfxItemSet& rSet)
     {
         sal_uInt32 nWidth = static_cast<sal_uInt32>(m_pWidthMF->Denormalize(m_pWidthMF->GetValue(FUNIT_TWIP)));
         sal_uInt32 nHeight = static_cast<sal_uInt32>(m_pHeightMF->Denormalize(m_pHeightMF->GetValue(FUNIT_TWIP)));
-        rSet.Put( SfxUInt32Item( GetWhich( SID_ATTR_TRANSFORM_WIDTH ),
+        rSet->Put( SfxUInt32Item( GetWhich( SID_ATTR_TRANSFORM_WIDTH ),
                         (sal_uInt32) nWidth ) );
-        rSet.Put( SfxUInt32Item( GetWhich( SID_ATTR_TRANSFORM_HEIGHT ),
+        rSet->Put( SfxUInt32Item( GetWhich( SID_ATTR_TRANSFORM_HEIGHT ),
                         (sal_uInt32) nHeight ) );
         //this item is required by SdrEditView::SetGeoAttrToMarked()
-        rSet.Put( SfxAllEnumItem( GetWhich( SID_ATTR_TRANSFORM_SIZE_POINT ), RP_LT ) );
+        rSet->Put( SfxAllEnumItem( GetWhich( SID_ATTR_TRANSFORM_SIZE_POINT ), RP_LT ) );
 
-        bModified |= sal_True;
+        bModified = true;
     }
 
     return bModified;
 }
 
-void SvxSwPosSizeTabPage::Reset( const SfxItemSet& rSet)
+void SvxSwPosSizeTabPage::Reset( const SfxItemSet* rSet)
 {
-    const SfxPoolItem* pItem = GetItem( rSet, SID_ATTR_TRANSFORM_ANCHOR );
+    const SfxPoolItem* pItem = GetItem( *rSet, SID_ATTR_TRANSFORM_ANCHOR );
     bool bInvalidateAnchor = false;
     short nAnchorType = TextContentAnchorType_AT_PARAGRAPH;
     if(pItem)
@@ -908,46 +939,49 @@ void SvxSwPosSizeTabPage::Reset( const SfxItemSet& rSet)
     }
     if(bInvalidateAnchor)
     {
-        m_pToPageRB->Enable( sal_False );
-        m_pToParaRB->Enable( sal_False );
-        m_pToCharRB->Enable( sal_False );
-        m_pAsCharRB->Enable( sal_False );
-        m_pToFrameRB->Enable( sal_False );
+        m_pToPageRB->Enable( false );
+        m_pToParaRB->Enable( false );
+        m_pToCharRB->Enable( false );
+        m_pAsCharRB->Enable( false );
+        m_pToFrameRB->Enable( false );
     }
 
-    pItem = GetItem( rSet, SID_ATTR_TRANSFORM_PROTECT_POS );
+    pItem = GetItem( *rSet, SID_ATTR_TRANSFORM_PROTECT_POS );
     if ( pItem )
     {
-        sal_Bool bProtected = ( ( const SfxBoolItem* )pItem )->GetValue();
-        m_pPositionCB->SetState( bProtected ? STATE_CHECK : STATE_NOCHECK );
-        m_pPositionCB->EnableTriState( sal_False );
+        bool bProtected = static_cast<const SfxBoolItem*>(pItem)->GetValue();
+        m_pPositionCB->SetState( bProtected ? TRISTATE_TRUE : TRISTATE_FALSE );
+        m_pPositionCB->EnableTriState( false );
         m_pSizeCB->Enable( !bProtected );
     }
     else
     {
-        m_pPositionCB->SetState( STATE_DONTKNOW );
+        m_pPositionCB->SetState( TRISTATE_INDET );
     }
 
     m_pPositionCB->SaveValue();
 
-    pItem = GetItem( rSet, SID_ATTR_TRANSFORM_PROTECT_SIZE );
+    pItem = GetItem( *rSet, SID_ATTR_TRANSFORM_PROTECT_SIZE );
 
     if ( pItem )
     {
-        m_pSizeCB->SetState( ( (const SfxBoolItem*)pItem )->GetValue()
-                              ? STATE_CHECK : STATE_NOCHECK );
-        m_pSizeCB->EnableTriState( sal_False );
+        m_pSizeCB->SetState( static_cast<const SfxBoolItem*>(pItem)->GetValue()
+                              ? TRISTATE_TRUE : TRISTATE_FALSE );
+        m_pSizeCB->EnableTriState( false );
     }
     else
-        m_pSizeCB->SetState( STATE_DONTKNOW );
+        m_pSizeCB->SetState( TRISTATE_INDET );
     m_pSizeCB->SaveValue();
 
-    pItem = GetItem( rSet, SID_HTML_MODE );
+    pItem = GetItem( *rSet, SID_HTML_MODE );
     if(pItem)
-        m_nHtmlMode = static_cast<const SfxUInt16Item*>(pItem)->GetValue();
-    m_bHtmlMode = 0 != (m_bHtmlMode & HTMLMODE_ON);
+    {
+        m_bHtmlMode =
+            (static_cast<const SfxUInt16Item*>(pItem)->GetValue() & HTMLMODE_ON)
+            != 0;
+    }
 
-    pItem = GetItem( rSet, SID_ATTR_TRANSFORM_IN_VERTICAL_TEXT );
+    pItem = GetItem( *rSet, SID_ATTR_TRANSFORM_IN_VERTICAL_TEXT );
     if(pItem && static_cast<const SfxBoolItem*>(pItem)->GetValue())
     {
         OUString sHLabel = m_pHoriFT->GetText();
@@ -955,11 +989,11 @@ void SvxSwPosSizeTabPage::Reset( const SfxItemSet& rSet)
         m_pVertFT->SetText(sHLabel);
         m_bIsVerticalFrame = true;
     }
-    pItem = GetItem( rSet, SID_ATTR_TRANSFORM_IN_RTL_TEXT);
+    pItem = GetItem( *rSet, SID_ATTR_TRANSFORM_IN_RTL_TEXT);
     if(pItem)
         m_bIsInRightToLeft = static_cast<const SfxBoolItem*>(pItem)->GetValue();
 
-    pItem = GetItem( rSet, SID_SW_FOLLOW_TEXT_FLOW);
+    pItem = GetItem( *rSet, SID_SW_FOLLOW_TEXT_FLOW);
     if(pItem)
     {
         const bool bFollowTextFlow =
@@ -970,10 +1004,10 @@ void SvxSwPosSizeTabPage::Reset( const SfxItemSet& rSet)
 
     if(m_bHtmlMode)
     {
-        m_pHoriMirrorCB->Show(sal_False);
-        m_pKeepRatioCB->Enable(sal_False);
+        m_pHoriMirrorCB->Show(false);
+        m_pKeepRatioCB->Enable(false);
         // #i18732# - hide checkbox in HTML mode
-        m_pFollowCB->Show(sal_False);
+        m_pFollowCB->Show(false);
     }
     else
     {
@@ -985,52 +1019,52 @@ void SvxSwPosSizeTabPage::Reset( const SfxItemSet& rSet)
                                   m_pToCharRB->IsChecked() );
     }
 
-    pItem = GetItem( rSet, SID_ATTR_TRANSFORM_WIDTH );
+    pItem = GetItem( *rSet, SID_ATTR_TRANSFORM_WIDTH );
     sal_Int32 nWidth = std::max( pItem ? ( static_cast<const SfxUInt32Item*>(pItem)->GetValue()) : 0, (sal_uInt32)1 );
 
     m_pWidthMF->SetValue(m_pWidthMF->Normalize(nWidth), FUNIT_TWIP);
 
-    pItem = GetItem( rSet, SID_ATTR_TRANSFORM_HEIGHT );
+    pItem = GetItem( *rSet, SID_ATTR_TRANSFORM_HEIGHT );
     sal_Int32 nHeight = std::max( pItem ? ( static_cast<const SfxUInt32Item*>(pItem)->GetValue()) : 0, (sal_uInt32)1 );
     m_pHeightMF->SetValue(m_pHeightMF->Normalize(nHeight), FUNIT_TWIP);
     m_fWidthHeightRatio = nHeight ? double(nWidth) / double(nHeight) : 1.0;
 
     if(!m_bPositioningDisabled)
     {
-        pItem = GetItem( rSet, SID_ATTR_TRANSFORM_HORI_ORIENT);
+        pItem = GetItem( *rSet, SID_ATTR_TRANSFORM_HORI_ORIENT);
         if(pItem)
         {
             short nHoriOrientation = static_cast< const SfxInt16Item*>(pItem)->GetValue();
             m_nOldH = nHoriOrientation;
         }
-        pItem = GetItem( rSet, SID_ATTR_TRANSFORM_VERT_ORIENT);
+        pItem = GetItem( *rSet, SID_ATTR_TRANSFORM_VERT_ORIENT);
         if(pItem)
         {
             short nVertOrientation = static_cast< const SfxInt16Item*>(pItem)->GetValue();
             m_nOldV = nVertOrientation;
         }
-        pItem = GetItem( rSet, SID_ATTR_TRANSFORM_HORI_RELATION);
+        pItem = GetItem( *rSet, SID_ATTR_TRANSFORM_HORI_RELATION);
         if(pItem)
         {
             m_nOldHRel = static_cast< const SfxInt16Item*>(pItem)->GetValue();
         }
 
-        pItem = GetItem( rSet, SID_ATTR_TRANSFORM_VERT_RELATION);
+        pItem = GetItem( *rSet, SID_ATTR_TRANSFORM_VERT_RELATION);
         if(pItem)
         {
             m_nOldVRel = static_cast< const SfxInt16Item*>(pItem)->GetValue();
         }
-        pItem = GetItem( rSet, SID_ATTR_TRANSFORM_HORI_MIRROR);
+        pItem = GetItem( *rSet, SID_ATTR_TRANSFORM_HORI_MIRROR);
         if(pItem)
             m_pHoriMirrorCB->Check(static_cast<const SfxBoolItem*>(pItem)->GetValue());
         m_pHoriMirrorCB->SaveValue();
 
         sal_Int32 nHoriPos = 0;
         sal_Int32 nVertPos = 0;
-        pItem = GetItem( rSet, SID_ATTR_TRANSFORM_HORI_POSITION);
+        pItem = GetItem( *rSet, SID_ATTR_TRANSFORM_HORI_POSITION);
         if(pItem)
             nHoriPos = static_cast<const SfxInt32Item*>(pItem)->GetValue();
-        pItem = GetItem( rSet, SID_ATTR_TRANSFORM_VERT_POSITION);
+        pItem = GetItem( *rSet, SID_ATTR_TRANSFORM_VERT_POSITION);
         if(pItem)
             nVertPos = static_cast<const SfxInt32Item*>(pItem)->GetValue();
 
@@ -1041,15 +1075,15 @@ void SvxSwPosSizeTabPage::Reset( const SfxItemSet& rSet)
         // #i18732#
         m_pFollowCB->SaveValue();
 
-        RangeModifyHdl(m_pWidthMF);  // initially set maximum values
+        RangeModifyHdl(*m_pWidthMF);  // initially set maximum values
     }
 }
 
-int  SvxSwPosSizeTabPage::DeactivatePage( SfxItemSet* _pSet )
+SfxTabPage::sfxpg SvxSwPosSizeTabPage::DeactivatePage( SfxItemSet* _pSet )
 {
     if( _pSet )
-        FillItemSet( *_pSet );
-    return( LEAVE_PAGE );
+        FillItemSet( _pSet );
+    return LEAVE_PAGE;
 }
 
 void SvxSwPosSizeTabPage::EnableAnchorTypes(sal_uInt16 nAnchorEnable)
@@ -1057,13 +1091,13 @@ void SvxSwPosSizeTabPage::EnableAnchorTypes(sal_uInt16 nAnchorEnable)
     if((nAnchorEnable & SVX_OBJ_AT_FLY))
         m_pToFrameRB->Show();
     if(!(nAnchorEnable & SVX_OBJ_PAGE))
-        m_pToPageRB->Enable(sal_False);
+        m_pToPageRB->Enable(false);
 }
 
 short SvxSwPosSizeTabPage::GetAnchorType(bool* pbHasChanged)
 {
     short nRet = -1;
-    RadioButton* pCheckedButton = 0;
+    RadioButton* pCheckedButton = nullptr;
     if(m_pToParaRB->IsEnabled())
     {
         if(m_pToPageRB->IsChecked())
@@ -1095,17 +1129,21 @@ short SvxSwPosSizeTabPage::GetAnchorType(bool* pbHasChanged)
     if(pbHasChanged)
     {
          if(pCheckedButton)
-             *pbHasChanged = pCheckedButton->IsChecked() != pCheckedButton->GetSavedValue();
+             *pbHasChanged = pCheckedButton->IsValueChangedFromSaved();
          else
              *pbHasChanged = false;
     }
    return nRet;
 }
 
-IMPL_LINK_NOARG(SvxSwPosSizeTabPage, RangeModifyHdl)
+IMPL_LINK_NOARG_TYPED(SvxSwPosSizeTabPage, RangeModifyClickHdl, Button*, void)
+{
+    RangeModifyHdl(*m_pWidthMF);
+}
+IMPL_LINK_NOARG_TYPED(SvxSwPosSizeTabPage, RangeModifyHdl, Control&, void)
 {
     if(m_bPositioningDisabled)
-        return 0;
+        return;
     SvxSwFrameValidation        aVal;
 
     aVal.nAnchorType = GetAnchorType();
@@ -1154,8 +1192,7 @@ IMPL_LINK_NOARG(SvxSwPosSizeTabPage, RangeModifyHdl)
     aVal.nWidth  = nWidth;
     aVal.nHeight = nHeight;
 
-    if(m_aValidateLink.IsSet())
-        m_aValidateLink.Call(&aVal);
+    m_aValidateLink.Call(aVal);
 
     nWidth = aVal.nWidth;
     nHeight = aVal.nHeight;
@@ -1182,11 +1219,9 @@ IMPL_LINK_NOARG(SvxSwPosSizeTabPage, RangeModifyHdl)
     m_pVertByMF->SetMax(m_pVertByMF->Normalize(aVal.nMaxVPos), FUNIT_TWIP);
     if ( aVal.nVPos != nAtVertPosVal )
         m_pVertByMF->SetValue(m_pVertByMF->Normalize(aVal.nVPos), FUNIT_TWIP);
-
-    return 0;
 }
 
-IMPL_LINK_NOARG(SvxSwPosSizeTabPage, AnchorTypeHdl)
+IMPL_LINK_NOARG_TYPED(SvxSwPosSizeTabPage, AnchorTypeHdl, Button*, void)
 {
     m_pHoriMirrorCB->Enable(!m_pAsCharRB->IsChecked() && !m_bIsMultiSelection);
 
@@ -1197,34 +1232,31 @@ IMPL_LINK_NOARG(SvxSwPosSizeTabPage, AnchorTypeHdl)
     short nId = GetAnchorType();
 
     InitPos( nId, USHRT_MAX, 0, USHRT_MAX, 0, LONG_MAX, LONG_MAX);
-    RangeModifyHdl(0);
+    RangeModifyHdl(*m_pWidthMF);
 
     if(m_bHtmlMode)
     {
-        PosHdl(m_pHoriLB);
-        PosHdl(m_pVertLB);
+        PosHdl(*m_pHoriLB);
+        PosHdl(*m_pVertLB);
     }
-    return 0;
 }
 
-IMPL_LINK_NOARG(SvxSwPosSizeTabPage, MirrorHdl)
+IMPL_LINK_NOARG_TYPED(SvxSwPosSizeTabPage, MirrorHdl, Button*, void)
 {
     short nId = GetAnchorType();
     InitPos( nId, USHRT_MAX, 0, USHRT_MAX, 0, LONG_MAX, LONG_MAX);
-
-    return 0;
 }
 
-IMPL_LINK( SvxSwPosSizeTabPage, RelHdl, ListBox *, pLB )
+IMPL_LINK_TYPED( SvxSwPosSizeTabPage, RelHdl, ListBox&, rLB, void )
 {
-    sal_Bool bHori = pLB == m_pHoriToLB;
+    bool bHori = &rLB == m_pHoriToLB;
 
     UpdateExample();
 
     if (bHori)
-        m_bAtHoriPosModified = sal_True;
+        m_bAtHoriPosModified = true;
     else
-        m_bAtVertPosModified = sal_True;
+        m_bAtVertPosModified = true;
 
     if(m_bHtmlMode  && TextContentAnchorType_AT_CHARACTER == GetAnchorType()) // again special treatment
     {
@@ -1241,46 +1273,41 @@ IMPL_LINK( SvxSwPosSizeTabPage, RelHdl, ListBox *, pLB )
             }
         }
     }
-    if (pLB)    // only if the hanlder has been called by a change of the controller
-        RangeModifyHdl(0);
-
-    return 0;
-
+    RangeModifyHdl(*m_pWidthMF);
 }
 
-IMPL_LINK( SvxSwPosSizeTabPage, PosHdl, ListBox *, pLB )
+IMPL_LINK_TYPED( SvxSwPosSizeTabPage, PosHdl, ListBox&, rLB, void )
 {
-    sal_Bool bHori = pLB == m_pHoriLB;
+    bool bHori = &rLB == m_pHoriLB;
     ListBox *pRelLB = bHori ? m_pHoriToLB : m_pVertToLB;
     FixedText *pRelFT = bHori ? m_pHoriToFT : m_pVertToFT;
     FrmMap *pMap = bHori ? m_pHMap : m_pVMap;
 
 
-    sal_uInt16 nMapPos = GetMapPos(pMap, *pLB);
-    sal_uInt16 nAlign = GetAlignment(pMap, nMapPos, *pLB, *pRelLB);
+    sal_uInt16 nMapPos = GetMapPos(pMap, rLB);
+    sal_uInt16 nAlign = GetAlignment(pMap, nMapPos, rLB, *pRelLB);
 
     if (bHori)
     {
-        sal_Bool bEnable = HoriOrientation::NONE == nAlign;
+        bool bEnable = HoriOrientation::NONE == nAlign;
         m_pHoriByMF->Enable( bEnable );
         m_pHoriByFT->Enable( bEnable );
     }
     else
     {
-        sal_Bool bEnable = VertOrientation::NONE == nAlign;
+        bool bEnable = VertOrientation::NONE == nAlign;
         m_pVertByMF->Enable( bEnable );
         m_pVertByFT->Enable( bEnable );
     }
 
-    if (pLB)    // only if the hanlder has been called by a change of the controller
-        RangeModifyHdl( 0 );
+    RangeModifyHdl( *m_pWidthMF );
 
     short nRel = 0;
-    if (pLB->GetSelectEntryCount())
+    if (rLB.GetSelectEntryCount())
     {
 
         if (pRelLB->GetSelectEntryPos() != LISTBOX_ENTRY_NOTFOUND)
-            nRel = ((RelationMap *)pRelLB->GetEntryData(pRelLB->GetSelectEntryPos()))->nRelation;
+            nRel = static_cast<RelationMap *>(pRelLB->GetSelectEntryData())->nRelation;
 
         FillRelLB(pMap, nMapPos, nAlign, nRel, *pRelLB, *pRelFT);
     }
@@ -1290,14 +1317,14 @@ IMPL_LINK( SvxSwPosSizeTabPage, PosHdl, ListBox *, pLB )
     UpdateExample();
 
     if (bHori)
-        m_bAtHoriPosModified = sal_True;
+        m_bAtHoriPosModified = true;
     else
-        m_bAtVertPosModified = sal_True;
+        m_bAtVertPosModified = true;
 
     // special treatment for HTML-Mode with horz-vert-dependencies
     if(m_bHtmlMode && TextContentAnchorType_AT_CHARACTER == GetAnchorType())
     {
-        sal_Bool bSet = sal_False;
+        bool bSet = false;
         if(bHori)
         {
             // on the right only below is allowed - from the left only at the top
@@ -1309,20 +1336,20 @@ IMPL_LINK( SvxSwPosSizeTabPage, PosHdl, ListBox *, pLB )
                     m_pVertLB->SelectEntryPos(1);
                 else
                     m_pVertLB->SelectEntryPos(0);
-                bSet = sal_True;
+                bSet = true;
             }
             else if(HoriOrientation::LEFT == nAlign && 1 == m_pVertLB->GetSelectEntryPos())
             {
                 m_pVertLB->SelectEntryPos(0);
-                bSet = sal_True;
+                bSet = true;
             }
             else if(HoriOrientation::NONE == nAlign && 1 == m_pVertLB->GetSelectEntryPos())
             {
                 m_pVertLB->SelectEntryPos(0);
-                bSet = sal_True;
+                bSet = true;
             }
             if(bSet)
-                PosHdl(m_pVertLB);
+                PosHdl(*m_pVertLB);
         }
         else
         {
@@ -1331,7 +1358,7 @@ IMPL_LINK( SvxSwPosSizeTabPage, PosHdl, ListBox *, pLB )
                 if(1 == m_pHoriLB->GetSelectEntryPos())
                 {
                     m_pHoriLB->SelectEntryPos(0);
-                    bSet = sal_True;
+                    bSet = true;
                 }
                 m_pHoriToLB->SelectEntryPos(1);
             }
@@ -1340,30 +1367,29 @@ IMPL_LINK( SvxSwPosSizeTabPage, PosHdl, ListBox *, pLB )
                 if(2 == m_pHoriLB->GetSelectEntryPos())
                 {
                     m_pHoriLB->SelectEntryPos(0);
-                    bSet = sal_True;
+                    bSet = true;
                 }
                 m_pHoriToLB->SelectEntryPos(0) ;
             }
             if(bSet)
-                PosHdl(m_pHoriLB);
+                PosHdl(*m_pHoriLB);
         }
 
     }
-    return 0;
 }
 
-IMPL_LINK( SvxSwPosSizeTabPage, ModifyHdl, Edit *, pEdit )
+IMPL_LINK_TYPED( SvxSwPosSizeTabPage, ModifyHdl, Edit&, rEdit, void )
 {
     sal_Int64 nWidth = m_pWidthMF->Denormalize(m_pWidthMF->GetValue(FUNIT_TWIP));
     sal_Int64 nHeight = m_pHeightMF->Denormalize(m_pHeightMF->GetValue(FUNIT_TWIP));
     if ( m_pKeepRatioCB->IsChecked() )
     {
-        if ( pEdit == m_pWidthMF )
+        if ( &rEdit == m_pWidthMF )
         {
             nHeight = sal_Int64((double)nWidth / m_fWidthHeightRatio);
             m_pHeightMF->SetValue(m_pHeightMF->Normalize(nHeight), FUNIT_TWIP);
         }
-        else if(pEdit == m_pHeightMF)
+        else if(&rEdit == m_pHeightMF)
         {
             nWidth = sal_Int64((double)nHeight * m_fWidthHeightRatio);
             m_pWidthMF->SetValue(m_pWidthMF->Normalize(nWidth), FUNIT_TWIP);
@@ -1371,23 +1397,21 @@ IMPL_LINK( SvxSwPosSizeTabPage, ModifyHdl, Edit *, pEdit )
     }
     m_fWidthHeightRatio = nHeight ? double(nWidth) / double(nHeight) : 1.0;
     UpdateExample();
-    return 0;
 }
 
-IMPL_LINK_NOARG(SvxSwPosSizeTabPage, ProtectHdl)
+IMPL_LINK_NOARG_TYPED(SvxSwPosSizeTabPage, ProtectHdl, Button*, void)
 {
     m_pSizeCB->Enable(m_pPositionCB->IsEnabled() && !m_pPositionCB->IsChecked());
-    return 0;
 }
 
 short SvxSwPosSizeTabPage::GetRelation(FrmMap *, ListBox &rRelationLB)
 {
     short nRel = 0;
-    sal_uInt16 nPos = rRelationLB.GetSelectEntryPos();
+    sal_Int32 nPos = rRelationLB.GetSelectEntryPos();
 
     if (nPos != LISTBOX_ENTRY_NOTFOUND)
     {
-        RelationMap *pEntry = (RelationMap *)rRelationLB.GetEntryData(nPos);
+        RelationMap *pEntry = static_cast<RelationMap *>(rRelationLB.GetEntryData(nPos));
         nRel = pEntry->nRelation;
     }
 
@@ -1405,7 +1429,7 @@ short SvxSwPosSizeTabPage::GetAlignment(FrmMap *pMap, sal_uInt16 nMapPos, ListBo
     {
         if (rRelationLB.GetSelectEntryPos() != LISTBOX_ENTRY_NOTFOUND)
         {
-            sal_uLong  nRel = ((RelationMap *)rRelationLB.GetEntryData(rRelationLB.GetSelectEntryPos()))->nLBRelation;
+            sal_uLong  nRel = static_cast<RelationMap *>(rRelationLB.GetSelectEntryData())->nLBRelation;
             std::size_t nMapCount = ::lcl_GetFrmMapCount(pMap);
             SvxSwFramePosString::StringId eStrId = pMap[nMapPos].eStrId;
 
@@ -1432,7 +1456,7 @@ short SvxSwPosSizeTabPage::GetAlignment(FrmMap *pMap, sal_uInt16 nMapPos, ListBo
 sal_uInt16 SvxSwPosSizeTabPage::GetMapPos(FrmMap *pMap, ListBox &rAlignLB)
 {
     sal_uInt16 nMapPos = 0;
-    sal_uInt16 nLBSelPos = rAlignLB.GetSelectEntryPos();
+    sal_Int32 nLBSelPos = rAlignLB.GetSelectEntryPos();
 
     if (nLBSelPos != LISTBOX_ENTRY_NOTFOUND)
     {
@@ -1469,13 +1493,13 @@ void SvxSwPosSizeTabPage::InitPos(short nAnchor,
                                 long   nX,
                                 long   nY)
 {
-    sal_uInt16 nPos = m_pVertLB->GetSelectEntryPos();
+    sal_Int32 nPos = m_pVertLB->GetSelectEntryPos();
     if ( nPos != LISTBOX_ENTRY_NOTFOUND && m_pVMap )
     {
         m_nOldV    = m_pVMap[nPos].nAlign;
         nPos = m_pVertToLB->GetSelectEntryPos();
         if (nPos != LISTBOX_ENTRY_NOTFOUND)
-            m_nOldVRel = ((RelationMap *)m_pVertToLB->GetEntryData(nPos))->nRelation;
+            m_nOldVRel = static_cast<RelationMap *>(m_pVertToLB->GetEntryData(nPos))->nRelation;
     }
 
     nPos = m_pHoriLB->GetSelectEntryPos();
@@ -1485,10 +1509,10 @@ void SvxSwPosSizeTabPage::InitPos(short nAnchor,
 
         nPos = m_pHoriToLB->GetSelectEntryPos();
         if (nPos != LISTBOX_ENTRY_NOTFOUND)
-            m_nOldHRel = ((RelationMap *)m_pHoriToLB->GetEntryData(nPos))->nRelation;
+            m_nOldHRel = static_cast<RelationMap *>(m_pHoriToLB->GetEntryData(nPos))->nRelation;
     }
 
-    sal_Bool bEnable = sal_True;
+    bool bEnable = true;
     if( m_bIsMultiSelection )
     {
         m_pVMap = aVMultiSelectionMap;
@@ -1535,8 +1559,8 @@ void SvxSwPosSizeTabPage::InitPos(short nAnchor,
     else if ( nAnchor == TextContentAnchorType_AS_CHARACTER )
     {
         m_pVMap = m_bHtmlMode ? aVAsCharHtmlMap     : aVAsCharMap;
-        m_pHMap = 0;
-        bEnable = sal_False;
+        m_pHMap = nullptr;
+        bEnable = false;
     }
     m_pHoriLB->Enable( bEnable );
     m_pHoriFT->Enable( bEnable );
@@ -1613,7 +1637,7 @@ void SvxSwPosSizeTabPage::InitPos(short nAnchor,
 
 void SvxSwPosSizeTabPage::UpdateExample()
 {
-    sal_uInt16 nPos = m_pHoriLB->GetSelectEntryPos();
+    sal_Int32 nPos = m_pHoriLB->GetSelectEntryPos();
     if ( m_pHMap && nPos != LISTBOX_ENTRY_NOTFOUND )
     {
         sal_uInt16 nMapPos = GetMapPos(m_pHMap, *m_pHoriLB);
@@ -1674,7 +1698,7 @@ sal_uLong SvxSwPosSizeTabPage::FillRelLB(FrmMap *pMap, sal_uInt16 nMapPos, sal_u
 
                             sStrId1 = lcl_ChangeResIdToVerticalOrRTL(sStrId1, m_bIsVerticalFrame, m_bIsInRightToLeft);
                             OUString sEntry = m_aFramePosString.GetString(sStrId1);
-                            sal_uInt16 nPos = rLB.InsertEntry(sEntry);
+                            sal_Int32 nPos = rLB.InsertEntry(sEntry);
                             rLB.SetEntryData(nPos, &aAsCharRelationMap[nRelPos]);
                             if (pMap[_nMapPos].nAlign == nAlign)
                                 sSelEntry = sEntry;
@@ -1691,9 +1715,9 @@ sal_uLong SvxSwPosSizeTabPage::FillRelLB(FrmMap *pMap, sal_uInt16 nMapPos, sal_u
 
                 if (!rLB.GetSelectEntryCount())
                 {
-                    for (sal_uInt16 i = 0; i < rLB.GetEntryCount(); i++)
+                    for (sal_Int32 i = 0; i < rLB.GetEntryCount(); i++)
                     {
-                        RelationMap *pEntry = (RelationMap *)rLB.GetEntryData(i);
+                        RelationMap *pEntry = static_cast<RelationMap *>(rLB.GetEntryData(i));
                         if (pEntry->nLBRelation == LB_REL_CHAR) // Default
                         {
                             rLB.SelectEntryPos(i);
@@ -1733,7 +1757,7 @@ sal_uLong SvxSwPosSizeTabPage::FillRelLB(FrmMap *pMap, sal_uInt16 nMapPos, sal_u
                             SvxSwFramePosString::StringId sStrId1 = m_pHoriMirrorCB->IsChecked() ? aRelationMap[nRelPos].eMirrorStrId : aRelationMap[nRelPos].eStrId;
                             sStrId1 = lcl_ChangeResIdToVerticalOrRTL(sStrId1, m_bIsVerticalFrame, m_bIsInRightToLeft);
                             OUString sEntry = m_aFramePosString.GetString(sStrId1);
-                            sal_uInt16 nPos = rLB.InsertEntry(sEntry);
+                            sal_Int32 nPos = rLB.InsertEntry(sEntry);
                             rLB.SetEntryData(nPos, &aRelationMap[nRelPos]);
                             if (sSelEntry.isEmpty() && aRelationMap[nRelPos].nRelation == nRel)
                                 sSelEntry = sEntry;
@@ -1760,15 +1784,15 @@ sal_uLong SvxSwPosSizeTabPage::FillRelLB(FrmMap *pMap, sal_uInt16 nMapPos, sal_u
                     default:
                         if (rLB.GetEntryCount())
                         {
-                            RelationMap *pEntry = (RelationMap *)rLB.GetEntryData(rLB.GetEntryCount() - 1);
+                            RelationMap *pEntry = static_cast<RelationMap *>(rLB.GetEntryData(rLB.GetEntryCount() - 1));
                             nRel = pEntry->nRelation;
                         }
                         break;
                 }
 
-                for (sal_uInt16 i = 0; i < rLB.GetEntryCount(); i++)
+                for (sal_Int32 i = 0; i < rLB.GetEntryCount(); i++)
                 {
-                    RelationMap *pEntry = (RelationMap *)rLB.GetEntryData(i);
+                    RelationMap *pEntry = static_cast<RelationMap *>(rLB.GetEntryData(i));
                     if (pEntry->nRelation == nRel)
                     {
                         rLB.SelectEntryPos(i);
@@ -1785,7 +1809,7 @@ sal_uLong SvxSwPosSizeTabPage::FillRelLB(FrmMap *pMap, sal_uInt16 nMapPos, sal_u
     rLB.Enable(rLB.GetEntryCount() != 0);
     rFT.Enable(rLB.GetEntryCount() != 0);
 
-    RelHdl(&rLB);
+    RelHdl(rLB);
 
     return nLBRelations;
 }
@@ -1838,7 +1862,7 @@ sal_uInt16 SvxSwPosSizeTabPage::FillPosLB(FrmMap *_pMap,
     if (!_rLB.GetSelectEntryCount())
         _rLB.SelectEntryPos(0);
 
-    PosHdl(&_rLB);
+    PosHdl(_rLB);
 
     return GetMapPos(_pMap, _rLB);
 }
@@ -1861,14 +1885,14 @@ void SvxSwPosSizeTabPage::SetView( const SdrView* pSdrView )
 
     // consider anchor position (for Writer)
     const SdrMarkList& rMarkList = m_pSdrView->GetMarkedObjectList();
-    if( rMarkList.GetMarkCount() >= 1 )
+    if( rMarkList.GetMarkCount() > 0 )
     {
         const SdrObject* pObj = rMarkList.GetMark( 0 )->GetMarkedSdrObj();
         m_aAnchorPos = pObj->GetAnchorPos();
 
         if( m_aAnchorPos != Point(0,0) ) // -> Writer
         {
-            for( sal_uInt16 i = 1; i < rMarkList.GetMarkCount(); i++ )
+            for( size_t i = 1; i < rMarkList.GetMarkCount(); ++i )
             {
                 pObj = rMarkList.GetMark( i )->GetMarkedSdrObj();
                 if( m_aAnchorPos != pObj->GetAnchorPos() )
