@@ -56,7 +56,7 @@ const sal_uInt16 SvxTextAttrPage::pRanges[] =
 SvxTextAttrPage::SvxTextAttrPage(vcl::Window* pWindow, const SfxItemSet& rInAttrs)
     : SvxTabPage(pWindow,"TextAttributesPage","cui/ui/textattrtabpage.ui", rInAttrs)
     , rOutAttrs(rInAttrs)
-    , pView(NULL)
+    , pView(nullptr)
     , bAutoGrowSizeEnabled(false)
     , bContourEnabled(false)
     , bAutoGrowWidthEnabled(false)
@@ -87,7 +87,7 @@ SvxTextAttrPage::SvxTextAttrPage(vcl::Window* pWindow, const SfxItemSet& rInAttr
     SetFieldUnit( *m_pMtrFldTop, eFUnit );
     SetFieldUnit( *m_pMtrFldBottom, eFUnit );
 
-    Link<> aLink( LINK( this, SvxTextAttrPage, ClickHdl_Impl ) );
+    Link<Button*,void> aLink( LINK( this, SvxTextAttrPage, ClickHdl_Impl ) );
     m_pTsbAutoGrowWidth->SetClickHdl( aLink );
     m_pTsbAutoGrowHeight->SetClickHdl( aLink );
     m_pTsbFitToSize->SetClickHdl( aLink );
@@ -287,7 +287,7 @@ void SvxTextAttrPage::Reset( const SfxItemSet* rAttrs )
         if((bLeftToRight && (SDRTEXTHORZADJUST_BLOCK == eTHA)) || (!bLeftToRight && (SDRTEXTVERTADJUST_BLOCK == eTVA)))
         {
             // Move anchor to valid position.
-            ClickFullWidthHdl_Impl(NULL);
+            ClickFullWidthHdl_Impl(nullptr);
             m_pTsbFullWidth->SetState(TRISTATE_TRUE);
         }
 
@@ -327,7 +327,7 @@ void SvxTextAttrPage::Reset( const SfxItemSet* rAttrs )
         m_pTsbContour->SetState( TRISTATE_INDET );
     m_pTsbContour->SaveValue();
 
-    ClickHdl_Impl( NULL );
+    ClickHdl_Impl( nullptr );
 }
 
 /*************************************************************************
@@ -582,7 +582,7 @@ void SvxTextAttrPage::PointChanged( vcl::Window*, RECT_POINT eRP )
     to be moved to a valid and adjacent position.  This position depends on
     the current anchor position and the text writing direction.
 */
-IMPL_LINK_NOARG(SvxTextAttrPage, ClickFullWidthHdl_Impl)
+IMPL_LINK_NOARG_TYPED(SvxTextAttrPage, ClickFullWidthHdl_Impl, Button*, void)
 {
     if( m_pTsbFullWidth->GetState() == TRISTATE_TRUE )
     {
@@ -631,7 +631,6 @@ IMPL_LINK_NOARG(SvxTextAttrPage, ClickFullWidthHdl_Impl)
             }
         }
     }
-    return 0L;
 }
 
 /*************************************************************************
@@ -640,7 +639,7 @@ IMPL_LINK_NOARG(SvxTextAttrPage, ClickFullWidthHdl_Impl)
 |*
 \************************************************************************/
 
-IMPL_LINK_NOARG(SvxTextAttrPage, ClickHdl_Impl)
+IMPL_LINK_NOARG_TYPED(SvxTextAttrPage, ClickHdl_Impl, Button*, void)
 {
     bool bAutoGrowWidth  = m_pTsbAutoGrowWidth->GetState() == TRISTATE_TRUE;
     bool bAutoGrowHeight = m_pTsbAutoGrowHeight->GetState() == TRISTATE_TRUE;
@@ -681,8 +680,6 @@ IMPL_LINK_NOARG(SvxTextAttrPage, ClickHdl_Impl)
 
     // #83698# enable/disable text anchoring dependent of contour
     m_pFlPosition->Enable(!bContour && !bHorAndVer);
-
-    return 0L;
 }
 
 
@@ -696,7 +693,7 @@ bool SvxTextAttrPage::IsTextDirectionLeftToRight() const
     {
         const SvxWritingModeItem& rItem = static_cast<const SvxWritingModeItem&> (
             rOutAttrs.Get (SDRATTR_TEXTDIRECTION));
-        if (rItem.GetValue() == com::sun::star::text::WritingMode_TB_RL)
+        if (rItem.GetValue() == css::text::WritingMode_TB_RL)
             bLeftToRightDirection = false;
     }
     return bLeftToRightDirection;
@@ -704,7 +701,7 @@ bool SvxTextAttrPage::IsTextDirectionLeftToRight() const
 
 void SvxTextAttrPage::PageCreated(const SfxAllItemSet& aSet)
 {
-    SFX_ITEMSET_ARG (&aSet,pViewItem,OfaPtrItem,SID_SVXTEXTATTRPAGE_VIEW,false);
+    const OfaPtrItem* pViewItem = aSet.GetItem<OfaPtrItem>(SID_SVXTEXTATTRPAGE_VIEW, false);
 
     if (pViewItem)
         SetView( static_cast<SdrView *>(pViewItem->GetValue()));
