@@ -34,76 +34,74 @@
 #include <com/sun/star/xml/sax/XDocumentHandler.hpp>
 
 #include <comphelper/namedvaluecollection.hxx>
+#include <cppuhelper/implbase.hxx>
 #include <connectivity/dbtools.hxx>
 #include <tools/diagnose_ex.h>
 #include <xmloff/XMLSettingsExportContext.hxx>
 #include <xmloff/SettingsExportHelper.hxx>
 
+#include <stack>
+
 namespace dbaccess
 {
 
-    using ::com::sun::star::uno::Reference;
-    using ::com::sun::star::uno::XInterface;
-    using ::com::sun::star::uno::UNO_QUERY;
-    using ::com::sun::star::uno::UNO_QUERY_THROW;
-    using ::com::sun::star::uno::UNO_SET_THROW;
-    using ::com::sun::star::uno::Exception;
-    using ::com::sun::star::uno::RuntimeException;
-    using ::com::sun::star::uno::Any;
-    using ::com::sun::star::uno::makeAny;
-    using ::com::sun::star::uno::Sequence;
-    using ::com::sun::star::uno::Type;
-    using ::com::sun::star::uno::XComponentContext;
-    using ::com::sun::star::lang::XMultiServiceFactory;
-    using ::com::sun::star::embed::XStorage;
-    using ::com::sun::star::sdb::application::XDatabaseDocumentUI;
-    using ::com::sun::star::beans::Pair;
-    using ::com::sun::star::frame::ModuleManager;
-    using ::com::sun::star::frame::XModuleManager2;
-    using ::com::sun::star::lang::XComponent;
-    using ::com::sun::star::frame::XModel;
-    using ::com::sun::star::frame::XController;
-    using ::com::sun::star::beans::XPropertySet;
-    using ::com::sun::star::beans::PropertyValue;
-    using ::com::sun::star::document::XStorageBasedDocument;
-    using ::com::sun::star::ucb::XCommandProcessor;
-    using ::com::sun::star::container::XHierarchicalNameAccess;
-    using ::com::sun::star::sdb::XFormDocumentsSupplier;
-    using ::com::sun::star::sdb::XReportDocumentsSupplier;
-    using ::com::sun::star::xml::sax::SAXException;
-    using ::com::sun::star::xml::sax::XLocator;
-    using ::com::sun::star::xml::sax::XDocumentHandler;
-    using ::com::sun::star::xml::sax::XAttributeList;
+    using css::uno::Reference;
+    using css::uno::XInterface;
+    using css::uno::UNO_QUERY;
+    using css::uno::UNO_QUERY_THROW;
+    using css::uno::UNO_SET_THROW;
+    using css::uno::Exception;
+    using css::uno::RuntimeException;
+    using css::uno::Any;
+    using css::uno::makeAny;
+    using css::uno::Sequence;
+    using css::uno::Type;
+    using css::uno::XComponentContext;
+    using css::lang::XMultiServiceFactory;
+    using css::embed::XStorage;
+    using css::sdb::application::XDatabaseDocumentUI;
+    using css::beans::Pair;
+    using css::frame::ModuleManager;
+    using css::frame::XModuleManager2;
+    using css::lang::XComponent;
+    using css::frame::XModel;
+    using css::frame::XController;
+    using css::beans::XPropertySet;
+    using css::beans::PropertyValue;
+    using css::document::XStorageBasedDocument;
+    using css::ucb::XCommandProcessor;
+    using css::container::XHierarchicalNameAccess;
+    using css::sdb::XFormDocumentsSupplier;
+    using css::sdb::XReportDocumentsSupplier;
+    using css::xml::sax::SAXException;
+    using css::xml::sax::XLocator;
+    using css::xml::sax::XDocumentHandler;
+    using css::xml::sax::XAttributeList;
 
-    namespace ElementModes = ::com::sun::star::embed::ElementModes;
+    namespace ElementModes = css::embed::ElementModes;
+    namespace DatabaseObject = css::sdb::application::DatabaseObject;
 
     // helper
     namespace
     {
-        static const OUString& lcl_getComponentStorageBaseName( const SubComponentType i_eType )
+        static OUString lcl_getComponentStorageBaseName( const SubComponentType i_eType )
         {
-            static const OUString s_sFormBaseName( "form" );
-            static const OUString s_sReportBaseName( "report" );
-            static const OUString s_sTableBaseName( "table" );
-            static const OUString s_sQueryBaseName( "query" );
-
             switch ( i_eType )
             {
             case FORM:
-                return s_sFormBaseName;
+                return OUString("form");
             case REPORT:
-                return s_sReportBaseName;
+                return OUString("report");
             case TABLE:
-                return s_sTableBaseName;
+                return OUString("table");
             case QUERY:
-                return s_sQueryBaseName;
+                return OUString("query");
             default:
                 break;
             }
 
             OSL_FAIL( "lcl_getComponentStorageBaseName: unimplemented case!" );
-            static const OUString s_sFallback;
-            return s_sFallback;
+            return OUString();
         }
 
         static SubComponentType lcl_databaseObjectToSubComponentType( const sal_Int32 i_nObjectType )
@@ -140,7 +138,7 @@ namespace dbaccess
             const SubComponentType i_eType, const OUString& i_rName )
         {
             Reference< XController > xController( i_rAppUI, UNO_QUERY_THROW );
-            ENSURE_OR_RETURN( ( i_eType == FORM ) || ( i_eType == REPORT ), "lcl_getSubComponentDef_nothrow: illegal controller", NULL );
+            ENSURE_OR_RETURN( ( i_eType == FORM ) || ( i_eType == REPORT ), "lcl_getSubComponentDef_nothrow: illegal controller", nullptr );
 
             Reference< XCommandProcessor > xCommandProcessor;
             try
@@ -165,17 +163,8 @@ namespace dbaccess
             return xCommandProcessor;
         }
 
-        static const OUString& lcl_getSettingsStreamName()
-        {
-            static const OUString s_sStatementStreamName( "settings.xml" );
-            return s_sStatementStreamName;
-        }
-
-        static const OUString& lcl_getCurrentQueryDesignName()
-        {
-            static const OUString s_sQuerySettingsName( "ooo:current-query-design" );
-            return s_sQuerySettingsName;
-        }
+        static const char sSettingsStreamName[] = "settings.xml";
+        static const char sCurrentQueryDesignName[] = "ooo:current-query-design";
     }
 
     // SettingsExportContext
@@ -194,14 +183,14 @@ namespace dbaccess
         }
 
     public:
-        virtual void    AddAttribute( enum ::xmloff::token::XMLTokenEnum i_eName, const OUString& i_rValue );
-        virtual void    AddAttribute( enum ::xmloff::token::XMLTokenEnum i_eName, enum ::xmloff::token::XMLTokenEnum i_eValue );
-        virtual void    StartElement( enum ::xmloff::token::XMLTokenEnum i_eName, const sal_Bool i_bIgnoreWhitespace );
-        virtual void    EndElement  ( const sal_Bool i_bIgnoreWhitespace );
-        virtual void    Characters( const OUString& i_rCharacters );
+        virtual void    AddAttribute( enum ::xmloff::token::XMLTokenEnum i_eName, const OUString& i_rValue ) override;
+        virtual void    AddAttribute( enum ::xmloff::token::XMLTokenEnum i_eName, enum ::xmloff::token::XMLTokenEnum i_eValue ) override;
+        virtual void    StartElement( enum ::xmloff::token::XMLTokenEnum i_eName, const bool i_bIgnoreWhitespace ) override;
+        virtual void    EndElement  ( const bool i_bIgnoreWhitespace ) override;
+        virtual void    Characters( const OUString& i_rCharacters ) override;
 
-        virtual ::com::sun::star::uno::Reference< ::com::sun::star::uno::XComponentContext >
-                        GetComponentContext() const;
+        virtual css::uno::Reference< css::uno::XComponentContext >
+                        GetComponentContext() const override;
 
     private:
         OUString impl_prefix( const ::xmloff::token::XMLTokenEnum i_eToken )
@@ -212,7 +201,7 @@ namespace dbaccess
     private:
         const Reference<XComponentContext>&   m_rContext;
         const StorageXMLOutputStream&           m_rDelegator;
-        const OUStringBuffer             m_aNamespace;
+        const OUString m_aNamespace;
     };
 
     void SettingsExportContext::AddAttribute( enum ::xmloff::token::XMLTokenEnum i_eName, const OUString& i_rValue )
@@ -225,7 +214,7 @@ namespace dbaccess
         m_rDelegator.addAttribute( impl_prefix( i_eName ), ::xmloff::token::GetXMLToken( i_eValue ) );
     }
 
-    void SettingsExportContext::StartElement( enum ::xmloff::token::XMLTokenEnum i_eName, const sal_Bool i_bIgnoreWhitespace )
+    void SettingsExportContext::StartElement( enum ::xmloff::token::XMLTokenEnum i_eName, const bool i_bIgnoreWhitespace )
     {
         if ( i_bIgnoreWhitespace )
             m_rDelegator.ignorableWhitespace( " " );
@@ -233,7 +222,7 @@ namespace dbaccess
         m_rDelegator.startElement( impl_prefix( i_eName ) );
     }
 
-    void SettingsExportContext::EndElement( const sal_Bool i_bIgnoreWhitespace )
+    void SettingsExportContext::EndElement( const bool i_bIgnoreWhitespace )
     {
         if ( i_bIgnoreWhitespace )
             m_rDelegator.ignorableWhitespace( " " );
@@ -245,14 +234,14 @@ namespace dbaccess
         m_rDelegator.characters( i_rCharacters );
     }
 
-    Reference< com::sun::star::uno::XComponentContext > SettingsExportContext::GetComponentContext() const
+    Reference< css::uno::XComponentContext > SettingsExportContext::GetComponentContext() const
     {
         return m_rContext;
     }
 
     // SettingsDocumentHandler
-    typedef ::cppu::WeakImplHelper1 <   XDocumentHandler
-                                    >   SettingsDocumentHandler_Base;
+    typedef ::cppu::WeakImplHelper<   XDocumentHandler
+                                  >   SettingsDocumentHandler_Base;
     class DBACCESS_DLLPRIVATE SettingsDocumentHandler : public SettingsDocumentHandler_Base
     {
     public:
@@ -267,14 +256,14 @@ namespace dbaccess
 
     public:
         // XDocumentHandler
-        virtual void SAL_CALL startDocument(  ) throw (SAXException, RuntimeException);
-        virtual void SAL_CALL endDocument(  ) throw (SAXException, RuntimeException);
-        virtual void SAL_CALL startElement( const OUString& aName, const Reference< XAttributeList >& xAttribs ) throw (SAXException, RuntimeException);
-        virtual void SAL_CALL endElement( const OUString& aName ) throw (SAXException, RuntimeException);
-        virtual void SAL_CALL characters( const OUString& aChars ) throw (SAXException, RuntimeException);
-        virtual void SAL_CALL ignorableWhitespace( const OUString& aWhitespaces ) throw (SAXException, RuntimeException);
-        virtual void SAL_CALL processingInstruction( const OUString& aTarget, const OUString& aData ) throw (SAXException, RuntimeException);
-        virtual void SAL_CALL setDocumentLocator( const Reference< XLocator >& xLocator ) throw (SAXException, RuntimeException);
+        virtual void SAL_CALL startDocument(  ) throw (SAXException, RuntimeException, std::exception) override;
+        virtual void SAL_CALL endDocument(  ) throw (SAXException, RuntimeException, std::exception) override;
+        virtual void SAL_CALL startElement( const OUString& aName, const Reference< XAttributeList >& xAttribs ) throw (SAXException, RuntimeException, std::exception) override;
+        virtual void SAL_CALL endElement( const OUString& aName ) throw (SAXException, RuntimeException, std::exception) override;
+        virtual void SAL_CALL characters( const OUString& aChars ) throw (SAXException, RuntimeException, std::exception) override;
+        virtual void SAL_CALL ignorableWhitespace( const OUString& aWhitespaces ) throw (SAXException, RuntimeException, std::exception) override;
+        virtual void SAL_CALL processingInstruction( const OUString& aTarget, const OUString& aData ) throw (SAXException, RuntimeException, std::exception) override;
+        virtual void SAL_CALL setDocumentLocator( const Reference< XLocator >& xLocator ) throw (SAXException, RuntimeException, std::exception) override;
 
         const ::comphelper::NamedValueCollection&   getSettings() const { return m_aSettings; }
 
@@ -283,15 +272,15 @@ namespace dbaccess
         ::comphelper::NamedValueCollection                  m_aSettings;
     };
 
-    void SAL_CALL SettingsDocumentHandler::startDocument(  ) throw (SAXException, RuntimeException)
+    void SAL_CALL SettingsDocumentHandler::startDocument(  ) throw (SAXException, RuntimeException, std::exception)
     {
     }
 
-    void SAL_CALL SettingsDocumentHandler::endDocument(  ) throw (SAXException, RuntimeException)
+    void SAL_CALL SettingsDocumentHandler::endDocument(  ) throw (SAXException, RuntimeException, std::exception)
     {
     }
 
-    void SAL_CALL SettingsDocumentHandler::startElement( const OUString& i_Name, const Reference< XAttributeList >& i_Attribs ) throw (SAXException, RuntimeException)
+    void SAL_CALL SettingsDocumentHandler::startElement( const OUString& i_Name, const Reference< XAttributeList >& i_Attribs ) throw (SAXException, RuntimeException, std::exception)
     {
         ::rtl::Reference< SettingsImport >  pNewState;
 
@@ -322,7 +311,7 @@ namespace dbaccess
         m_aStates.push( pNewState );
     }
 
-    void SAL_CALL SettingsDocumentHandler::endElement( const OUString& i_Name ) throw (SAXException, RuntimeException)
+    void SAL_CALL SettingsDocumentHandler::endElement( const OUString& i_Name ) throw (SAXException, RuntimeException, std::exception)
     {
         ENSURE_OR_THROW( !m_aStates.empty(), "no active element" );
         (void)i_Name;
@@ -332,7 +321,7 @@ namespace dbaccess
         m_aStates.pop();
     }
 
-    void SAL_CALL SettingsDocumentHandler::characters( const OUString& i_Chars ) throw (SAXException, RuntimeException)
+    void SAL_CALL SettingsDocumentHandler::characters( const OUString& i_Chars ) throw (SAXException, RuntimeException, std::exception)
     {
         ENSURE_OR_THROW( !m_aStates.empty(), "no active element" );
 
@@ -340,20 +329,20 @@ namespace dbaccess
         pCurrentState->characters( i_Chars );
     }
 
-    void SAL_CALL SettingsDocumentHandler::ignorableWhitespace( const OUString& aWhitespaces ) throw (SAXException, RuntimeException)
+    void SAL_CALL SettingsDocumentHandler::ignorableWhitespace( const OUString& aWhitespaces ) throw (SAXException, RuntimeException, std::exception)
     {
         // ignore them - that's why they're called "ignorable"
         (void)aWhitespaces;
     }
 
-    void SAL_CALL SettingsDocumentHandler::processingInstruction( const OUString& i_Target, const OUString& i_Data ) throw (SAXException, RuntimeException)
+    void SAL_CALL SettingsDocumentHandler::processingInstruction( const OUString& i_Target, const OUString& i_Data ) throw (SAXException, RuntimeException, std::exception)
     {
         OSL_FAIL( "SettingsDocumentHandler::processingInstruction: unexpected ..." );
         (void)i_Target;
         (void)i_Data;
     }
 
-    void SAL_CALL SettingsDocumentHandler::setDocumentLocator( const Reference< XLocator >& i_Locator ) throw (SAXException, RuntimeException)
+    void SAL_CALL SettingsDocumentHandler::setDocumentLocator( const Reference< XLocator >& i_Locator ) throw (SAXException, RuntimeException, std::exception)
     {
         (void)i_Locator;
     }
@@ -361,31 +350,24 @@ namespace dbaccess
     // SubComponentRecovery
     const OUString SubComponentRecovery::getComponentsStorageName( const SubComponentType i_eType )
     {
-        static const OUString s_sFormsStorageName( "forms" );
-        static const OUString s_sReportsStorageName( "reports" );
-        static const OUString s_sTablesStorageName( "tables" );
-        static const OUString s_sQueriesStorageName( "queries" );
-        static const OUString s_sRelationsStorageName( "relations" );
-
         switch ( i_eType )
         {
         case FORM:
-            return s_sFormsStorageName;
+            return OUString("forms");
         case REPORT:
-            return s_sReportsStorageName;
+            return OUString("reports");
         case TABLE:
-            return s_sTablesStorageName;
+            return OUString("tables");
         case QUERY:
-            return s_sQueriesStorageName;
+            return OUString("queries");
         case RELATION_DESIGN:
-            return s_sRelationsStorageName;
+            return OUString("relations");
         default:
             break;
         }
 
         OSL_FAIL( "SubComponentRecovery::getComponentsStorageName: unimplemented case!" );
-        static const OUString s_sFallback;
-        return s_sFallback;
+        return OUString();
     }
 
     void SubComponentRecovery::saveToRecoveryStorage( const Reference< XStorage >& i_rRecoveryStorage,
@@ -402,7 +384,7 @@ namespace dbaccess
 
         // find a free sub storage name, and create Yet Another Sub Storage
         const OUString& rBaseName( lcl_getComponentStorageBaseName( m_eType ) );
-        const OUString sStorName = ::dbtools::createUniqueName( xComponentsStorage.get(), rBaseName, true );
+        const OUString sStorName = ::dbtools::createUniqueName( xComponentsStorage.get(), rBaseName );
         const Reference< XStorage > xObjectStor( xComponentsStorage->openStorageElement(
             sStorName, ElementModes::READWRITE ), UNO_QUERY_THROW );
 
@@ -481,7 +463,7 @@ namespace dbaccess
             break;
         }
 
-        OSL_POSTCOND( m_eType != UNKNOWN,
+        SAL_WARN_IF( m_eType == UNKNOWN, "dbaccess",
             "SubComponentRecovery::impl_identifyComponent_throw: couldn't classify the component!" );
     }
 
@@ -497,7 +479,7 @@ namespace dbaccess
         OSL_VERIFY( xDesignerProps->getPropertyValue( "CurrentQueryDesign" ) >>= aCurrentQueryDesign );
 
         // write the query design
-        StorageXMLOutputStream aDesignOutput( m_rContext, i_rObjectStorage, lcl_getSettingsStreamName() );
+        StorageXMLOutputStream aDesignOutput( m_rContext, i_rObjectStorage, sSettingsStreamName );
         SettingsExportContext aSettingsExportContext( m_rContext, aDesignOutput );
 
         const OUString sWhitespace( " " );
@@ -506,7 +488,7 @@ namespace dbaccess
         aDesignOutput.ignorableWhitespace( sWhitespace );
 
         XMLSettingsExportHelper aSettingsExporter( aSettingsExportContext );
-        aSettingsExporter.exportAllSettings( aCurrentQueryDesign, lcl_getCurrentQueryDesignName() );
+        aSettingsExporter.exportAllSettings( aCurrentQueryDesign, sCurrentQueryDesignName );
 
         aDesignOutput.ignorableWhitespace( sWhitespace );
         aDesignOutput.endElement();
@@ -578,13 +560,13 @@ namespace dbaccess
         Reference< XComponent > xSubComponent;
 
         // first read the settings query design settings from the storage
-        StorageXMLInputStream aDesignInput( m_rContext, i_rRecoveryStorage, lcl_getSettingsStreamName() );
+        StorageXMLInputStream aDesignInput( m_rContext, i_rRecoveryStorage, sSettingsStreamName );
 
         ::rtl::Reference< SettingsDocumentHandler > pDocHandler( new SettingsDocumentHandler );
         aDesignInput.import( pDocHandler.get() );
 
         const ::comphelper::NamedValueCollection& rSettings( pDocHandler->getSettings() );
-        const Any aCurrentQueryDesign = rSettings.get( lcl_getCurrentQueryDesignName() );
+        const Any aCurrentQueryDesign = rSettings.get( sCurrentQueryDesignName );
 #if OSL_DEBUG_LEVEL > 0
         Sequence< PropertyValue > aQueryDesignLayout;
         OSL_VERIFY( aCurrentQueryDesign >>= aQueryDesignLayout );
