@@ -53,7 +53,7 @@
 #include <connectivity/dbtools.hxx>
 
 #include <boost/optional.hpp>
-#include <boost/scoped_ptr.hpp>
+#include <memory>
 
 namespace dbaxml
 {
@@ -68,14 +68,14 @@ namespace dbaxml
     public:
         static OUString SAL_CALL getImplementationName_Static(  ) throw (RuntimeException);
         static Sequence< OUString > SAL_CALL getSupportedServiceNames_Static(  ) throw(RuntimeException);
-        static Reference< XInterface > SAL_CALL Create(const Reference< ::com::sun::star::lang::XMultiServiceFactory >&);
+        static Reference< XInterface > SAL_CALL Create(const Reference< css::lang::XMultiServiceFactory >&);
     };
     class ODBFullExportHelper
     {
     public:
         static OUString SAL_CALL getImplementationName_Static(  ) throw (RuntimeException);
         static Sequence< OUString > SAL_CALL getSupportedServiceNames_Static(  ) throw(RuntimeException);
-        static Reference< XInterface > SAL_CALL Create(const Reference< ::com::sun::star::lang::XMultiServiceFactory >&);
+        static Reference< XInterface > SAL_CALL Create(const Reference< css::lang::XMultiServiceFactory >&);
     };
 }
 
@@ -104,7 +104,7 @@ namespace dbaxml
 
     Reference< XInterface > SAL_CALL ODBExportHelper::Create(const Reference< XMultiServiceFactory >& _rxORB)
     {
-        return static_cast< XServiceInfo* >(new ODBExport(comphelper::getComponentContext(_rxORB),EXPORT_SETTINGS | EXPORT_PRETTY ));
+        return static_cast< XServiceInfo* >(new ODBExport(comphelper::getComponentContext(_rxORB), getImplementationName_Static(), SvXMLExportFlags::SETTINGS | SvXMLExportFlags::PRETTY ));
     }
 
     OUString SAL_CALL ODBExportHelper::getImplementationName_Static(  ) throw (RuntimeException)
@@ -114,14 +114,13 @@ namespace dbaxml
 
     Sequence< OUString > SAL_CALL ODBExportHelper::getSupportedServiceNames_Static(  ) throw(RuntimeException)
     {
-        Sequence< OUString > aSupported(1);
-        aSupported[0] = "com.sun.star.document.ExportFilter";
+        Sequence< OUString > aSupported { "com.sun.star.document.ExportFilter" };
         return aSupported;
     }
 
     Reference< XInterface > SAL_CALL ODBFullExportHelper::Create(const Reference< XMultiServiceFactory >& _rxORB)
     {
-        return static_cast< XServiceInfo* >(new ODBExport(comphelper::getComponentContext(_rxORB),EXPORT_ALL));
+        return static_cast< XServiceInfo* >(new ODBExport(comphelper::getComponentContext(_rxORB), getImplementationName_Static(), SvXMLExportFlags::ALL));
     }
     OUString SAL_CALL ODBFullExportHelper::getImplementationName_Static(  ) throw (RuntimeException)
     {
@@ -129,8 +128,7 @@ namespace dbaxml
     }
     Sequence< OUString > SAL_CALL ODBFullExportHelper::getSupportedServiceNames_Static(  ) throw(RuntimeException)
     {
-        Sequence< OUString > aSupported(1);
-        aSupported[0] = "com.sun.star.document.ExportFilter";
+        Sequence< OUString > aSupported { "com.sun.star.document.ExportFilter" };
         return aSupported;
     }
 
@@ -167,7 +165,7 @@ namespace dbaxml
     class OSpecialHandleXMLExportPropertyMapper : public SvXMLExportPropertyMapper
     {
     public:
-        OSpecialHandleXMLExportPropertyMapper(const rtl::Reference< XMLPropertySetMapper >& rMapper) : SvXMLExportPropertyMapper(rMapper )
+        explicit OSpecialHandleXMLExportPropertyMapper(const rtl::Reference< XMLPropertySetMapper >& rMapper) : SvXMLExportPropertyMapper(rMapper )
         {
         }
         /** this method is called for every item that has the
@@ -178,14 +176,14 @@ namespace dbaxml
                 const SvXMLUnitConverter& /*rUnitConverter*/,
                 const SvXMLNamespaceMap& /*rNamespaceMap*/,
                 const ::std::vector< XMLPropertyState > * /*pProperties*/ ,
-                sal_uInt32 /*nIdx*/ ) const SAL_OVERRIDE
+                sal_uInt32 /*nIdx*/ ) const override
         {
             // nothing to do here
         }
     };
-ODBExport::ODBExport(const Reference< XComponentContext >& _rxContext,sal_uInt16 nExportFlag)
-: SvXMLExport( util::MeasureUnit::MM_10TH, _rxContext, getImplementationName_Static(), XML_DATABASE,
-        EXPORT_OASIS | nExportFlag)
+ODBExport::ODBExport(const Reference< XComponentContext >& _rxContext, OUString const & implementationName, SvXMLExportFlags nExportFlag)
+: SvXMLExport( util::MeasureUnit::MM_10TH, _rxContext, implementationName, XML_DATABASE,
+        SvXMLExportFlags::OASIS | nExportFlag)
 ,m_aTypeCollection(_rxContext)
 ,m_bAllreadyFilled(false)
 {
@@ -198,19 +196,19 @@ ODBExport::ODBExport(const Reference< XComponentContext >& _rxContext,sal_uInt16
 
     _GetNamespaceMap().Add( GetXMLToken(XML_NP_DB), GetXMLToken(XML_N_DB_OASIS), XML_NAMESPACE_DB );
 
-    if( (nExportFlag & (EXPORT_STYLES|EXPORT_MASTERSTYLES|EXPORT_AUTOSTYLES|EXPORT_FONTDECLS) ) != 0 )
+    if( nExportFlag & (SvXMLExportFlags::STYLES|SvXMLExportFlags::MASTERSTYLES|SvXMLExportFlags::AUTOSTYLES|SvXMLExportFlags::FONTDECLS) )
         _GetNamespaceMap().Add( GetXMLToken(XML_NP_FO), GetXMLToken(XML_N_FO_COMPAT), XML_NAMESPACE_FO );
 
-    if( (nExportFlag & (EXPORT_META|EXPORT_STYLES|EXPORT_MASTERSTYLES|EXPORT_AUTOSTYLES|EXPORT_CONTENT|EXPORT_SCRIPTS|EXPORT_SETTINGS) ) != 0 )
+    if( nExportFlag & (SvXMLExportFlags::META|SvXMLExportFlags::STYLES|SvXMLExportFlags::MASTERSTYLES|SvXMLExportFlags::AUTOSTYLES|SvXMLExportFlags::CONTENT|SvXMLExportFlags::SCRIPTS|SvXMLExportFlags::SETTINGS) )
     {
         _GetNamespaceMap().Add( GetXMLToken(XML_NP_XLINK), GetXMLToken(XML_N_XLINK), XML_NAMESPACE_XLINK );
     }
-    if( (nExportFlag & EXPORT_SETTINGS) != 0 )
+    if( nExportFlag & SvXMLExportFlags::SETTINGS )
     {
         _GetNamespaceMap().Add( GetXMLToken(XML_NP_CONFIG), GetXMLToken(XML_N_CONFIG), XML_NAMESPACE_CONFIG );
     }
 
-    if( (nExportFlag & (EXPORT_STYLES|EXPORT_MASTERSTYLES|EXPORT_AUTOSTYLES|EXPORT_CONTENT|EXPORT_FONTDECLS) ) != 0 )
+    if( nExportFlag & (SvXMLExportFlags::STYLES|SvXMLExportFlags::MASTERSTYLES|SvXMLExportFlags::AUTOSTYLES|SvXMLExportFlags::CONTENT|SvXMLExportFlags::FONTDECLS) )
     {
         _GetNamespaceMap().Add( GetXMLToken(XML_NP_STYLE), GetXMLToken(XML_N_STYLE), XML_NAMESPACE_STYLE );
     }
@@ -258,15 +256,14 @@ OUString ODBExport::getImplementationName_Static()
 css::uno::Sequence<OUString> ODBExport::getSupportedServiceNames_Static()
     throw (css::uno::RuntimeException)
 {
-    css::uno::Sequence<OUString> s(1);
-    s[0] = "com.sun.star.document.ExportFilter";
+    css::uno::Sequence<OUString> s { "com.sun.star.document.ExportFilter" };
     return s;
 }
 
-::com::sun::star::uno::Reference< ::com::sun::star::uno::XInterface >
-    SAL_CALL ODBExport::Create(const ::com::sun::star::uno::Reference< ::com::sun::star::lang::XMultiServiceFactory >& _rxORB)
+css::uno::Reference< css::uno::XInterface >
+    SAL_CALL ODBExport::Create(const css::uno::Reference< css::lang::XMultiServiceFactory >& _rxORB)
 {
-    return static_cast< XServiceInfo* >(new ODBExport( comphelper::getComponentContext(_rxORB)));
+    return static_cast< XServiceInfo* >(new ODBExport( comphelper::getComponentContext(_rxORB), getImplementationName_Static()));
 }
 
 void ODBExport::exportDataSource()
@@ -615,36 +612,13 @@ void ODBExport::exportConnectionData()
                         Reference< XPropertySet > xDataSourceSettings( xProp->getPropertyValue( PROPERTY_SETTINGS ), UNO_QUERY_THROW );
                         Reference< XPropertySetInfo > xSettingsInfo( xDataSourceSettings->getPropertySetInfo(), UNO_SET_THROW );
 
-                        struct PropertyMap
-                        {
-                            const sal_Char* pAsciiPropertyName;
-                            sal_uInt16      nAttributeId;
 
-                            PropertyMap( const sal_Char* _pAsciiPropertyName, const sal_uInt16 _nAttributeId )
-                                :pAsciiPropertyName( _pAsciiPropertyName )
-                                ,nAttributeId( _nAttributeId )
-                            {
-                            }
-                        };
-                        PropertyMap aProperties[] =
+                        const OUString sPropertyName = "LocalSocket";
+                        if ( xSettingsInfo->hasPropertyByName( sPropertyName ) )
                         {
-                            PropertyMap( "LocalSocket", XML_LOCAL_SOCKET )
-                            //PropertyMap( "NamedPipe", 0 /* TODO */ )
-                        };
-
-                        for (   size_t i=0;
-                                i < sizeof( aProperties ) / sizeof( aProperties[0] );
-                                ++i
-                            )
-                        {
-                            const OUString sPropertyName = OUString::createFromAscii( aProperties[i].pAsciiPropertyName );
-                            if ( xSettingsInfo->hasPropertyByName( sPropertyName ) )
-                            {
-                                OUString sPropertyValue;
-                                if ( ( xDataSourceSettings->getPropertyValue( sPropertyName ) >>= sPropertyValue ) && !sPropertyValue.isEmpty() )
-                                    AddAttribute( XML_NAMESPACE_DB, XML_LOCAL_SOCKET, sPropertyValue );
-
-                            }
+                            OUString sPropertyValue;
+                            if ( ( xDataSourceSettings->getPropertyValue( sPropertyName ) >>= sPropertyValue ) && !sPropertyValue.isEmpty() )
+                                AddAttribute( XML_NAMESPACE_DB, XML_LOCAL_SOCKET, sPropertyValue );
                         }
                     }
                     catch( const Exception& )
@@ -833,7 +807,7 @@ void ODBExport::exportCollection(const Reference< XNameAccess >& _xCollection
 {
     if ( _xCollection.is() )
     {
-        boost::scoped_ptr<SvXMLElementExport> pComponents;
+        std::unique_ptr<SvXMLElementExport> pComponents;
         if ( _bExportContext )
             pComponents.reset( new SvXMLElementExport(*this,XML_NAMESPACE_DB, _eComponents, true, true));
         Sequence< OUString> aSeq = _xCollection->getElementNames();
@@ -1113,7 +1087,7 @@ void ODBExport::exportQueries(bool _bExportContext)
             Reference< XNameAccess > xCollection = xSup->getQueryDefinitions();
             if ( xCollection.is() && xCollection->hasElements() )
             {
-                boost::scoped_ptr< ::comphelper::mem_fun1_t<ODBExport,XPropertySet* > > pMemFunc;
+                std::unique_ptr< ::comphelper::mem_fun1_t<ODBExport,XPropertySet* > > pMemFunc;
                 if ( _bExportContext )
                     pMemFunc.reset( new ::comphelper::mem_fun1_t<ODBExport,XPropertySet* >(&ODBExport::exportQuery) );
                 else
@@ -1133,7 +1107,7 @@ void ODBExport::exportTables(bool _bExportContext)
         Reference< XNameAccess > xCollection = xSup->getTables();
         if ( xCollection.is() && xCollection->hasElements() )
         {
-            boost::scoped_ptr< ::comphelper::mem_fun1_t<ODBExport,XPropertySet* > > pMemFunc;
+            std::unique_ptr< ::comphelper::mem_fun1_t<ODBExport,XPropertySet* > > pMemFunc;
             if ( _bExportContext )
                 pMemFunc.reset( new ::comphelper::mem_fun1_t<ODBExport,XPropertySet* >(&ODBExport::exportTable) );
             else
@@ -1225,7 +1199,7 @@ void ODBExport::exportAutoStyle(XPropertySet* _xProp)
                                 break;
                             case CTF_DB_COLUMN_TEXT_ALIGN:
                                 if ( !aItr->maValue.hasValue() )
-                                    aItr->maValue <<= ::com::sun::star::awt::TextAlign::LEFT;
+                                    aItr->maValue <<= css::awt::TextAlign::LEFT;
                                 break;
                         }
                     }
@@ -1258,7 +1232,7 @@ void ODBExport::_ExportMasterStyles()
 void ODBExport::_ExportAutoStyles()
 {
     // there are no styles that require their own autostyles
-    if ( getExportFlags() & EXPORT_CONTENT )
+    if ( getExportFlags() & SvXMLExportFlags::CONTENT )
     {
         collectComponentStyles();
         GetAutoStylePool()->exportXML(XML_STYLE_FAMILY_TABLE_TABLE
