@@ -43,7 +43,7 @@
 #include <unotools/ucbhelper.hxx>
 #include "dlgsave.hxx"
 #include <comphelper/types.hxx>
-#include <vcl/msgbox.hxx>
+#include <vcl/layout.hxx>
 #include <cppuhelper/typeprovider.hxx>
 #include <cppuhelper/exc_hlp.hxx>
 #include <connectivity/dbexception.hxx>
@@ -68,6 +68,7 @@
 #include "dbexchange.hxx"
 #include "UITools.hxx"
 #include <algorithm>
+#include <iterator>
 #include <svtools/treelistbox.hxx>
 #include <com/sun/star/sdb/XReportDocumentsSupplier.hpp>
 #include <com/sun/star/sdb/XFormDocumentsSupplier.hpp>
@@ -155,7 +156,7 @@ void OApplicationController::deleteTables(const ::std::vector< OUString>& _rList
                         if(e.TargetException >>= aSql)
                             aErrorInfo = aSql;
                         else
-                            OSL_FAIL("OApplicationController::implDropTable: something strange happended!");
+                            OSL_FAIL("OApplicationController::implDropTable: something strange happened!");
                     }
                     catch( const Exception& )
                     {
@@ -175,8 +176,8 @@ void OApplicationController::deleteTables(const ::std::vector< OUString>& _rList
         else
         {
             OUString sMessage(ModuleRes(STR_MISSING_TABLES_XDROP));
-            ErrorBox aError(getView(), WB_OK, sMessage);
-            aError.Execute();
+            ScopedVclPtrInstance< MessageDialog > aError(getView(), sMessage);
+            aError->Execute();
         }
     }
 }
@@ -188,7 +189,7 @@ void OApplicationController::deleteObjects( ElementType _eType, const ::std::vec
     if ( xNames.is() )
     {
         OString sDialogPosition;
-        svtools::QueryDeleteResult_Impl eResult = _bConfirm ? svtools::QUERYDELETE_YES : svtools::QUERYDELETE_ALL;
+        short eResult = _bConfirm ? svtools::QUERYDELETE_YES : svtools::QUERYDELETE_ALL;
 
         // The list of elements to delete is allowed to contain related elements: A given element may
         // be the ancestor or child of another element from the list.
@@ -210,20 +211,19 @@ void OApplicationController::deleteObjects( ElementType _eType, const ::std::vec
 
             if ( eResult != svtools::QUERYDELETE_ALL )
             {
-                svtools::QueryDeleteDlg_Impl aDlg( getView(), *aThisRound );
+                ScopedVclPtrInstance< svtools::QueryDeleteDlg_Impl > aDlg(getView(), *aThisRound);
 
                 if ( !sDialogPosition.isEmpty() )
-                    aDlg.SetWindowState( sDialogPosition );
+                    aDlg->SetWindowState( sDialogPosition );
 
                 if ( nObjectsLeft > 1 )
-                    aDlg.EnableAllButton();
+                    aDlg->EnableAllButton();
 
-                if ( aDlg.Execute() == RET_OK )
-                    eResult = aDlg.GetResult();
-                else
+                eResult = aDlg->Execute();
+                if (eResult == svtools::QUERYDELETE_CANCEL)
                     return;
 
-                sDialogPosition = aDlg.GetWindowState( );
+                sDialogPosition = aDlg->GetWindowState( );
             }
 
             bool bSuccess = false;
@@ -233,7 +233,7 @@ void OApplicationController::deleteObjects( ElementType _eType, const ::std::vec
                     ||  ( eResult == svtools::QUERYDELETE_YES );
 
             if  (   bUserConfirmedDelete
-                &&  (   ( _eType == E_QUERY ) ? m_pSubComponentManager->closeSubFrames( *aThisRound, _eType ) : true )
+                &&  (   _eType != E_QUERY || m_pSubComponentManager->closeSubFrames( *aThisRound, _eType ) )
                 )
             {
                 try
@@ -245,7 +245,7 @@ void OApplicationController::deleteObjects( ElementType _eType, const ::std::vec
 
                     bSuccess = true;
 
-                    // now that we removed the element, care for all it's child elements
+                    // now that we removed the element, care for all its child elements
                     // which may also be a part of the list
                     // #i33353#
                     OSL_ENSURE( aThisRound->getLength() - 1 >= 0, "OApplicationController::deleteObjects: empty name?" );
@@ -273,7 +273,7 @@ void OApplicationController::deleteObjects( ElementType _eType, const ::std::vec
                     if ( e.TargetException >>= aSql )
                         showError( SQLExceptionInfo( e.TargetException ) );
                     else
-                        OSL_FAIL( "OApplicationController::deleteObjects: something strange happended!" );
+                        OSL_FAIL( "OApplicationController::deleteObjects: something strange happened!" );
                 }
                 catch( const Exception& )
                 {
@@ -330,7 +330,7 @@ const SharedConnection& OApplicationController::ensureConnection( ::dbtools::SQL
     // because every access (read *or* write) to  m_xDataSourceConnection
     // is mutexed.
     // See http://www.cs.umd.edu/~pugh/java/memoryModel/DoubleCheckedLocking.html
-    // for what I'm refering to.
+    // for what I'm referring to.
     // We cannot use the TLS (thread-local storage) solution
     // since support for TLS is not up to the snuff on Windows :-(
 
@@ -410,15 +410,15 @@ const SharedConnection& OApplicationController::ensureConnection( ::dbtools::SQL
     return m_xDataSourceConnection;
 }
 
-sal_Bool OApplicationController::isDataSourceReadOnly() const
+bool OApplicationController::isDataSourceReadOnly() const
 {
     Reference<XStorable> xStore(m_xModel,UNO_QUERY);
     return !xStore.is() || xStore->isReadonly();
 }
 
-sal_Bool OApplicationController::isConnectionReadOnly() const
+bool OApplicationController::isConnectionReadOnly() const
 {
-    sal_Bool bIsConnectionReadOnly = sal_True;
+    bool bIsConnectionReadOnly = true;
     if ( m_xMetaData.is() )
     {
         try
@@ -457,7 +457,7 @@ Reference< XNameAccess > OApplicationController::getElements( ElementType _eType
 
         case E_QUERY:
         {
-            xElements.set( getQueryDefintions(), UNO_QUERY_THROW );
+            xElements.set( getQueryDefinitions(), UNO_QUERY_THROW );
         }
         break;
 
@@ -493,8 +493,7 @@ void OApplicationController::getSelectionElementNames(::std::vector< OUString>&
     getContainer()->getSelectionElementNames( _rNames );
 }
 
-SAL_WNODEPRECATED_DECLARATIONS_PUSH
-::std::auto_ptr< OLinkedDocumentsAccess > OApplicationController::getDocumentsAccess( ElementType _eType )
+::std::unique_ptr< OLinkedDocumentsAccess > OApplicationController::getDocumentsAccess( ElementType _eType )
 {
     OSL_ENSURE( ( _eType == E_TABLE ) || ( _eType == E_QUERY ) || ( _eType == E_FORM ) || ( _eType == E_REPORT ),
         "OApplicationController::getDocumentsAccess: only forms and reports are supported here!" );
@@ -502,20 +501,18 @@ SAL_WNODEPRECATED_DECLARATIONS_PUSH
     SharedConnection xConnection( ensureConnection() );
     Reference< XNameAccess > xDocContainer;
 
-    if ( ( _eType == E_FORM ) | ( _eType == E_REPORT ) )
+    if ( ( _eType == E_FORM ) || ( _eType == E_REPORT ) )
     {
         xDocContainer.set( getElements( _eType ) );
         OSL_ENSURE( xDocContainer.is(), "OApplicationController::getDocumentsAccess: invalid container!" );
     }
 
-    ::std::auto_ptr< OLinkedDocumentsAccess > pDocuments( new OLinkedDocumentsAccess(
+    ::std::unique_ptr< OLinkedDocumentsAccess > pDocuments( new OLinkedDocumentsAccess(
         getView(), this, getORB(), xDocContainer, xConnection, getDatabaseName()
     ) );
     return pDocuments;
 }
 
-SAL_WNODEPRECATED_DECLARATIONS_POP
-
 TransferableHelper* OApplicationController::copyObject()
 {
     try
@@ -524,7 +521,7 @@ TransferableHelper* OApplicationController::copyObject()
         ::osl::MutexGuard aGuard( getMutex() );
 
         ElementType eType = getContainer()->getElementType();
-        TransferableHelper* pData = NULL;
+        TransferableHelper* pData = nullptr;
         switch( eType )
         {
             case E_TABLE:
@@ -535,7 +532,7 @@ TransferableHelper* OApplicationController::copyObject()
                 if ( xConnection.is() )
                     xMetaData = xConnection->getMetaData();
 
-                OUString sName = getContainer()->getQualifiedName( NULL );
+                OUString sName = getContainer()->getQualifiedName( nullptr );
                 if ( !sName.isEmpty() )
                 {
                     OUString sDataSource = getDatabaseName();
@@ -568,7 +565,7 @@ TransferableHelper* OApplicationController::copyObject()
                 break;
         }
 
-        // the owner ship goes to ODataClipboards
+        // the ownership goes to ODataClipboards
         return pData;
     }
     catch(const SQLException&)
@@ -579,10 +576,10 @@ TransferableHelper* OApplicationController::copyObject()
     {
         DBG_UNHANDLED_EXCEPTION();
     }
-    return NULL;
+    return nullptr;
 }
 
-sal_Bool OApplicationController::paste( ElementType _eType,const ::svx::ODataAccessDescriptor& _rPasteData,const OUString& _sParentFolder ,sal_Bool _bMove)
+bool OApplicationController::paste( ElementType _eType, const svx::ODataAccessDescriptor& _rPasteData, const OUString& _sParentFolder, bool _bMove)
 {
     try
     {
@@ -597,14 +594,14 @@ sal_Bool OApplicationController::paste( ElementType _eType,const ::svx::ODataAcc
                 // read all necessary data
 
                 OUString sCommand;
-                sal_Bool bEscapeProcessing = sal_True;
+                bool bEscapeProcessing = true;
 
                 _rPasteData[daCommand] >>= sCommand;
                 if ( _rPasteData.has(daEscapeProcessing) )
                     _rPasteData[daEscapeProcessing] >>= bEscapeProcessing;
 
                 // plausibility check
-                sal_Bool bValidDescriptor = sal_False;
+                bool bValidDescriptor = false;
                 OUString sDataSourceName = _rPasteData.getDataSource();
                 if (CommandType::QUERY == nCommandType)
                     bValidDescriptor = sDataSourceName.getLength() && sCommand.getLength();
@@ -613,7 +610,7 @@ sal_Bool OApplicationController::paste( ElementType _eType,const ::svx::ODataAcc
                 if (!bValidDescriptor)
                 {
                     OSL_FAIL("OApplicationController::paste: invalid descriptor!");
-                    return sal_False;
+                    return false;
                 }
 
                 // the target object name (as we'll suggest it to the user)
@@ -628,8 +625,8 @@ sal_Bool OApplicationController::paste( ElementType _eType,const ::svx::ODataAcc
                         OUString sDefaultName = OUString( ModuleRes( STR_QRY_TITLE ) );
                         sDefaultName = sDefaultName.getToken( 0, ' ' );
 
-                        Reference< XNameAccess > xQueries( getQueryDefintions(), UNO_QUERY_THROW );
-                        sTargetName = ::dbtools::createUniqueName( xQueries, sDefaultName, sal_False );
+                        Reference< XNameAccess > xQueries( getQueryDefinitions(), UNO_QUERY_THROW );
+                        sTargetName = ::dbtools::createUniqueName( xQueries, sDefaultName, false );
                     }
                 }
                 catch(const Exception&)
@@ -641,12 +638,12 @@ sal_Bool OApplicationController::paste( ElementType _eType,const ::svx::ODataAcc
                 if (CommandType::QUERY == nCommandType)
                 {
                     // need to extract the statement and the escape processing flag from the query object
-                    sal_Bool bSuccess = sal_False;
+                    bool bSuccess = false;
                     try
                     {
                         // the concrete query
                         Reference< XQueryDefinitionsSupplier > xSourceQuerySup(
-                            getDataSourceByName( sDataSourceName, getView(), getORB(), NULL ),
+                            getDataSourceByName( sDataSourceName, getView(), getORB(), nullptr ),
                             UNO_QUERY_THROW );
                         Reference< XNameAccess > xQueries( xSourceQuerySup->getQueryDefinitions(), UNO_SET_THROW );
                         if ( xQueries->hasByName( sCommand ) )
@@ -665,16 +662,16 @@ sal_Bool OApplicationController::paste( ElementType _eType,const ::svx::ODataAcc
                     {
                         OSL_FAIL("OApplicationController::paste: could not extract the source query object!");
                         // TODO: maybe this is worth an error message to be displayed to the user ....
-                        return sal_False;
+                        return false;
                     }
                 }
 
-                Reference< XNameContainer > xDestQueries(getQueryDefintions(), UNO_QUERY);
+                Reference< XNameContainer > xDestQueries(getQueryDefinitions(), UNO_QUERY);
                 Reference< XSingleServiceFactory > xQueryFactory(xDestQueries, UNO_QUERY);
                 if (!xQueryFactory.is())
                 {
                     OSL_FAIL("OApplicationController::paste: invalid destination query container!");
-                    return sal_False;
+                    return false;
                 }
 
                 // here we have everything needed to create a new query object ...
@@ -690,17 +687,18 @@ sal_Bool OApplicationController::paste( ElementType _eType,const ::svx::ODataAcc
                                                 has a /table/ with that name) */
                 if ( bNeedAskForName )
                 {
-                    OSaveAsDlg aAskForName( getView(),
+                    ScopedVclPtrInstance<OSaveAsDlg> aAskForName(
+                                            getView(),
                                             CommandType::QUERY,
                                             getORB(),
                                             getConnection(),
                                             sTargetName,
                                             aNameChecker,
-                                            SAD_ADDITIONAL_DESCRIPTION | SAD_TITLE_PASTE_AS);
-                    if ( RET_OK != aAskForName.Execute() )
+                                            SAD_ADDITIONAL_DESCRIPTION | SAD_TITLE_PASTE_AS );
+                    if ( RET_OK != aAskForName->Execute() )
                         // cancelled by the user
-                        return sal_False;
-                    sTargetName = aAskForName.getName();
+                        return false;
+                    sTargetName = aAskForName->getName();
                 }
 
                 // create a new object
@@ -749,7 +747,7 @@ sal_Bool OApplicationController::paste( ElementType _eType,const ::svx::ODataAcc
             }
             else
                 OSL_TRACE("There should be a sequence in it!");
-            return sal_True;
+            return true;
         }
         else if ( _rPasteData.has(daComponent) ) // forms or reports
         {
@@ -763,10 +761,10 @@ sal_Bool OApplicationController::paste( ElementType _eType,const ::svx::ODataAcc
     {
         DBG_UNHANDLED_EXCEPTION();
     }
-    return sal_False;
+    return false;
 }
 
-Reference<XNameContainer> OApplicationController::getQueryDefintions() const
+Reference<XNameContainer> OApplicationController::getQueryDefinitions() const
 {
     Reference<XQueryDefinitionsSupplier> xSet(m_xDataSource,UNO_QUERY);
     Reference<XNameContainer> xNames;
@@ -777,31 +775,31 @@ Reference<XNameContainer> OApplicationController::getQueryDefintions() const
     return xNames;
 }
 
-void OApplicationController::getSupportedFormats(ElementType _eType,::std::vector<SotFormatStringId>& _rFormatIds) const
+void OApplicationController::getSupportedFormats(ElementType _eType,::std::vector<SotClipboardFormatId>& _rFormatIds)
 {
     switch( _eType )
     {
         case E_TABLE:
-            _rFormatIds.push_back(SOT_FORMATSTR_ID_DBACCESS_TABLE);
-            _rFormatIds.push_back(SOT_FORMAT_RTF);
-            _rFormatIds.push_back(SOT_FORMATSTR_ID_HTML);
+            _rFormatIds.push_back(SotClipboardFormatId::DBACCESS_TABLE);
+            _rFormatIds.push_back(SotClipboardFormatId::RTF);
+            _rFormatIds.push_back(SotClipboardFormatId::HTML);
             // run through
         case E_QUERY:
-            _rFormatIds.push_back(SOT_FORMATSTR_ID_DBACCESS_QUERY);
+            _rFormatIds.push_back(SotClipboardFormatId::DBACCESS_QUERY);
             break;
         default:
             break;
     }
 }
 
-sal_Bool OApplicationController::isTableFormat()  const
+bool OApplicationController::isTableFormat()  const
 {
-    return m_aTableCopyHelper.isTableFormat(getViewClipboard());
+    return OTableCopyHelper::isTableFormat(getViewClipboard());
 }
 
-IMPL_LINK( OApplicationController, OnAsyncDrop, void*, /*NOTINTERESTEDIN*/ )
+IMPL_LINK_NOARG_TYPED( OApplicationController, OnAsyncDrop, void*, void )
 {
-    m_nAsyncDrop = 0;
+    m_nAsyncDrop = nullptr;
     SolarMutexGuard aSolarGuard;
     ::osl::MutexGuard aGuard( getMutex() );
 
@@ -831,8 +829,6 @@ IMPL_LINK( OApplicationController, OnAsyncDrop, void*, /*NOTINTERESTEDIN*/ )
     }
 
     m_aAsyncDrop.aDroppedData.clear();
-
-    return 0L;
 }
 
 }   // namespace dbaui
