@@ -17,6 +17,10 @@
  *   the License at http://www.apache.org/licenses/LICENSE-2.0 .
  */
 
+#include <sal/config.h>
+
+#include <memory>
+
 #include "unodatbr.hxx"
 #include "browserids.hxx"
 #include "listviewitems.hxx"
@@ -100,9 +104,9 @@ SbaTableQueryBrowser::EntryType SbaTableQueryBrowser::getEntryType( const SvTree
     return etQueryContainer;
 }
 
-void SbaTableQueryBrowser::select(SvTreeListEntry* _pEntry, sal_Bool _bSelect)
+void SbaTableQueryBrowser::select(SvTreeListEntry* _pEntry, bool _bSelect)
 {
-    SvLBoxItem* pTextItem = _pEntry ? _pEntry->GetFirstItem(SV_ITEM_ID_BOLDLBSTRING) : NULL;
+    SvLBoxItem* pTextItem = _pEntry ? _pEntry->GetFirstItem(SV_ITEM_ID_BOLDLBSTRING) : nullptr;
     if (pTextItem)
     {
         static_cast<OBoldListboxString*>(pTextItem)->emphasize(_bSelect);
@@ -113,7 +117,7 @@ void SbaTableQueryBrowser::select(SvTreeListEntry* _pEntry, sal_Bool _bSelect)
     }
 }
 
-void SbaTableQueryBrowser::selectPath(SvTreeListEntry* _pEntry, sal_Bool _bSelect)
+void SbaTableQueryBrowser::selectPath(SvTreeListEntry* _pEntry, bool _bSelect)
 {
     while (_pEntry)
     {
@@ -122,15 +126,15 @@ void SbaTableQueryBrowser::selectPath(SvTreeListEntry* _pEntry, sal_Bool _bSelec
     }
 }
 
-sal_Bool SbaTableQueryBrowser::isSelected(SvTreeListEntry* _pEntry) const
+bool SbaTableQueryBrowser::isSelected(SvTreeListEntry* _pEntry)
 {
-    SvLBoxItem* pTextItem = _pEntry ? _pEntry->GetFirstItem(SV_ITEM_ID_BOLDLBSTRING) : NULL;
+    SvLBoxItem* pTextItem = _pEntry ? _pEntry->GetFirstItem(SV_ITEM_ID_BOLDLBSTRING) : nullptr;
     if (pTextItem)
         return static_cast<OBoldListboxString*>(pTextItem)->isEmphasized();
     else {
         OSL_FAIL("SbaTableQueryBrowser::isSelected: invalid entry!");
     }
-    return sal_False;
+    return false;
 }
 
 void SbaTableQueryBrowser::SelectionChanged()
@@ -175,15 +179,15 @@ sal_Int32 SbaTableQueryBrowser::getDatabaseObjectType( EntryType _eType )
     {
     case etQuery:
     case etQueryContainer:
-        return DatabaseObject::QUERY;
+        return css::sdb::application::DatabaseObject::QUERY;
     case etTableOrView:
     case etTableContainer:
-        return DatabaseObject::TABLE;
+        return css::sdb::application::DatabaseObject::TABLE;
     default:
         break;
     }
     OSL_FAIL( "SbaTableQueryBrowser::getDatabaseObjectType: folder types and 'Unknown' not allowed here!" );
-    return DatabaseObject::TABLE;
+    return css::sdb::application::DatabaseObject::TABLE;
 }
 
 void SbaTableQueryBrowser::notifyHiContrastChanged()
@@ -202,19 +206,19 @@ void SbaTableQueryBrowser::notifyHiContrastChanged()
             }
 
             // the connection to which this entry belongs, if any
-            ::std::auto_ptr< ImageProvider > pImageProvider( getImageProviderFor( pEntryLoop ) );
+            std::unique_ptr< ImageProvider > pImageProvider( getImageProviderFor( pEntryLoop ) );
 
             // the images for this entry
             Image aImage;
             if ( pData->eType == etDatasource )
-                aImage = pImageProvider->getDatabaseImage();
+                aImage = ImageProvider::getDatabaseImage();
             else
             {
                 bool bIsFolder = !isObject( pData->eType );
                 if ( bIsFolder )
                 {
                     sal_Int32 nObjectType( getDatabaseObjectType( pData->eType ) );
-                    aImage = pImageProvider->getFolderImage( nObjectType );
+                    aImage = ImageProvider::getFolderImage( nObjectType );
                 }
                 else
                 {
@@ -227,14 +231,14 @@ void SbaTableQueryBrowser::notifyHiContrastChanged()
             sal_uInt16 nCount = pEntryLoop->ItemCount();
             for (sal_uInt16 i=0;i<nCount;++i)
             {
-                SvLBoxItem* pItem = pEntryLoop->GetItem(i);
-                if (!pItem || pItem->GetType() != SV_ITEM_ID_LBOXCONTEXTBMP)
+                SvLBoxItem& rItem = pEntryLoop->GetItem(i);
+                if (rItem.GetType() != SV_ITEM_ID_LBOXCONTEXTBMP)
                     continue;
 
-                SvLBoxContextBmp* pContextBitmapItem = static_cast< SvLBoxContextBmp* >( pItem );
+                SvLBoxContextBmp& rContextBitmapItem = static_cast< SvLBoxContextBmp& >( rItem );
 
-                pContextBitmapItem->SetBitmap1( aImage );
-                pContextBitmapItem->SetBitmap2( aImage );
+                rContextBitmapItem.SetBitmap1( aImage );
+                rContextBitmapItem.SetBitmap2( aImage );
                 break;
             }
 
