@@ -45,6 +45,10 @@
 #include "UITools.hxx"
 #include "commontypes.hxx"
 
+#include <com/sun/star/ui/XSidebarProvider.hpp>
+#include <sfx2/sidebar/UnoSidebar.hxx>
+
+
 #include <vcl/waitobj.hxx>
 #include <svl/urihelper.hxx>
 #include "datasourceconnector.hxx"
@@ -53,12 +57,10 @@
 #include <com/sun/star/frame/status/Visibility.hpp>
 #include <com/sun/star/util/XModifiable.hpp>
 #include <rtl/ustring.hxx>
-#include <algorithm>
-#include <o3tl/compat_functional.hxx>
-#include <boost/scoped_ptr.hpp>
-#include <boost/unordered_map.hpp>
+#include <o3tl/functional.hxx>
 #include <cppuhelper/implbase1.hxx>
 #include <limits>
+#include <unordered_map>
 
 using namespace ::com::sun::star;
 using namespace ::com::sun::star::uno;
@@ -72,6 +74,7 @@ using namespace ::com::sun::star::sdbc;
 using namespace ::com::sun::star::sdb;
 using namespace ::com::sun::star::task;
 using namespace ::com::sun::star::awt;
+using namespace ::com::sun::star::ui;
 using namespace ::dbtools;
 using namespace ::comphelper;
 
@@ -79,14 +82,7 @@ using namespace ::comphelper;
 #define FIRST_USER_DEFINED_FEATURE  ( ::std::numeric_limits< sal_uInt16 >::max() - 1000 )
 #define LAST_USER_DEFINED_FEATURE   ( ::std::numeric_limits< sal_uInt16 >::max()        )
 
-typedef ::boost::unordered_map< sal_Int16, sal_Int16 > CommandHashMap;
-typedef ::std::list< DispatchInformation > DispatchInfoList;
-
-const OUString& getConfirmDeletionURL()
-{
-    static const OUString sConfirmDeletionURL(  ".uno:FormSlots/ConfirmDeletion" );
-    return sConfirmDeletionURL;
-}
+typedef std::unordered_map< sal_Int16, sal_Int16 > CommandHashMap;
 
 namespace dbaui
 {
@@ -95,13 +91,13 @@ namespace dbaui
 class UserDefinedFeatures
 {
 public:
-    UserDefinedFeatures( const Reference< XController >& _rxController );
+    explicit UserDefinedFeatures( const Reference< XController >& _rxController );
 
-    FeatureState    getState( const URL& _rFeatureURL );
+    static FeatureState getState( const URL& _rFeatureURL );
     void            execute( const URL& _rFeatureURL, const Sequence< PropertyValue>& _rArgs );
 
 private:
-    ::com::sun::star::uno::WeakReference< XController > m_aController;
+    css::uno::WeakReference< XController > m_aController;
 };
 
 UserDefinedFeatures::UserDefinedFeatures( const Reference< XController >& _rxController )
@@ -123,11 +119,11 @@ void UserDefinedFeatures::execute( const URL& _rFeatureURL, const Sequence< Prop
 {
     try
     {
-        Reference< XController > xController( (Reference< XController >)m_aController, UNO_SET_THROW );
+        Reference< XController > xController( Reference< XController >(m_aController), UNO_SET_THROW );
         Reference< XDispatchProvider > xDispatchProvider( xController->getFrame(), UNO_QUERY_THROW );
         Reference< XDispatch > xDispatch( xDispatchProvider->queryDispatch(
             _rFeatureURL,
-            OUString( "_self" ),
+            "_self",
             FrameSearchFlag::AUTO
         ) );
 
@@ -162,7 +158,7 @@ struct OGenericUnoController_Data
 // OGenericUnoController
 OGenericUnoController::OGenericUnoController(const Reference< XComponentContext >& _rM)
     :OGenericUnoController_Base( getMutex() )
-    ,m_pView(NULL)
+    ,m_pView(nullptr)
 #ifdef DBG_UTIL
     ,m_bDescribingSupportedFeatures( false )
 #endif
@@ -226,7 +222,7 @@ OGenericUnoController::~OGenericUnoController()
 
 }
 
-bool OGenericUnoController::Construct(Window* /*pParent*/)
+bool OGenericUnoController::Construct(vcl::Window* /*pParent*/)
 {
     OSL_ENSURE( getView(), "the view is NULL!" );
 
@@ -249,17 +245,16 @@ bool OGenericUnoController::Construct(Window* /*pParent*/)
     {
         SAL_WARN("dbaccess.ui","OGenericUnoController::Construct: could not create (or start listening at) the database context!");
         // at least notify the user. Though the whole component does not make any sense without the database context ...
-        ShowServiceNotAvailableError(getView(), OUString("com.sun.star.sdb.DatabaseContext"), true);
+        ShowServiceNotAvailableError(getView(), "com.sun.star.sdb.DatabaseContext", true);
     }
 
     return true;
 }
 
-IMPL_LINK_NOARG(OGenericUnoController, OnAsyncInvalidateAll)
+IMPL_LINK_NOARG_TYPED(OGenericUnoController, OnAsyncInvalidateAll, void*, void)
 {
     if ( !OGenericUnoController_Base::rBHelper.bInDispose && !OGenericUnoController_Base::rBHelper.bDisposed )
         InvalidateFeature_Impl();
-    return 0L;
 }
 
 void OGenericUnoController::impl_initialize()
@@ -280,11 +275,11 @@ void SAL_CALL OGenericUnoController::initialize( const Sequence< Any >& aArgumen
 
     for ( ; pIter != pEnd; ++pIter )
     {
-        if ( ( *pIter >>= aValue ) && aValue.Name.equalsAscii( "Frame" ) )
+        if ( ( *pIter >>= aValue ) && aValue.Name == "Frame" )
         {
             xFrame.set(aValue.Value,UNO_QUERY_THROW);
         }
-        else if ( ( *pIter >>= aValue ) && aValue.Name.equalsAscii( "Preview" ) )
+        else if ( ( *pIter >>= aValue ) && aValue.Name == "Preview" )
         {
             aValue.Value >>= m_bPreview;
             m_bReadOnly = true;
@@ -297,7 +292,7 @@ void SAL_CALL OGenericUnoController::initialize( const Sequence< Any >& aArgumen
 
         xParent = xFrame->getContainerWindow();
         VCLXWindow* pParentComponent = VCLXWindow::GetImplementation(xParent);
-        Window* pParentWin = pParentComponent ? pParentComponent->GetWindow() : NULL;
+        VclPtr< vcl::Window > pParentWin = pParentComponent ? pParentComponent->GetWindow() : VclPtr< vcl::Window >();
         if (!pParentWin)
         {
             throw IllegalArgumentException("Parent window is null", *this, 1 );
@@ -318,8 +313,7 @@ void SAL_CALL OGenericUnoController::initialize( const Sequence< Any >& aArgumen
     catch(Exception&)
     {
         // no one clears my view if I won't
-        boost::scoped_ptr<Window> aTemp(m_pView);
-        m_pView = NULL;
+        m_pView = nullptr;
         throw;
     }
 }
@@ -370,10 +364,16 @@ void OGenericUnoController::modified(const EventObject& aEvent) throw( RuntimeEx
 
 Reference< XWindow > SAL_CALL OGenericUnoController::getComponentWindow() throw (RuntimeException, std::exception)
 {
+    SolarMutexGuard g;
     return VCLUnoHelper::GetInterface( getView() );
 }
 
-OUString SAL_CALL OGenericUnoController::getViewControllerName() throw (::com::sun::star::uno::RuntimeException, std::exception)
+Reference<XSidebarProvider> SAL_CALL OGenericUnoController::getSidebar() throw (RuntimeException, std::exception)
+{
+        return nullptr;
+}
+
+OUString SAL_CALL OGenericUnoController::getViewControllerName() throw (css::uno::RuntimeException, std::exception)
 {
     return OUString( "Default" );
 }
@@ -400,23 +400,6 @@ void OGenericUnoController::attachFrame( const Reference< XFrame >& _rxFrame ) t
         getView()->attachFrame( xFrame );
 }
 
-struct CommandCollector : public ::std::unary_function< SupportedFeatures::value_type, void>
-{
-    sal_uInt16  m_nFeature;
-    StringBag&  m_rFeatureCommands;
-    CommandCollector( sal_uInt16 _nFeature, StringBag& _rFeatureCommands )
-        :m_nFeature        ( _nFeature         )
-        ,m_rFeatureCommands( _rFeatureCommands )
-    {
-    }
-
-    void operator() ( const SupportedFeatures::value_type& lhs )
-    {
-        if ( lhs.second.nFeatureId == m_nFeature )
-            m_rFeatureCommands.insert( lhs.first );
-    }
-};
-
 namespace
 {
     typedef ::std::vector< Any >    States;
@@ -479,7 +462,7 @@ void OGenericUnoController::ImplBroadcastFeatureState(const OUString& _rFeature,
     aEvent.FeatureURL.Complete = _rFeature;
     if (m_xUrlTransformer.is())
         m_xUrlTransformer->parseStrict(aEvent.FeatureURL);
-    aEvent.Source       = (XDispatch*)this;
+    aEvent.Source       = static_cast<XDispatch*>(this);
     aEvent.IsEnabled    = aFeatState.bEnabled;
 
     // collect all states to be notified
@@ -492,11 +475,11 @@ void OGenericUnoController::ImplBroadcastFeatureState(const OUString& _rFeature,
     else
     {   // no -> iterate through all listeners responsible for the URL
         StringBag aFeatureCommands;
-        ::std::for_each(
-            m_aSupportedFeatures.begin(),
-            m_aSupportedFeatures.end(),
-            CommandCollector( nFeat, aFeatureCommands )
-        );
+        for( const auto& rFeature : m_aSupportedFeatures )
+        {
+            if( rFeature.second.nFeatureId == nFeat )
+                aFeatureCommands.insert( rFeature.first );
+        }
 
         // it is possible that listeners are registered or revoked while
         // we are notifying them, so we must use a copy of m_arrStatusListener, not
@@ -530,11 +513,6 @@ bool OGenericUnoController::isFeatureSupported( sal_Int32 _nId )
     return ( m_aSupportedFeatures.end() != aFeaturePos && !aFeaturePos->first.isEmpty());
 }
 
-void OGenericUnoController::InvalidateFeature(const OUString& _rURLPath, const Reference< XStatusListener > & _xListener, bool _bForceBroadcast)
-{
-    ImplInvalidateFeature( m_aSupportedFeatures[ _rURLPath ].nFeatureId, _xListener, _bForceBroadcast );
-}
-
 void OGenericUnoController::InvalidateFeature_Impl()
 {
 #ifdef DBG_UTIL
@@ -628,7 +606,7 @@ void OGenericUnoController::InvalidateFeature(sal_uInt16 _nId, const Reference<
 
 void OGenericUnoController::InvalidateAll()
 {
-    ImplInvalidateFeature( ALL_FEATURES, NULL, true );
+    ImplInvalidateFeature( ALL_FEATURES, nullptr, true );
 }
 
 void OGenericUnoController::InvalidateAll_Impl()
@@ -639,7 +617,7 @@ void OGenericUnoController::InvalidateAll_Impl()
             aIter != m_aSupportedFeatures.end();
             ++aIter
         )
-        ImplBroadcastFeatureState( aIter->first, NULL, true );
+        ImplBroadcastFeatureState( aIter->first, nullptr, true );
 
     {
         ::osl::MutexGuard aGuard( m_aFeatureMutex);
@@ -659,7 +637,7 @@ Reference< XDispatch >  OGenericUnoController::queryDispatch(const URL& aURL, co
         fillSupportedFeatures();
 
     // URL's we can handle ourself?
-    if  (   aURL.Complete.equals( getConfirmDeletionURL() )
+    if  (   aURL.Complete == ".uno:FormSlots/ConfirmDeletion"
         ||  (   ( m_aSupportedFeatures.find( aURL.Complete ) != m_aSupportedFeatures.end() )
             &&  !isUserDefinedFeature( aURL.Complete )
             )
@@ -697,7 +675,7 @@ Sequence< Reference< XDispatch > > OGenericUnoController::queryDispatches(const
     return aReturn;
 }
 
-Reference< XDispatchProvider >  OGenericUnoController::getSlaveDispatchProvider(void) throw( RuntimeException, std::exception )
+Reference< XDispatchProvider >  OGenericUnoController::getSlaveDispatchProvider() throw( RuntimeException, std::exception )
 {
     return m_xSlaveDispatcher;
 }
@@ -707,7 +685,7 @@ void OGenericUnoController::setSlaveDispatchProvider(const Reference< XDispatchP
     m_xSlaveDispatcher = _xNewProvider;
 }
 
-Reference< XDispatchProvider >  OGenericUnoController::getMasterDispatchProvider(void) throw( RuntimeException, std::exception )
+Reference< XDispatchProvider >  OGenericUnoController::getMasterDispatchProvider() throw( RuntimeException, std::exception )
 {
     return m_xMasterDispatcher;
 }
@@ -816,7 +794,7 @@ void OGenericUnoController::disposing()
         m_arrStatusListener.clear();
     }
 
-    m_xDatabaseContext = NULL;
+    m_xDatabaseContext = nullptr;
     {
         ::osl::MutexGuard aGuard( m_aFeatureMutex);
         m_aAsyncInvalidateAll.CancelCall();
@@ -828,10 +806,10 @@ void OGenericUnoController::disposing()
     // check out from all the objects we are listening
     // the frame
     stopFrameListening( m_aCurrentFrame.getFrame() );
-    m_aCurrentFrame.attachFrame( NULL );
+    m_aCurrentFrame.attachFrame( nullptr );
 
-    m_xMasterDispatcher = NULL;
-    m_xSlaveDispatcher = NULL;
+    m_xMasterDispatcher = nullptr;
+    m_xSlaveDispatcher = nullptr;
     m_xTitleHelper.clear();
     m_xUrlTransformer.clear();
     m_aInitParameters.clear();
@@ -898,7 +876,7 @@ FeatureState OGenericUnoController::GetState( sal_uInt16 _nId ) const
             aReturn.bEnabled = true;
             break;
         default:
-            aReturn = m_pData->m_aUserDefinedFeatures.getState( getURLForId( _nId ) );
+            aReturn = UserDefinedFeatures::getState( getURLForId( _nId ) );
             break;
     }
 
@@ -935,7 +913,7 @@ URL OGenericUnoController::getURLForId(sal_Int32 _nId) const
     return aReturn;
 }
 
-bool OGenericUnoController::isUserDefinedFeature( const sal_uInt16 _nFeatureId ) const
+bool OGenericUnoController::isUserDefinedFeature( const sal_uInt16 _nFeatureId )
 {
     return ( _nFeatureId >= FIRST_USER_DEFINED_FEATURE ) && ( _nFeatureId < LAST_USER_DEFINED_FEATURE );
 }
@@ -994,12 +972,22 @@ Reference< XConnection > OGenericUnoController::connect( const OUString& _rDataS
     return xConnection;
 }
 
+void OGenericUnoController::setView( const VclPtr<ODataView> &i_rView )
+{
+    m_pView = i_rView;
+}
+
+void OGenericUnoController::clearView()
+{
+    m_pView = nullptr;
+}
+
 void OGenericUnoController::showError(const SQLExceptionInfo& _rInfo)
 {
     ::dbaui::showError(_rInfo,getView(),getORB());
 }
 
-Reference< XLayoutManager > OGenericUnoController::getLayoutManager(const Reference< XFrame >& _xFrame) const
+Reference< XLayoutManager > OGenericUnoController::getLayoutManager(const Reference< XFrame >& _xFrame)
 {
     Reference< XPropertySet > xPropSet( _xFrame, UNO_QUERY );
     Reference< XLayoutManager > xLayoutManager;
@@ -1022,8 +1010,8 @@ void OGenericUnoController::loadMenu(const Reference< XFrame >& _xFrame)
     if ( xLayoutManager.is() )
     {
         xLayoutManager->lock();
-        xLayoutManager->createElement( OUString( "private:resource/menubar/menubar" ));
-        xLayoutManager->createElement( OUString( "private:resource/toolbar/toolbar" ));
+        xLayoutManager->createElement( "private:resource/menubar/menubar" );
+        xLayoutManager->createElement( "private:resource/toolbar/toolbar" );
         xLayoutManager->unlock();
         xLayoutManager->doLayout();
     }
@@ -1041,7 +1029,7 @@ void OGenericUnoController::closeTask()
     m_aAsyncCloseTask.Call();
 }
 
-IMPL_LINK_NOARG(OGenericUnoController, OnAsyncCloseTask)
+IMPL_LINK_NOARG_TYPED(OGenericUnoController, OnAsyncCloseTask, void*, void)
 {
     if ( !OGenericUnoController_Base::rBHelper.bInDispose )
     {
@@ -1055,10 +1043,9 @@ IMPL_LINK_NOARG(OGenericUnoController, OnAsyncCloseTask)
             DBG_UNHANDLED_EXCEPTION();
         }
     }
-    return 0L;
 }
 
-Any SAL_CALL OGenericUnoController::getViewData(void) throw( RuntimeException, std::exception )
+Any SAL_CALL OGenericUnoController::getViewData() throw( RuntimeException, std::exception )
 {
     return Any();
 }
@@ -1067,12 +1054,12 @@ void SAL_CALL OGenericUnoController::restoreViewData(const Any& /*Data*/) throw(
 {
 }
 
-Reference< XModel > SAL_CALL OGenericUnoController::getModel(void) throw( RuntimeException, std::exception )
+Reference< XModel > SAL_CALL OGenericUnoController::getModel() throw( RuntimeException, std::exception )
 {
     return Reference< XModel >();
 }
 
-Reference< XFrame > SAL_CALL OGenericUnoController::getFrame(void) throw( RuntimeException, std::exception )
+Reference< XFrame > SAL_CALL OGenericUnoController::getFrame() throw( RuntimeException, std::exception )
 {
     ::osl::MutexGuard aGuard( getMutex() );
     return m_aCurrentFrame.getFrame();
@@ -1119,7 +1106,7 @@ namespace
 {
     OUString lcl_getModuleHelpModuleName( const Reference< XFrame >& _rxFrame )
     {
-        const sal_Char* pReturn = NULL;
+        const sal_Char* pReturn = nullptr;
 
         try
         {
@@ -1137,7 +1124,7 @@ namespace
 
                 Reference< XFrame > xParentFrame;
                 if ( _rxFrame.is() )
-                    xParentFrame = xParentFrame.query( _rxFrame->getCreator() );
+                    xParentFrame.set(_rxFrame->getCreator(), css::uno::UNO_QUERY);
                 // did we find a parent frame? Which is no top-level frame?
                 if ( xParentFrame.is() && !_rxFrame->isTop() )
                     // TODO: to prevent framework assertions, re-insert this "isTop" once 98303 is fixed
@@ -1191,21 +1178,21 @@ namespace
                 // could not determine the document type we're living in
                 // ->fallback
                 SvtModuleOptions aModOpt;
-                if ( aModOpt.IsModuleInstalled( SvtModuleOptions::E_SWRITER ) )
+                if ( aModOpt.IsModuleInstalled( SvtModuleOptions::EModule::WRITER ) )
                     pReturn = "swriter";
-                else if ( aModOpt.IsModuleInstalled( SvtModuleOptions::E_SDATABASE ) )
+                else if ( aModOpt.IsModuleInstalled( SvtModuleOptions::EModule::DATABASE ) )
                     pReturn = "sdatabase";
-                else if ( aModOpt.IsModuleInstalled( SvtModuleOptions::E_SCALC ) )
+                else if ( aModOpt.IsModuleInstalled( SvtModuleOptions::EModule::CALC ) )
                     pReturn = "scalc";
-                else if ( aModOpt.IsModuleInstalled( SvtModuleOptions::E_SIMPRESS ) )
+                else if ( aModOpt.IsModuleInstalled( SvtModuleOptions::EModule::IMPRESS ) )
                     pReturn = "simpress";
-                else if ( aModOpt.IsModuleInstalled( SvtModuleOptions::E_SDRAW ) )
+                else if ( aModOpt.IsModuleInstalled( SvtModuleOptions::EModule::DRAW ) )
                     pReturn = "sdraw";
-                else if ( aModOpt.IsModuleInstalled( SvtModuleOptions::E_SMATH ) )
+                else if ( aModOpt.IsModuleInstalled( SvtModuleOptions::EModule::MATH ) )
                     pReturn = "smath";
-                else if ( aModOpt.IsModuleInstalled( SvtModuleOptions::E_SCHART ) )
+                else if ( aModOpt.IsModuleInstalled( SvtModuleOptions::EModule::CHART ) )
                     pReturn = "schart";
-                else if ( aModOpt.IsModuleInstalled( SvtModuleOptions::E_SBASIC ) )
+                else if ( aModOpt.IsModuleInstalled( SvtModuleOptions::EModule::BASIC ) )
                     pReturn = "sbasic";
                 else
                 {
@@ -1256,7 +1243,7 @@ void OGenericUnoController::openHelpAgent( const URL& _rURL )
         Reference< XDispatchProvider > xDispProv( m_aCurrentFrame.getFrame(), UNO_QUERY );
         Reference< XDispatch > xHelpDispatch;
         if ( xDispProv.is() )
-            xHelpDispatch = xDispProv->queryDispatch(aURL, OUString( "_helpagent" ), FrameSearchFlag::PARENT | FrameSearchFlag::SELF);
+            xHelpDispatch = xDispProv->queryDispatch(aURL, "_helpagent", FrameSearchFlag::PARENT | FrameSearchFlag::SELF);
         OSL_ENSURE(xHelpDispatch.is(), "SbaTableQueryBrowser::openHelpAgent: could not get a dispatcher!");
         if (xHelpDispatch.is())
         {
@@ -1271,7 +1258,7 @@ void OGenericUnoController::openHelpAgent( const URL& _rURL )
 
 Reference< awt::XWindow> OGenericUnoController::getTopMostContainerWindow() const
 {
-    Reference< ::com::sun::star::awt::XWindow> xWindow;
+    Reference< css::awt::XWindow> xWindow;
 
     // get the top most window
     Reference< XFrame > xFrame( m_aCurrentFrame.getFrame() );
@@ -1389,7 +1376,7 @@ sal_uInt16 OGenericUnoController::registerCommandURL( const OUString& _rComplete
     if ( aIter != m_aSupportedFeatures.end() )
         return aIter->second.nFeatureId;
 
-    // this is a previously unkwnon command
+    // this is a previously unknown command
     sal_uInt16 nFeatureId = FIRST_USER_DEFINED_FEATURE;
     while ( isFeatureSupported( nFeatureId ) && ( nFeatureId < LAST_USER_DEFINED_FEATURE ) )
         ++nFeatureId;
@@ -1456,14 +1443,7 @@ Sequence< ::sal_Int16 > SAL_CALL OGenericUnoController::getSupportedCommandGroup
         if ( aIter->second.GroupId != CommandGroup::INTERNAL )
             aCmdHashMap.insert( CommandHashMap::value_type( aIter->second.GroupId, 0 ));
 
-    Sequence< sal_Int16 > aCommandGroups( aCmdHashMap.size() );
-    ::std::transform( aCmdHashMap.begin(),
-        aCmdHashMap.end(),
-        aCommandGroups.getArray(),
-        ::o3tl::select1st< CommandHashMap::value_type >()
-    );
-
-    return aCommandGroups;
+    return comphelper::mapKeysToSequence( aCmdHashMap );
 }
 
 namespace
@@ -1478,7 +1458,7 @@ namespace
 
 Sequence< DispatchInformation > SAL_CALL OGenericUnoController::getConfigurableDispatchInformation( ::sal_Int16 CommandGroup ) throw (RuntimeException, std::exception)
 {
-    DispatchInfoList    aInformationList;
+    ::std::list< DispatchInformation > aInformationList;
     DispatchInformation aDispatchInfo;
     for (   SupportedFeatures::const_iterator aIter = m_aSupportedFeatures.begin();
             aIter != m_aSupportedFeatures.end();
@@ -1513,7 +1493,7 @@ void OGenericUnoController::fillSupportedFeatures()
 #endif
 }
 
-void SAL_CALL OGenericUnoController::dispose() throw(::com::sun::star::uno::RuntimeException, std::exception)
+void SAL_CALL OGenericUnoController::dispose() throw(css::uno::RuntimeException, std::exception)
 {
     SolarMutexGuard aSolarGuard;
     OGenericUnoController_Base::dispose();
