@@ -20,7 +20,6 @@
 #include "WColumnSelect.hxx"
 #include "dbu_misc.hrc"
 #include <osl/diagnose.h>
-#include "WizardPages.hrc"
 #include "WCopyTable.hxx"
 #include <com/sun/star/sdbcx/XDataDescriptorFactory.hpp>
 #include <com/sun/star/sdbcx/XColumnsSupplier.hpp>
@@ -31,7 +30,6 @@
 #include <com/sun/star/sdb/application/CopyTableOperation.hpp>
 #include "dbustrings.hrc"
 #include <functional>
-#include <o3tl/compat_functional.hxx>
 
 using namespace ::com::sun::star::uno;
 using namespace ::com::sun::star::beans;
@@ -44,22 +42,26 @@ namespace CopyTableOperation = ::com::sun::star::sdb::application::CopyTableOper
 
 OUString OWizColumnSelect::GetTitle() const { return ModuleRes(STR_WIZ_COLUMN_SELECT_TITEL); }
 
-OWizardPage::OWizardPage( Window* pParent, const ResId& rResId )
-    : TabPage(pParent,rResId)
-    ,m_pParent(static_cast<OCopyTableWizard*>(pParent))
-    ,m_bFirstTime(true)
-{
-}
-
-OWizardPage::OWizardPage(Window* pParent, const OString& rID, const OUString& rUIXMLDescription)
+OWizardPage::OWizardPage(vcl::Window* pParent, const OString& rID, const OUString& rUIXMLDescription)
     : TabPage(pParent, rID, rUIXMLDescription)
      ,m_pParent(static_cast<OCopyTableWizard*>(pParent))
      ,m_bFirstTime(true)
 {
 }
 
+OWizardPage::~OWizardPage()
+{
+    disposeOnce();
+}
+
+void OWizardPage::dispose()
+{
+    m_pParent.clear();
+    TabPage::dispose();
+}
+
 // OWizColumnSelect
-OWizColumnSelect::OWizColumnSelect( Window* pParent)
+OWizColumnSelect::OWizColumnSelect( vcl::Window* pParent)
     :OWizardPage( pParent, "ApplyColPage", "dbaccess/ui/applycolpage.ui")
 {
     get(m_pOrgColumnNames, "from");
@@ -88,6 +90,11 @@ OWizColumnSelect::OWizColumnSelect( Window* pParent)
 }
 
 OWizColumnSelect::~OWizColumnSelect()
+{
+    disposeOnce();
+}
+
+void OWizColumnSelect::dispose()
 {
     while ( m_pNewColumnNames->GetEntryCount() )
     {
@@ -98,6 +105,13 @@ OWizColumnSelect::~OWizColumnSelect()
         m_pNewColumnNames->RemoveEntry(0);
     }
     m_pNewColumnNames->Clear();
+    m_pOrgColumnNames.clear();
+    m_pColumn_RH.clear();
+    m_pColumns_RH.clear();
+    m_pColumn_LH.clear();
+    m_pColumns_LH.clear();
+    m_pNewColumnNames.clear();
+    OWizardPage::dispose();
 }
 
 void OWizColumnSelect::Reset()
@@ -108,13 +122,13 @@ void OWizColumnSelect::Reset()
     m_pParent->m_mNameMapping.clear();
 
     // insert the source columns in the left listbox
-    const ODatabaseExport::TColumnVector* pSrcColumns = m_pParent->getSrcVector();
-    ODatabaseExport::TColumnVector::const_iterator aIter = pSrcColumns->begin();
-    ODatabaseExport::TColumnVector::const_iterator aEnd = pSrcColumns->end();
+    const ODatabaseExport::TColumnVector& rSrcColumns = m_pParent->getSrcVector();
+    ODatabaseExport::TColumnVector::const_iterator aIter = rSrcColumns.begin();
+    ODatabaseExport::TColumnVector::const_iterator aEnd = rSrcColumns.end();
 
     for(;aIter != aEnd;++aIter)
     {
-        sal_uInt16 nPos = m_pOrgColumnNames->InsertEntry((*aIter)->first);
+        const sal_Int32 nPos = m_pOrgColumnNames->InsertEntry((*aIter)->first);
         m_pOrgColumnNames->SetEntryData(nPos,(*aIter)->second);
     }
 
@@ -127,18 +141,18 @@ void OWizColumnSelect::Reset()
 void OWizColumnSelect::ActivatePage( )
 {
     // if there are no dest columns reset the left side with the origibnal columns
-    if(m_pParent->getDestColumns()->empty())
+    if(m_pParent->getDestColumns().empty())
         Reset();
 
     clearListBox(*m_pNewColumnNames);
 
-    const ODatabaseExport::TColumnVector* pDestColumns = m_pParent->getDestVector();
+    const ODatabaseExport::TColumnVector& rDestColumns = m_pParent->getDestVector();
 
-    ODatabaseExport::TColumnVector::const_iterator aIter = pDestColumns->begin();
-    ODatabaseExport::TColumnVector::const_iterator aEnd = pDestColumns->end();
+    ODatabaseExport::TColumnVector::const_iterator aIter = rDestColumns.begin();
+    ODatabaseExport::TColumnVector::const_iterator aEnd = rDestColumns.end();
     for(;aIter != aEnd;++aIter)
     {
-        sal_uInt16 nPos = m_pNewColumnNames->InsertEntry((*aIter)->first);
+        const sal_Int32 nPos = m_pNewColumnNames->InsertEntry((*aIter)->first);
         m_pNewColumnNames->SetEntryData(nPos,new OFieldDescription(*((*aIter)->second)));
         m_pOrgColumnNames->RemoveEntry((*aIter)->first);
     }
@@ -152,7 +166,7 @@ bool OWizColumnSelect::LeavePage()
 
     m_pParent->clearDestColumns();
 
-    for(sal_uInt16 i=0 ; i< m_pNewColumnNames->GetEntryCount();++i)
+    for(sal_Int32 i=0 ; i< m_pNewColumnNames->GetEntryCount();++i)
     {
         OFieldDescription* pField = static_cast<OFieldDescription*>(m_pNewColumnNames->GetEntryData(i));
         OSL_ENSURE(pField,"The field information can not be null!");
@@ -164,15 +178,15 @@ bool OWizColumnSelect::LeavePage()
     if  (   m_pParent->GetPressedButton() == OCopyTableWizard::WIZARD_NEXT
         ||  m_pParent->GetPressedButton() == OCopyTableWizard::WIZARD_FINISH
         )
-        return m_pParent->getDestColumns()->size() != 0;
+        return m_pParent->getDestColumns().size() != 0;
     else
         return true;
 }
 
-IMPL_LINK( OWizColumnSelect, ButtonClickHdl, Button *, pButton )
+IMPL_LINK_TYPED( OWizColumnSelect, ButtonClickHdl, Button *, pButton, void )
 {
-    ListBox *pLeft = NULL;
-    ListBox *pRight = NULL;
+    ListBox *pLeft = nullptr;
+    ListBox *pRight = nullptr;
     bool bAll = false;
 
     if (pButton == m_pColumn_RH)
@@ -197,7 +211,9 @@ IMPL_LINK( OWizColumnSelect, ButtonClickHdl, Button *, pButton )
         pRight = m_pOrgColumnNames;
         bAll   = true;
     }
-    // else ????
+
+    if (!pLeft || !pRight)
+        return;
 
     Reference< XDatabaseMetaData > xMetaData( m_pParent->m_xDestConnection->getMetaData() );
     OUString sExtraChars = xMetaData->getExtraNameCharacters();
@@ -209,33 +225,31 @@ IMPL_LINK( OWizColumnSelect, ButtonClickHdl, Button *, pButton )
 
     if(!bAll)
     {
-        for(sal_uInt16 i=0; i < pLeft->GetSelectEntryCount(); ++i)
+        for(sal_Int32 i=0; i < pLeft->GetSelectEntryCount(); ++i)
             moveColumn(pRight,pLeft,aRightColumns,pLeft->GetSelectEntry(i),sExtraChars,nMaxNameLen,aCase);
 
-        for(sal_uInt16 j=pLeft->GetSelectEntryCount(); j ; --j)
+        for(sal_Int32 j=pLeft->GetSelectEntryCount(); j ; --j)
             pLeft->RemoveEntry(pLeft->GetSelectEntry(j-1));
     }
     else
     {
-        sal_uInt16 nEntries = pLeft->GetEntryCount();
-        for(sal_uInt16 i=0; i < nEntries; ++i)
+        const sal_Int32 nEntries = pLeft->GetEntryCount();
+        for(sal_Int32 i=0; i < nEntries; ++i)
             moveColumn(pRight,pLeft,aRightColumns,pLeft->GetEntry(i),sExtraChars,nMaxNameLen,aCase);
-        for(sal_uInt16 j=pLeft->GetEntryCount(); j ; --j)
-            pLeft->RemoveEntry(j-1);
+        for(sal_Int32 j=pLeft->GetEntryCount(); j ; )
+            pLeft->RemoveEntry(--j);
     }
 
     enableButtons();
 
     if(m_pOrgColumnNames->GetEntryCount())
         m_pOrgColumnNames->SelectEntryPos(0);
-
-    return 0;
 }
 
-IMPL_LINK( OWizColumnSelect, ListDoubleClickHdl, ListBox *, pListBox )
+IMPL_LINK_TYPED( OWizColumnSelect, ListDoubleClickHdl, ListBox&, rListBox, void )
 {
     ListBox *pLeft,*pRight;
-    if(pListBox == m_pOrgColumnNames)
+    if(&rListBox == m_pOrgColumnNames)
     {
         pLeft  = m_pOrgColumnNames;
         pRight = m_pNewColumnNames;
@@ -255,13 +269,12 @@ IMPL_LINK( OWizColumnSelect, ListDoubleClickHdl, ListBox *, pListBox )
     ::std::vector< OUString> aRightColumns;
     fillColumns(pRight,aRightColumns);
 
-    for(sal_uInt16 i=0; i < pLeft->GetSelectEntryCount(); ++i)
+    for(sal_Int32 i=0; i < pLeft->GetSelectEntryCount(); ++i)
         moveColumn(pRight,pLeft,aRightColumns,pLeft->GetSelectEntry(i),sExtraChars,nMaxNameLen,aCase);
-    for(sal_uInt16 j=pLeft->GetSelectEntryCount(); j ; --j)
-        pLeft->RemoveEntry(pLeft->GetSelectEntry(j-1));
+    for(sal_Int32 j=pLeft->GetSelectEntryCount(); j ; )
+        pLeft->RemoveEntry(pLeft->GetSelectEntry(--j));
 
     enableButtons();
-    return 0;
 }
 
 void OWizColumnSelect::clearListBox(ListBox& _rListBox)
@@ -273,9 +286,9 @@ void OWizColumnSelect::clearListBox(ListBox& _rListBox)
 
 void OWizColumnSelect::fillColumns(ListBox* pRight,::std::vector< OUString> &_rRightColumns)
 {
-    sal_uInt16 nCount = pRight->GetEntryCount();
+    const sal_Int32 nCount = pRight->GetEntryCount();
     _rRightColumns.reserve(nCount);
-    for(sal_uInt16 i=0; i < nCount;++i)
+    for(sal_Int32 i=0; i < nCount; ++i)
         _rRightColumns.push_back(pRight->GetEntry(i));
 }
 
@@ -323,23 +336,22 @@ void OWizColumnSelect::moveColumn(  ListBox* _pRight,
     {
         // find the new column in the dest name mapping to obtain the old column
         OCopyTableWizard::TNameMapping::iterator aIter = ::std::find_if(m_pParent->m_mNameMapping.begin(),m_pParent->m_mNameMapping.end(),
-                                                                ::o3tl::compose1(
-                                                                    ::std::bind2nd(_aCase, _sColumnName),
-                                                                    ::o3tl::select2nd<OCopyTableWizard::TNameMapping::value_type>())
-                                                                    );
+            [&_aCase, &_sColumnName] (const OCopyTableWizard::TNameMapping::value_type& nameMap) {
+                return _aCase(nameMap.second, _sColumnName);
+            });
 
         OSL_ENSURE(aIter != m_pParent->m_mNameMapping.end(),"Column must be defined");
         if ( aIter == m_pParent->m_mNameMapping.end() )
             return; // do nothing
-        const ODatabaseExport::TColumns* pSrcColumns = m_pParent->getSourceColumns();
-        ODatabaseExport::TColumns::const_iterator aSrcIter = pSrcColumns->find((*aIter).first);
-        if ( aSrcIter != pSrcColumns->end() )
+        const ODatabaseExport::TColumns& rSrcColumns = m_pParent->getSourceColumns();
+        ODatabaseExport::TColumns::const_iterator aSrcIter = rSrcColumns.find((*aIter).first);
+        if ( aSrcIter != rSrcColumns.end() )
         {
             // we need also the old position of this column to insert it back on that position again
-            const ODatabaseExport::TColumnVector* pSrcVector = m_pParent->getSrcVector();
-            ODatabaseExport::TColumnVector::const_iterator aPos = ::std::find(pSrcVector->begin(),pSrcVector->end(),aSrcIter);
-            OSL_ENSURE( aPos != pSrcVector->end(),"Invalid position for the iterator here!");
-            ODatabaseExport::TColumnVector::size_type nPos = (aPos - pSrcVector->begin()) - adjustColumnPosition(_pLeft, _sColumnName, (aPos - pSrcVector->begin()), _aCase);
+            const ODatabaseExport::TColumnVector& rSrcVector = m_pParent->getSrcVector();
+            ODatabaseExport::TColumnVector::const_iterator aPos = ::std::find(rSrcVector.begin(), rSrcVector.end(), aSrcIter);
+            OSL_ENSURE( aPos != rSrcVector.end(),"Invalid position for the iterator here!");
+            ODatabaseExport::TColumnVector::size_type nPos = (aPos - rSrcVector.begin()) - adjustColumnPosition(_pLeft, _sColumnName, (aPos - rSrcVector.begin()), _aCase);
 
             _pRight->SetEntryData( _pRight->InsertEntry( (*aIter).first, sal::static_int_cast< sal_uInt16 >(nPos)),aSrcIter->second );
             _rRightColumns.push_back((*aIter).first);
@@ -349,44 +361,43 @@ void OWizColumnSelect::moveColumn(  ListBox* _pRight,
 }
 
 // Simply returning fields back to their original position is
-// not enough. We need to take into acccount what fields have
+// not enough. We need to take into account what fields have
 // been removed earlier and adjust accordingly. Based on the
 // algorithm employed in moveColumn().
-sal_uInt16 OWizColumnSelect::adjustColumnPosition( ListBox* _pLeft,
+sal_Int32 OWizColumnSelect::adjustColumnPosition( ListBox* _pLeft,
                                                const OUString&   _sColumnName,
                                                ODatabaseExport::TColumnVector::size_type nCurrentPos,
                                                const ::comphelper::UStringMixEqual& _aCase)
 {
-    sal_uInt16 nAdjustedPos = 0;
+    sal_Int32 nAdjustedPos = 0;
 
     // if returning all entries to their original position,
     // then there is no need to adjust the positions.
     if (m_pColumns_LH->HasFocus())
         return nAdjustedPos;
 
-    sal_uInt16 nCount = _pLeft->GetEntryCount();
+    const sal_Int32 nCount = _pLeft->GetEntryCount();
     OUString sColumnString;
-    for(sal_uInt16 i=0; i < nCount; ++i)
+    for(sal_Int32 i=0; i < nCount; ++i)
     {
         sColumnString = _pLeft->GetEntry(i);
         if(_sColumnName != sColumnString)
         {
             // find the new column in the dest name mapping to obtain the old column
             OCopyTableWizard::TNameMapping::iterator aIter = ::std::find_if(m_pParent->m_mNameMapping.begin(),m_pParent->m_mNameMapping.end(),
-                                                                    ::o3tl::compose1(
-                                                                    ::std::bind2nd(_aCase, sColumnString),
-                                                                    ::o3tl::select2nd<OCopyTableWizard::TNameMapping::value_type>())
-                                                                    );
+                [&_aCase, &sColumnString] (const OCopyTableWizard::TNameMapping::value_type& nameMap) {
+                    return _aCase(nameMap.second, sColumnString);
+                });
 
             OSL_ENSURE(aIter != m_pParent->m_mNameMapping.end(),"Column must be defined");
-            const ODatabaseExport::TColumns* pSrcColumns = m_pParent->getSourceColumns();
-            ODatabaseExport::TColumns::const_iterator aSrcIter = pSrcColumns->find((*aIter).first);
-            if ( aSrcIter != pSrcColumns->end() )
+            const ODatabaseExport::TColumns& rSrcColumns = m_pParent->getSourceColumns();
+            ODatabaseExport::TColumns::const_iterator aSrcIter = rSrcColumns.find((*aIter).first);
+            if ( aSrcIter != rSrcColumns.end() )
             {
                 // we need also the old position of this column to insert it back on that position again
-                const ODatabaseExport::TColumnVector* pSrcVector = m_pParent->getSrcVector();
-                ODatabaseExport::TColumnVector::const_iterator aPos = ::std::find(pSrcVector->begin(),pSrcVector->end(),aSrcIter);
-                ODatabaseExport::TColumnVector::size_type nPos = aPos - pSrcVector->begin();
+                const ODatabaseExport::TColumnVector& rSrcVector = m_pParent->getSrcVector();
+                ODatabaseExport::TColumnVector::const_iterator aPos = ::std::find(rSrcVector.begin(), rSrcVector.end(), aSrcIter);
+                ODatabaseExport::TColumnVector::size_type nPos = aPos - rSrcVector.begin();
                 if( nPos < nCurrentPos)
                 {
                     nAdjustedPos++;
