@@ -47,16 +47,14 @@ public:
 };
 
 OModuleImpl::OModuleImpl()
-    :m_pResources(NULL)
+    :m_pResources(nullptr)
 {
 
 }
 
 OModuleImpl::~OModuleImpl()
 {
-    if (m_pResources)
-        delete m_pResources;
-
+    delete m_pResources;
 }
 
 ResMgr* OModuleImpl::getResManager()
@@ -74,7 +72,7 @@ ResMgr* OModuleImpl::getResManager()
 // OModule
 ::osl::Mutex    OModule::s_aMutex;
 sal_Int32       OModule::s_nClients = 0;
-OModuleImpl*    OModule::s_pImpl = NULL;
+OModuleImpl*    OModule::s_pImpl = nullptr;
 ResMgr* OModule::getResManager()
 {
     ENTER_MOD_METHOD();
@@ -93,7 +91,7 @@ void OModule::revokeClient()
     if (!--s_nClients && s_pImpl)
     {
         delete s_pImpl;
-        s_pImpl = NULL;
+        s_pImpl = nullptr;
     }
 }
 
