@@ -66,6 +66,7 @@
 #include <com/sun/star/frame/XUntitledNumbers.hpp>
 #include <com/sun/star/ui/XUIElement.hpp>
 
+#include <comphelper/propertysequence.hxx>
 #include <comphelper/processfactory.hxx>
 #include <comphelper/property.hxx>
 #include <comphelper/seqstream.hxx>
@@ -100,27 +101,26 @@ namespace dbaui
 
     class OViewController : public OQueryController
     {
-        virtual OUString SAL_CALL getImplementationName() throw( RuntimeException, std::exception ) SAL_OVERRIDE
+        virtual OUString SAL_CALL getImplementationName() throw( RuntimeException, std::exception ) override
         {
             return getImplementationName_Static();
         }
-        virtual Sequence< OUString> SAL_CALL getSupportedServiceNames() throw(RuntimeException, std::exception) SAL_OVERRIDE
+        virtual Sequence< OUString> SAL_CALL getSupportedServiceNames() throw(RuntimeException, std::exception) override
         {
             return getSupportedServiceNames_Static();
         }
 
     public:
-        OViewController(const Reference< XComponentContext >& _rM) : OQueryController(_rM){}
+        explicit OViewController(const Reference< XComponentContext >& _rM) : OQueryController(_rM){}
 
         // need by registration
         static OUString getImplementationName_Static() throw( RuntimeException )
         {
             return OUString("org.openoffice.comp.dbu.OViewDesign");
         }
-        static Sequence< OUString > getSupportedServiceNames_Static(void) throw( RuntimeException )
+        static Sequence< OUString > getSupportedServiceNames_Static() throw( RuntimeException )
         {
-            Sequence< OUString> aSupported(1);
-            aSupported.getArray()[0] = "com.sun.star.sdb.ViewDesign";
+            Sequence<OUString> aSupported { "com.sun.star.sdb.ViewDesign" };
             return aSupported;
         }
         static Reference< XInterface > SAL_CALL Create(const Reference< XMultiServiceFactory >& _rM)
@@ -255,7 +255,7 @@ namespace
 {
     void ensureToolbars( OQueryController& _rController, bool _bDesign )
     {
-        Reference< ::com::sun::star::frame::XLayoutManager > xLayoutManager = _rController.getLayoutManager( _rController.getFrame() );
+        Reference< css::frame::XLayoutManager > xLayoutManager = OGenericUnoController::getLayoutManager( _rController.getFrame() );
         if ( xLayoutManager.is() )
         {
             xLayoutManager->lock();
@@ -284,13 +284,13 @@ namespace
     void grabFocusFromLimitBox( OQueryController& _rController )
     {
         static const char sResourceURL[] = "private:resource/toolbar/designobjectbar";
-        Reference< XLayoutManager > xLayoutManager = _rController.getLayoutManager( _rController.getFrame() );
+        Reference< XLayoutManager > xLayoutManager = OGenericUnoController::getLayoutManager( _rController.getFrame() );
         Reference< XUIElement > xUIElement = xLayoutManager->getElement(sResourceURL);
         if (xUIElement.is())
         {
             Reference< XWindow > xWindow(xUIElement->getRealInterface(), css::uno::UNO_QUERY);
             vcl::Window* pWindow = VCLUnoHelper::GetWindow( xWindow );
-            if( pWindow || pWindow->HasChildPathFocus() )
+            if( pWindow && pWindow->HasChildPathFocus() )
             {
                 pWindow->GrabFocusToDocument();
             }
@@ -308,10 +308,9 @@ OUString OQueryController::getImplementationName_Static() throw( RuntimeExceptio
     return OUString("org.openoffice.comp.dbu.OQueryDesign");
 }
 
-Sequence< OUString> OQueryController::getSupportedServiceNames_Static(void) throw( RuntimeException )
+Sequence< OUString> OQueryController::getSupportedServiceNames_Static() throw( RuntimeException )
 {
-    Sequence< OUString> aSupported(1);
-    aSupported.getArray()[0] = "com.sun.star.sdb.QueryDesign";
+    Sequence<OUString> aSupported { "com.sun.star.sdb.QueryDesign" };
     return aSupported;
 }
 
@@ -330,24 +329,21 @@ OQueryController::OQueryController(const Reference< XComponentContext >& _rM)
     ,OQueryController_PBase( getBroadcastHelper() )
     ,m_pParseContext( new svxform::OSystemParseContext )
     ,m_aSqlParser( _rM, m_pParseContext )
-    ,m_pSqlIterator(NULL)
+    ,m_pSqlIterator(nullptr)
     ,m_nLimit(-1)
     ,m_nVisibleRows(0x400)
     ,m_nSplitPos(-1)
     ,m_nCommandType( CommandType::QUERY )
     ,m_bGraphicalDesign(false)
     ,m_bDistinct(false)
-    ,m_bViewAlias(false)
-    ,m_bViewTable(false)
-    ,m_bViewFunction(false)
     ,m_bEscapeProcessing(true)
 {
     InvalidateAll();
 
     registerProperty( PROPERTY_ACTIVECOMMAND, PROPERTY_ID_ACTIVECOMMAND, PropertyAttribute::READONLY | PropertyAttribute::BOUND,
-        &m_sStatement, ::getCppuType( &m_sStatement ) );
+        &m_sStatement, cppu::UnoType<decltype(m_sStatement)>::get() );
     registerProperty( PROPERTY_ESCAPE_PROCESSING, PROPERTY_ID_ESCAPE_PROCESSING, PropertyAttribute::READONLY | PropertyAttribute::BOUND,
-        &m_bEscapeProcessing, ::getCppuType( &m_bEscapeProcessing ) );
+        &m_bEscapeProcessing, cppu::UnoType<decltype(m_bEscapeProcessing)>::get() );
 }
 
 OQueryController::~OQueryController()
@@ -413,7 +409,7 @@ void SAL_CALL OQueryController::getFastPropertyValue( Any& o_rValue, sal_Int32 i
 
 ::cppu::IPropertyArrayHelper& OQueryController::getInfoHelper()
 {
-    return *const_cast< OQueryController* >( this )->getArrayHelper();
+    return *getArrayHelper();
 }
 
 ::cppu::IPropertyArrayHelper* OQueryController::createArrayHelper( ) const
@@ -447,7 +443,7 @@ void OQueryController::deleteIterator()
         delete m_pSqlIterator->getParseTree();
         m_pSqlIterator->dispose();
         delete m_pSqlIterator;
-        m_pSqlIterator = NULL;
+        m_pSqlIterator = nullptr;
     }
 }
 
@@ -489,9 +485,9 @@ FeatureState OQueryController::GetState(sal_uInt16 _nId) const
                 aReturn = OJoinController::GetState( _nId );
             break;
 
-        case ID_BROWSER_ESACPEPROCESSING:
+        case ID_BROWSER_ESCAPEPROCESSING:
             aReturn.bChecked = !m_bEscapeProcessing;
-            aReturn.bEnabled = ( m_pSqlIterator != NULL ) && !m_bGraphicalDesign;
+            aReturn.bEnabled = ( m_pSqlIterator != nullptr ) && !m_bGraphicalDesign;
             break;
         case SID_RELATION_ADD_RELATION:
             aReturn.bEnabled = isEditable() && m_bGraphicalDesign && m_vTableData.size() > 1;
@@ -500,7 +496,7 @@ FeatureState OQueryController::GetState(sal_uInt16 _nId) const
             aReturn.bEnabled = !editingCommand() && !editingView() && (!m_bGraphicalDesign || !(m_vTableFieldDesc.empty() || m_vTableData.empty()));
             break;
         case ID_BROWSER_SAVEDOC:
-            aReturn.bEnabled = impl_isModified() && (!m_bGraphicalDesign || !(m_vTableFieldDesc.empty() || m_vTableData.empty()));
+            aReturn.bEnabled = isEditable() && (!m_bGraphicalDesign || !(m_vTableFieldDesc.empty() || m_vTableData.empty()));
             break;
         case SID_PRINTDOCDIRECT:
             break;
@@ -569,7 +565,7 @@ void OQueryController::Execute(sal_uInt16 _nId, const Sequence< PropertyValue >&
 {
     switch(_nId)
     {
-        case ID_BROWSER_ESACPEPROCESSING:
+        case ID_BROWSER_ESCAPEPROCESSING:
             setEscapeProcessing_fireEvent( !m_bEscapeProcessing );
             if ( !editingView() )
                 setModified(sal_True);
@@ -612,7 +608,7 @@ void OQueryController::Execute(sal_uInt16 _nId, const Sequence< PropertyValue >&
                 {
                     // change the view of the data
                     delete m_pSqlIterator->getParseTree();
-                    m_pSqlIterator->setParseTree(NULL);
+                    m_pSqlIterator->setParseTree(nullptr);
                     m_bGraphicalDesign = !m_bGraphicalDesign;
                     impl_setViewMode( &aError );
                 }
@@ -636,7 +632,7 @@ void OQueryController::Execute(sal_uInt16 _nId, const Sequence< PropertyValue >&
                             {
                                 aError = SQLException(
                                     OUString( ModuleRes( STR_QRY_NOSELECT ) ),
-                                    NULL,
+                                    nullptr,
                                     "S1000",
                                     1000,
                                     Any()
@@ -659,7 +655,7 @@ void OQueryController::Execute(sal_uInt16 _nId, const Sequence< PropertyValue >&
                     {
                         aError = SQLException(
                             OUString( ModuleRes( STR_QRY_SYNTAX ) ),
-                            NULL,
+                            nullptr,
                             "S1000",
                             1000,
                             Any()
@@ -726,7 +722,7 @@ void OQueryController::Execute(sal_uInt16 _nId, const Sequence< PropertyValue >&
         case SID_DB_QUERY_PREVIEW:
             try
             {
-                Reference< ::com::sun::star::util::XCloseable > xCloseFrame( getContainer()->getPreviewFrame(), UNO_QUERY );
+                Reference< css::util::XCloseable > xCloseFrame( getContainer()->getPreviewFrame(), UNO_QUERY );
                 if ( xCloseFrame.is() )
                 {
                     try
@@ -763,9 +759,9 @@ void OQueryController::Execute(sal_uInt16 _nId, const Sequence< PropertyValue >&
                 if ( pNode )
                 {
                     vcl::Window* pView = getView();
-                    ModalDialog* pWindow = new ModalDialog( pView, WB_STDMODAL | WB_SIZEMOVE | WB_CENTER );
+                    ScopedVclPtrInstance<ModalDialog> pWindow( pView, WB_STDMODAL | WB_SIZEMOVE | WB_CENTER );
                     pWindow->SetSizePixel( ::Size( pView->GetSizePixel().Width() / 2, pView->GetSizePixel().Height() / 2 ) );
-                    SvTreeListBox* pTreeBox = new SvTreeListBox( pWindow, WB_BORDER | WB_HASLINES | WB_HASBUTTONS | WB_HASBUTTONSATROOT | WB_HASLINESATROOT | WB_VSCROLL );
+                    ScopedVclPtrInstance<SvTreeListBox> pTreeBox( pWindow, WB_BORDER | WB_HASLINES | WB_HASBUTTONS | WB_HASBUTTONSATROOT | WB_HASLINESATROOT | WB_VSCROLL );
                     pTreeBox->SetPosSizePixel( ::Point( 6, 6 ), ::Size( pWindow->GetSizePixel().Width() - 12, pWindow->GetSizePixel().Height() - 12 ));
                     pTreeBox->SetNodeDefaultImages();
 
@@ -799,8 +795,6 @@ void OQueryController::Execute(sal_uInt16 _nId, const Sequence< PropertyValue >&
                     pTreeBox->Show();
                     pWindow->Execute();
 
-                    delete pTreeBox;
-                    delete pWindow;
                     delete pNode;
                 }
                 break;
@@ -813,7 +807,7 @@ void OQueryController::Execute(sal_uInt16 _nId, const Sequence< PropertyValue >&
     InvalidateFeature(_nId);
 }
 
-void OQueryController::impl_showAutoSQLViewError( const ::com::sun::star::uno::Any& _rErrorDetails )
+void OQueryController::impl_showAutoSQLViewError( const css::uno::Any& _rErrorDetails )
 {
     SQLContext aErrorContext;
     aErrorContext.Message = lcl_getObjectResourceString( STR_ERROR_PARSING_STATEMENT, m_nCommandType );
@@ -835,7 +829,7 @@ bool OQueryController::impl_setViewMode( ::dbtools::SQLExceptionInfo* _pErrorInf
     {
         m_bGraphicalDesign = !m_bGraphicalDesign;
         // restore old state
-        getContainer()->switchView( NULL );
+        getContainer()->switchView( nullptr );
             // don't pass &aError here, this would overwrite the error which the first switchView call
             // returned in this location.
         if ( _pErrorInfo )
@@ -888,11 +882,11 @@ void OQueryController::impl_initialize()
     }
 
     // non-legacy parameters which overwrite the legacy parameters
-    rArguments.get_ensureType( OUString(PROPERTY_COMMAND), sCommand );
-    rArguments.get_ensureType( OUString(PROPERTY_COMMAND_TYPE), m_nCommandType );
+    rArguments.get_ensureType( PROPERTY_COMMAND, sCommand );
+    rArguments.get_ensureType( PROPERTY_COMMAND_TYPE, m_nCommandType );
 
     // translate Command/Type into proper members
-    // TODO/Later: all this (including those members) should be hidden behind some abstact interface,
+    // TODO/Later: all this (including those members) should be hidden behind some abstract interface,
     // which is implemented for all the three commands
     switch ( m_nCommandType )
     {
@@ -913,17 +907,17 @@ void OQueryController::impl_initialize()
 
     // more legacy parameters
     bool bGraphicalDesign( true );
-    if ( rArguments.get_ensureType( OUString(PROPERTY_QUERYDESIGNVIEW), bGraphicalDesign ) )
+    if ( rArguments.get_ensureType( PROPERTY_QUERYDESIGNVIEW, bGraphicalDesign ) )
     {
         OSL_FAIL( "OQueryController::impl_initialize: QueryDesignView is regognized for compatibility only!" );
         m_bGraphicalDesign = bGraphicalDesign;
     }
 
     // more non-legacy
-    rArguments.get_ensureType( OUString(PROPERTY_GRAPHICAL_DESIGN), m_bGraphicalDesign );
+    rArguments.get_ensureType( PROPERTY_GRAPHICAL_DESIGN, m_bGraphicalDesign );
 
     bool bEscapeProcessing( true );
-    if ( rArguments.get_ensureType( OUString(PROPERTY_ESCAPE_PROCESSING), bEscapeProcessing ) )
+    if ( rArguments.get_ensureType( PROPERTY_ESCAPE_PROCESSING, bEscapeProcessing ) )
     {
         setEscapeProcessing_fireEvent( bEscapeProcessing );
 
@@ -942,11 +936,11 @@ void OQueryController::impl_initialize()
         ::comphelper::NamedValueCollection aCurrentQueryDesign( aCurrentQueryDesignProps );
         if ( aCurrentQueryDesign.has( OUString(PROPERTY_GRAPHICAL_DESIGN) ) )
         {
-            aCurrentQueryDesign.get_ensureType( OUString(PROPERTY_GRAPHICAL_DESIGN), m_bGraphicalDesign );
+            aCurrentQueryDesign.get_ensureType( PROPERTY_GRAPHICAL_DESIGN, m_bGraphicalDesign );
         }
         if ( aCurrentQueryDesign.has( OUString(PROPERTY_ESCAPE_PROCESSING) ) )
         {
-            aCurrentQueryDesign.get_ensureType( OUString(PROPERTY_ESCAPE_PROCESSING), m_bEscapeProcessing );
+            aCurrentQueryDesign.get_ensureType( PROPERTY_ESCAPE_PROCESSING, m_bEscapeProcessing );
         }
         if ( aCurrentQueryDesign.has( "Statement" ) )
         {
@@ -987,8 +981,8 @@ void OQueryController::impl_initialize()
                 OUString aTitle( ModuleRes( STR_QUERYDESIGN_NO_VIEW_SUPPORT ) );
                 OUString aMessage( ModuleRes( STR_QUERYDESIGN_NO_VIEW_ASK ) );
                 ODataView* pWindow = getView();
-                OSQLMessageBox aDlg( pWindow, aTitle, aMessage, WB_YES_NO | WB_DEF_YES, OSQLMessageBox::Query );
-                bClose = aDlg.Execute() == RET_NO;
+                ScopedVclPtrInstance< OSQLMessageBox > aDlg( pWindow, aTitle, aMessage, WB_YES_NO | WB_DEF_YES, OSQLMessageBox::Query );
+                bClose = aDlg->Execute() == RET_NO;
             }
             if ( bClose )
                 throw VetoException();
@@ -1060,13 +1054,13 @@ void OQueryController::impl_initialize()
             m_bGraphicalDesign = false;
             getContainer()->initialize();
             ODataView* pWindow = getView();
-            OSQLMessageBox(pWindow,e).Execute();
+            ScopedVclPtr<OSQLMessageBox>::Create(pWindow,e)->Execute();
         }
         throw;
     }
 }
 
-void OQueryController::onLoadedMenu(const Reference< ::com::sun::star::frame::XLayoutManager >& /*_xLayoutManager*/)
+void OQueryController::onLoadedMenu(const Reference< css::frame::XLayoutManager >& /*_xLayoutManager*/)
 {
     ensureToolbars( *this, m_bGraphicalDesign );
 }
@@ -1103,12 +1097,12 @@ void OQueryController::setQueryComposer()
             }
             catch(const Exception&)
             {
-                m_xComposer = NULL;
+                m_xComposer = nullptr;
             }
             OSL_ENSURE(m_xComposer.is(),"No querycomposer available!");
             Reference<XTablesSupplier> xTablesSup(getConnection(), UNO_QUERY);
             deleteIterator();
-            m_pSqlIterator = new ::connectivity::OSQLParseTreeIterator( getConnection(), xTablesSup->getTables(), m_aSqlParser, NULL );
+            m_pSqlIterator = new ::connectivity::OSQLParseTreeIterator( getConnection(), xTablesSup->getTables(), m_aSqlParser, nullptr );
         }
     }
 }
@@ -1117,7 +1111,7 @@ bool OQueryController::Construct(vcl::Window* pParent)
 {
     // TODO: we have to check if we should create the text view or the design view
 
-    setView( * new OQueryContainerWindow( pParent, *this, getORB() ) );
+    setView( VclPtr<OQueryContainerWindow>::Create( pParent, *this, getORB() ) );
 
     return OJoinController::Construct(pParent);
 }
@@ -1131,7 +1125,7 @@ void OQueryController::describeSupportedFeatures()
 {
     OJoinController::describeSupportedFeatures();
     implDescribeSupportedFeature( ".uno:SaveAs",            ID_BROWSER_SAVEASDOC,       CommandGroup::DOCUMENT );
-    implDescribeSupportedFeature( ".uno:SbaNativeSql",      ID_BROWSER_ESACPEPROCESSING,CommandGroup::FORMAT );
+    implDescribeSupportedFeature( ".uno:SbaNativeSql",      ID_BROWSER_ESCAPEPROCESSING,CommandGroup::FORMAT );
     implDescribeSupportedFeature( ".uno:DBViewFunctions",   SID_QUERY_VIEW_FUNCTIONS,   CommandGroup::VIEW );
     implDescribeSupportedFeature( ".uno:DBViewTableNames",  SID_QUERY_VIEW_TABLES,      CommandGroup::VIEW );
     implDescribeSupportedFeature( ".uno:DBViewAliases",     SID_QUERY_VIEW_ALIASES,     CommandGroup::VIEW );
@@ -1195,7 +1189,7 @@ void OQueryController::reconnect(bool _bUI)
         {
             m_bGraphicalDesign = false;
             // don't call Execute(SQL) because this changes the sql statement
-            impl_setViewMode( NULL );
+            impl_setViewMode( nullptr );
         }
         InvalidateAll();
     }
@@ -1238,15 +1232,15 @@ void OQueryController::loadViewSettings( const ::comphelper::NamedValueCollectio
 
 void OQueryController::execute_QueryPropDlg()
 {
-    QueryPropertiesDialog aQueryPropDlg(
+    ScopedVclPtrInstance<QueryPropertiesDialog> aQueryPropDlg(
         getContainer(), m_bDistinct, m_nLimit );
 
-    if( aQueryPropDlg.Execute() == RET_OK )
+    if( aQueryPropDlg->Execute() == RET_OK )
     {
-        m_bDistinct = aQueryPropDlg.getDistinct();
-        m_nLimit = aQueryPropDlg.getLimit();
+        m_bDistinct = aQueryPropDlg->getDistinct();
+        m_nLimit = aQueryPropDlg->getLimit();
         InvalidateFeature( SID_QUERY_DISTINCT_VALUES );
-        InvalidateFeature( SID_QUERY_LIMIT, 0, true );
+        InvalidateFeature( SID_QUERY_LIMIT, nullptr, true );
     }
 }
 
@@ -1254,7 +1248,7 @@ sal_Int32 OQueryController::getColWidth(sal_uInt16 _nColPos)  const
 {
     if ( _nColPos < m_aFieldInformation.getLength() )
     {
-        ::std::unique_ptr<OTableFieldDesc> pField( new OTableFieldDesc());
+        rtl::Reference<OTableFieldDesc> pField( new OTableFieldDesc());
         pField->Load( m_aFieldInformation[ _nColPos ], false );
         return pField->GetColWidth();
     }
@@ -1321,33 +1315,18 @@ void OQueryController::executeQuery()
             }
             if (xDisp.is())
             {
-                Sequence< PropertyValue> aProps(9);
-                aProps[0].Name = PROPERTY_DATASOURCENAME;
-                aProps[0].Value <<= sDataSourceName;
-
-                aProps[1].Name = PROPERTY_COMMAND_TYPE;
-                aProps[1].Value <<= CommandType::COMMAND;
-
-                aProps[2].Name = PROPERTY_COMMAND;
-                aProps[2].Value <<= sTranslatedStmt;
-
-                aProps[3].Name = PROPERTY_ENABLE_BROWSER;
-                aProps[3].Value <<= false;
-
-                aProps[4].Name = PROPERTY_ACTIVE_CONNECTION;
-                aProps[4].Value <<= getConnection();
-
-                aProps[5].Name = PROPERTY_UPDATE_CATALOGNAME;
-                aProps[5].Value <<= m_sUpdateCatalogName;
-
-                aProps[6].Name = PROPERTY_UPDATE_SCHEMANAME;
-                aProps[6].Value <<= m_sUpdateSchemaName;
-
-                aProps[7].Name = PROPERTY_UPDATE_TABLENAME;
-                aProps[7].Value <<= m_sUpdateTableName;
-
-                aProps[8].Name = PROPERTY_ESCAPE_PROCESSING;
-                aProps[8].Value <<= m_bEscapeProcessing;
+                auto aProps(::comphelper::InitPropertySequence(
+                    {
+                        { PROPERTY_DATASOURCENAME, makeAny(sDataSourceName) },
+                        { PROPERTY_COMMAND_TYPE, makeAny(CommandType::COMMAND) },
+                        { PROPERTY_COMMAND, makeAny(sTranslatedStmt) },
+                        { PROPERTY_ENABLE_BROWSER, makeAny(false) },
+                        { PROPERTY_ACTIVE_CONNECTION, makeAny(getConnection()) },
+                        { PROPERTY_UPDATE_CATALOGNAME, makeAny(m_sUpdateCatalogName) },
+                        { PROPERTY_UPDATE_SCHEMANAME, makeAny(m_sUpdateSchemaName) },
+                        { PROPERTY_UPDATE_TABLENAME, makeAny(m_sUpdateTableName) },
+                        { PROPERTY_ESCAPE_PROCESSING, makeAny(m_bEscapeProcessing) }
+                    }));
 
                 xDisp->dispatch(aWantToDispatch, aProps);
                 // check the state of the beamer
@@ -1357,7 +1336,7 @@ void OQueryController::executeQuery()
                 {
                     OSL_ENSURE(Reference< XFrame >(xComponent, UNO_QUERY).get() == getContainer()->getPreviewFrame().get(),
                         "OQueryController::executeQuery: oops ... which window do I have here?");
-                    Reference< XEventListener> xEvtL((::cppu::OWeakObject*)this,UNO_QUERY);
+                    Reference< XEventListener> xEvtL(static_cast<cppu::OWeakObject*>(this),UNO_QUERY);
                     xComponent->addEventListener(xEvtL);
                 }
             }
@@ -1398,7 +1377,7 @@ bool OQueryController::askForNewName(const Reference<XNameAccess>& _xElements, b
         }
 
         DynamicTableOrQueryNameCheck aNameChecker( getConnection(), CommandType::QUERY );
-        OSaveAsDlg aDlg(
+        ScopedVclPtrInstance<OSaveAsDlg> aDlg(
                 getView(),
                 m_nCommandType,
                 getORB(),
@@ -1407,14 +1386,14 @@ bool OQueryController::askForNewName(const Reference<XNameAccess>& _xElements, b
                 aNameChecker,
                 SAD_DEFAULT );
 
-        bRet = ( aDlg.Execute() == RET_OK );
+        bRet = ( aDlg->Execute() == RET_OK );
         if ( bRet )
         {
-            m_sName = aDlg.getName();
+            m_sName = aDlg->getName();
             if ( editingView() )
             {
-                m_sUpdateCatalogName    = aDlg.getCatalog();
-                m_sUpdateSchemaName     = aDlg.getSchema();
+                m_sUpdateCatalogName    = aDlg->getCatalog();
+                m_sUpdateSchemaName     = aDlg->getSchema();
             }
         }
     }
@@ -1427,7 +1406,7 @@ bool OQueryController::doSaveAsDoc(bool _bSaveAs)
     if ( !editingCommand() && !haveDataSource() )
     {
         OUString aMessage(ModuleRes(STR_DATASOURCE_DELETED));
-        OSQLWarningBox( getView(), aMessage ).Execute();
+        ScopedVclPtr<OSQLWarningBox>::Create( getView(), aMessage )->Execute();
         return false;
     }
 
@@ -1552,7 +1531,7 @@ bool OQueryController::doSaveAsDoc(bool _bSaveAs)
                 if ( !xViewProps.is() ) // correct name and try again
                     m_sName = ::dbtools::composeTableName( getMetaData(), xQuery, ::dbtools::eInDataManipulation, false, false, false );
 
-                OSL_ENSURE( xElements->hasByName( m_sName ), "OQueryController::doSaveAsDoc: newly creaed view does not exist!" );
+                OSL_ENSURE( xElements->hasByName( m_sName ), "OQueryController::doSaveAsDoc: newly created view does not exist!" );
 
                 if ( xElements->hasByName( m_sName ) )
                     m_xAlterView.set( xElements->getByName( m_sName ), UNO_QUERY );
@@ -1620,8 +1599,8 @@ static ::std::vector< CommentStrip > getComment( const OUString& rQuery )
     ::std::vector< CommentStrip > aRet;
     // First a quick search if there is any "--" or "//" or "/*", if not then
     // the whole copying loop is pointless.
-    if (rQuery.indexOfAsciiL( "--", 2, 0) < 0 && rQuery.indexOfAsciiL( "//", 2, 0) < 0 &&
-            rQuery.indexOfAsciiL( "/*", 2, 0) < 0)
+    if (rQuery.indexOf( "--" ) < 0 && rQuery.indexOf( "//" ) < 0 &&
+            rQuery.indexOf( "/*" ) < 0)
         return aRet;
 
     const sal_Unicode* pCopy = rQuery.getStr();
@@ -1779,7 +1758,7 @@ OUString OQueryController::translateStatement( bool _bFireStatementChange )
         ModuleRes aModuleRes(STR_QRY_NOSELECT);
         OUString sTmpStr(aModuleRes);
         OUString sError(sTmpStr);
-        showError(SQLException(sError,NULL,"S1000",1000,Any()));
+        showError(SQLException(sError,nullptr,"S1000",1000,Any()));
     }
     else
         sTranslatedStmt = m_sStatement;
@@ -1802,9 +1781,9 @@ short OQueryController::saveModified()
         )
     {
         OUString sMessageText( lcl_getObjectResourceString( STR_QUERY_SAVEMODIFIED, m_nCommandType ) );
-        QueryBox aQry( getView(), WB_YES_NO_CANCEL | WB_DEF_YES, sMessageText );
+        ScopedVclPtrInstance< QueryBox > aQry( getView(), WB_YES_NO_CANCEL | WB_DEF_YES, sMessageText );
 
-        nRet = aQry.Execute();
+        nRet = aQry->Execute();
         if  (   ( nRet == RET_YES )
             &&  !doSaveAsDoc( false )
             )
@@ -1835,9 +1814,9 @@ void OQueryController::impl_reset( const bool i_bForceCurrentControllerSettings
                     xProp->getPropertyValue( PROPERTY_COMMAND ) >>= sNewStatement;
                     setStatement_fireEvent( sNewStatement );
 
-                    bool bNewEscapeProcessing( true );
                     if ( editingQuery() )
                     {
+                        bool bNewEscapeProcessing( true );
                         xProp->getPropertyValue( PROPERTY_ESCAPE_PROCESSING ) >>= bNewEscapeProcessing;
                         setEscapeProcessing_fireEvent( bNewEscapeProcessing );
                     }
@@ -1914,8 +1893,8 @@ void OQueryController::impl_reset( const bool i_bForceCurrentControllerSettings
                     if ( !i_bForceCurrentControllerSettings && !editingView() )
                     {
                         OUString aTitle(ModuleRes(STR_SVT_SQL_SYNTAX_ERROR));
-                        OSQLMessageBox aDlg(getView(),aTitle,aErrorMsg);
-                        aDlg.Execute();
+                        ScopedVclPtrInstance< OSQLMessageBox > aDlg(getView(),aTitle,aErrorMsg);
+                        aDlg->Execute();
                     }
                     bError = true;
                 }
@@ -1941,7 +1920,7 @@ void OQueryController::impl_reset( const bool i_bForceCurrentControllerSettings
 void OQueryController::reset()
 {
     impl_reset();
-    getContainer()->reset( NULL );
+    getContainer()->reset( nullptr );
     ClearUndoManager();
 }
 
@@ -1969,10 +1948,9 @@ void OQueryController::setEscapeProcessing_fireEvent( const bool _bEscapeProcess
     fire( &nHandle, &aNewValue, &aOldValue, 1, sal_False );
 }
 
-IMPL_LINK( OQueryController, OnExecuteAddTable, void*, /*pNotInterestedIn*/ )
+IMPL_LINK_NOARG_TYPED( OQueryController, OnExecuteAddTable, void*, void )
 {
     Execute( ID_BROWSER_ADDTABLE,Sequence<PropertyValue>() );
-    return 0L;
 }
 
 bool OQueryController::allowViews() const
@@ -1987,7 +1965,7 @@ bool OQueryController::allowQueries() const
         return false;
 
     const NamedValueCollection& rArguments( getInitParams() );
-    sal_Int32 nCommandType = rArguments.getOrDefault( OUString(PROPERTY_COMMAND_TYPE), (sal_Int32)CommandType::QUERY );
+    sal_Int32 nCommandType = rArguments.getOrDefault( PROPERTY_COMMAND_TYPE, (sal_Int32)CommandType::QUERY );
     bool bCreatingView = ( nCommandType == CommandType::TABLE );
     return !bCreatingView;
 }
