@@ -17,16 +17,16 @@
  *   the License at http://www.apache.org/licenses/LICENSE-2.0 .
  */
 
-#include "vcl/svapp.hxx"
-#include "vcl/msgbox.hxx"
+#include <vcl/svapp.hxx>
+#include <vcl/msgbox.hxx>
 
-#include "osl/mutex.hxx"
+#include <osl/mutex.hxx>
 
 #include <toolkit/helper/vclunohelper.hxx>
 
-#include "com/sun/star/beans/XPropertySet.hpp"
-#include "com/sun/star/configuration/theDefaultProvider.hpp"
-#include "com/sun/star/frame/Desktop.hpp"
+#include <com/sun/star/beans/XPropertySet.hpp>
+#include <com/sun/star/configuration/theDefaultProvider.hpp>
+#include <com/sun/star/frame/Desktop.hpp>
 
 #include "dp_gui_dialog2.hxx"
 #include "dp_gui_extensioncmdqueue.hxx"
@@ -34,28 +34,28 @@
 #include "dp_identifier.hxx"
 #include "dp_update.hxx"
 
-#define USER_PACKAGE_MANAGER    OUString("user")
-#define SHARED_PACKAGE_MANAGER  OUString("shared")
+#define USER_PACKAGE_MANAGER    "user"
+#define SHARED_PACKAGE_MANAGER  "shared"
 
 using namespace ::com::sun::star;
 
 namespace dp_gui {
 
-//------------------------------------------------------------------------------
+
 
 ::rtl::Reference< TheExtensionManager > TheExtensionManager::s_ExtMgr;
 
-//------------------------------------------------------------------------------
-//                             TheExtensionManager
-//------------------------------------------------------------------------------
 
-TheExtensionManager::TheExtensionManager( Window *pParent,
+//                             TheExtensionManager
+
+
+TheExtensionManager::TheExtensionManager( const uno::Reference< awt::XWindow > &xParent,
                                           const uno::Reference< uno::XComponentContext > &xContext ) :
     m_xContext( xContext ),
-    m_pParent( pParent ),
-    m_pExtMgrDialog( NULL ),
-    m_pUpdReqDialog( NULL ),
-    m_pExecuteCmdQueue( NULL )
+    m_xParent( xParent ),
+    m_pExtMgrDialog( nullptr ),
+    m_pUpdReqDialog( nullptr ),
+    m_pExecuteCmdQueue( nullptr )
 {
     m_xExtensionManager = deployment::ExtensionManager::get( xContext );
     m_xExtensionManager->addModifyListener( this );
@@ -66,18 +66,20 @@ TheExtensionManager::TheExtensionManager( Window *pParent,
     beans::PropertyValue aValue( OUString("nodepath"), 0, uno::Any( OUString("/org.openoffice.Office.OptionsDialog/Nodes") ),
                                  beans::PropertyState_DIRECT_VALUE );
     args[0] <<= aValue;
-    m_xNameAccessNodes = uno::Reference< container::XNameAccess >(
-        xConfig->createInstanceWithArguments( OUString("com.sun.star.configuration.ConfigurationAccess"),
-                                              uno::Sequence< uno::Any >( args, 1 )), uno::UNO_QUERY_THROW);
+    m_xNameAccessNodes.set(
+        xConfig->createInstanceWithArguments( "com.sun.star.configuration.ConfigurationAccess",
+                                              uno::Sequence< uno::Any >( args, 1 )),
+        uno::UNO_QUERY_THROW);
 
     // get the 'get more extensions here' url
     uno::Reference< container::XNameAccess > xNameAccessRepositories;
     beans::PropertyValue aValue2( OUString("nodepath"), 0, uno::Any( OUString("/org.openoffice.Office.ExtensionManager/ExtensionRepositories") ),
                                   beans::PropertyState_DIRECT_VALUE );
     args[0] <<= aValue2;
-    xNameAccessRepositories = uno::Reference< container::XNameAccess > (
-        xConfig->createInstanceWithArguments( OUString("com.sun.star.configuration.ConfigurationAccess"),
-                                              uno::Sequence< uno::Any >( args, 1 )), uno::UNO_QUERY_THROW);
+    xNameAccessRepositories.set(
+        xConfig->createInstanceWithArguments( "com.sun.star.configuration.ConfigurationAccess",
+                                              uno::Sequence< uno::Any >( args, 1 )),
+        uno::UNO_QUERY_THROW);
     try
     {   //throws css::container::NoSuchElementException, css::lang::WrappedTargetException
         uno::Any value = xNameAccessRepositories->getByName("WebsiteLink");
@@ -95,15 +97,15 @@ TheExtensionManager::TheExtensionManager( Window *pParent,
     }
 }
 
-//------------------------------------------------------------------------------
+
 TheExtensionManager::~TheExtensionManager()
 {
-    delete m_pUpdReqDialog;
-    delete m_pExtMgrDialog;
+    m_pUpdReqDialog.disposeAndClear();
+    m_pExtMgrDialog.disposeAndClear();
     delete m_pExecuteCmdQueue;
 }
 
-//------------------------------------------------------------------------------
+
 void TheExtensionManager::createDialog( const bool bCreateUpdDlg )
 {
     const SolarMutexGuard guard;
@@ -112,23 +114,26 @@ void TheExtensionManager::createDialog( const bool bCreateUpdDlg )
     {
         if ( !m_pUpdReqDialog )
         {
-            m_pUpdReqDialog = new UpdateRequiredDialog( NULL, this );
+            m_pUpdReqDialog = VclPtr<UpdateRequiredDialog>::Create( nullptr, this );
             delete m_pExecuteCmdQueue;
-            m_pExecuteCmdQueue = new ExtensionCmdQueue( (DialogHelper*) m_pUpdReqDialog, this, m_xContext );
+            m_pExecuteCmdQueue = new ExtensionCmdQueue( m_pUpdReqDialog.get(), this, m_xContext );
             createPackageList();
         }
     }
     else if ( !m_pExtMgrDialog )
     {
-        m_pExtMgrDialog = new ExtMgrDialog( m_pParent, this );
+        if (m_xParent.is())
+            m_pExtMgrDialog = VclPtr<ExtMgrDialog>::Create( VCLUnoHelper::GetWindow(m_xParent), this );
+        else
+            m_pExtMgrDialog = VclPtr<ExtMgrDialog>::Create( nullptr, this, Dialog::InitFlag::NoParent );
         delete m_pExecuteCmdQueue;
-        m_pExecuteCmdQueue = new ExtensionCmdQueue( (DialogHelper*) m_pExtMgrDialog, this, m_xContext );
+        m_pExecuteCmdQueue = new ExtensionCmdQueue( m_pExtMgrDialog.get(), this, m_xContext );
         m_pExtMgrDialog->setGetExtensionsURL( m_sGetExtensionsURL );
         createPackageList();
     }
 }
 
-//------------------------------------------------------------------------------
+
 void TheExtensionManager::Show()
 {
     const SolarMutexGuard guard;
@@ -136,7 +141,7 @@ void TheExtensionManager::Show()
     getDialog()->Show();
 }
 
-//------------------------------------------------------------------------------
+
 void TheExtensionManager::SetText( const OUString &rTitle )
 {
     const SolarMutexGuard guard;
@@ -144,15 +149,15 @@ void TheExtensionManager::SetText( const OUString &rTitle )
     getDialog()->SetText( rTitle );
 }
 
-//------------------------------------------------------------------------------
-void TheExtensionManager::ToTop( sal_uInt16 nFlags )
+
+void TheExtensionManager::ToTop( ToTopFlags nFlags )
 {
     const SolarMutexGuard guard;
 
     getDialog()->ToTop( nFlags );
 }
 
-//------------------------------------------------------------------------------
+
 bool TheExtensionManager::Close()
 {
     if ( m_pExtMgrDialog )
@@ -163,7 +168,7 @@ bool TheExtensionManager::Close()
         return true;
 }
 
-//------------------------------------------------------------------------------
+
 sal_Int16 TheExtensionManager::execute()
 {
     sal_Int16 nRet = 0;
@@ -171,20 +176,19 @@ sal_Int16 TheExtensionManager::execute()
     if ( m_pUpdReqDialog )
     {
         nRet = m_pUpdReqDialog->Execute();
-        delete m_pUpdReqDialog;
-        m_pUpdReqDialog = NULL;
+        m_pUpdReqDialog.disposeAndClear();
     }
 
     return nRet;
 }
 
-//------------------------------------------------------------------------------
+
 bool TheExtensionManager::isVisible()
 {
     return getDialog()->IsVisible();
 }
 
-//------------------------------------------------------------------------------
+
 bool TheExtensionManager::checkUpdates( bool /* bShowUpdateOnly */, bool /*bParentVisible*/ )
 {
     std::vector< uno::Reference< deployment::XPackage >  > vEntries;
@@ -217,7 +221,7 @@ bool TheExtensionManager::checkUpdates( bool /* bShowUpdateOnly */, bool /*bPare
     return true;
 }
 
-//------------------------------------------------------------------------------
+
 bool TheExtensionManager::installPackage( const OUString &rPackageURL, bool bWarnUser )
 {
     if ( rPackageURL.isEmpty() )
@@ -243,7 +247,7 @@ bool TheExtensionManager::installPackage( const OUString &rPackageURL, bool bWar
     return true;
 }
 
-//------------------------------------------------------------------------------
+
 bool TheExtensionManager::queryTermination()
 {
     if ( dp_misc::office_is_running() )
@@ -253,21 +257,19 @@ bool TheExtensionManager::queryTermination()
     return true;
 }
 
-//------------------------------------------------------------------------------
+
 void TheExtensionManager::terminateDialog()
 {
     if ( ! dp_misc::office_is_running() )
     {
         const SolarMutexGuard guard;
-        delete m_pExtMgrDialog;
-        m_pExtMgrDialog = NULL;
-        delete m_pUpdReqDialog;
-        m_pUpdReqDialog = NULL;
+        m_pExtMgrDialog.disposeAndClear();
+        m_pUpdReqDialog.disposeAndClear();
         Application::Quit();
     }
 }
 
-//------------------------------------------------------------------------------
+
 void TheExtensionManager::createPackageList()
 {
     uno::Sequence< uno::Sequence< uno::Reference< deployment::XPackage > > > xAllPackages;
@@ -317,8 +319,8 @@ void TheExtensionManager::createPackageList()
     }
 }
 
-//------------------------------------------------------------------------------
-PackageState TheExtensionManager::getPackageState( const uno::Reference< deployment::XPackage > &xPackage ) const
+
+PackageState TheExtensionManager::getPackageState( const uno::Reference< deployment::XPackage > &xPackage )
 {
     try {
         beans::Optional< beans::Ambiguous< sal_Bool > > option(
@@ -345,7 +347,7 @@ PackageState TheExtensionManager::getPackageState( const uno::Reference< deploym
     }
 }
 
-//------------------------------------------------------------------------------
+
 bool TheExtensionManager::isReadOnly( const uno::Reference< deployment::XPackage > &xPackage ) const
 {
     if ( m_xExtensionManager.is() && xPackage.is() )
@@ -356,7 +358,7 @@ bool TheExtensionManager::isReadOnly( const uno::Reference< deployment::XPackage
         return true;
 }
 
-//------------------------------------------------------------------------------
+
 // The function investigates if the extension supports options.
 bool TheExtensionManager::supportsOptions( const uno::Reference< deployment::XPackage > &xPackage ) const
 {
@@ -408,10 +410,10 @@ bool TheExtensionManager::supportsOptions( const uno::Reference< deployment::XPa
     return bOptions;
 }
 
-//------------------------------------------------------------------------------
+
 // XEventListener
 void TheExtensionManager::disposing( lang::EventObject const & rEvt )
-    throw ( uno::RuntimeException )
+    throw ( uno::RuntimeException, std::exception )
 {
     bool shutDown = (rEvt.Source == m_xDesktop);
 
@@ -426,28 +428,26 @@ void TheExtensionManager::disposing( lang::EventObject const & rEvt )
         if ( dp_misc::office_is_running() )
         {
             const SolarMutexGuard guard;
-            delete m_pExtMgrDialog;
-            m_pExtMgrDialog = NULL;
-            delete m_pUpdReqDialog;
-            m_pUpdReqDialog = NULL;
+            m_pExtMgrDialog.disposeAndClear();
+            m_pUpdReqDialog.disposeAndClear();
         }
         s_ExtMgr.clear();
     }
 }
 
-//------------------------------------------------------------------------------
+
 // XTerminateListener
 void TheExtensionManager::queryTermination( ::lang::EventObject const & )
-    throw ( frame::TerminationVetoException, uno::RuntimeException )
+    throw ( frame::TerminationVetoException, uno::RuntimeException, std::exception )
 {
     DialogHelper *pDialogHelper = getDialogHelper();
 
     if ( m_pExecuteCmdQueue->isBusy() || ( pDialogHelper && pDialogHelper->isBusy() ) )
     {
-        ToTop( TOTOP_RESTOREWHENMIN );
+        ToTop( ToTopFlags::RestoreWhenMin );
         throw frame::TerminationVetoException(
-            OUString("The office cannot be closed while the Extension Manager is running"),
-            uno::Reference<XInterface>(static_cast<frame::XTerminateListener*>(this), uno::UNO_QUERY));
+            "The office cannot be closed while the Extension Manager is running",
+            static_cast<frame::XTerminateListener*>(this));
     }
     else
     {
@@ -458,24 +458,24 @@ void TheExtensionManager::queryTermination( ::lang::EventObject const & )
     }
 }
 
-//------------------------------------------------------------------------------
+
 void TheExtensionManager::notifyTermination( ::lang::EventObject const & rEvt )
-    throw ( uno::RuntimeException )
+    throw ( uno::RuntimeException, std::exception )
 {
     disposing( rEvt );
 }
 
-//------------------------------------------------------------------------------
+
 // XModifyListener
 void TheExtensionManager::modified( ::lang::EventObject const & /*rEvt*/ )
-    throw ( uno::RuntimeException )
+    throw ( uno::RuntimeException, std::exception )
 {
     getDialogHelper()->prepareChecking();
     createPackageList();
     getDialogHelper()->checkEntries();
 }
 
-//------------------------------------------------------------------------------
+
 ::rtl::Reference< TheExtensionManager > TheExtensionManager::get( const uno::Reference< uno::XComponentContext > &xContext,
                                                                   const uno::Reference< awt::XWindow > &xParent,
                                                                   const OUString & extensionURL )
@@ -488,11 +488,7 @@ void TheExtensionManager::modified( ::lang::EventObject const & /*rEvt*/ )
         return s_ExtMgr;
     }
 
-    Window* pParent = DIALOG_NO_PARENT;
-    if (xParent.is())
-        pParent = VCLUnoHelper::GetWindow(xParent);
-
-    ::rtl::Reference<TheExtensionManager> that( new TheExtensionManager( pParent, xContext ) );
+    ::rtl::Reference<TheExtensionManager> that( new TheExtensionManager( xParent, xContext ) );
 
     const SolarMutexGuard guard;
     if ( ! s_ExtMgr.is() )
