@@ -31,7 +31,7 @@
 #include <osl/process.h>
 #include <osl/conditn.hxx>
 #include <osl/file.hxx>
-#include <cppuhelper/implbase1.hxx>
+#include <cppuhelper/implbase.hxx>
 #include <cppuhelper/exc_hlp.hxx>
 #include <comphelper/anytostring.hxx>
 #include <comphelper/sequence.hxx>
@@ -39,10 +39,12 @@
 
 #include <com/sun/star/deployment/ui/PackageManagerDialog.hpp>
 #include <com/sun/star/ui/dialogs/XExecutableDialog.hpp>
-#include <boost/scoped_array.hpp>
 #include <com/sun/star/ui/dialogs/XDialogClosedListener.hpp>
 #include <com/sun/star/bridge/BridgeFactory.hpp>
 #include <stdio.h>
+#if defined(UNX)
+  #include <unistd.h>
+#endif
 #include <vector>
 
 
@@ -54,7 +56,7 @@ namespace {
 struct ExtensionName
 {
     OUString m_str;
-    ExtensionName( OUString const & str ) : m_str( str ) {}
+    explicit ExtensionName( OUString const & str ) : m_str( str ) {}
     bool operator () ( Reference<deployment::XPackage> const & e ) const
     {
         if (m_str.equals(dp_misc::getIdentifier(e))
@@ -116,26 +118,26 @@ const OptionInfo s_option_infos [] = {
     { RTL_CONSTASCII_STRINGPARAM("bundled"), '\0', false},
     { RTL_CONSTASCII_STRINGPARAM("suppress-license"), 's', false},
 
-    { 0, 0, '\0', false }
+    { nullptr, 0, '\0', false }
 };
 
 class DialogClosedListenerImpl :
-    public ::cppu::WeakImplHelper1< ui::dialogs::XDialogClosedListener >
+    public ::cppu::WeakImplHelper< ui::dialogs::XDialogClosedListener >
 {
     osl::Condition & m_rDialogClosedCondition;
 
 public:
-    DialogClosedListenerImpl( osl::Condition & rDialogClosedCondition )
+    explicit DialogClosedListenerImpl( osl::Condition & rDialogClosedCondition )
         : m_rDialogClosedCondition( rDialogClosedCondition ) {}
 
     // XEventListener (base of XDialogClosedListener)
     virtual void SAL_CALL disposing( lang::EventObject const & Source )
-        throw (RuntimeException, std::exception) SAL_OVERRIDE;
+        throw (RuntimeException, std::exception) override;
 
     // XDialogClosedListener
     virtual void SAL_CALL dialogClosed(
         ui::dialogs::DialogClosedEvent const & aEvent )
-        throw (RuntimeException, std::exception) SAL_OVERRIDE;
+        throw (RuntimeException, std::exception) override;
 };
 
 // XEventListener (base of XDialogClosedListener)
@@ -177,7 +179,7 @@ Reference<deployment::XPackage> findPackage(
 
 } // anon namespace
 
-extern "C" DESKTOP_DLLPUBLIC int unopkg_main()
+extern "C" int unopkg_main()
 {
     tools::extendApplicationEnvironment();
     bool bNoOtherErrorMsg = false;
@@ -187,7 +189,7 @@ extern "C" DESKTOP_DLLPUBLIC int unopkg_main()
     bool option_verbose = false;
     bool option_bundled = false;
     bool option_suppressLicense = false;
-    bool subcmd_add = false;
+    bool option_help = false;
     bool subcmd_gui = false;
     OUString logFile;
     OUString repository;
@@ -239,7 +241,7 @@ extern "C" DESKTOP_DLLPUBLIC int unopkg_main()
         osl_getCommandArg( nPos, &subCommand.pData );
         ++nPos;
         subCommand = subCommand.trim();
-        subcmd_add = subCommand == "add";
+        bool subcmd_add = subCommand == "add";
         subcmd_gui = subCommand == "gui";
 
         // sun-command options and packages:
@@ -254,6 +256,7 @@ extern "C" DESKTOP_DLLPUBLIC int unopkg_main()
                      !readOption( &option_force, info_force, &nPos ) &&
                      !readOption( &option_bundled, info_bundled, &nPos ) &&
                      !readOption( &option_suppressLicense, info_suppressLicense, &nPos ) &&
+                     !readOption( &option_help, info_help, &nPos ) &&
                      !readArgument( &repository, info_context, &nPos ) &&
                      !isBootstrapVariable(&nPos))
             {
@@ -302,10 +305,24 @@ extern "C" DESKTOP_DLLPUBLIC int unopkg_main()
             }
             else if (option_shared) {
                 dp_misc::writeConsoleError(
-                    OUString("WARNING: explicit context given!  ") +
-                    "Ignoring option " + toString( info_shared ) + "!\n" );
+                    "WARNING: explicit context given!  Ignoring option " +
+                    toString( info_shared ) + "!\n" );
             }
         }
+#if defined(UNX)
+        if ( geteuid() == 0 )
+        {
+            if ( !(option_shared || option_bundled || option_help) )
+            {
+                dp_misc::writeConsoleError(
+                    "ERROR: cannot run "  APP_NAME  " as root without " +
+                    toString( info_shared ) + " or " + toString( info_bundled )
+                    + " option.\n");
+                return 1;
+            }
+
+        }
+#endif
 
         if (subCommand == "reinstall")
         {
@@ -324,7 +341,7 @@ extern "C" DESKTOP_DLLPUBLIC int unopkg_main()
             ::rtl::Bootstrap::expandMacros(extensionUnorc);
             oslFileError e = osl_removeFile(extensionUnorc.pData);
             if (e != osl_File_E_None && e != osl_File_E_NOENT)
-                throw Exception("Could not delete " + extensionUnorc, 0);
+                throw Exception("Could not delete " + extensionUnorc, nullptr);
         }
 
         xComponentContext = getUNO(
@@ -333,7 +350,7 @@ extern "C" DESKTOP_DLLPUBLIC int unopkg_main()
         Reference<deployment::XExtensionManager> xExtensionManager(
             deployment::ExtensionManager::get( xComponentContext ) );
 
-        Reference< ::com::sun::star::ucb::XCommandEnvironment > xCmdEnv(
+        Reference< css::ucb::XCommandEnvironment > xCmdEnv(
             createCmdEnv( xComponentContext, logFile,
                           option_force, option_verbose, option_suppressLicense) );
 
@@ -426,7 +443,7 @@ extern "C" DESKTOP_DLLPUBLIC int unopkg_main()
                       vec_packages.size(), false);
 
                 dp_misc::writeConsole(
-                    OUString("All deployed ") + repository + " extensions:\n\n");
+                    "All deployed " + repository + " extensions:\n\n");
             }
             else
             {
@@ -470,7 +487,7 @@ extern "C" DESKTOP_DLLPUBLIC int unopkg_main()
                     else
                         throw lang::IllegalArgumentException(
                             "There is no such extension deployed: " +
-                            cmdPackages[pos],0,-1);
+                            cmdPackages[pos],nullptr,-1);
                 }
 
             }
@@ -577,10 +594,10 @@ extern "C" DESKTOP_DLLPUBLIC int unopkg_main()
     catch (const LockFileException & e)
     {
         if (!subcmd_gui)
-            dp_misc::writeConsoleError(e.Message);
+            dp_misc::writeConsoleError(e.Message + "\n");
         bNoOtherErrorMsg = true;
     }
-    catch (const ::com::sun::star::uno::Exception & e ) {
+    catch (const css::uno::Exception & e ) {
         Any exc( ::cppu::getCaughtException() );
 
         dp_misc::writeConsoleError("\nERROR: " +
