@@ -32,7 +32,7 @@
 // helper class for animated graphics
 
 #include <vcl/animate.hxx>
-#include <vcl/graph.hxx>
+#include <vcl/graphic.hxx>
 #include <vcl/virdev.hxx>
 #include <vcl/svapp.hxx>
 #include <vcl/metaact.hxx>
@@ -53,7 +53,7 @@ namespace
         sal_uInt32 generateStepTime(sal_uInt32 nIndex) const;
 
     public:
-        animatedBitmapExPreparator(const Graphic& rGraphic);
+        explicit animatedBitmapExPreparator(const Graphic& rGraphic);
 
         sal_uInt32 count() const { return maSteps.size(); }
         sal_uInt32 loopCount() const { return (sal_uInt32)maAnimation.GetLoopCount(); }
@@ -66,7 +66,6 @@ namespace
         const AnimationBitmap& rAnimBitmap = maAnimation.Get(sal_uInt16(nIndex));
         sal_uInt32 nWaitTime(rAnimBitmap.nWait * 10);
 
-        // #115934#
         // Take care of special value for MultiPage TIFFs. ATM these shall just
         // show their first page. Later we will offer some switching when object
         // is selected.
@@ -97,7 +96,8 @@ namespace
         if(maAnimation.Count())
         {
             ScopedVclPtrInstance< VirtualDevice > aVirtualDevice(*Application::GetDefaultDevice());
-            ScopedVclPtrInstance< VirtualDevice > aVirtualDeviceMask(*Application::GetDefaultDevice(), 1L);
+            ScopedVclPtrInstance< VirtualDevice > aVirtualDeviceMask(*Application::GetDefaultDevice(),
+                                                                     DeviceFormat::BITMASK);
 
             // Prepare VirtualDevices and their states
             aVirtualDevice->EnableMapMode(false);
@@ -107,7 +107,7 @@ namespace
             aVirtualDevice->Erase();
             aVirtualDeviceMask->Erase();
 
-            for(sal_uInt16 a(0L); a < maAnimation.Count(); a++)
+            for(size_t a(0); a < maAnimation.Count(); a++)
             {
                 animationStep aNextStep;
                 aNextStep.mnTime = generateStepTime(a);
