@@ -48,7 +48,7 @@ namespace drawinglayer
         {
             if(BufferedDecompositionPrimitive2D::operator==(rPrimitive))
             {
-                const BaseTextStrikeoutPrimitive2D& rCompare = (BaseTextStrikeoutPrimitive2D&)rPrimitive;
+                const BaseTextStrikeoutPrimitive2D& rCompare = static_cast<const BaseTextStrikeoutPrimitive2D&>(rPrimitive);
 
                 return (getObjectTransformation() == rCompare.getObjectTransformation()
                     && getWidth() == rCompare.getWidth()
@@ -117,7 +117,7 @@ namespace drawinglayer
             const basegfx::BColor& rFontColor,
             sal_Unicode aStrikeoutChar,
             const attribute::FontAttribute& rFontAttribute,
-            const ::com::sun::star::lang::Locale& rLocale)
+            const css::lang::Locale& rLocale)
         :   BaseTextStrikeoutPrimitive2D(rObjectTransformation, fWidth, rFontColor),
             maStrikeoutChar(aStrikeoutChar),
             maFontAttribute(rFontAttribute),
@@ -129,7 +129,7 @@ namespace drawinglayer
         {
             if(BaseTextStrikeoutPrimitive2D::operator==(rPrimitive))
             {
-                const TextCharacterStrikeoutPrimitive2D& rCompare = (TextCharacterStrikeoutPrimitive2D&)rPrimitive;
+                const TextCharacterStrikeoutPrimitive2D& rCompare = static_cast<const TextCharacterStrikeoutPrimitive2D&>(rPrimitive);
 
                 return (getStrikeoutChar() == rCompare.getStrikeoutChar()
                     && getFontAttribute() == rCompare.getFontAttribute()
@@ -204,7 +204,7 @@ namespace drawinglayer
             aStrikeoutLine.transform(aUnscaledTransform);
 
             // add primitive
-            const attribute::LineAttribute aLineAttribute(getFontColor(), fStrikeoutHeight, basegfx::B2DLINEJOIN_NONE);
+            const attribute::LineAttribute aLineAttribute(getFontColor(), fStrikeoutHeight, basegfx::B2DLineJoin::NONE);
             Primitive2DSequence xRetval(1);
             xRetval[0] = Primitive2DReference(new PolygonStrokePrimitive2D(aStrikeoutLine, aLineAttribute));
 
@@ -255,7 +255,7 @@ namespace drawinglayer
         {
             if(BaseTextStrikeoutPrimitive2D::operator==(rPrimitive))
             {
-                const TextGeometryStrikeoutPrimitive2D& rCompare = (TextGeometryStrikeoutPrimitive2D&)rPrimitive;
+                const TextGeometryStrikeoutPrimitive2D& rCompare = static_cast<const TextGeometryStrikeoutPrimitive2D&>(rPrimitive);
 
                 return (getHeight() == rCompare.getHeight()
                     && getOffset() == rCompare.getOffset()
