@@ -25,12 +25,12 @@
 #include <impedit.hxx>
 #include <editeng/editview.hxx>
 
-//  ----------------------------------------------------------------------
+
 //  class EditSelFunctionSet
-//  ----------------------------------------------------------------------
+
 EditSelFunctionSet::EditSelFunctionSet()
 {
-    pCurView = NULL;
+    pCurView = nullptr;
 }
 
 void EditSelFunctionSet::CreateAnchor()
@@ -44,20 +44,20 @@ void EditSelFunctionSet::DestroyAnchor()
     // Only with multiple selection
 }
 
-sal_Bool EditSelFunctionSet::SetCursorAtPoint( const Point& rPointPixel, sal_Bool )
+bool EditSelFunctionSet::SetCursorAtPoint( const Point& rPointPixel, bool )
 {
     if ( pCurView )
         return pCurView->pImpEditView->SetCursorAtPoint( rPointPixel );
 
-    return sal_False;
+    return false;
 }
 
-sal_Bool EditSelFunctionSet::IsSelectionAtPoint( const Point& rPointPixel )
+bool EditSelFunctionSet::IsSelectionAtPoint( const Point& rPointPixel )
 {
     if ( pCurView )
         return pCurView->pImpEditView->IsSelectionAtPoint( rPointPixel );
 
-    return sal_False;
+    return false;
 }
 
 void EditSelFunctionSet::DeselectAtPoint( const Point& )
@@ -79,24 +79,24 @@ void EditSelFunctionSet::DeselectAll()
         pCurView->pImpEditView->DeselectAll();
 }
 
-//  ----------------------------------------------------------------------
+
 //  class EditSelectionEngine
-//  ----------------------------------------------------------------------
-EditSelectionEngine::EditSelectionEngine() : SelectionEngine( (Window*)0 )
+
+EditSelectionEngine::EditSelectionEngine() : SelectionEngine( nullptr )
 {
     SetSelectionMode( RANGE_SELECTION );
-    EnableDrag( sal_True );
+    EnableDrag( true );
 }
 
 void EditSelectionEngine::SetCurView( EditView* pNewView )
 {
     if ( GetFunctionSet() )
-        ((EditSelFunctionSet*)GetFunctionSet())->SetCurView( pNewView );
+        const_cast<EditSelFunctionSet*>(static_cast<const EditSelFunctionSet*>(GetFunctionSet()))->SetCurView( pNewView );
 
     if ( pNewView )
         SetWindow( pNewView->GetWindow() );
     else
-        SetWindow( (Window*)0 );
+        SetWindow( nullptr );
 }
 
 /* vim:set shiftwidth=4 softtabstop=4 expandtab: */
