@@ -44,11 +44,11 @@ OutlinerEditEng::~OutlinerEditEng()
 {
 }
 
-void OutlinerEditEng::PaintingFirstLine( sal_Int32 nPara, const Point& rStartPos, long nBaseLineY, const Point& rOrigin, short nOrientation, OutputDevice* pOutDev )
+void OutlinerEditEng::PaintingFirstLine( sal_Int32 nPara, const Point& rStartPos, long /*nBaseLineY*/, const Point& rOrigin, short nOrientation, OutputDevice* pOutDev )
 {
-    if( GetControlWord() & EE_CNTRL_OUTLINER )
+    if( GetControlWord() & EEControlBits::OUTLINER )
     {
-        PaintFirstLineInfo aInfo( nPara, rStartPos, nBaseLineY, rOrigin, nOrientation, pOutDev );
+        PaintFirstLineInfo aInfo( nPara, rStartPos, pOutDev );
         pOwner->maPaintFirstLineHdl.Call( &aInfo );
     }
 
@@ -57,7 +57,7 @@ void OutlinerEditEng::PaintingFirstLine( sal_Int32 nPara, const Point& rStartPos
 
 const SvxNumberFormat* OutlinerEditEng::GetNumberFormat( sal_Int32 nPara ) const
 {
-    const SvxNumberFormat* pFmt = NULL;
+    const SvxNumberFormat* pFmt = nullptr;
     if (pOwner)
         pFmt = pOwner->GetNumberFormat( nPara );
     return pFmt;
@@ -94,9 +94,9 @@ void OutlinerEditEng::ParagraphConnected( sal_Int32 /*nLeftParagraph*/, sal_Int3
     if( pOwner && pOwner->IsUndoEnabled() && !const_cast<EditEngine&>(pOwner->GetEditEngine()).IsInUndo() )
     {
         Paragraph* pPara = pOwner->GetParagraph( nRightParagraph );
-        if( pPara && pOwner->HasParaFlag( pPara, PARAFLAG_ISPAGE ) )
+        if( pPara && Outliner::HasParaFlag( pPara, ParaFlag::ISPAGE ) )
         {
-            pOwner->InsertUndo( new OutlinerUndoChangeParaFlags( pOwner, nRightParagraph, PARAFLAG_ISPAGE, 0 ) );
+            pOwner->InsertUndo( new OutlinerUndoChangeParaFlags( pOwner, nRightParagraph, ParaFlag::ISPAGE, ParaFlag::NONE ) );
         }
     }
 }
@@ -147,26 +147,26 @@ OUString OutlinerEditEng::GetUndoComment( sal_uInt16 nUndoId ) const
 }
 
 void OutlinerEditEng::DrawingText( const Point& rStartPos, const OUString& rText, sal_Int32 nTextStart, sal_Int32 nTextLen,
-                                   const long* pDXArray, const SvxFont& rFont, sal_Int32 nPara, sal_Int32 nIndex, sal_uInt8 nRightToLeft,
+                                   const long* pDXArray, const SvxFont& rFont, sal_Int32 nPara, sal_Int32 /*nIndex*/, sal_uInt8 nRightToLeft,
                                    const EEngineData::WrongSpellVector* pWrongSpellVector,
                                    const SvxFieldData* pFieldData,
                                    bool bEndOfLine,
                                    bool bEndOfParagraph,
                                    bool bEndOfBullet,
-                                   const ::com::sun::star::lang::Locale* pLocale,
+                                   const css::lang::Locale* pLocale,
                                    const Color& rOverlineColor,
                                    const Color& rTextLineColor)
 {
-    pOwner->DrawingText(rStartPos,rText,nTextStart,nTextLen,pDXArray,rFont,nPara,nIndex,nRightToLeft,
+    pOwner->DrawingText(rStartPos,rText,nTextStart,nTextLen,pDXArray,rFont,nPara,nRightToLeft,
         pWrongSpellVector, pFieldData, bEndOfLine, bEndOfParagraph, bEndOfBullet, pLocale, rOverlineColor, rTextLineColor);
 }
 
 void OutlinerEditEng::DrawingTab( const Point& rStartPos, long nWidth, const OUString& rChar,
-    const SvxFont& rFont, sal_Int32 nPara, sal_Int32 nIndex, sal_uInt8 nRightToLeft,
+    const SvxFont& rFont, sal_Int32 nPara, sal_Int32 /*nIndex*/, sal_uInt8 nRightToLeft,
     bool bEndOfLine, bool bEndOfParagraph,
     const Color& rOverlineColor, const Color& rTextLineColor)
 {
-    pOwner->DrawingTab(rStartPos, nWidth, rChar, rFont, nPara, nIndex, nRightToLeft,
+    pOwner->DrawingTab(rStartPos, nWidth, rChar, rFont, nPara, nRightToLeft,
             bEndOfLine, bEndOfParagraph, rOverlineColor, rTextLineColor );
 }
 
@@ -176,11 +176,6 @@ void OutlinerEditEng::FieldClicked( const SvxFieldItem& rField, sal_Int32 nPara,
     pOwner->FieldClicked( rField, nPara, nPos );
 }
 
-void OutlinerEditEng::FieldSelected( const SvxFieldItem& rField, sal_Int32 nPara, sal_Int32 nPos )
-{
-    pOwner->FieldSelected( rField, nPara, nPos );
-}
-
 OUString OutlinerEditEng::CalcFieldValue( const SvxFieldItem& rField, sal_Int32 nPara, sal_Int32 nPos, Color*& rpTxtColor, Color*& rpFldColor )
 {
     return pOwner->CalcFieldValue( rField, nPara, nPos, rpTxtColor, rpFldColor );
@@ -198,7 +193,7 @@ void OutlinerEditEng::SetParaAttribs( sal_Int32 nPara, const SfxItemSet& rSet )
 
         pOwner->ImplCheckNumBulletItem( nPara );
         // #i100014#
-        // It is not a good idea to substract 1 from a count and cast the result
+        // It is not a good idea to subtract 1 from a count and cast the result
         // to sal_uInt16 without check, if the count is 0.
         pOwner->ImplCheckParagraphs( nPara, pOwner->pParaList->GetParagraphCount() );
 
