@@ -45,7 +45,7 @@
 
 #include "commonembobj.hxx"
 #include "intercept.hxx"
-
+#include "embedobj.hxx"
 
 using namespace ::com::sun::star;
 
@@ -69,7 +69,7 @@ awt::Rectangle GetRectangleInterception( const awt::Rectangle& aRect1, const awt
     return aResult;
 }
 
-//----------------------------------------------
+
 sal_Int32 OCommonEmbeddedObject::ConvertVerbToState_Impl( sal_Int32 nVerb )
 {
     for ( sal_Int32 nInd = 0; nInd < m_aVerbTable.getLength(); nInd++ )
@@ -79,7 +79,7 @@ sal_Int32 OCommonEmbeddedObject::ConvertVerbToState_Impl( sal_Int32 nVerb )
     throw lang::IllegalArgumentException(); // TODO: unexpected verb provided
 }
 
-//----------------------------------------------
+
 void OCommonEmbeddedObject::Deactivate()
 {
     uno::Reference< util::XModifiable > xModif( m_pDocHolder->GetComponent(), uno::UNO_QUERY );
@@ -101,8 +101,8 @@ void OCommonEmbeddedObject::Deactivate()
         catch( const uno::Exception& e )
         {
             throw embed::StorageWrappedTargetException(
-                OUString( "The client could not store the object!" ),
-                uno::Reference< uno::XInterface >( static_cast< ::cppu::OWeakObject* >( this ) ),
+                "The client could not store the object!",
+                static_cast< ::cppu::OWeakObject* >( this ),
                 uno::makeAny( e ) );
         }
     }
@@ -112,14 +112,14 @@ void OCommonEmbeddedObject::Deactivate()
     xClientSite->visibilityChanged( sal_False );
 }
 
-//----------------------------------------------
-void OCommonEmbeddedObject::StateChangeNotification_Impl( sal_Bool bBeforeChange, sal_Int32 nOldState, sal_Int32 nNewState ,::osl::ResettableMutexGuard& rGuard )
+
+void OCommonEmbeddedObject::StateChangeNotification_Impl( bool bBeforeChange, sal_Int32 nOldState, sal_Int32 nNewState ,::osl::ResettableMutexGuard& rGuard )
 {
     if ( m_pInterfaceContainer )
     {
         ::cppu::OInterfaceContainerHelper* pContainer = m_pInterfaceContainer->getContainer(
-                            ::getCppuType( ( const uno::Reference< embed::XStateChangeListener >*) NULL ) );
-        if ( pContainer != NULL )
+                            cppu::UnoType<embed::XStateChangeListener>::get());
+        if ( pContainer != nullptr )
         {
             lang::EventObject aSource( static_cast< ::cppu::OWeakObject* >( this ) );
             ::cppu::OInterfaceIteratorHelper pIterator(*pContainer);
@@ -132,9 +132,9 @@ void OCommonEmbeddedObject::StateChangeNotification_Impl( sal_Bool bBeforeChange
                 try
                 {
                     if ( bBeforeChange )
-                        ((embed::XStateChangeListener*)pIterator.next())->changingState( aSource, nOldState, nNewState );
+                        static_cast<embed::XStateChangeListener*>(pIterator.next())->changingState( aSource, nOldState, nNewState );
                     else
-                        ((embed::XStateChangeListener*)pIterator.next())->stateChanged( aSource, nOldState, nNewState );
+                        static_cast<embed::XStateChangeListener*>(pIterator.next())->stateChanged( aSource, nOldState, nNewState );
                 }
                 catch( const uno::Exception& )
                 {
@@ -150,7 +150,7 @@ void OCommonEmbeddedObject::StateChangeNotification_Impl( sal_Bool bBeforeChange
     }
 }
 
-//----------------------------------------------
+
 void OCommonEmbeddedObject::SwitchStateTo_Impl( sal_Int32 nNextState )
 {
     // TODO: may be needs interaction handler to detect wherether the object state
@@ -161,7 +161,7 @@ void OCommonEmbeddedObject::SwitchStateTo_Impl( sal_Int32 nNextState )
         if ( nNextState == embed::EmbedStates::RUNNING )
         {
             // after the object reaches the running state the cloned size is not necessary any more
-            m_bHasClonedSize = sal_False;
+            m_bHasClonedSize = false;
 
             if ( m_bIsLink )
             {
@@ -216,7 +216,7 @@ void OCommonEmbeddedObject::SwitchStateTo_Impl( sal_Int32 nNextState )
             m_bHasClonedSize = m_pDocHolder->GetExtent( embed::Aspects::MSOLE_CONTENT, &m_aClonedSize );
 
             // actually frame should not exist at this point
-            m_pDocHolder->CloseDocument( sal_False, sal_False );
+            m_pDocHolder->CloseDocument( false, false );
 
             m_nObjectState = nNextState;
         }
@@ -225,10 +225,7 @@ void OCommonEmbeddedObject::SwitchStateTo_Impl( sal_Int32 nNextState )
             if ( nNextState == embed::EmbedStates::INPLACE_ACTIVE )
             {
                 if ( !m_xClientSite.is() )
-                    throw embed::WrongStateException(
-                        OUString( "client site not set, yet" ),
-                        *this
-                );
+                    throw embed::WrongStateException( "client site not set, yet", *this );
 
                 uno::Reference< embed::XInplaceClient > xInplaceClient( m_xClientSite, uno::UNO_QUERY );
                 if ( xInplaceClient.is() && xInplaceClient->canInplaceActivate() )
@@ -252,7 +249,7 @@ void OCommonEmbeddedObject::SwitchStateTo_Impl( sal_Int32 nNextState )
 
                     // dispatch provider may not be provided
                     uno::Reference< frame::XDispatchProvider > xContainerDP = xInplaceClient->getInplaceDispatchProvider();
-                    sal_Bool bOk = m_pDocHolder->ShowInplace( xClientWindowPeer, aRectangleToShow, xContainerDP );
+                    bool bOk = m_pDocHolder->ShowInplace( xClientWindowPeer, aRectangleToShow, xContainerDP );
                     m_nObjectState = nNextState;
                     if ( !bOk )
                     {
@@ -301,7 +298,7 @@ void OCommonEmbeddedObject::SwitchStateTo_Impl( sal_Int32 nNextState )
             {
                 uno::Reference< embed::XInplaceClient > xInplaceClient( m_xClientSite, uno::UNO_QUERY_THROW );
                 // TODO:
-                uno::Reference< ::com::sun::star::frame::XLayoutManager > xContainerLM =
+                uno::Reference< css::frame::XLayoutManager > xContainerLM =
                             xInplaceClient->getLayoutManager();
                 if ( xContainerLM.is() )
                 {
@@ -326,7 +323,7 @@ void OCommonEmbeddedObject::SwitchStateTo_Impl( sal_Int32 nNextState )
                     // the container. Locking the LM will prevent flicker.
                     xContainerLM->lock();
                     xInplaceClient->activatingUI();
-                    sal_Bool bOk = m_pDocHolder->ShowUI( xContainerLM, xContainerDP, aModuleName );
+                    bool bOk = m_pDocHolder->ShowUI( xContainerLM, xContainerDP, aModuleName );
                     xContainerLM->unlock();
 
                     if ( bOk )
@@ -368,29 +365,29 @@ void OCommonEmbeddedObject::SwitchStateTo_Impl( sal_Int32 nNextState )
         if ( nNextState == embed::EmbedStates::INPLACE_ACTIVE )
         {
             uno::Reference< embed::XInplaceClient > xInplaceClient( m_xClientSite, uno::UNO_QUERY_THROW );
-            uno::Reference< ::com::sun::star::frame::XLayoutManager > xContainerLM =
+            uno::Reference< css::frame::XLayoutManager > xContainerLM =
                         xInplaceClient->getLayoutManager();
 
-            sal_Bool bOk = sal_False;
+            bool bOk = false;
             if ( xContainerLM.is() )
-                   bOk = m_pDocHolder->HideUI( xContainerLM );
+                bOk = m_pDocHolder->HideUI( xContainerLM );
 
             if ( bOk )
             {
                 m_nObjectState = nNextState;
                 m_pDocHolder->ResizeHatchWindow();
-                   xInplaceClient->deactivatedUI();
+                xInplaceClient->deactivatedUI();
             }
             else
                 throw embed::WrongStateException(); //TODO: can't activate UI
         }
     }
     else
-        throw embed::WrongStateException( OUString( "The object is in unacceptable state!\n" ),
-                                        uno::Reference< uno::XInterface >( static_cast< ::cppu::OWeakObject* >(this) ) );
+        throw embed::WrongStateException( "The object is in unacceptable state!",
+                                          static_cast< ::cppu::OWeakObject* >(this) );
 }
 
-//----------------------------------------------
+
 uno::Sequence< sal_Int32 > OCommonEmbeddedObject::GetIntermediateStatesSequence_Impl( sal_Int32 nNewState )
 {
     sal_Int32 nCurInd = 0;
@@ -399,8 +396,8 @@ uno::Sequence< sal_Int32 > OCommonEmbeddedObject::GetIntermediateStatesSequence_
             break;
 
     if ( nCurInd == m_aAcceptedStates.getLength() )
-        throw embed::WrongStateException( OUString( "The object is in unacceptable state!\n" ),
-                                        uno::Reference< uno::XInterface >( static_cast< ::cppu::OWeakObject* >(this) ) );
+        throw embed::WrongStateException( "The object is in unacceptable state!",
+                                          static_cast< ::cppu::OWeakObject* >(this) );
 
     sal_Int32 nDestInd = 0;
     for ( nDestInd = 0; nDestInd < m_aAcceptedStates.getLength(); nDestInd++ )
@@ -409,32 +406,29 @@ uno::Sequence< sal_Int32 > OCommonEmbeddedObject::GetIntermediateStatesSequence_
 
     if ( nDestInd == m_aAcceptedStates.getLength() )
         throw embed::UnreachableStateException(
-            OUString( "The state either not reachable, or the object allows the state only as an intermediate one!\n" ),
-            uno::Reference< uno::XInterface >( static_cast< ::cppu::OWeakObject* >(this) ),
+            "The state either not reachable, or the object allows the state only as an intermediate one!",
+            static_cast< ::cppu::OWeakObject* >(this),
             m_nObjectState,
             nNewState );
 
     return m_pIntermediateStatesSeqs[nCurInd][nDestInd];
 }
 
-//----------------------------------------------
+
 void SAL_CALL OCommonEmbeddedObject::changeState( sal_Int32 nNewState )
         throw ( embed::UnreachableStateException,
                 embed::WrongStateException,
                 uno::Exception,
-                uno::RuntimeException )
+                uno::RuntimeException, std::exception )
 {
-    SAL_INFO( "embeddedobj.common", "embeddedobj (mv76033) OCommonEmbeddedObject::changeState" );
-
-    uno::Reference< uno::XInterface >( static_cast< ::cppu::OWeakObject* >( this ), uno::UNO_QUERY);
     {
         ::osl::ResettableMutexGuard aGuard( m_aMutex );
         if ( m_bDisposed )
             throw lang::DisposedException(); // TODO
 
         if ( m_nObjectState == -1 )
-            throw embed::WrongStateException( OUString( "The object has no persistence!\n" ),
-                                            uno::Reference< uno::XInterface >( static_cast< ::cppu::OWeakObject* >(this) ) );
+            throw embed::WrongStateException( "The object has no persistence!",
+                                              static_cast< ::cppu::OWeakObject* >(this) );
 
         sal_Int32 nOldState = m_nObjectState;
 
@@ -463,7 +457,7 @@ void SAL_CALL OCommonEmbeddedObject::changeState( sal_Int32 nNewState )
             uno::Sequence< sal_Int32 > aIntermediateStates = GetIntermediateStatesSequence_Impl( nNewState );
 
             // notify listeners that the object is going to change the state
-            StateChangeNotification_Impl( sal_True, nOldState, nNewState,aGuard );
+            StateChangeNotification_Impl( true, nOldState, nNewState,aGuard );
 
             try {
                 for ( sal_Int32 nInd = 0; nInd < aIntermediateStates.getLength(); nInd++ )
@@ -475,61 +469,59 @@ void SAL_CALL OCommonEmbeddedObject::changeState( sal_Int32 nNewState )
             {
                 if ( nOldState != m_nObjectState )
                     // notify listeners that the object has changed the state
-                    StateChangeNotification_Impl( sal_False, nOldState, m_nObjectState, aGuard );
+                    StateChangeNotification_Impl( false, nOldState, m_nObjectState, aGuard );
 
                 throw;
             }
         }
 
         // notify listeners that the object has changed the state
-        StateChangeNotification_Impl( sal_False, nOldState, nNewState, aGuard );
+        StateChangeNotification_Impl( false, nOldState, nNewState, aGuard );
 
         // let the object window be shown
         if ( nNewState == embed::EmbedStates::UI_ACTIVE || nNewState == embed::EmbedStates::INPLACE_ACTIVE )
-            PostEvent_Impl( OUString( "OnVisAreaChanged" ) );
+            PostEvent_Impl( "OnVisAreaChanged" );
     }
 }
 
-//----------------------------------------------
+
 uno::Sequence< sal_Int32 > SAL_CALL OCommonEmbeddedObject::getReachableStates()
         throw ( embed::WrongStateException,
-                uno::RuntimeException )
+                uno::RuntimeException, std::exception )
 {
     if ( m_bDisposed )
         throw lang::DisposedException(); // TODO
 
     if ( m_nObjectState == -1 )
-        throw embed::WrongStateException( OUString( "The object has no persistence!\n" ),
-                                        uno::Reference< uno::XInterface >( static_cast< ::cppu::OWeakObject* >(this) ) );
+        throw embed::WrongStateException( "The object has no persistence!",
+                                           static_cast< ::cppu::OWeakObject* >(this) );
 
     return m_aAcceptedStates;
 }
 
-//----------------------------------------------
+
 sal_Int32 SAL_CALL OCommonEmbeddedObject::getCurrentState()
         throw ( embed::WrongStateException,
-                uno::RuntimeException )
+                uno::RuntimeException, std::exception )
 {
     if ( m_bDisposed )
         throw lang::DisposedException(); // TODO
 
     if ( m_nObjectState == -1 )
-        throw embed::WrongStateException( OUString( "The object has no persistence!\n" ),
-                                        uno::Reference< uno::XInterface >( static_cast< ::cppu::OWeakObject* >(this) ) );
+        throw embed::WrongStateException( "The object has no persistence!",
+                                          static_cast< ::cppu::OWeakObject* >(this) );
 
     return m_nObjectState;
 }
 
-//----------------------------------------------
+
 void SAL_CALL OCommonEmbeddedObject::doVerb( sal_Int32 nVerbID )
         throw ( lang::IllegalArgumentException,
                 embed::WrongStateException,
                 embed::UnreachableStateException,
                 uno::Exception,
-                uno::RuntimeException )
+                uno::RuntimeException, std::exception )
 {
-    SAL_INFO( "embeddedobj.common", "embeddedobj (mv76033) OCommonEmbeddedObject::doVerb" );
-
     SolarMutexGuard aSolarGuard;
         //TODO: a gross hack to avoid deadlocks when this is called from the
         // outside and OCommonEmbeddedObject::changeState, with m_aMutex locked,
@@ -545,8 +537,8 @@ void SAL_CALL OCommonEmbeddedObject::doVerb( sal_Int32 nVerbID )
         throw lang::DisposedException(); // TODO
 
     if ( m_nObjectState == -1 )
-        throw embed::WrongStateException( OUString( "The object has no persistence!\n" ),
-                                        uno::Reference< uno::XInterface >( static_cast< ::cppu::OWeakObject* >(this) ) );
+        throw embed::WrongStateException( "The object has no persistence!",
+                                          static_cast< ::cppu::OWeakObject* >(this) );
 
     // for internal documents this call is just a duplicate of changeState
     sal_Int32 nNewState = -1;
@@ -569,26 +561,26 @@ void SAL_CALL OCommonEmbeddedObject::doVerb( sal_Int32 nVerbID )
     }
 }
 
-//----------------------------------------------
+
 uno::Sequence< embed::VerbDescriptor > SAL_CALL OCommonEmbeddedObject::getSupportedVerbs()
         throw ( embed::WrongStateException,
-                uno::RuntimeException )
+                uno::RuntimeException, std::exception )
 {
     if ( m_bDisposed )
         throw lang::DisposedException(); // TODO
 
     if ( m_nObjectState == -1 )
-        throw embed::WrongStateException( OUString( "The object has no persistence!\n" ),
-                                        uno::Reference< uno::XInterface >( static_cast< ::cppu::OWeakObject* >(this) ) );
+        throw embed::WrongStateException( "The object has no persistence!",
+                                          static_cast< ::cppu::OWeakObject* >(this) );
 
     return m_aObjectVerbs;
 }
 
-//----------------------------------------------
+
 void SAL_CALL OCommonEmbeddedObject::setClientSite(
                 const uno::Reference< embed::XEmbeddedClient >& xClient )
         throw ( embed::WrongStateException,
-                uno::RuntimeException )
+                uno::RuntimeException, std::exception )
 {
     ::osl::MutexGuard aGuard( m_aMutex );
     if ( m_bDisposed )
@@ -598,57 +590,57 @@ void SAL_CALL OCommonEmbeddedObject::setClientSite(
     {
         if ( m_nObjectState != embed::EmbedStates::LOADED && m_nObjectState != embed::EmbedStates::RUNNING )
             throw embed::WrongStateException(
-                                    OUString( "The client site can not be set currently!\n" ),
-                                    uno::Reference< uno::XInterface >( static_cast< ::cppu::OWeakObject* >(this) ) );
+                                    "The client site can not be set currently!",
+                                     static_cast< ::cppu::OWeakObject* >(this) );
 
         m_xClientSite = xClient;
     }
 }
 
-//----------------------------------------------
+
 uno::Reference< embed::XEmbeddedClient > SAL_CALL OCommonEmbeddedObject::getClientSite()
         throw ( embed::WrongStateException,
-                uno::RuntimeException )
+                uno::RuntimeException, std::exception )
 {
     if ( m_bDisposed )
         throw lang::DisposedException(); // TODO
 
     if ( m_nObjectState == -1 )
-        throw embed::WrongStateException( OUString( "The object has no persistence!\n" ),
-                                        uno::Reference< uno::XInterface >( static_cast< ::cppu::OWeakObject* >(this) ) );
+        throw embed::WrongStateException( "The object has no persistence!",
+                                          static_cast< ::cppu::OWeakObject* >(this) );
 
     return m_xClientSite;
 }
 
-//----------------------------------------------
+
 void SAL_CALL OCommonEmbeddedObject::update()
         throw ( embed::WrongStateException,
                 uno::Exception,
-                uno::RuntimeException )
+                uno::RuntimeException, std::exception )
 {
     ::osl::MutexGuard aGuard( m_aMutex );
     if ( m_bDisposed )
         throw lang::DisposedException(); // TODO
 
     if ( m_nObjectState == -1 )
-        throw embed::WrongStateException( OUString( "The object has no persistence!\n" ),
-                                        uno::Reference< uno::XInterface >( static_cast< ::cppu::OWeakObject* >(this) ) );
+        throw embed::WrongStateException( "The object has no persistence!",
+                                          static_cast< ::cppu::OWeakObject* >(this) );
 
-    PostEvent_Impl( OUString( "OnVisAreaChanged" ) );
+    PostEvent_Impl( "OnVisAreaChanged" );
 }
 
-//----------------------------------------------
+
 void SAL_CALL OCommonEmbeddedObject::setUpdateMode( sal_Int32 nMode )
         throw ( embed::WrongStateException,
-                uno::RuntimeException )
+                uno::RuntimeException, std::exception )
 {
     ::osl::MutexGuard aGuard( m_aMutex );
     if ( m_bDisposed )
         throw lang::DisposedException(); // TODO
 
     if ( m_nObjectState == -1 )
-        throw embed::WrongStateException( OUString( "The object has no persistence!\n" ),
-                                        uno::Reference< uno::XInterface >( static_cast< ::cppu::OWeakObject* >(this) ) );
+        throw embed::WrongStateException( "The object has no persistence!",
+                                          static_cast< ::cppu::OWeakObject* >(this) );
 
     OSL_ENSURE( nMode == embed::EmbedUpdateModes::ALWAYS_UPDATE
                     || nMode == embed::EmbedUpdateModes::EXPLICIT_UPDATE,
@@ -656,10 +648,10 @@ void SAL_CALL OCommonEmbeddedObject::setUpdateMode( sal_Int32 nMode )
     m_nUpdateMode = nMode;
 }
 
-//----------------------------------------------
+
 sal_Int64 SAL_CALL OCommonEmbeddedObject::getStatus( sal_Int64 )
         throw ( embed::WrongStateException,
-                uno::RuntimeException )
+                uno::RuntimeException, std::exception )
 {
     if ( m_bDisposed )
         throw lang::DisposedException(); // TODO
@@ -667,9 +659,9 @@ sal_Int64 SAL_CALL OCommonEmbeddedObject::getStatus( sal_Int64 )
     return m_nMiscStatus;
 }
 
-//----------------------------------------------
+
 void SAL_CALL OCommonEmbeddedObject::setContainerName( const OUString& sName )
-        throw ( uno::RuntimeException )
+        throw ( uno::RuntimeException, std::exception )
 {
     ::osl::MutexGuard aGuard( m_aMutex );
     if ( m_bDisposed )
@@ -678,12 +670,12 @@ void SAL_CALL OCommonEmbeddedObject::setContainerName( const OUString& sName )
     m_aContainerName = sName;
 }
 
-com::sun::star::uno::Reference< com::sun::star::uno::XInterface > SAL_CALL OCommonEmbeddedObject::getParent() throw (::com::sun::star::uno::RuntimeException)
+css::uno::Reference< css::uno::XInterface > SAL_CALL OCommonEmbeddedObject::getParent() throw (css::uno::RuntimeException, std::exception)
 {
     return m_xParent;
 }
 
-void SAL_CALL OCommonEmbeddedObject::setParent( const com::sun::star::uno::Reference< com::sun::star::uno::XInterface >& xParent ) throw (::com::sun::star::lang::NoSupportException, ::com::sun::star::uno::RuntimeException)
+void SAL_CALL OCommonEmbeddedObject::setParent( const css::uno::Reference< css::uno::XInterface >& xParent ) throw (css::lang::NoSupportException, css::uno::RuntimeException, std::exception)
 {
     m_xParent = xParent;
     if ( m_nObjectState != -1 && m_nObjectState != embed::EmbedStates::LOADED )
@@ -695,7 +687,7 @@ void SAL_CALL OCommonEmbeddedObject::setParent( const com::sun::star::uno::Refer
 }
 
 // XDefaultSizeTransmitter
-void SAL_CALL OCommonEmbeddedObject::setDefaultSize( const ::com::sun::star::awt::Size& rSize_100TH_MM ) throw (::com::sun::star::uno::RuntimeException)
+void SAL_CALL OCommonEmbeddedObject::setDefaultSize( const css::awt::Size& rSize_100TH_MM ) throw (css::uno::RuntimeException, std::exception)
 {
     //#i103460# charts do not necessaryly have an own size within ODF files, in this case they need to use the size settings from the surrounding frame, which is made available with this method
     m_aDefaultSizeForChart_In_100TH_MM = rSize_100TH_MM;
