@@ -104,7 +104,7 @@ uno::Reference< io::XInputStream > createTempXInStreamFromIStream(
             if ( xTempSeek.is() )
             {
                 xTempSeek->seek ( 0 );
-                xResult = uno::Reference< io::XInputStream >( xTempOut, uno::UNO_QUERY );
+                xResult.set( xTempOut, uno::UNO_QUERY );
             }
         }
     }
@@ -163,9 +163,9 @@ HRESULT copyXTempOutToIStream( uno::Reference< io::XOutputStream > xTempOut, ISt
 }
 
 
-//===============================================================================
+
 // EmbedDocument_Impl
-//===============================================================================
+
 
 EmbedDocument_Impl::EmbedDocument_Impl( const uno::Reference< lang::XMultiServiceFactory >& xFactory, const GUID* guid )
 : m_refCount( 0L )
@@ -274,7 +274,7 @@ HRESULT EmbedDocument_Impl::SaveTo_Impl( IStorage* pStg )
     return hr;
 }
 
-//-------------------------------------------------------------------------------
+
 // IUnknown
 
 STDMETHODIMP EmbedDocument_Impl::QueryInterface( REFIID riid, void FAR* FAR* ppv )
@@ -362,7 +362,7 @@ STDMETHODIMP_(ULONG) EmbedDocument_Impl::Release()
     return nCount;
 }
 
-//-------------------------------------------------------------------------------
+
 // IPersist
 
 STDMETHODIMP EmbedDocument_Impl::GetClassID( CLSID* pClassId )
@@ -371,7 +371,7 @@ STDMETHODIMP EmbedDocument_Impl::GetClassID( CLSID* pClassId )
     return S_OK;
 }
 
-//-------------------------------------------------------------------------------
+
 // IPersistStorage
 
 STDMETHODIMP EmbedDocument_Impl::IsDirty()
@@ -738,7 +738,7 @@ STDMETHODIMP EmbedDocument_Impl::HandsOffStorage()
     return S_OK;
 }
 
-//-------------------------------------------------------------------------------
+
 // IPersistFile
 
 STDMETHODIMP EmbedDocument_Impl::Load( LPCOLESTR pszFileName, DWORD /*dwMode*/ )
@@ -920,7 +920,7 @@ STDMETHODIMP EmbedDocument_Impl::GetCurFile( LPOLESTR *ppszFileName )
     return m_aFileName.getLength() ? S_OK : S_FALSE;
 }
 
-// ===============================================
+
 
 LockedEmbedDocument_Impl EmbeddedDocumentInstanceAccess_Impl::GetEmbedDocument()
 {
@@ -934,7 +934,7 @@ void EmbeddedDocumentInstanceAccess_Impl::ClearEmbedDocument()
     m_pEmbedDocument = NULL;
 }
 
-// ===============================================
+
 
 LockedEmbedDocument_Impl::LockedEmbedDocument_Impl()
 : m_pEmbedDocument( NULL )
@@ -991,11 +991,4 @@ void LockedEmbedDocument_Impl::ExecuteMethod( sal_Int16 nId )
     }
 }
 
-// Fix strange warnings about some
-// ATL::CAxHostWindow::QueryInterface|AddRef|Releae functions.
-// warning C4505: 'xxx' : unreferenced local function has been removed
-#if defined(_MSC_VER)
-#pragma warning(disable: 4505)
-#endif
-
 /* vim:set shiftwidth=4 softtabstop=4 expandtab: */
