@@ -19,9 +19,6 @@
 
 // SOActiveX.cpp : Implementation of CSOActiveX
 
-#pragma warning (disable:4505)
-// permanently suppress "unreferenced local function has been removed" warning
-
 #pragma warning (push,1)
 #pragma warning (disable:4265)
 
@@ -37,7 +34,7 @@
 #define STAROFFICE_WINDOWCLASS "SOParentWindow"
 
 
-/////////////////////////////////////////////////////////////////////////////
+
 
 void OutputError_Impl( HWND hw, HRESULT ErrorCode )
 {
@@ -140,7 +137,7 @@ HRESULT GetPropertiesFromIDisp( IDispatch* pdispObject,
 
     return S_OK;
 }
-/////////////////////////////////////////////////////////////////////////////
+
 // CSOActiveX
 
 CSOActiveX::CSOActiveX()
@@ -148,8 +145,8 @@ CSOActiveX::CSOActiveX()
 , mCurFileUrl( L"private:factory/swriter" )
 , mbLoad( FALSE )
 , mParentWin( NULL )
-, mOffWin( NULL )
 , mbViewOnly( TRUE )
+, mOffWin( NULL )
 , mpDispatchInterceptor( NULL )
 , mnVersion( SO_NOT_DETECTED )
 , mbReadyForActivation( FALSE )
@@ -279,7 +276,7 @@ HRESULT CSOActiveX::TerminateOffice()
     if ( SUCCEEDED( hr ) )
     {
         if ( ( aFrames.vt == ( VT_ARRAY | VT_DISPATCH ) || aFrames.vt == ( VT_ARRAY | VT_VARIANT ) )
-          && ( !aFrames.parray || aFrames.parray->cDims == 1 && aFrames.parray->rgsabound[0].cElements == 0 ) )
+          && ( !aFrames.parray || (aFrames.parray->cDims == 1 && aFrames.parray->rgsabound[0].cElements == 0) ) )
         {
             // there is no frames open
             // TODO: check whether the frames are hidden if they are open?
@@ -983,8 +980,8 @@ HRESULT CSOActiveX::OnDrawAdvanced( ATL_DRAWINFO& di )
                 CComVariant dummyResult;
                 CComVariant aPropVar;
                 aPropVar.vt = VT_BOOL; aPropVar.boolVal = VARIANT_FALSE;
-                HRESULT hr = ExecuteFunc( mpDispFrame, L"close", &aPropVar, 1, &dummyResult );
-                (void)hr;
+                HRESULT hres = ExecuteFunc( mpDispFrame, L"close", &aPropVar, 1, &dummyResult );
+                (void)hres;
                 mpDispFrame = CComPtr<IDispatch>();
             }
 
@@ -1166,6 +1163,6 @@ HRESULT CSOActiveX::GetURL( const OLECHAR* url,
 }
 
 
-// ---------------------------------------------------------------------------
+
 
 /* vim:set shiftwidth=4 softtabstop=4 expandtab: */
