@@ -21,7 +21,7 @@
 
 #include "updatecheck.hxx"
 
-#include <cppuhelper/implbase1.hxx>
+#include <cppuhelper/implbase.hxx>
 #include <com/sun/star/beans/XFastPropertySet.hpp>
 #include <com/sun/star/lang/XComponent.hpp>
 #include <com/sun/star/frame/Desktop.hpp>
@@ -139,8 +139,8 @@ OUString getImageFromFileName(const OUString& aFile)
             aUnpackPath  += "unpack_update";
         }
 
-        oslFileHandle hOut = NULL;
-        oslProcess hProcess = NULL;
+        oslFileHandle hOut = nullptr;
+        oslProcess hProcess = nullptr;
 
         OUString aSystemPath;
         osl::File::getSystemPathFromFileURL(aFile, aSystemPath);
@@ -149,11 +149,11 @@ OUString getImageFromFileName(const OUString& aFile)
             aUnpackPath.pData,                                  // [in] Image name
             &aSystemPath.pData, 1,                              // [in] Arguments
             osl_Process_WAIT | osl_Process_NORMAL,              // [in] Options
-            NULL,                                               // [in] Security
-            NULL,                                               // [in] Working directory
-            NULL, 0,                                            // [in] Environment variables
+            nullptr,                                               // [in] Security
+            nullptr,                                               // [in] Working directory
+            nullptr, 0,                                            // [in] Environment variables
             &hProcess,                                          // [out] Process handle
-            NULL, &hOut, NULL                                   // [out] File handles for redirected I/O
+            nullptr, &hOut, nullptr                                   // [out] File handles for redirected I/O
         );
 
         if( osl_Process_E_None == rc )
@@ -238,15 +238,15 @@ public:
     UpdateCheckThread( osl::Condition& rCondition,
         const uno::Reference<uno::XComponentContext>& xContext );
 
-    virtual void SAL_CALL join() SAL_OVERRIDE;
-    virtual void SAL_CALL terminate() SAL_OVERRIDE;
-    virtual void cancel() SAL_OVERRIDE;
+    virtual void SAL_CALL join() override;
+    virtual void SAL_CALL terminate() override;
+    virtual void cancel() override;
 
 protected:
     virtual ~UpdateCheckThread();
 
-    virtual void SAL_CALL run() SAL_OVERRIDE;
-    virtual void SAL_CALL onTerminated() SAL_OVERRIDE;
+    virtual void SAL_CALL run() override;
+    virtual void SAL_CALL onTerminated() override;
 
     /* Wrapper around checkForUpdates */
     bool runCheck( bool & rbExtensionsChecked );
@@ -297,18 +297,18 @@ public:
     ManualUpdateCheckThread( osl::Condition& rCondition, const uno::Reference<uno::XComponentContext>& xContext ) :
         UpdateCheckThread(rCondition, xContext) {};
 
-    virtual void SAL_CALL run() SAL_OVERRIDE;
+    virtual void SAL_CALL run() override;
 };
 
 
-class MenuBarButtonJob : public ::cppu::WeakImplHelper1< task::XJob >
+class MenuBarButtonJob : public ::cppu::WeakImplHelper< task::XJob >
 {
 public:
     MenuBarButtonJob(const rtl::Reference< UpdateCheck >& rUpdateCheck);
 
     // XJob
     virtual uno::Any SAL_CALL execute(const uno::Sequence<beans::NamedValue>&)
-        throw (lang::IllegalArgumentException, uno::Exception, std::exception) SAL_OVERRIDE;
+        throw (lang::IllegalArgumentException, uno::Exception, std::exception) override;
 
 private:
     rtl::Reference< UpdateCheck > m_aUpdateCheck;
@@ -323,10 +323,10 @@ public:
         const rtl::Reference< DownloadInteractionHandler >& rHandler,
         const OUString& rURL );
 
-    virtual void SAL_CALL run() SAL_OVERRIDE;
-    virtual void cancel() SAL_OVERRIDE;
-    virtual void SAL_CALL suspend() SAL_OVERRIDE;
-    virtual void SAL_CALL onTerminated() SAL_OVERRIDE;
+    virtual void SAL_CALL run() override;
+    virtual void cancel() override;
+    virtual void SAL_CALL suspend() override;
+    virtual void SAL_CALL onTerminated() override;
 
 protected:
     virtual ~DownloadThread();
@@ -344,8 +344,8 @@ class ShutdownThread :  public osl::Thread
 public:
     ShutdownThread( const uno::Reference<uno::XComponentContext>& xContext );
 
-    virtual void SAL_CALL run() SAL_OVERRIDE;
-    virtual void SAL_CALL onTerminated() SAL_OVERRIDE;
+    virtual void SAL_CALL run() override;
+    virtual void SAL_CALL onTerminated() override;
 
 protected:
     virtual ~ShutdownThread();
@@ -743,7 +743,7 @@ void SAL_CALL ShutdownThread::onTerminated()
 UpdateCheck::UpdateCheck()
     : m_eState(NOT_INITIALIZED)
     , m_eUpdateState(UPDATESTATES_COUNT)
-    , m_pThread(NULL)
+    , m_pThread(nullptr)
     , m_bHasExtensionUpdate(false)
     , m_bShowExtUpdDlg(false)
 {
@@ -861,7 +861,7 @@ UpdateCheck::cancel()
 
     aGuard.clear();
 
-    if( NULL != pThread )
+    if( nullptr != pThread )
         pThread->cancel();
 
     setUIState(eUIState);
@@ -947,7 +947,7 @@ UpdateCheck::pause()
 {
     osl::ClearableMutexGuard aGuard(m_aMutex);
 
-    if( NULL != m_pThread )
+    if( nullptr != m_pThread )
         m_pThread->suspend();
 
     rtl::Reference< UpdateCheckConfig > rModel = UpdateCheckConfig::get(m_xContext);
@@ -964,7 +964,7 @@ UpdateCheck::resume()
 {
     osl::ClearableMutexGuard aGuard(m_aMutex);
 
-    if( NULL != m_pThread )
+    if( nullptr != m_pThread )
         m_pThread->resume();
 
     rtl::Reference< UpdateCheckConfig > rModel = UpdateCheckConfig::get(m_xContext);
@@ -998,10 +998,10 @@ UpdateCheck::shutdownThread(bool join)
 
     // copy thread object pointer to stack
     osl::Thread *pThread = m_pThread;
-    m_pThread = NULL;
+    m_pThread = nullptr;
     aGuard.clear();
 
-    if( NULL != pThread )
+    if( nullptr != pThread )
     {
         pThread->terminate();
         if( join )
@@ -1029,7 +1029,7 @@ UpdateCheck::enableAutoCheck(bool enable)
 void
 UpdateCheck::enableDownload(bool enable, bool paused)
 {
-    OSL_ASSERT(NULL == m_pThread);
+    OSL_ASSERT(nullptr == m_pThread);
 
     State eState = DISABLED;
     if( enable )
@@ -1254,7 +1254,7 @@ UpdateCheck::showDialog(bool forceCheck)
         aGuard.reset();
     }
 
-    getUpdateHandler()->setVisible(true);
+    getUpdateHandler()->setVisible();
 
     // Run check in separate thread ..
     if( UPDATESTATE_CHECKING == eDialogState )
@@ -1487,7 +1487,7 @@ UpdateCheck::storeReleaseNote(sal_Int8 nNum, const OUString &rURL)
     osl::FileBase::RC rc;
     OUString aTargetDir( UpdateCheckConfig::getAllUsersDirectory() + "/sun" );
 
-    rc = osl::Directory::createPath( aTargetDir );
+    osl::Directory::createPath( aTargetDir );
 
     OUString aFileName = "releasenote" +
                               OUString::number( nNum ) +
@@ -1497,7 +1497,7 @@ UpdateCheck::storeReleaseNote(sal_Int8 nNum, const OUString &rURL)
     rc = osl::FileBase::getAbsoluteFileURL( aTargetDir, aFileName, aFilePath );
     if ( rc != osl::FileBase::E_None ) return false;
 
-    rc = osl::File::remove( aFilePath );
+    osl::File::remove( aFilePath );
 
     // don't store empty release notes, but delete old ones
     if ( rURL.isEmpty() )
@@ -1505,7 +1505,6 @@ UpdateCheck::storeReleaseNote(sal_Int8 nNum, const OUString &rURL)
 
     osl::File aFile( aFilePath );
     rc = aFile.open( osl_File_OpenFlag_Write | osl_File_OpenFlag_Create );
-
     if ( rc != osl::FileBase::E_None ) return false;
 
     OString aLineBuf("[InternetShortcut]\r\n");
