@@ -36,7 +36,6 @@
 #include <comphelper/sequence.hxx>
 #include <comphelper/property.hxx>
 #include <comphelper/basicio.hxx>
-#include <comphelper/types.hxx>
 #include <comphelper/servicehelper.hxx>
 #include "services.hxx"
 #include "frm_resource.hrc"
@@ -63,9 +62,9 @@ const sal_uInt16 OLD_HIDDEN         = 0x0004;
 const sal_uInt16 COMPATIBLE_HIDDEN  = 0x0008;
 
 
-const StringSequence& getColumnTypes()
+const css::uno::Sequence<OUString>& getColumnTypes()
 {
-    static StringSequence aColumnTypes(10);
+    static css::uno::Sequence<OUString> aColumnTypes(10);
     if (aColumnTypes.getConstArray()[0].isEmpty())
     {
         OUString* pNames = aColumnTypes.getArray();
@@ -97,22 +96,20 @@ sal_Int32 getColumnTypeByModelName(const OUString& aModelName)
         sal_Int32 nPrefixPos = aModelName.indexOf(aModelPrefix);
 #ifdef DBG_UTIL
         sal_Int32 nCompatiblePrefixPos = aModelName.indexOf(aCompatibleModelPrefix);
-#endif
         DBG_ASSERT( (nPrefixPos != -1) ||   (nCompatiblePrefixPos != -1),
                 "::getColumnTypeByModelName() : wrong servivce !");
+#endif
 
         OUString aColumnType = (nPrefixPos != -1)
             ? aModelName.copy(aModelPrefix.getLength())
             : aModelName.copy(aCompatibleModelPrefix.getLength());
 
-        const StringSequence& rColumnTypes = getColumnTypes();
+        const css::uno::Sequence<OUString>& rColumnTypes = getColumnTypes();
         nTypeId = ::detail::findPos(aColumnType, rColumnTypes);
     }
     return nTypeId;
 }
 
-/*************************************************************************/
-
 namespace
 {
     class theOGridColumnImplementationId : public rtl::Static< UnoTunnelIdInit, theOGridColumnImplementationId > {};
@@ -178,11 +175,11 @@ Any SAL_CALL OGridColumn::queryAggregation( const Type& _rType ) throw (RuntimeE
 {
     Any aReturn;
     // some functionality at our aggregate cannot be reasonably fulfilled here.
-    if  (   _rType.equals(::getCppuType(static_cast< Reference< XFormComponent >* >(NULL)))
-        ||  _rType.equals(::getCppuType(static_cast< Reference< XServiceInfo >* >(NULL)))
-        ||  _rType.equals(::getCppuType(static_cast< Reference< XBindableValue >* >(NULL)))
-        ||  _rType.equals(::getCppuType(static_cast< Reference< XPropertyContainer >* >(NULL)))
-        ||  comphelper::isAssignableFrom(::getCppuType(static_cast< Reference< XTextRange >* >(NULL)),_rType)
+    if  (   _rType.equals(cppu::UnoType<XFormComponent>::get())
+        ||  _rType.equals(cppu::UnoType<XServiceInfo>::get())
+        ||  _rType.equals(cppu::UnoType<XBindableValue>::get())
+        ||  _rType.equals(cppu::UnoType<XPropertyContainer>::get())
+        ||  comphelper::isAssignableFrom(cppu::UnoType<XTextRange>::get(),_rType)
         )
         return aReturn;
 
@@ -208,7 +205,7 @@ OGridColumn::OGridColumn( const Reference<XComponentContext>& _rContext, const O
     // Create the UnoControlModel
     if ( !m_aModelName.isEmpty() ) // is there a to-be-aggregated model?
     {
-        increment( m_refCount );
+        osl_atomic_increment( &m_refCount );
 
         {
             m_xAggregate.set( _rContext->getServiceManager()->createInstanceWithContext( m_aModelName, _rContext ), UNO_QUERY );
@@ -221,7 +218,7 @@ OGridColumn::OGridColumn( const Reference<XComponentContext>& _rContext, const O
         }
 
         // Set refcount back to zero
-        decrement( m_refCount );
+        osl_atomic_decrement( &m_refCount );
     }
 }
 
@@ -237,7 +234,7 @@ OGridColumn::OGridColumn( const OGridColumn* _pOriginal )
     m_aModelName = _pOriginal->m_aModelName;
     m_aLabel = _pOriginal->m_aLabel;
 
-    increment( m_refCount );
+    osl_atomic_increment( &m_refCount );
     {
         {
             m_xAggregate = createAggregateClone( _pOriginal );
@@ -249,7 +246,7 @@ OGridColumn::OGridColumn( const OGridColumn* _pOriginal )
             m_xAggregate->setDelegator( static_cast< ::cppu::OWeakObject* >( this ) );
         }
     }
-    decrement( m_refCount );
+    osl_atomic_decrement( &m_refCount );
 }
 
 
@@ -264,7 +261,7 @@ OGridColumn::~OGridColumn()
     // Free the aggregate
     if (m_xAggregate.is())
     {
-        InterfaceRef  xIface;
+        css::uno::Reference<css::uno::XInterface>  xIface;
         m_xAggregate->setDelegator(xIface);
     }
 
@@ -402,10 +399,10 @@ sal_Bool OGridColumn::convertFastPropertyValue( Any& rConvertedValue, Any& rOldV
             bModified = tryPropertyValue(rConvertedValue, rOldValue, rValue, m_aLabel);
             break;
         case PROPERTY_ID_WIDTH:
-            bModified = tryPropertyValue(rConvertedValue, rOldValue, rValue, m_aWidth, ::getCppuType((const sal_Int32*)NULL));
+            bModified = tryPropertyValue(rConvertedValue, rOldValue, rValue, m_aWidth, cppu::UnoType<sal_Int32>::get());
             break;
         case PROPERTY_ID_ALIGN:
-            bModified = tryPropertyValue( rConvertedValue, rOldValue, rValue, m_aAlign, ::getCppuType( (const sal_Int32*)NULL ) );
+            bModified = tryPropertyValue( rConvertedValue, rOldValue, rValue, m_aAlign, cppu::UnoType<sal_Int32>::get());
             // strange enough, css.awt.TextAlign is a 32-bit integer, while the Align property (both here for grid controls
             // and for ordinary toolkit controls) is a 16-bit integer. So, allow for 32 bit, but normalize it to 16 bit
             if ( bModified )
@@ -423,7 +420,7 @@ sal_Bool OGridColumn::convertFastPropertyValue( Any& rConvertedValue, Any& rOldV
 }
 
 
-void OGridColumn::setFastPropertyValue_NoBroadcast( sal_Int32 nHandle, const Any& rValue ) throw (::com::sun::star::uno::Exception, std::exception)
+void OGridColumn::setFastPropertyValue_NoBroadcast( sal_Int32 nHandle, const Any& rValue ) throw (css::uno::Exception, std::exception)
 {
     switch (nHandle)
     {
