@@ -22,7 +22,7 @@
 #include <tools/debug.hxx>
 #include <cppuhelper/queryinterface.hxx>
 
-#include <boost/scoped_ptr.hpp>
+#include <memory>
 
 namespace frm
 {
@@ -35,12 +35,12 @@ OComponentEventThread::OComponentEventThread( ::cppu::OComponentHelper* pCompImp
     m_pCompImpl( pCompImpl )
 {
 
-    increment(m_refCount);
+    osl_atomic_increment(&m_refCount);
 
     // Hold a reference of the Control
     {
-        InterfaceRef xIFace(static_cast<XWeak*>(pCompImpl));
-        query_interface(xIFace, m_xComp);
+        css::uno::Reference<css::uno::XInterface> xIFace(static_cast<XWeak*>(pCompImpl));
+        m_xComp.set(xIFace, css::uno::UNO_QUERY);
     }
 
     // and add us at the Control
@@ -49,7 +49,7 @@ OComponentEventThread::OComponentEventThread( ::cppu::OComponentHelper* pCompImp
         m_xComp->addEventListener( xEvtLstnr );
     }
 
-    decrement(m_refCount);
+    osl_atomic_decrement(&m_refCount);
 }
 
 OComponentEventThread::~OComponentEventThread()
@@ -86,7 +86,7 @@ void OComponentEventThread::impl_clearEventQueue()
     m_aFlags.erase( m_aFlags.begin(), m_aFlags.end() );
 }
 
-void OComponentEventThread::disposing( const EventObject& evt ) throw ( ::com::sun::star::uno::RuntimeException, std::exception)
+void OComponentEventThread::disposing( const EventObject& evt ) throw ( css::uno::RuntimeException, std::exception)
 {
     if( evt.Source == m_xComp )
     {
@@ -101,8 +101,8 @@ void OComponentEventThread::disposing( const EventObject& evt ) throw ( ::com::s
 
         // Free the Control and set pCompImpl to 0,
         // so that the thread knows, that it should terminate.
-        m_xComp = 0;
-        m_pCompImpl = 0;
+        m_xComp = nullptr;
+        m_pCompImpl = nullptr;
 
         // Wake up the thread and terminate
         m_aCond.set();
@@ -145,14 +145,6 @@ void OComponentEventThread::implTerminated( )
     release( );
 }
 
-void SAL_CALL OComponentEventThread::kill()
-{
-    OComponentEventThread_TBASE::terminate();
-    OComponentEventThread_TBASE::join();
-
-    implTerminated( );
-}
-
 void SAL_CALL OComponentEventThread::onTerminated()
 {
     OComponentEventThread_TBASE::onTerminated();
@@ -167,7 +159,7 @@ void OComponentEventThread::run()
     implStarted( );
 
     // Hold on to ourselves, so that we're not deleted if a dispose is called at some point in time
-    InterfaceRef xThis(static_cast<XWeak*>(this));
+    css::uno::Reference<css::uno::XInterface> xThis(static_cast<XWeak*>(this));
 
     do
     {
@@ -180,7 +172,7 @@ void OComponentEventThread::run()
             ::cppu::OComponentHelper *pCompImpl = m_pCompImpl;
 
             ThreadEvents::iterator firstEvent( m_aEvents.begin() );
-            boost::scoped_ptr<EventObject> pEvt(*firstEvent);
+            std::unique_ptr<EventObject> pEvt(*firstEvent);
             m_aEvents.erase( firstEvent );
 
             ThreadObjects::iterator firstControl( m_aControls.begin() );
@@ -197,7 +189,8 @@ void OComponentEventThread::run()
                 // the mutex is locked.
                 Reference<XControl>  xControl;
                 if ( xControlAdapter.is() )
-                    query_interface(xControlAdapter->queryAdapted(), xControl);
+                    xControl.set(
+                        xControlAdapter->queryAdapted(), css::uno::UNO_QUERY);
 
                 if( xComp.is() )
                     processEvent( pCompImpl, pEvt.get(), xControl, bFlag );
