@@ -19,11 +19,11 @@
 
 #include "Filter.hxx"
 #include "FormComponent.hxx"
-#include "frm_module.hxx"
 #include "frm_resource.hrc"
 #include "frm_resource.hxx"
 #include "property.hrc"
 #include "property.hxx"
+#include "services.hxx"
 
 #include <com/sun/star/awt/VclWindowPeerAttribute.hpp>
 #include <com/sun/star/awt/XCheckBox.hpp>
@@ -64,17 +64,9 @@
 #include <vcl/svapp.hxx>
 #include <tools/wintypes.hxx>
 
-//--------------------------------------------------------------------------
-extern "C" void SAL_CALL createRegistryInfo_OFilterControl()
-{
-    static ::frm::OMultiInstanceAutoRegistration< ::frm::OFilterControl > aAutoRegistration;
-}
 
-//.........................................................................
 namespace frm
 {
-//.........................................................................
-
     using namespace ::com::sun::star::uno;
     using namespace ::com::sun::star::awt;
     using namespace ::com::sun::star::lang;
@@ -89,42 +81,41 @@ namespace frm
 
     using namespace ::connectivity;
 
-    //=====================================================================
-    // OFilterControl
-    //=====================================================================
-    //---------------------------------------------------------------------
     OFilterControl::OFilterControl( const Reference< XComponentContext >& _rxORB )
         :UnoControl()
         ,m_aTextListeners( *this )
         ,m_xContext( _rxORB )
+#if HAVE_FEATURE_DBCONNECTIVITY
         ,m_aParser( _rxORB )
+#endif
         ,m_nControlClass( FormComponentType::TEXTFIELD )
-        ,m_bFilterList( sal_False )
-        ,m_bMultiLine( sal_False )
-        ,m_bFilterListFilled( sal_False )
+        ,m_bFilterList( false )
+        ,m_bMultiLine( false )
+        ,m_bFilterListFilled( false )
     {
     }
 
-    //---------------------------------------------------------------------
-    sal_Bool OFilterControl::ensureInitialized( )
+
+    bool OFilterControl::ensureInitialized( )
     {
+#if HAVE_FEATURE_DBCONNECTIVITY
         if ( !m_xField.is() )
         {
             OSL_FAIL( "OFilterControl::ensureInitialized: improperly initialized: no field!" );
-            return sal_False;
+            return false;
         }
 
         if ( !m_xConnection.is() )
         {
             OSL_FAIL( "OFilterControl::ensureInitialized: improperly initialized: no connection!" );
-            return sal_False;
+            return false;
         }
 
         if ( !m_xFormatter.is() )
         {
             // we can create one from the connection, if it's an SDB connection
 
-            Reference< XNumberFormatsSupplier > xFormatSupplier = ::dbtools::getNumberFormats( m_xConnection, sal_True, m_xContext );
+            Reference< XNumberFormatsSupplier > xFormatSupplier = ::dbtools::getNumberFormats( m_xConnection, true, m_xContext );
 
             if ( xFormatSupplier.is() )
             {
@@ -136,14 +127,14 @@ namespace frm
         {
             OSL_FAIL( "OFilterControl::ensureInitialized: no number formatter!" );
             // no fallback anymore
-            return sal_False;
+            return false;
         }
-
-        return sal_True;
+#endif
+        return true;
     }
 
-    //---------------------------------------------------------------------
-    Any SAL_CALL OFilterControl::queryAggregation( const Type & rType ) throw(RuntimeException)
+
+    Any SAL_CALL OFilterControl::queryAggregation( const Type & rType ) throw(RuntimeException, std::exception)
     {
         Any aRet = UnoControl::queryAggregation( rType);
         if(!aRet.hasValue())
@@ -152,7 +143,7 @@ namespace frm
         return aRet;
     }
 
-    //------------------------------------------------------------------
+
     OUString OFilterControl::GetComponentServiceName()
     {
         OUString aServiceName;
@@ -180,16 +171,16 @@ namespace frm
     }
 
     // XComponent
-    //---------------------------------------------------------------------
-    void OFilterControl::dispose() throw( RuntimeException  )
+
+    void OFilterControl::dispose() throw( RuntimeException, std::exception  )
     {
         EventObject aEvt(*this);
         m_aTextListeners.disposeAndClear( aEvt );
         UnoControl::dispose();
     }
 
-    //---------------------------------------------------------------------
-    void OFilterControl::createPeer( const Reference< XToolkit > & rxToolkit, const Reference< XWindowPeer >  & rParentPeer ) throw(RuntimeException)
+
+    void OFilterControl::createPeer( const Reference< XToolkit > & rxToolkit, const Reference< XWindowPeer >  & rParentPeer ) throw(RuntimeException, std::exception)
     {
         UnoControl::createPeer( rxToolkit, rParentPeer );
 
@@ -201,8 +192,8 @@ namespace frm
                 case FormComponentType::CHECKBOX:
                 {
                     // checkboxes always have a tristate-mode
-                    xVclWindow->setProperty( PROPERTY_TRISTATE, makeAny( sal_Bool( sal_True ) ) );
-                    xVclWindow->setProperty( PROPERTY_STATE, makeAny( sal_Int32( STATE_DONTKNOW ) ) );
+                    xVclWindow->setProperty( PROPERTY_TRISTATE, makeAny( true ) );
+                    xVclWindow->setProperty( PROPERTY_STATE, makeAny( sal_Int32( TRISTATE_INDET ) ) );
 
                     Reference< XCheckBox >  xBox( getPeer(), UNO_QUERY_THROW );
                     xBox->addItemListener( this );
@@ -212,7 +203,7 @@ namespace frm
 
                 case FormComponentType::RADIOBUTTON:
                 {
-                    xVclWindow->setProperty( PROPERTY_STATE, makeAny( sal_Int32( STATE_NOCHECK ) ) );
+                    xVclWindow->setProperty( PROPERTY_STATE, makeAny( sal_Int32( TRISTATE_FALSE ) ) );
 
                     Reference< XRadioButton >  xRadio( getPeer(), UNO_QUERY_THROW );
                     xRadio->addItemListener( this );
@@ -228,7 +219,7 @@ namespace frm
 
                 case FormComponentType::COMBOBOX:
                 {
-                    xVclWindow->setProperty(PROPERTY_AUTOCOMPLETE, makeAny( sal_Bool( sal_True ) ) );
+                    xVclWindow->setProperty(PROPERTY_AUTOCOMPLETE, makeAny( true ) );
                 }
                 // no break
 
@@ -244,13 +235,11 @@ namespace frm
                 break;
             }
 
-            OControl::initFormControlPeer( getPeer() );
-
             // filter controls are _never_ readonly
             Reference< XPropertySet > xModel( getModel(), UNO_QUERY_THROW );
             Reference< XPropertySetInfo > xModelPSI( xModel->getPropertySetInfo(), UNO_SET_THROW );
             if ( xModelPSI->hasPropertyByName( PROPERTY_READONLY ) )
-                xVclWindow->setProperty( PROPERTY_READONLY, makeAny( sal_Bool( sal_False ) ) );
+                xVclWindow->setProperty( PROPERTY_READONLY, makeAny( false ) );
         }
         catch( const Exception& )
         {
@@ -258,17 +247,17 @@ namespace frm
         }
 
         if (m_bFilterList)
-            m_bFilterListFilled = sal_False;
+            m_bFilterListFilled = false;
     }
 
-    //---------------------------------------------------------------------
+
     void OFilterControl::PrepareWindowDescriptor( WindowDescriptor& rDescr )
     {
         if (m_bFilterList)
             rDescr.WindowAttributes |= VclWindowPeerAttribute::DROPDOWN;
     }
 
-    //---------------------------------------------------------------------
+
     void OFilterControl::ImplSetPeerProperty( const OUString& rPropName, const Any& rVal )
     {
         // these properties are ignored
@@ -280,29 +269,32 @@ namespace frm
     }
 
     // XEventListener
-    //---------------------------------------------------------------------
-    void SAL_CALL OFilterControl::disposing(const EventObject& Source) throw( RuntimeException )
+
+    void SAL_CALL OFilterControl::disposing(const EventObject& Source) throw( RuntimeException, std::exception )
     {
         UnoControl::disposing(Source);
     }
 
     // XItemListener
-    //---------------------------------------------------------------------
-    void SAL_CALL OFilterControl::itemStateChanged( const ItemEvent& rEvent ) throw(RuntimeException)
+
+    void SAL_CALL OFilterControl::itemStateChanged( const ItemEvent& rEvent ) throw(RuntimeException, std::exception)
     {
+#if !HAVE_FEATURE_DBCONNECTIVITY
+        (void) rEvent;
+#else
         OUStringBuffer aText;
         switch (m_nControlClass)
         {
             case FormComponentType::CHECKBOX:
             {
-                if ( ( rEvent.Selected == STATE_CHECK ) || ( rEvent.Selected == STATE_NOCHECK ) )
+                if ( ( rEvent.Selected == TRISTATE_TRUE ) || ( rEvent.Selected == TRISTATE_FALSE ) )
                 {
                     sal_Int32 nBooleanComparisonMode = ::dbtools::DatabaseMetaData( m_xConnection ).getBooleanComparisonMode();
 
-                    bool bSelected = ( rEvent.Selected == STATE_CHECK );
+                    bool bSelected = ( rEvent.Selected == TRISTATE_TRUE );
 
                     OUString sExpressionMarker( "$expression$" );
-                    ::dbtools::getBoleanComparisonPredicate(
+                    ::dbtools::getBooleanComparisonPredicate(
                         sExpressionMarker,
                         bSelected,
                         nBooleanComparisonMode,
@@ -360,7 +352,7 @@ namespace frm
 
             case FormComponentType::RADIOBUTTON:
             {
-                if ( rEvent.Selected == STATE_CHECK )
+                if ( rEvent.Selected == TRISTATE_TRUE )
                     aText.append( ::comphelper::getString( Reference< XPropertySet >( getModel(), UNO_QUERY )->getPropertyValue( PROPERTY_REFVALUE ) ) );
             }
             break;
@@ -374,13 +366,15 @@ namespace frm
             aEvt.Source = *this;
             ::cppu::OInterfaceIteratorHelper aIt( m_aTextListeners );
             while( aIt.hasMoreElements() )
-                ((XTextListener *)aIt.next())->textChanged( aEvt );
+                static_cast<XTextListener *>(aIt.next())->textChanged( aEvt );
         }
+#endif
     }
 
-    //---------------------------------------------------------------------
+
     void OFilterControl::implInitFilterList()
     {
+#if HAVE_FEATURE_DBCONNECTIVITY
         if ( !ensureInitialized( ) )
             // already asserted in ensureInitialized
             return;
@@ -391,7 +385,7 @@ namespace frm
 
         try
         {
-            m_bFilterListFilled = sal_True;
+            m_bFilterListFilled = true;
 
             if ( !m_xField.is() )
                 return;
@@ -429,7 +423,7 @@ namespace frm
             const Reference< XDatabaseMetaData >  xMeta( xConnection->getMetaData(), UNO_SET_THROW );
             const OUString sQuoteChar = xMeta->getIdentifierQuoteString();
 
-            aStatement.appendAscii( "SELECT DISTINCT " );
+            aStatement.append( "SELECT DISTINCT " );
             aStatement.append( sQuoteChar );
             aStatement.append( sRealFieldName );
             aStatement.append( sQuoteChar );
@@ -437,13 +431,13 @@ namespace frm
             // if the field had an alias in our form's statement, give it this alias in the new statement, too
             if ( !sFieldName.isEmpty() && ( sFieldName != sRealFieldName ) )
             {
-                aStatement.appendAscii(" AS ");
+                aStatement.append(" AS ");
                 aStatement.append( sQuoteChar );
                 aStatement.append( sFieldName );
                 aStatement.append( sQuoteChar );
             }
 
-            aStatement.appendAscii( " FROM " );
+            aStatement.append( " FROM " );
 
             OUString sCatalog, sSchema, sTable;
             ::dbtools::qualifiedNameComponents( xMeta, sTableName, sCatalog, sSchema, sTable, ::dbtools::eInDataManipulation );
@@ -472,8 +466,7 @@ namespace frm
             }
 
             // fill the list items into our peer
-            Sequence< OUString> aStringSeq( aProposals.size() );
-            ::std::copy( aProposals.begin(), aProposals.end(), aStringSeq.getArray() );
+            Sequence< OUString> aStringSeq( comphelper::containerToSequence(aProposals) );
 
             const Reference< XComboBox >  xComboBox( getPeer(), UNO_QUERY_THROW );
             xComboBox->addItems( aStringSeq, 0 );
@@ -486,25 +479,27 @@ namespace frm
         {
             DBG_UNHANDLED_EXCEPTION();
         }
+#endif
     }
 
     // XFocusListener
-    //---------------------------------------------------------------------
-    void SAL_CALL OFilterControl::focusGained(const FocusEvent& /*e*/)  throw( RuntimeException  )
+
+    void SAL_CALL OFilterControl::focusGained(const FocusEvent& /*e*/)  throw( RuntimeException, std::exception  )
     {
         // should we fill the combobox?
         if (m_bFilterList && !m_bFilterListFilled)
             implInitFilterList();
     }
 
-    //---------------------------------------------------------------------
-    void SAL_CALL OFilterControl::focusLost(const FocusEvent& /*e*/) throw( RuntimeException )
+
+    void SAL_CALL OFilterControl::focusLost(const FocusEvent& /*e*/) throw( RuntimeException, std::exception )
     {
     }
 
-    //---------------------------------------------------------------------
-    sal_Bool SAL_CALL OFilterControl::commit() throw(RuntimeException)
+
+    sal_Bool SAL_CALL OFilterControl::commit() throw(RuntimeException, std::exception)
     {
+#if HAVE_FEATURE_DBCONNECTIVITY
         if ( !ensureInitialized( ) )
             // already asserted in ensureInitialized
             return sal_True;
@@ -549,24 +544,25 @@ namespace frm
             while( aIt.hasMoreElements() )
                 static_cast< XTextListener* >( aIt.next() )->textChanged( aEvt );
         }
+#endif
         return sal_True;
     }
 
     // XTextComponent
-    //---------------------------------------------------------------------
-    void SAL_CALL OFilterControl::addTextListener(const Reference< XTextListener > & l) throw(RuntimeException)
+
+    void SAL_CALL OFilterControl::addTextListener(const Reference< XTextListener > & l) throw(RuntimeException, std::exception)
     {
         m_aTextListeners.addInterface( l );
     }
 
-    //---------------------------------------------------------------------
-    void SAL_CALL OFilterControl::removeTextListener(const Reference< XTextListener > & l) throw(RuntimeException)
+
+    void SAL_CALL OFilterControl::removeTextListener(const Reference< XTextListener > & l) throw(RuntimeException, std::exception)
     {
         m_aTextListeners.removeInterface( l );
     }
 
-    //---------------------------------------------------------------------
-    void SAL_CALL OFilterControl::setText( const OUString& aText ) throw(RuntimeException)
+
+    void SAL_CALL OFilterControl::setText( const OUString& aText ) throw(RuntimeException, std::exception)
     {
         if ( !ensureInitialized( ) )
             // already asserted in ensureInitialized
@@ -585,14 +581,14 @@ namespace frm
                         ||  aText.equalsIgnoreAsciiCase("IS TRUE")
                         )
                     {
-                        aValue <<= (sal_Int32)STATE_CHECK;
+                        aValue <<= (sal_Int32)TRISTATE_TRUE;
                     }
                     else if ( aText == "0" || aText.equalsIgnoreAsciiCase("FALSE") )
                     {
-                        aValue <<= (sal_Int32)STATE_NOCHECK;
+                        aValue <<= (sal_Int32)TRISTATE_FALSE;
                     }
                     else
-                        aValue <<= (sal_Int32)STATE_DONTKNOW;
+                        aValue <<= (sal_Int32)TRISTATE_INDET;
 
                     m_aText = aText;
                     xVclWindow->setProperty( PROPERTY_STATE, aValue );
@@ -603,12 +599,12 @@ namespace frm
                 Reference< XVclWindowPeer >  xVclWindow( getPeer(), UNO_QUERY );
                 if (xVclWindow.is())
                 {
-                    OUString aRefText = ::comphelper::getString(com::sun::star::uno::Reference< XPropertySet > (getModel(), UNO_QUERY)->getPropertyValue(PROPERTY_REFVALUE));
+                    OUString aRefText = ::comphelper::getString(css::uno::Reference< XPropertySet > (getModel(), UNO_QUERY)->getPropertyValue(PROPERTY_REFVALUE));
                     Any aValue;
                     if (aText == aRefText)
-                        aValue <<= (sal_Int32)STATE_CHECK;
+                        aValue <<= (sal_Int32)TRISTATE_TRUE;
                     else
-                        aValue <<= (sal_Int32)STATE_NOCHECK;
+                        aValue <<= (sal_Int32)TRISTATE_FALSE;
                     m_aText = aText;
                     xVclWindow->setProperty(PROPERTY_STATE, aValue);
                 }
@@ -635,7 +631,7 @@ namespace frm
                     OSL_ENSURE( ( itemPos != m_aDisplayItemToValueItem.end() ) || m_aText.isEmpty(),
                         "OFilterControl::setText: this text is not in my display list!" );
                     if ( itemPos == m_aDisplayItemToValueItem.end() )
-                        m_aText = "";
+                        m_aText.clear();
 
                     if ( m_aText.isEmpty() )
                     {
@@ -664,8 +660,8 @@ namespace frm
         }
     }
 
-    //---------------------------------------------------------------------
-    void SAL_CALL OFilterControl::insertText( const ::com::sun::star::awt::Selection& rSel, const OUString& aText ) throw(::com::sun::star::uno::RuntimeException)
+
+    void SAL_CALL OFilterControl::insertText( const css::awt::Selection& rSel, const OUString& aText ) throw(css::uno::RuntimeException, std::exception)
     {
         Reference< XTextComponent >  xText( getPeer(), UNO_QUERY );
         if (xText.is())
@@ -675,14 +671,14 @@ namespace frm
         }
     }
 
-    //---------------------------------------------------------------------
-    OUString SAL_CALL OFilterControl::getText() throw(RuntimeException)
+
+    OUString SAL_CALL OFilterControl::getText() throw(RuntimeException, std::exception)
     {
         return m_aText;
     }
 
-    //---------------------------------------------------------------------
-    OUString SAL_CALL OFilterControl::getSelectedText( void ) throw(RuntimeException)
+
+    OUString SAL_CALL OFilterControl::getSelectedText() throw(RuntimeException, std::exception)
     {
         OUString aSelected;
         Reference< XTextComponent >  xText( getPeer(), UNO_QUERY );
@@ -692,56 +688,56 @@ namespace frm
         return aSelected;
     }
 
-    //---------------------------------------------------------------------
-    void SAL_CALL OFilterControl::setSelection( const ::com::sun::star::awt::Selection& aSelection ) throw(::com::sun::star::uno::RuntimeException)
+
+    void SAL_CALL OFilterControl::setSelection( const css::awt::Selection& aSelection ) throw(css::uno::RuntimeException, std::exception)
     {
         Reference< XTextComponent >  xText( getPeer(), UNO_QUERY );
         if (xText.is())
             xText->setSelection( aSelection );
     }
 
-    //---------------------------------------------------------------------
-    ::com::sun::star::awt::Selection SAL_CALL OFilterControl::getSelection( void ) throw(::com::sun::star::uno::RuntimeException)
+
+    css::awt::Selection SAL_CALL OFilterControl::getSelection() throw(css::uno::RuntimeException, std::exception)
     {
-        ::com::sun::star::awt::Selection aSel;
+        css::awt::Selection aSel;
         Reference< XTextComponent >  xText( getPeer(), UNO_QUERY );
         if (xText.is())
             aSel = xText->getSelection();
         return aSel;
     }
 
-    //---------------------------------------------------------------------
-    sal_Bool SAL_CALL OFilterControl::isEditable( void ) throw(RuntimeException)
+
+    sal_Bool SAL_CALL OFilterControl::isEditable() throw(RuntimeException, std::exception)
     {
         Reference< XTextComponent >  xText( getPeer(), UNO_QUERY );
         return xText.is() && xText->isEditable();
     }
 
-    //---------------------------------------------------------------------
-    void SAL_CALL OFilterControl::setEditable( sal_Bool bEditable ) throw(RuntimeException)
+
+    void SAL_CALL OFilterControl::setEditable( sal_Bool bEditable ) throw(RuntimeException, std::exception)
     {
         Reference< XTextComponent >  xText( getPeer(), UNO_QUERY );
         if (xText.is())
             xText->setEditable(bEditable);
     }
 
-    //---------------------------------------------------------------------
-    sal_Int16 SAL_CALL OFilterControl::getMaxTextLen() throw(RuntimeException)
+
+    sal_Int16 SAL_CALL OFilterControl::getMaxTextLen() throw(RuntimeException, std::exception)
     {
         Reference< XTextComponent >  xText( getPeer(), UNO_QUERY );
         return xText.is() ? xText->getMaxTextLen() : 0;
     }
 
-    //---------------------------------------------------------------------
-    void SAL_CALL OFilterControl::setMaxTextLen( sal_Int16 nLength ) throw(RuntimeException)
+
+    void SAL_CALL OFilterControl::setMaxTextLen( sal_Int16 nLength ) throw(RuntimeException, std::exception)
     {
         Reference< XTextComponent >  xText( getPeer(), UNO_QUERY );
         if (xText.is())
             xText->setMaxTextLen(nLength);
     }
 
-    //---------------------------------------------------------------------
-    void OFilterControl::displayException( const ::com::sun::star::sdb::SQLContext& _rExcept )
+
+    void OFilterControl::displayException( const css::sdb::SQLContext& _rExcept )
     {
         try
         {
@@ -754,16 +750,16 @@ namespace frm
         }
     }
 
-    //---------------------------------------------------------------------
-    void SAL_CALL OFilterControl::initialize( const Sequence< Any >& aArguments ) throw (Exception, RuntimeException)
+
+    void SAL_CALL OFilterControl::initialize( const Sequence< Any >& aArguments ) throw (Exception, RuntimeException, std::exception)
     {
         const Any* pArguments = aArguments.getConstArray();
         const Any* pArgumentsEnd = pArguments + aArguments.getLength();
 
         PropertyValue aProp;
         NamedValue aValue;
-        const OUString* pName = NULL;
-        const Any* pValue = NULL;
+        const OUString* pName = nullptr;
+        const Any* pValue = nullptr;
         Reference< XPropertySet > xControlModel;
 
         if (aArguments.getLength() == 3
@@ -792,19 +788,19 @@ namespace frm
                 continue;
             }
 
-            if ( pName->equalsAscii( "MessageParent" ) )
+            if ( *pName == "MessageParent" )
             {
                 // the message parent
                 *pValue >>= m_xMessageParent;
                 OSL_ENSURE( m_xMessageParent.is(), "OFilterControl::initialize: invalid MessageParent!" );
             }
-            else if ( pName->equalsAscii( "NumberFormatter" ) )
+            else if ( *pName == "NumberFormatter" )
             {
                 // the number format. This argument is optional.
                 *pValue >>= m_xFormatter;
                 OSL_ENSURE( m_xFormatter.is(), "OFilterControl::initialize: invalid NumberFormatter!" );
             }
-            else if ( pName->equalsAscii( "ControlModel" ) )
+            else if ( *pName == "ControlModel" )
             {
                 // the control model for which we act as filter control
                 if ( !(*pValue >>= xControlModel ) )
@@ -819,19 +815,22 @@ namespace frm
 
     void OFilterControl::initControlModel(Reference< XPropertySet >& xControlModel)
     {
+#if !HAVE_FEATURE_DBCONNECTIVITY
+        (void) xControlModel;
+#else
         if ( !xControlModel.is() )
         {
             OSL_FAIL( "OFilterControl::initialize: invalid control model argument!" );
             return;
         }
         // some properties which are "derived" from the control model we're working for
-        // ...................................................
+
         // the field
         m_xField.clear();
         OSL_ENSURE( ::comphelper::hasProperty( PROPERTY_BOUNDFIELD, xControlModel ), "OFilterControl::initialize: control model needs a bound field property!" );
         xControlModel->getPropertyValue( PROPERTY_BOUNDFIELD ) >>= m_xField;
 
-        // ...................................................
+
         // filter list and control class
         m_bFilterList = ::comphelper::hasProperty( PROPERTY_FILTERPROPOSAL, xControlModel ) && ::comphelper::getBOOL( xControlModel->getPropertyValue( PROPERTY_FILTERPROPOSAL ) );
         if ( m_bFilterList )
@@ -864,27 +863,28 @@ namespace frm
             }
         }
 
-        // ...................................................
+
         // the connection meta data for the form which we're working for
         Reference< XChild > xModel( xControlModel, UNO_QUERY );
         Reference< XRowSet > xForm;
         if ( xModel.is() )
-            xForm = xForm.query( xModel->getParent() );
+            xForm.set(xModel->getParent(), css::uno::UNO_QUERY);
         m_xConnection = ::dbtools::getConnection( xForm );
         OSL_ENSURE( m_xConnection.is(), "OFilterControl::initialize: unable to determine the form's connection!" );
+#endif
     }
 
-    OUString SAL_CALL OFilterControl::getImplementationName(  ) throw (RuntimeException)
+    OUString SAL_CALL OFilterControl::getImplementationName(  ) throw (RuntimeException, std::exception)
     {
         return getImplementationName_Static();
     }
 
-    sal_Bool SAL_CALL OFilterControl::supportsService( const OUString& ServiceName ) throw (RuntimeException)
+    sal_Bool SAL_CALL OFilterControl::supportsService( const OUString& ServiceName ) throw (RuntimeException, std::exception)
     {
         return cppu::supportsService(this, ServiceName);
     }
 
-    Sequence< OUString > SAL_CALL OFilterControl::getSupportedServiceNames(  ) throw (RuntimeException)
+    Sequence< OUString > SAL_CALL OFilterControl::getSupportedServiceNames(  ) throw (RuntimeException, std::exception)
     {
         return getSupportedServiceNames_Static();
     }
@@ -901,15 +901,13 @@ namespace frm
         aNames[ 1 ] = "com.sun.star.awt.UnoControl";
         return aNames;
     }
-
-    //---------------------------------------------------------------------
-    Reference< XInterface > SAL_CALL OFilterControl::Create( const Reference< XMultiServiceFactory >& _rxFactory )
-    {
-        return static_cast< XServiceInfo* >( new OFilterControl( comphelper::getComponentContext(_rxFactory) ) );
-    }
-
-//.........................................................................
 }   // namespace frm
-//.........................................................................
+
+extern "C" SAL_DLLPUBLIC_EXPORT css::uno::XInterface* SAL_CALL
+com_sun_star_comp_forms_OFilterControl_get_implementation(css::uno::XComponentContext* context,
+        css::uno::Sequence<css::uno::Any> const &)
+{
+    return cppu::acquire(new frm::OFilterControl(context));
+}
 
 /* vim:set shiftwidth=4 softtabstop=4 expandtab: */
