@@ -20,118 +20,98 @@
 #include "Pattern.hxx"
 #include "comphelper/processfactory.hxx"
 
-//.........................................................................
+using ::com::sun::star::uno::Reference;
+using ::com::sun::star::lang::XMultiServiceFactory;
+using ::com::sun::star::uno::Sequence;
+using ::com::sun::star::uno::Type;
+using ::com::sun::star::uno::XComponentContext;
+using ::com::sun::star::beans::Property;
+using ::com::sun::star::uno::Exception;
+using ::com::sun::star::uno::XInterface;
+using ::com::sun::star::uno::Any;
+using ::com::sun::star::uno::makeAny;
+using ::com::sun::star::sdbc::XRowSet;
+using ::com::sun::star::uno::UNO_QUERY;
+
+namespace FormComponentType = ::com::sun::star::form::FormComponentType;
+
 namespace frm
 {
-//.........................................................................
 
-    using ::com::sun::star::uno::Reference;
-    using ::com::sun::star::lang::XMultiServiceFactory;
-    using ::com::sun::star::uno::Sequence;
-    using ::com::sun::star::uno::Type;
-    using ::com::sun::star::uno::XComponentContext;
-    using ::com::sun::star::beans::Property;
-    using ::com::sun::star::uno::Exception;
-    using ::com::sun::star::uno::XInterface;
-    using ::com::sun::star::uno::Any;
-    using ::com::sun::star::uno::makeAny;
-    using ::com::sun::star::sdbc::XRowSet;
-    using ::com::sun::star::uno::UNO_QUERY;
-
-    namespace FormComponentType = ::com::sun::star::form::FormComponentType;
-
-//==================================================================
-// OPatternControl
-//==================================================================
-//------------------------------------------------------------------
 OPatternControl::OPatternControl(const Reference<XComponentContext>& _rxFactory)
     :OBoundControl(_rxFactory, VCL_CONTROL_PATTERNFIELD)
 {
 }
 
-//------------------------------------------------------------------
-InterfaceRef SAL_CALL OPatternControl_CreateInstance(const Reference<XMultiServiceFactory>& _rxFactory)
-{
-    return *(new OPatternControl( comphelper::getComponentContext(_rxFactory) ));
-}
 
-//------------------------------------------------------------------------------
 Sequence<Type> OPatternControl::_getTypes()
 {
     return OBoundControl::_getTypes();
 }
 
-//------------------------------------------------------------------------------
-StringSequence OPatternControl::getSupportedServiceNames() throw()
+
+css::uno::Sequence<OUString> OPatternControl::getSupportedServiceNames() throw(std::exception)
 {
-    StringSequence aSupported = OBoundControl::getSupportedServiceNames();
-    aSupported.realloc(aSupported.getLength() + 1);
+    css::uno::Sequence<OUString> aSupported = OBoundControl::getSupportedServiceNames();
+    aSupported.realloc(aSupported.getLength() + 2);
 
     OUString*pArray = aSupported.getArray();
-    pArray[aSupported.getLength()-1] = FRM_SUN_CONTROL_PATTERNFIELD;
+    pArray[aSupported.getLength()-2] = FRM_SUN_CONTROL_PATTERNFIELD;
+    pArray[aSupported.getLength()-1] = STARDIV_ONE_FORM_CONTROL_PATTERNFIELD;
     return aSupported;
 }
 
-//==================================================================
-// OPatternModel
-//==================================================================
-//------------------------------------------------------------------
-InterfaceRef SAL_CALL OPatternModel_CreateInstance(const Reference<XMultiServiceFactory>& _rxFactory)
-{
-    return *(new OPatternModel( comphelper::getComponentContext(_rxFactory) ));
-}
 
-//------------------------------------------------------------------------------
+// OPatternModel
+
+
 Sequence<Type> OPatternModel::_getTypes()
 {
     return OEditBaseModel::_getTypes();
 }
 
-//------------------------------------------------------------------
-DBG_NAME( OPatternModel )
-//------------------------------------------------------------------
+
+
 OPatternModel::OPatternModel(const Reference<XComponentContext>& _rxFactory)
-    :OEditBaseModel( _rxFactory, VCL_CONTROLMODEL_PATTERNFIELD, FRM_SUN_CONTROL_PATTERNFIELD, sal_False, sal_False )
+    :OEditBaseModel( _rxFactory, VCL_CONTROLMODEL_PATTERNFIELD, FRM_SUN_CONTROL_PATTERNFIELD, false, false )
                                     // use the old control name for compytibility reasons
 {
-    DBG_CTOR( OPatternModel, NULL );
 
     m_nClassId = FormComponentType::PATTERNFIELD;
     initValueProperty( PROPERTY_TEXT, PROPERTY_ID_TEXT );
 }
 
-//------------------------------------------------------------------
+
 OPatternModel::OPatternModel( const OPatternModel* _pOriginal, const Reference<XComponentContext>& _rxFactory )
     :OEditBaseModel( _pOriginal, _rxFactory )
 {
-    DBG_CTOR( OPatternModel, NULL );
 }
 
-//------------------------------------------------------------------
+
 OPatternModel::~OPatternModel()
 {
-    DBG_DTOR( OPatternModel, NULL );
 }
 
 // XCloneable
-//------------------------------------------------------------------------------
+
 IMPLEMENT_DEFAULT_CLONING( OPatternModel )
 
 // XServiceInfo
-//------------------------------------------------------------------------------
-StringSequence SAL_CALL OPatternModel::getSupportedServiceNames() throw()
+
+css::uno::Sequence<OUString> SAL_CALL OPatternModel::getSupportedServiceNames() throw(std::exception)
 {
-    StringSequence aSupported = OBoundControlModel::getSupportedServiceNames();
-    aSupported.realloc(aSupported.getLength() + 2);
+    css::uno::Sequence<OUString> aSupported = OBoundControlModel::getSupportedServiceNames();
+    aSupported.realloc(aSupported.getLength() + 3);
 
     OUString*pArray = aSupported.getArray();
-    pArray[aSupported.getLength()-2] = FRM_SUN_COMPONENT_DATABASE_PATTERNFIELD;
-    pArray[aSupported.getLength()-1] = FRM_SUN_COMPONENT_PATTERNFIELD;
+    pArray[aSupported.getLength()-3] = FRM_SUN_COMPONENT_DATABASE_PATTERNFIELD;
+    pArray[aSupported.getLength()-2] = FRM_SUN_COMPONENT_PATTERNFIELD;
+    pArray[aSupported.getLength()-1] = FRM_COMPONENT_PATTERNFIELD;
     return aSupported;
 }
 
 
-//------------------------------------------------------------------------------
+
 void OPatternModel::describeFixedProperties( Sequence< Property >& _rProps ) const
 {
     BEGIN_DESCRIBE_PROPERTIES( 4, OEditBaseModel )
@@ -142,14 +122,14 @@ void OPatternModel::describeFixedProperties( Sequence< Property >& _rProps ) con
     END_DESCRIBE_PROPERTIES();
 }
 
-//------------------------------------------------------------------------------
-OUString SAL_CALL OPatternModel::getServiceName() throw ( ::com::sun::star::uno::RuntimeException)
+
+OUString SAL_CALL OPatternModel::getServiceName() throw ( css::uno::RuntimeException, std::exception)
 {
     return OUString(FRM_COMPONENT_PATTERNFIELD);  // old (non-sun) name for compatibility !
 }
 
-//------------------------------------------------------------------------------
-sal_Bool OPatternModel::commitControlValueToDbColumn( bool /*_bPostReset*/ )
+
+bool OPatternModel::commitControlValueToDbColumn( bool /*_bPostReset*/ )
 {
     Any aNewValue( m_xAggregateFastSet->getFastPropertyValue( getValuePropertyAggHandle() ) );
 
@@ -170,19 +150,19 @@ sal_Bool OPatternModel::commitControlValueToDbColumn( bool /*_bPostReset*/ )
         {
             OSL_ENSURE( m_pFormattedValue.get(), "OPatternModel::commitControlValueToDbColumn: no value helper!" );
             if ( !m_pFormattedValue.get() )
-                return sal_False;
+                return false;
 
             if ( !m_pFormattedValue->setFormattedValue( sNewValue ) )
-                return sal_False;
+                return false;
         }
 
         m_aLastKnownValue = aNewValue;
     }
 
-    return sal_True;
+    return true;
 }
 
-//------------------------------------------------------------------------------
+
 void OPatternModel::onConnectedDbColumn( const Reference< XInterface >& _rxForm )
 {
     OEditBaseModel::onConnectedDbColumn( _rxForm );
@@ -194,7 +174,7 @@ void OPatternModel::onConnectedDbColumn( const Reference< XInterface >& _rxForm
     m_pFormattedValue.reset( new ::dbtools::FormattedColumnValue( getContext(), Reference< XRowSet >( _rxForm, UNO_QUERY ), xField ) );
 }
 
-//------------------------------------------------------------------------------
+
 void OPatternModel::onDisconnectedDbColumn()
 {
     OEditBaseModel::onDisconnectedDbColumn();
@@ -202,7 +182,7 @@ void OPatternModel::onDisconnectedDbColumn()
 }
 
 // XPropertyChangeListener
-//------------------------------------------------------------------------------
+
 Any OPatternModel::translateDbColumnToControlValue()
 {
     OSL_PRECOND( m_pFormattedValue.get(), "OPatternModel::translateDbColumnToControlValue: no value helper!" );
@@ -226,25 +206,36 @@ Any OPatternModel::translateDbColumnToControlValue()
         m_aLastKnownValue.clear();
 
     return m_aLastKnownValue.hasValue() ? m_aLastKnownValue : makeAny( OUString() );
-        // (m_aLastKnownValue is alllowed to be VOID, the control value isn't)
+        // (m_aLastKnownValue is allowed to be VOID, the control value isn't)
 }
 
 // XReset
-//------------------------------------------------------------------------------
+
 Any OPatternModel::getDefaultForReset() const
 {
     return makeAny( m_aDefaultText );
 }
 
-//------------------------------------------------------------------------------
 void OPatternModel::resetNoBroadcast()
 {
     OEditBaseModel::resetNoBroadcast();
     m_aLastKnownValue.clear();
 }
 
-//.........................................................................
 }   // namespace frm
-//.........................................................................
+
+extern "C" SAL_DLLPUBLIC_EXPORT css::uno::XInterface* SAL_CALL
+com_sun_star_form_OPatternModel_get_implementation(css::uno::XComponentContext* component,
+        css::uno::Sequence<css::uno::Any> const &)
+{
+    return cppu::acquire(new frm::OPatternModel(component));
+}
+
+extern "C" SAL_DLLPUBLIC_EXPORT css::uno::XInterface* SAL_CALL
+com_sun_star_form_OPatternControl_get_implementation(css::uno::XComponentContext* component,
+        css::uno::Sequence<css::uno::Any> const &)
+{
+    return cppu::acquire(new frm::OPatternControl(component));
+}
 
 /* vim:set shiftwidth=4 softtabstop=4 expandtab: */
