@@ -25,12 +25,12 @@
 #include <com/sun/star/form/runtime/FormFeature.hpp>
 
 #include <tools/debug.hxx>
+#include <osl/diagnose.h>
 
 
-//.........................................................................
 namespace frm
 {
-//.........................................................................
+
 
     using namespace ::com::sun::star::uno;
     using namespace ::com::sun::star::beans;
@@ -39,66 +39,59 @@ namespace frm
     using namespace ::com::sun::star::frame;
     namespace FormFeature = ::com::sun::star::form::runtime::FormFeature;
 
-    //==================================================================
-    //= OFormNavigationHelper
-    //==================================================================
-    DBG_NAME( OFormNavigationHelper )
-    //------------------------------------------------------------------
     OFormNavigationHelper::OFormNavigationHelper( const Reference< XComponentContext >& _rxORB )
         :m_xORB( _rxORB )
         ,m_nConnectedFeatures( 0 )
     {
-        DBG_CTOR( OFormNavigationHelper, NULL );
         m_pFeatureInterception.reset( new ControlFeatureInterception( m_xORB ) );
     }
 
-    //------------------------------------------------------------------
+
     OFormNavigationHelper::~OFormNavigationHelper()
     {
-        DBG_DTOR( OFormNavigationHelper, NULL );
     }
 
-    //------------------------------------------------------------------
+
     void SAL_CALL OFormNavigationHelper::dispose( ) throw( RuntimeException )
     {
         m_pFeatureInterception->dispose();
         disconnectDispatchers();
     }
 
-    //------------------------------------------------------------------
+
     void OFormNavigationHelper::interceptorsChanged( )
     {
         updateDispatches();
     }
 
-    //------------------------------------------------------------------
-    void OFormNavigationHelper::featureStateChanged( sal_Int16 /*_nFeatureId*/, sal_Bool /*_bEnabled*/ )
+
+    void OFormNavigationHelper::featureStateChanged( sal_Int16 /*_nFeatureId*/, bool /*_bEnabled*/ )
     {
         // not interested in
     }
 
-    //------------------------------------------------------------------
+
     void OFormNavigationHelper::allFeatureStatesChanged( )
     {
         // not interested in
     }
 
-    //------------------------------------------------------------------
-    void SAL_CALL OFormNavigationHelper::registerDispatchProviderInterceptor( const Reference< XDispatchProviderInterceptor >& _rxInterceptor ) throw (RuntimeException)
+
+    void SAL_CALL OFormNavigationHelper::registerDispatchProviderInterceptor( const Reference< XDispatchProviderInterceptor >& _rxInterceptor ) throw (RuntimeException, std::exception)
     {
         m_pFeatureInterception->registerDispatchProviderInterceptor( _rxInterceptor );
         interceptorsChanged();
     }
 
-    //------------------------------------------------------------------
-    void SAL_CALL OFormNavigationHelper::releaseDispatchProviderInterceptor( const Reference< XDispatchProviderInterceptor >& _rxInterceptor ) throw (RuntimeException)
+
+    void SAL_CALL OFormNavigationHelper::releaseDispatchProviderInterceptor( const Reference< XDispatchProviderInterceptor >& _rxInterceptor ) throw (RuntimeException, std::exception)
     {
         m_pFeatureInterception->releaseDispatchProviderInterceptor( _rxInterceptor );
         interceptorsChanged();
     }
 
-    //------------------------------------------------------------------
-    void SAL_CALL OFormNavigationHelper::statusChanged( const FeatureStateEvent& _rState ) throw (RuntimeException)
+
+    void SAL_CALL OFormNavigationHelper::statusChanged( const FeatureStateEvent& _rState ) throw (RuntimeException, std::exception)
     {
         for (   FeatureMap::iterator aFeature = m_aSupportedFeatures.begin();
                 aFeature != m_aSupportedFeatures.end();
@@ -107,7 +100,7 @@ namespace frm
         {
             if ( aFeature->second.aURL.Main == _rState.FeatureURL.Main )
             {
-                if  (  ( aFeature->second.bCachedState != _rState.IsEnabled )
+                if  (  ( aFeature->second.bCachedState != bool(_rState.IsEnabled) )
                     || ( aFeature->second.aCachedAdditionalState != _rState.State )
                     )
                 {
@@ -125,8 +118,8 @@ namespace frm
         OSL_FAIL( "OFormNavigationHelper::statusChanged: huh? An invalid/unknown URL?" );
     }
 
-    //------------------------------------------------------------------
-    void SAL_CALL OFormNavigationHelper::disposing( const EventObject& _rSource ) throw (RuntimeException)
+
+    void SAL_CALL OFormNavigationHelper::disposing( const EventObject& _rSource ) throw (RuntimeException, std::exception)
     {
         // was it one of our external dispatchers?
         if ( m_nConnectedFeatures )
@@ -139,19 +132,19 @@ namespace frm
                 if ( aFeature->second.xDispatcher == _rSource.Source )
                 {
                     aFeature->second.xDispatcher->removeStatusListener( static_cast< XStatusListener* >( this ), aFeature->second.aURL );
-                    aFeature->second.xDispatcher = NULL;
-                    aFeature->second.bCachedState = sal_False;
+                    aFeature->second.xDispatcher = nullptr;
+                    aFeature->second.bCachedState = false;
                     aFeature->second.aCachedAdditionalState.clear();
                     --m_nConnectedFeatures;
 
-                    featureStateChanged( aFeature->first, sal_False );
+                    featureStateChanged( aFeature->first, false );
                     break;
                 }
             }
         }
     }
 
-    //------------------------------------------------------------------
+
     void OFormNavigationHelper::updateDispatches()
     {
         if ( !m_nConnectedFeatures )
@@ -189,14 +182,14 @@ namespace frm
             if ( xCurrentDispatcher.is() )
                 ++m_nConnectedFeatures;
             else
-                aFeature->second.bCachedState = sal_False;
+                aFeature->second.bCachedState = false;
         }
 
         // notify derivee that (potentially) all features changed their state
         allFeatureStatesChanged( );
     }
 
-    //------------------------------------------------------------------
+
     void OFormNavigationHelper::connectDispatchers()
     {
         if ( m_nConnectedFeatures )
@@ -214,7 +207,7 @@ namespace frm
                 ++aFeature
             )
         {
-            aFeature->second.bCachedState = sal_False;
+            aFeature->second.bCachedState = false;
             aFeature->second.aCachedAdditionalState.clear();
             aFeature->second.xDispatcher = queryDispatch( aFeature->second.aURL );
             if ( aFeature->second.xDispatcher.is() )
@@ -228,7 +221,7 @@ namespace frm
         allFeatureStatesChanged( );
     }
 
-    //------------------------------------------------------------------
+
     void OFormNavigationHelper::disconnectDispatchers()
     {
         if ( m_nConnectedFeatures )
@@ -241,8 +234,8 @@ namespace frm
                 if ( aFeature->second.xDispatcher.is() )
                     aFeature->second.xDispatcher->removeStatusListener( static_cast< XStatusListener* >( this ), aFeature->second.aURL );
 
-                aFeature->second.xDispatcher = NULL;
-                aFeature->second.bCachedState = sal_False;
+                aFeature->second.xDispatcher = nullptr;
+                aFeature->second.bCachedState = false;
                 aFeature->second.aCachedAdditionalState.clear();
             }
 
@@ -253,7 +246,7 @@ namespace frm
         allFeatureStatesChanged( );
     }
 
-    //------------------------------------------------------------------
+
     void OFormNavigationHelper::initializeSupportedFeatures( )
     {
         if ( m_aSupportedFeatures.empty() )
@@ -282,13 +275,13 @@ namespace frm
         }
     }
 
-    //------------------------------------------------------------------
+
     Reference< XDispatch > OFormNavigationHelper::queryDispatch( const URL& _rURL )
     {
         return m_pFeatureInterception->queryDispatch( _rURL );
     }
 
-    //------------------------------------------------------------------
+
     void OFormNavigationHelper::dispatchWithArgument( sal_Int16 _nFeatureId, const sal_Char* _pParamAsciiName,
         const Any& _rParamValue ) const
     {
@@ -306,7 +299,7 @@ namespace frm
         }
     }
 
-    //------------------------------------------------------------------
+
     void OFormNavigationHelper::dispatch( sal_Int16 _nFeatureId ) const
     {
         FeatureMap::const_iterator aInfo = m_aSupportedFeatures.find( _nFeatureId );
@@ -320,7 +313,7 @@ namespace frm
         }
     }
 
-    //------------------------------------------------------------------
+
     bool OFormNavigationHelper::isEnabled( sal_Int16 _nFeatureId ) const
     {
         FeatureMap::const_iterator aInfo = m_aSupportedFeatures.find( _nFeatureId );
@@ -330,10 +323,10 @@ namespace frm
         return false;
     }
 
-    //------------------------------------------------------------------
+
     bool OFormNavigationHelper::getBooleanState( sal_Int16 _nFeatureId ) const
     {
-        sal_Bool bState = sal_False;
+        bool bState = false;
 
         FeatureMap::const_iterator aInfo = m_aSupportedFeatures.find( _nFeatureId );
         if ( m_aSupportedFeatures.end() != aInfo )
@@ -342,7 +335,7 @@ namespace frm
         return (bool)bState;
     }
 
-    //------------------------------------------------------------------
+
     OUString OFormNavigationHelper::getStringState( sal_Int16 _nFeatureId ) const
     {
         OUString sState;
@@ -354,7 +347,7 @@ namespace frm
         return sState;
     }
 
-    //------------------------------------------------------------------
+
     sal_Int32 OFormNavigationHelper::getIntegerState( sal_Int16 _nFeatureId ) const
     {
         sal_Int32 nState = 0;
@@ -366,7 +359,7 @@ namespace frm
         return nState;
     }
 
-    //------------------------------------------------------------------
+
     void OFormNavigationHelper::invalidateSupportedFeaturesSet()
     {
         disconnectDispatchers( );
@@ -375,21 +368,17 @@ namespace frm
         m_aSupportedFeatures.swap( aEmpty );
     }
 
-    //==================================================================
-    //= OFormNavigationMapper
-    //==================================================================
-    //------------------------------------------------------------------
     OFormNavigationMapper::OFormNavigationMapper( const Reference< XComponentContext >& _rxORB )
     {
         m_pUrlTransformer.reset( new UrlTransformer( _rxORB ) );
     }
 
-    //------------------------------------------------------------------
+
     OFormNavigationMapper::~OFormNavigationMapper( )
     {
     }
 
-    //------------------------------------------------------------------
+
     bool OFormNavigationMapper::getFeatureURL( sal_Int16 _nFeatureId, URL& /* [out] */ _rURL )
     {
         // get the ascii version of the URL
@@ -397,10 +386,10 @@ namespace frm
         if ( pAsciiURL )
             _rURL = m_pUrlTransformer->getStrictURLFromAscii( pAsciiURL );
 
-        return ( pAsciiURL != NULL );
+        return ( pAsciiURL != nullptr );
     }
 
-    //------------------------------------------------------------------
+
     namespace
     {
         struct FeatureURL
@@ -437,13 +426,13 @@ namespace frm
                 FeatureURL( FormFeature::InteractiveFilter,       URL_FORM_FILTER ),
                 FeatureURL( FormFeature::ToggleApplyFilter,       URL_FORM_APPLY_FILTER ),
                 FeatureURL( FormFeature::RemoveFilterAndSort,     URL_FORM_REMOVE_FILTER ),
-                FeatureURL( 0, NULL )
+                FeatureURL( 0, nullptr )
             };
             return s_aFeatureURLs;
         }
     }
 
-    //------------------------------------------------------------------
+
     const char* OFormNavigationMapper::getFeatureURLAscii( sal_Int16 _nFeatureId )
     {
         const FeatureURL* pFeatures = lcl_getFeatureTable();
@@ -453,10 +442,10 @@ namespace frm
                 return pFeatures->pAsciiURL;
             ++pFeatures;
         }
-        return NULL;
+        return nullptr;
     }
 
-    //------------------------------------------------------------------
+
     sal_Int16 OFormNavigationMapper::getFeatureId( const OUString& _rCompleteURL )
     {
         const FeatureURL* pFeatures = lcl_getFeatureTable();
@@ -469,8 +458,8 @@ namespace frm
         return -1;
     }
 
-//.........................................................................
+
 }   // namespace frm
-//.........................................................................
+
 
 /* vim:set shiftwidth=4 softtabstop=4 expandtab: */
