@@ -18,7 +18,6 @@
  */
 
 #include "richtextcontrol.hxx"
-#include "frm_module.hxx"
 #include "property.hrc"
 #include "services.hxx"
 
@@ -40,13 +39,6 @@
 #include <svl/itempool.hxx>
 #include <sfx2/msgpool.hxx>
 
-
-extern "C" void SAL_CALL createRegistryInfo_ORichTextControl()
-{
-    static ::frm::OMultiInstanceAutoRegistration< ::frm::ORichTextControl > aAutoRegistration;
-}
-
-
 namespace frm
 {
 
@@ -57,24 +49,6 @@ namespace frm
     using namespace ::com::sun::star::lang;
     using namespace ::com::sun::star::frame;
 
-#define FORWARD_TO_PEER_1_RET( returnType, unoInterface, method, param1 )   \
-    returnType aReturn; \
-    Reference< unoInterface > xTypedPeer( getPeer(), UNO_QUERY );   \
-    if ( xTypedPeer.is() )  \
-    {   \
-        aReturn = xTypedPeer->method( param1 );  \
-    }   \
-    return aReturn;
-
-#define FORWARD_TO_PEER_3_RET( returnType, unoInterface, method, param1, param2, param3 )   \
-    returnType aReturn; \
-    Reference< unoInterface > xTypedPeer( getPeer(), UNO_QUERY );   \
-    if ( xTypedPeer.is() )  \
-    {   \
-        aReturn = xTypedPeer->method( param1, param2, param3 );  \
-    }   \
-    return aReturn;
-
     ORichTextControl::ORichTextControl()
         :UnoEditControl()
     {
@@ -186,7 +160,6 @@ namespace frm
         if ( !bReallyActAsRichText )
         {
             UnoEditControl::createPeer( _rToolkit, _rParentPeer );
-            OControl::initFormControlPeer( getPeer() );
             return;
         }
 
@@ -197,7 +170,7 @@ namespace frm
             mbCreatingPeer = true;
 
             // determine the VLC window for the parent
-            vcl::Window* pParentWin = NULL;
+            vcl::Window* pParentWin = nullptr;
             if ( _rParentPeer.is() )
             {
                 VCLXWindow* pParentXWin = VCLXWindow::GetImplementation( _rParentPeer );
@@ -239,8 +212,6 @@ namespace frm
             }
 
             mbCreatingPeer = false;
-
-            OControl::initFormControlPeer( getPeer() );
         }
     }
 
@@ -256,13 +227,11 @@ namespace frm
         return getSupportedServiceNames_Static();
     }
 
-
     OUString SAL_CALL ORichTextControl::getImplementationName_Static()
     {
         return OUString( "com.sun.star.comp.form.ORichTextControl" );
     }
 
-
     Sequence< OUString > SAL_CALL ORichTextControl::getSupportedServiceNames_Static()
     {
         Sequence< OUString > aServices( 3 );
@@ -272,34 +241,34 @@ namespace frm
         return aServices;
     }
 
-
-    Reference< XInterface > SAL_CALL ORichTextControl::Create( const Reference< XMultiServiceFactory >& )
+    Reference< XDispatch > SAL_CALL ORichTextControl::queryDispatch( const css::util::URL& _rURL, const OUString& _rTargetFrameName, sal_Int32 _nSearchFlags ) throw (RuntimeException, std::exception)
     {
-        return *( new ORichTextControl() );
+        Reference< XDispatch > aReturn;
+        Reference< XDispatchProvider > xTypedPeer( getPeer(), UNO_QUERY );
+        if ( xTypedPeer.is() )
+        {
+            aReturn = xTypedPeer->queryDispatch( _rURL, _rTargetFrameName, _nSearchFlags );
+        }
+        return aReturn;
     }
 
-
-    Reference< XDispatch > SAL_CALL ORichTextControl::queryDispatch( const ::com::sun::star::util::URL& _rURL, const OUString& _rTargetFrameName, sal_Int32 _nSearchFlags ) throw (RuntimeException, std::exception)
-    {
-        FORWARD_TO_PEER_3_RET( Reference< XDispatch >, XDispatchProvider, queryDispatch, _rURL, _rTargetFrameName, _nSearchFlags );
-    }
-
-
     Sequence< Reference< XDispatch > > SAL_CALL ORichTextControl::queryDispatches( const Sequence< DispatchDescriptor >& _rRequests ) throw (RuntimeException, std::exception)
     {
-        FORWARD_TO_PEER_1_RET( Sequence< Reference< XDispatch > >, XDispatchProvider, queryDispatches, _rRequests );
+        Sequence< Reference< XDispatch > > aReturn;
+        Reference< XDispatchProvider > xTypedPeer( getPeer(), UNO_QUERY );
+        if ( xTypedPeer.is() )
+        {
+            aReturn = xTypedPeer->queryDispatches( _rRequests );
+        }
+        return aReturn;
     }
 
-
     bool ORichTextControl::requiresNewPeer( const OUString& _rPropertyName ) const
     {
-        return UnoControl::requiresNewPeer( _rPropertyName ) || _rPropertyName.equals( PROPERTY_RICH_TEXT );
+        return UnoControl::requiresNewPeer( _rPropertyName ) || _rPropertyName == PROPERTY_RICH_TEXT;
     }
 
-
     // ORichTextPeer
-
-
     ORichTextPeer* ORichTextPeer::Create( const Reference< XControlModel >& _rxModel, vcl::Window* _pParentWindow, WinBits _nStyle )
     {
         DBG_TESTSOLARMUTEX();
@@ -308,14 +277,14 @@ namespace frm
         RichTextEngine* pEngine = ORichTextModel::getEditEngine( _rxModel );
         OSL_ENSURE( pEngine, "ORichTextPeer::Create: could not obtaine the edit engine from the model!" );
         if ( !pEngine )
-            return NULL;
+            return nullptr;
 
         // the peer itself
         ORichTextPeer* pPeer = new ORichTextPeer;
         pPeer->acquire();   // by definition, the returned object is acquired once
 
         // the VCL control for the peer
-        RichTextControl* pRichTextControl = new RichTextControl( pEngine, _pParentWindow, _nStyle, NULL, pPeer );
+        VclPtrInstance<RichTextControl> pRichTextControl( pEngine, _pParentWindow, _nStyle, nullptr, pPeer );
 
         // some knittings
         pRichTextControl->SetComponentInterface( pPeer );
@@ -339,7 +308,7 @@ namespace frm
     {
         {
             SolarMutexGuard aGuard;
-            RichTextControl* pRichTextControl = static_cast< RichTextControl* >( GetWindow() );
+            VclPtr< RichTextControl > pRichTextControl = GetAs< RichTextControl >();
 
             if ( pRichTextControl )
             {
@@ -361,16 +330,16 @@ namespace frm
     }
 
 
-    void SAL_CALL ORichTextPeer::draw( sal_Int32 _nX, sal_Int32 _nY ) throw(::com::sun::star::uno::RuntimeException, std::exception)
+    void SAL_CALL ORichTextPeer::draw( sal_Int32 _nX, sal_Int32 _nY ) throw(css::uno::RuntimeException, std::exception)
     {
         SolarMutexGuard aGuard;
 
-        RichTextControl* pControl = static_cast< RichTextControl* >( GetWindow() );
+        VclPtr< RichTextControl > pControl = GetAs< RichTextControl >();
         if ( !pControl )
             return;
 
         OutputDevice* pTargetDevice = VCLUnoHelper::GetOutputDevice( getGraphics() );
-        OSL_ENSURE( pTargetDevice != NULL, "ORichTextPeer::draw: no graphics -> no drawing!" );
+        OSL_ENSURE( pTargetDevice != nullptr, "ORichTextPeer::draw: no graphics -> no drawing!" );
         if ( !pTargetDevice )
             return;
 
@@ -384,7 +353,7 @@ namespace frm
         if ( eTargetUnit != MAP_PIXEL )
             aPos = pTargetDevice->PixelToLogic( aPos );
 
-        pControl->Draw( pTargetDevice, aPos, aSize, WINDOW_DRAW_NOCONTROLS );
+        pControl->Draw( pTargetDevice, aPos, aSize, DrawFlags::NoControls );
     }
 
 
@@ -392,15 +361,17 @@ namespace frm
         throw (RuntimeException,
                std::exception)
     {
+        SolarMutexGuard g;
+
         if ( !GetWindow() )
         {
             VCLXWindow::setProperty( _rPropertyName, _rValue );
             return;
         }
 
-        if ( _rPropertyName.equals( PROPERTY_BACKGROUNDCOLOR ) )
+        if ( _rPropertyName == PROPERTY_BACKGROUNDCOLOR )
         {
-            RichTextControl* pControl = static_cast< RichTextControl* >( GetWindow() );
+            VclPtr< RichTextControl > pControl = GetAs< RichTextControl >();
             if ( !_rValue.hasValue() )
             {
                 pControl->SetBackgroundColor( );
@@ -412,21 +383,21 @@ namespace frm
                 pControl->SetBackgroundColor( Color( nColor ) );
             }
         }
-        else if (  _rPropertyName.equals( PROPERTY_HSCROLL ) )
+        else if ( _rPropertyName == PROPERTY_HSCROLL )
         {
             adjustTwoStateWinBit( GetWindow(), _rValue, WB_HSCROLL );
         }
-        else if ( _rPropertyName.equals( PROPERTY_VSCROLL ) )
+        else if ( _rPropertyName == PROPERTY_VSCROLL )
         {
             adjustTwoStateWinBit( GetWindow(), _rValue, WB_VSCROLL );
         }
-        else if ( _rPropertyName.equals( PROPERTY_HARDLINEBREAKS ) )
+        else if ( _rPropertyName == PROPERTY_HARDLINEBREAKS )
         {
             adjustTwoStateWinBit( GetWindow(), _rValue, WB_WORDBREAK, true );
         }
-        else if ( _rPropertyName.equals( PROPERTY_READONLY ) )
+        else if ( _rPropertyName == PROPERTY_READONLY )
         {
-            RichTextControl* pControl = static_cast< RichTextControl* >( GetWindow() );
+            VclPtr< RichTextControl > pControl = GetAs< RichTextControl >();
             bool bReadOnly( pControl->IsReadOnly() );
             OSL_VERIFY( _rValue >>= bReadOnly );
             pControl->SetReadOnly( bReadOnly );
@@ -440,9 +411,9 @@ namespace frm
                 aDispatcherLoop->second->invalidate();
             }
         }
-        else if ( _rPropertyName.equals( PROPERTY_HIDEINACTIVESELECTION ) )
+        else if ( _rPropertyName == PROPERTY_HIDEINACTIVESELECTION )
         {
-            RichTextControl* pRichTextControl = static_cast< RichTextControl* >( GetWindow() );
+            VclPtr< RichTextControl > pRichTextControl = GetAs< RichTextControl >();
             bool bHide = pRichTextControl->GetHideInactiveSelection();
             OSL_VERIFY( _rValue >>= bHide );
             pRichTextControl->SetHideInactiveSelection( bHide );
@@ -492,15 +463,15 @@ namespace frm
     }
 
 
-    ORichTextPeer::SingleAttributeDispatcher ORichTextPeer::implCreateDispatcher( SfxSlotId _nSlotId, const ::com::sun::star::util::URL& _rURL )
+    ORichTextPeer::SingleAttributeDispatcher ORichTextPeer::implCreateDispatcher( SfxSlotId _nSlotId, const css::util::URL& _rURL )
     {
-        RichTextControl* pRichTextControl = static_cast< RichTextControl* >( GetWindow() );
+        VclPtr< RichTextControl > pRichTextControl = GetAs< RichTextControl >();
         OSL_PRECOND( pRichTextControl, "ORichTextPeer::implCreateDispatcher: invalid window!" );
         if ( !pRichTextControl )
-            return SingleAttributeDispatcher( NULL );
+            return SingleAttributeDispatcher( nullptr );
 
-        ORichTextFeatureDispatcher* pDispatcher = NULL;
-        OAttributeDispatcher* pAttributeDispatcher = NULL;
+        ORichTextFeatureDispatcher* pDispatcher = nullptr;
+        OAttributeDispatcher* pAttributeDispatcher = nullptr;
         switch ( _nSlotId )
         {
         case SID_CUT:
@@ -577,9 +548,9 @@ namespace frm
                 }
                 else
                 {
-                    SfxSlotPool& rSlotPool = SfxSlotPool::GetSlotPool( NULL );
+                    SfxSlotPool& rSlotPool = SfxSlotPool::GetSlotPool();
                     const SfxSlot* pSlot = rSlotPool.GetSlot( _nSlotId );
-                    const SfxType* pType = pSlot ? pSlot->GetType() : NULL;
+                    const SfxType* pType = pSlot ? pSlot->GetType() : nullptr;
                     if ( pType )
                     {
                         bNeedParametrizedDispatcher = ( pType->nAttribs > 0 );
@@ -654,7 +625,7 @@ namespace frm
     }
 
 
-    Reference< XDispatch > SAL_CALL ORichTextPeer::queryDispatch( const ::com::sun::star::util::URL& _rURL, const OUString& /*_rTargetFrameName*/, sal_Int32 /*_nSearchFlags*/ ) throw (RuntimeException, std::exception)
+    Reference< XDispatch > SAL_CALL ORichTextPeer::queryDispatch( const css::util::URL& _rURL, const OUString& /*_rTargetFrameName*/, sal_Int32 /*_nSearchFlags*/ ) throw (RuntimeException, std::exception)
     {
         Reference< XDispatch > xReturn;
         if ( !GetWindow() )
@@ -668,7 +639,7 @@ namespace frm
         if ( _rURL.Complete.startsWith( sUnoProtocolPrefix ) )
         {
             OUString sUnoSlotName = _rURL.Complete.copy( sUnoProtocolPrefix.getLength() );
-            SfxSlotId nSlotId = lcl_getSlotFromUnoName( SfxSlotPool::GetSlotPool( NULL ), sUnoSlotName );
+            SfxSlotId nSlotId = lcl_getSlotFromUnoName( SfxSlotPool::GetSlotPool(), sUnoSlotName );
             if ( nSlotId > 0 )
             {
                 // do we already have a dispatcher for this?
@@ -720,5 +691,11 @@ namespace frm
 
 }   // namespace frm
 
+extern "C" SAL_DLLPUBLIC_EXPORT css::uno::XInterface* SAL_CALL
+com_sun_star_comp_form_ORichTextControl_get_implementation(css::uno::XComponentContext*,
+        css::uno::Sequence<css::uno::Any> const &)
+{
+    return cppu::acquire(new frm::ORichTextControl());
+}
 
 /* vim:set shiftwidth=4 softtabstop=4 expandtab: */
