@@ -16,6 +16,11 @@
  *   except in compliance with the License. You may obtain a copy of
  *   the License at http://www.apache.org/licenses/LICENSE-2.0 .
  */
+
+#include <sal/config.h>
+
+#include <utility>
+
 #include "formula/FormulaOpCodeMapperObj.hxx"
 #include "formula/opcode.hxx"
 #include <comphelper/sequence.hxx>
@@ -25,42 +30,40 @@ namespace formula
 {
     using namespace ::com::sun::star;
 
-sal_Bool SAL_CALL FormulaOpCodeMapperObj::supportsService( const OUString& _rServiceName ) throw(uno::RuntimeException)
+sal_Bool SAL_CALL FormulaOpCodeMapperObj::supportsService( const OUString& _rServiceName ) throw(uno::RuntimeException, std::exception)
 {
     return cppu::supportsService(this, _rServiceName);
 }
 
-SAL_WNODEPRECATED_DECLARATIONS_PUSH
-FormulaOpCodeMapperObj::FormulaOpCodeMapperObj(::std::auto_ptr<FormulaCompiler> _pCompiler)
-: m_pCompiler(_pCompiler)
+FormulaOpCodeMapperObj::FormulaOpCodeMapperObj(::std::unique_ptr<FormulaCompiler> && _pCompiler)
+: m_pCompiler(std::move(_pCompiler))
 {
 }
-SAL_WNODEPRECATED_DECLARATIONS_POP
 
 FormulaOpCodeMapperObj::~FormulaOpCodeMapperObj()
 {
 }
 
 ::sal_Int32 SAL_CALL FormulaOpCodeMapperObj::getOpCodeExternal()
-    throw (::com::sun::star::uno::RuntimeException)
+    throw (css::uno::RuntimeException, std::exception)
 {
     return ocExternal;
 }
 
 
 ::sal_Int32 SAL_CALL FormulaOpCodeMapperObj::getOpCodeUnknown()
-    throw (::com::sun::star::uno::RuntimeException)
+    throw (css::uno::RuntimeException, std::exception)
 {
     return FormulaCompiler::OpCodeMap::getOpCodeUnknown();
 }
 
 
-::com::sun::star::uno::Sequence< ::com::sun::star::sheet::FormulaToken >
+css::uno::Sequence< css::sheet::FormulaToken >
 SAL_CALL FormulaOpCodeMapperObj::getMappings(
-        const ::com::sun::star::uno::Sequence< OUString >& rNames,
+        const css::uno::Sequence< OUString >& rNames,
         sal_Int32 nLanguage )
-    throw ( ::com::sun::star::lang::IllegalArgumentException,
-            ::com::sun::star::uno::RuntimeException)
+    throw ( css::lang::IllegalArgumentException,
+            css::uno::RuntimeException, std::exception)
 {
     FormulaCompiler::OpCodeMapPtr xMap = m_pCompiler->GetOpCodeMap( nLanguage);
     if (!xMap)
@@ -69,51 +72,45 @@ SAL_CALL FormulaOpCodeMapperObj::getMappings(
 }
 
 
-::com::sun::star::uno::Sequence< ::com::sun::star::sheet::FormulaOpCodeMapEntry >
+css::uno::Sequence< css::sheet::FormulaOpCodeMapEntry >
 SAL_CALL FormulaOpCodeMapperObj::getAvailableMappings(
         sal_Int32 nLanguage, sal_Int32 nGroups )
-    throw ( ::com::sun::star::lang::IllegalArgumentException,
-            ::com::sun::star::uno::RuntimeException)
+    throw ( css::lang::IllegalArgumentException,
+            css::uno::RuntimeException, std::exception)
 {
     FormulaCompiler::OpCodeMapPtr xMap = m_pCompiler->GetOpCodeMap( nLanguage);
     if (!xMap)
         throw lang::IllegalArgumentException();
     return xMap->createSequenceOfAvailableMappings( *m_pCompiler,nGroups);
 }
-//--------------------------------------------------------------------------
-OUString SAL_CALL FormulaOpCodeMapperObj::getImplementationName(  ) throw(uno::RuntimeException)
+
+OUString SAL_CALL FormulaOpCodeMapperObj::getImplementationName(  ) throw(uno::RuntimeException, std::exception)
 {
     return getImplementationName_Static();
 }
-// -----------------------------------------------------------------------------
+
 OUString SAL_CALL FormulaOpCodeMapperObj::getImplementationName_Static()
 {
     return OUString( "simple.formula.FormulaOpCodeMapperObj" );
 }
-// --------------------------------------------------------------------------------
-uno::Sequence< OUString > SAL_CALL FormulaOpCodeMapperObj::getSupportedServiceNames(  ) throw(uno::RuntimeException)
+
+uno::Sequence< OUString > SAL_CALL FormulaOpCodeMapperObj::getSupportedServiceNames(  ) throw(uno::RuntimeException, std::exception)
 {
     return getSupportedServiceNames_Static();
 }
 uno::Sequence< OUString > SAL_CALL FormulaOpCodeMapperObj::getSupportedServiceNames_Static()
 {
-    uno::Sequence< OUString > aSeq( 1 );
-    aSeq[0] = "com.sun.star.sheet.FormulaOpCodeMapper";
+    uno::Sequence<OUString> aSeq { "com.sun.star.sheet.FormulaOpCodeMapper" };
     return aSeq;
 }
 
-SAL_WNODEPRECATED_DECLARATIONS_PUSH
 uno::Reference< uno::XInterface > SAL_CALL FormulaOpCodeMapperObj::create(
                 uno::Reference< uno::XComponentContext > const & /*_xContext*/)
 {
-    return static_cast<sheet::XFormulaOpCodeMapper*>(new FormulaOpCodeMapperObj(::std::auto_ptr<FormulaCompiler>(new FormulaCompiler())));
+    return static_cast<sheet::XFormulaOpCodeMapper*>(new FormulaOpCodeMapperObj(::std::unique_ptr<FormulaCompiler>(new FormulaCompiler())));
 }
-SAL_WNODEPRECATED_DECLARATIONS_POP
 
-// -----------------------------------------------------------------------------
-
-// =============================================================================
 } // formula
-// =============================================================================
+
 
 /* vim:set shiftwidth=4 softtabstop=4 expandtab: */
