@@ -30,6 +30,7 @@
 #include "../misc/WinImplHelper.hxx"
 #include "shared.hxx"
 
+#include <com/sun/star/awt/XWindow.hpp>
 #include <com/sun/star/lang/DisposedException.hpp>
 #include <com/sun/star/ui/dialogs/TemplateDescription.hpp>
 #include <com/sun/star/ui/dialogs/XFilePickerNotifier.hpp>
@@ -256,19 +257,18 @@ OUString SAL_CALL VistaFilePicker::getDisplayDirectory()
 css::uno::Sequence< OUString > SAL_CALL VistaFilePicker::getFiles()
     throw(css::uno::RuntimeException)
 {
-    RequestRef rRequest(new Request());
-    rRequest->setRequest (VistaFilePickerImpl::E_GET_SELECTED_FILES);
-
-    m_aAsyncExecute.triggerRequestThreadAware(rRequest, AsyncRequests::BLOCKED);
-
-    const  css::uno::Sequence< OUString > lFiles = rRequest->getArgumentOrDefault(PROP_SELECTED_FILES, css::uno::Sequence< OUString >());
+    css::uno::Sequence< OUString > lFiles = getSelectedFiles();
+    // multiselection doesn't really work
+    // so just retrieve the first url
+    if (lFiles.getLength() > 1)
+        lFiles.realloc(1);
     m_lLastFiles = lFiles;
     return lFiles;
 }
 
 
 css::uno::Sequence< OUString > SAL_CALL VistaFilePicker::getSelectedFiles()
-    throw(css::uno::RuntimeException)
+    throw(css::uno::RuntimeException, std::exception)
 {
     RequestRef rRequest(new Request());
     rRequest->setRequest (VistaFilePickerImpl::E_GET_SELECTED_FILES);
@@ -574,7 +574,11 @@ void SAL_CALL VistaFilePicker::initialize(const css::uno::Sequence< css::uno::An
         }
         break;
     }
-
+    css::uno::Reference<css::awt::XWindow> xParentWindow;
+    if(lArguments.getLength() > 1)
+    {
+        lArguments[1] >>= xParentWindow;
+    }
     RequestRef rRequest(new Request());
     if (bFileOpenDialog)
         rRequest->setRequest (VistaFilePickerImpl::E_CREATE_OPEN_DIALOG);
@@ -582,6 +586,8 @@ void SAL_CALL VistaFilePicker::initialize(const css::uno::Sequence< css::uno::An
         rRequest->setRequest (VistaFilePickerImpl::E_CREATE_SAVE_DIALOG);
     rRequest->setArgument(PROP_FEATURES, nFeatures);
     rRequest->setArgument(PROP_TEMPLATE_DESCR, nTemplate);
+    if(xParentWindow.is())
+        rRequest->setArgument(PROP_PARENT_WINDOW, xParentWindow);
     if ( ! m_aAsyncExecute.isRunning())
         m_aAsyncExecute.create();
     m_aAsyncExecute.triggerRequestThreadAware(rRequest, AsyncRequests::NON_BLOCKED);
