@@ -18,6 +18,7 @@
  */
 
 #include <accelerators/storageholder.hxx>
+#include <accelerators/acceleratorconfiguration.hxx>
 
 #include <services.h>
 
@@ -37,9 +38,10 @@
 
 #include <com/sun/star/io/XSeekable.hpp>
 
-#define PATH_SEPARATOR_ASCII        "/"
+#include <algorithm>
+
+#define PATH_SEPARATOR "/"
 #define PATH_SEPARATOR_UNICODE      ((sal_Unicode)'/')
-#define PATH_SEPARATOR              OUString(PATH_SEPARATOR_ASCII)
 
 namespace framework
 {
@@ -102,9 +104,7 @@ css::uno::Reference< css::embed::XStorage > StorageHolder::openPath(const OUStri
          ++pIt                    )
     {
         const OUString& sChild     = *pIt;
-              OUString  sCheckPath (sRelPath);
-                               sCheckPath += sChild;
-                               sCheckPath += PATH_SEPARATOR;
+              OUString  sCheckPath (sRelPath + sChild + PATH_SEPARATOR);
 
         // SAFE -> ------------------------------
         aReadLock.reset();
@@ -112,7 +112,7 @@ css::uno::Reference< css::embed::XStorage > StorageHolder::openPath(const OUStri
         // If we found an already open storage ... we must increase
         // its use count. Otherwhise it will may be closed to early :-)
         TPath2StorageInfo::iterator pCheck = m_lStorages.find(sCheckPath);
-        TStorageInfo*               pInfo  = 0;
+        TStorageInfo*               pInfo  = nullptr;
         if (pCheck != m_lStorages.end())
         {
             pInfo = &(pCheck->second);
@@ -155,11 +155,10 @@ css::uno::Reference< css::embed::XStorage > StorageHolder::openPath(const OUStri
         }
 
         xParent   = xChild;
-        sRelPath += sChild;
-        sRelPath += PATH_SEPARATOR;
+        sRelPath += sChild + PATH_SEPARATOR;
     }
 
-    // TODO think about return last storage as working storage ... but dont caching it inside this holder!
+    // TODO think about return last storage as working storage ... but don't caching it inside this holder!
     // => otherwise the same storage is may be commit more than once.
 
     return xChild;
@@ -181,9 +180,7 @@ StorageHolder::TStorageList StorageHolder::getAllPathStorages(const OUString& sP
          ++pIt                    )
     {
         const OUString& sChild     = *pIt;
-              OUString  sCheckPath (sRelPath);
-                               sCheckPath += sChild;
-                               sCheckPath += PATH_SEPARATOR;
+              OUString  sCheckPath (sRelPath + sChild + PATH_SEPARATOR);
 
         TPath2StorageInfo::iterator pCheck = m_lStorages.find(sCheckPath);
         if (pCheck == m_lStorages.end())
@@ -197,8 +194,7 @@ StorageHolder::TStorageList StorageHolder::getAllPathStorages(const OUString& sP
         TStorageInfo& rInfo = pCheck->second;
         lStoragesOfPath.push_back(rInfo.Storage);
 
-        sRelPath += sChild;
-        sRelPath += PATH_SEPARATOR;
+        sRelPath += sChild + PATH_SEPARATOR;
     }
 
     return lStoragesOfPath;
@@ -214,7 +210,7 @@ void StorageHolder::commitPath(const OUString& sPath)
            pIt != lStorages.rend();
          ++pIt                      )
     {
-        xCommit = css::uno::Reference< css::embed::XTransactedObject >(*pIt, css::uno::UNO_QUERY);
+        xCommit.set(*pIt, css::uno::UNO_QUERY);
         if (!xCommit.is())
             continue;
         xCommit->commit();
@@ -222,7 +218,7 @@ void StorageHolder::commitPath(const OUString& sPath)
 
     // SAFE -> ------------------------------
     osl::ClearableMutexGuard aReadLock(m_mutex);
-    xCommit = css::uno::Reference< css::embed::XTransactedObject >(m_xRoot, css::uno::UNO_QUERY);
+    xCommit.set(m_xRoot, css::uno::UNO_QUERY);
     aReadLock.clear();
     // <- SAFE ------------------------------
 
@@ -246,9 +242,7 @@ void StorageHolder::closePath(const OUString& rPath)
            pIt1 != lFolders.end();
          ++pIt1                    )
     {
-        OUString sCurrentRelPath  = sParentPath;
-                        sCurrentRelPath += *pIt1;
-                        sCurrentRelPath += PATH_SEPARATOR;
+        OUString sCurrentRelPath(sParentPath + *pIt1 + PATH_SEPARATOR);
         *pIt1       = sCurrentRelPath;
         sParentPath = sCurrentRelPath;
     }
@@ -291,13 +285,13 @@ void StorageHolder::notifyPath(const OUString& sPath)
            pIt2 != rInfo.Listener.end();
          ++pIt2                          )
     {
-        IStorageListener* pListener = *pIt2;
+        XMLBasedAcceleratorConfiguration* pListener = *pIt2;
         if (pListener)
-            pListener->changesOccurred(sNormedPath);
+            pListener->changesOccurred();
     }
 }
 
-void StorageHolder::addStorageListener(      IStorageListener* pListener,
+void StorageHolder::addStorageListener(      XMLBasedAcceleratorConfiguration* pListener,
                                        const OUString&  sPath    )
 {
     OUString sNormedPath = StorageHolder::impl_st_normPath(sPath);
@@ -314,7 +308,7 @@ void StorageHolder::addStorageListener(      IStorageListener* pListener,
         rInfo.Listener.push_back(pListener);
 }
 
-void StorageHolder::removeStorageListener(      IStorageListener* pListener,
+void StorageHolder::removeStorageListener(      XMLBasedAcceleratorConfiguration* pListener,
                                           const OUString&  sPath    )
 {
     OUString sNormedPath = StorageHolder::impl_st_normPath(sPath);
@@ -384,8 +378,7 @@ css::uno::Reference< css::embed::XStorage > StorageHolder::getParentStorage(cons
     sal_Int32       i = 0;
     for (i=0; i<c-1; ++i)
     {
-        sParentPath += lFolders[i];
-        sParentPath += PATH_SEPARATOR;
+        sParentPath += lFolders[i] + PATH_SEPARATOR;
     }
 
     TPath2StorageInfo::const_iterator pParent = m_lStorages.find(sParentPath);
@@ -434,7 +427,7 @@ css::uno::Reference< css::embed::XStorage > StorageHolder::openSubStorageWithFal
         throw exResult;
 
     // c) try it readonly
-    //    dont catch exception here! Outside code wish to know, if operation failed or not.
+    //    don't catch exception here! Outside code wish to know, if operation failed or not.
     //    Otherwhise they work on NULL references ...
     sal_Int32 eNewMode = (eOpenMode & ~css::embed::ElementModes::WRITE);
     css::uno::Reference< css::embed::XStorage > xSubStorage = xBaseStorage->openStorageElement(sSubStorage, eNewMode);
@@ -473,7 +466,7 @@ css::uno::Reference< css::io::XStream > StorageHolder::openSubStreamWithFallback
         throw exResult;
 
     // c) try it readonly
-    //    dont catch exception here! Outside code wish to know, if operation failed or not.
+    //    don't catch exception here! Outside code wish to know, if operation failed or not.
     //    Otherwhise they work on NULL references ...
     sal_Int32 eNewMode = (eOpenMode & ~css::embed::ElementModes::WRITE);
     css::uno::Reference< css::io::XStream > xSubStream = xBaseStorage->openStreamElement(sSubStream, eNewMode);
@@ -492,15 +485,14 @@ OUString StorageHolder::impl_st_normPath(const OUString& sPath)
     OUString sNormedPath = sPath;
 
     // "/bla" => "bla" && "/" => "" (!)
-    if (sNormedPath.startsWith(PATH_SEPARATOR))
-        sNormedPath += sNormedPath.copy(1);
+    (void)sNormedPath.startsWith(PATH_SEPARATOR, &sNormedPath);
 
     // "/" => "" || "" => "" ?
     if (sNormedPath.isEmpty())
         return OUString();
 
     // "bla" => "bla/"
-    if (sNormedPath.lastIndexOf(PATH_SEPARATOR) != (sNormedPath.getLength()-1))
+    if (sNormedPath.lastIndexOf(PATH_SEPARATOR_UNICODE) != (sNormedPath.getLength()-1))
         sNormedPath += PATH_SEPARATOR;
 
     return sNormedPath;
