@@ -18,8 +18,6 @@
  */
 
 #include <jobs/jobdata.hxx>
-#include <threadhelp/readguard.hxx>
-#include <threadhelp/writeguard.hxx>
 #include <classes/converter.hxx>
 #include <general.h>
 #include <services.h>
@@ -31,57 +29,26 @@
 
 #include <tools/wldcrd.hxx>
 #include <unotools/configpaths.hxx>
-#include <rtl/ustrbuf.hxx>
 #include <vcl/svapp.hxx>
 
-
 namespace framework{
 
-
-const sal_Char* JobData::JOBCFG_ROOT              = "/org.openoffice.Office.Jobs/Jobs/"   ;
-const sal_Char* JobData::JOBCFG_PROP_SERVICE      = "Service"                             ;
-const sal_Char* JobData::JOBCFG_PROP_CONTEXT      = "Context"                             ;
-const sal_Char* JobData::JOBCFG_PROP_ARGUMENTS    = "Arguments"                           ;
-
-const sal_Char* JobData::EVENTCFG_ROOT            = "/org.openoffice.Office.Jobs/Events/" ;
-const sal_Char* JobData::EVENTCFG_PATH_JOBLIST    = "/JobList"                            ;
-const sal_Char* JobData::EVENTCFG_PROP_ADMINTIME  = "AdminTime"                           ;
-const sal_Char* JobData::EVENTCFG_PROP_USERTIME   = "UserTime"                            ;
-
-const sal_Char* JobData::PROPSET_CONFIG           = "Config"                              ;
-const sal_Char* JobData::PROPSET_OWNCONFIG        = "JobConfig"                           ;
-const sal_Char* JobData::PROPSET_ENVIRONMENT      = "Environment"                         ;
-const sal_Char* JobData::PROPSET_DYNAMICDATA      = "DynamicData"                         ;
-
-const sal_Char* JobData::PROP_ALIAS               = "Alias"                               ;
-const sal_Char* JobData::PROP_EVENTNAME           = "EventName"                           ;
-const sal_Char* JobData::PROP_ENVTYPE             = "EnvType"                             ;
-const sal_Char* JobData::PROP_FRAME               = "Frame"                               ;
-const sal_Char* JobData::PROP_MODEL               = "Model"                               ;
-const sal_Char* JobData::PROP_SERVICE             = "Service"                             ;
-const sal_Char* JobData::PROP_CONTEXT             = "Context"                             ;
-
-
-
-//________________________________
 /**
     @short      standard ctor
     @descr      It initialize this new instance.
-                But for real working it's neccessary to call setAlias() or setService() later.
+                But for real working it's necessary to call setAlias() or setService() later.
                 Because we need the job data ...
 
     @param      rxContext
                     reference to the uno service manager
 */
 JobData::JobData( const css::uno::Reference< css::uno::XComponentContext >& rxContext )
-    : ThreadHelpBase(&Application::GetSolarMutex())
-    , m_xContext    (rxContext                    )
+    : m_xContext    (rxContext                    )
 {
     // share code for member initialization with defaults!
     impl_reset();
 }
 
-//________________________________
 /**
     @short  copy ctor
     @descr  Sometimes such job data container must be moved from one using place
@@ -91,13 +58,11 @@ JobData::JobData( const css::uno::Reference< css::uno::XComponentContext >& rxCo
                 the original instance, from which we must copy all data
 */
 JobData::JobData( const JobData& rCopy )
-    : ThreadHelpBase(&Application::GetSolarMutex())
 {
     // use the copy operator to share the same code
     *this = rCopy;
 }
 
-//________________________________
 /**
     @short  operator for coping JobData instances
     @descr  Sometimes such job data container must be moved from one using place
@@ -108,23 +73,19 @@ JobData::JobData( const JobData& rCopy )
 */
 void JobData::operator=( const JobData& rCopy )
 {
-    /* SAFE { */
-    WriteGuard aWriteLock(m_aLock);
+    SolarMutexGuard g;
     // Please don't copy the uno service manager reference.
     // That can change the uno context, which isn't a good idea!
-    m_eMode                = rCopy.m_eMode               ;
-    m_eEnvironment         = rCopy.m_eEnvironment        ;
-    m_sAlias               = rCopy.m_sAlias              ;
-    m_sService             = rCopy.m_sService            ;
-    m_sContext             = rCopy.m_sContext            ;
-    m_sEvent               = rCopy.m_sEvent              ;
-    m_lArguments           = rCopy.m_lArguments          ;
+    m_eMode                = rCopy.m_eMode;
+    m_eEnvironment         = rCopy.m_eEnvironment;
+    m_sAlias               = rCopy.m_sAlias;
+    m_sService             = rCopy.m_sService;
+    m_sContext             = rCopy.m_sContext;
+    m_sEvent               = rCopy.m_sEvent;
+    m_lArguments           = rCopy.m_lArguments;
     m_aLastExecutionResult = rCopy.m_aLastExecutionResult;
-    aWriteLock.unlock();
-    /* } SAFE */
 }
 
-//________________________________
 /**
     @short  let this instance die
     @descr  There is no chance any longer to work. We have to
@@ -135,10 +96,9 @@ JobData::~JobData()
     impl_reset();
 }
 
-//________________________________
 /**
     @short      initalize this instance as a job with configuration
-    @descr      They given alias can be used to address some configuraton data.
+    @descr      They given alias can be used to address some configuration data.
                 We read it and fill our internal structures. Of course old information
                 will be lost doing so.
 
@@ -147,8 +107,7 @@ JobData::~JobData()
 */
 void JobData::setAlias( const OUString& sAlias )
 {
-    /* SAFE { */
-    WriteGuard aWriteLock(m_aLock);
+    SolarMutexGuard g;
     // delete all old information! Otherwhise we mix it with the new one ...
     impl_reset();
 
@@ -158,10 +117,10 @@ void JobData::setAlias( const OUString& sAlias )
 
     // try to open the configuration set of this job directly and get a property access to it
     // We open it readonly here
-    OUString sKey(OUString::createFromAscii(JOBCFG_ROOT));
-    sKey += ::utl::wrapConfigurationElementName(m_sAlias);
-
-    ConfigAccess aConfig(m_xContext, sKey);
+    ConfigAccess aConfig(
+        m_xContext,
+        ("/org.openoffice.Office.Jobs/Jobs/"
+         + utl::wrapConfigurationElementName(m_sAlias)));
     aConfig.open(ConfigAccess::E_READONLY);
     if (aConfig.getMode()==ConfigAccess::E_CLOSED)
     {
@@ -175,15 +134,15 @@ void JobData::setAlias( const OUString& sAlias )
         css::uno::Any aValue;
 
         // read uno implementation name
-        aValue   = xJobProperties->getPropertyValue(OUString::createFromAscii(JOBCFG_PROP_SERVICE));
+        aValue   = xJobProperties->getPropertyValue("Service");
         aValue >>= m_sService;
 
         // read module context list
-        aValue   = xJobProperties->getPropertyValue(OUString::createFromAscii(JOBCFG_PROP_CONTEXT));
+        aValue   = xJobProperties->getPropertyValue("Context");
         aValue >>= m_sContext;
 
         // read whole argument list
-        aValue = xJobProperties->getPropertyValue(OUString::createFromAscii(JOBCFG_PROP_ARGUMENTS));
+        aValue = xJobProperties->getPropertyValue("Arguments");
         css::uno::Reference< css::container::XNameAccess > xArgumentList;
         if (
             (aValue >>= xArgumentList)  &&
@@ -202,11 +161,8 @@ void JobData::setAlias( const OUString& sAlias )
     }
 
     aConfig.close();
-    aWriteLock.unlock();
-    /* } SAFE */
 }
 
-//________________________________
 /**
     @short      initalize this instance as a job without configuration
     @descr      This job has no configuration data. We have to forget all old information
@@ -217,29 +173,23 @@ void JobData::setAlias( const OUString& sAlias )
 */
 void JobData::setService( const OUString& sService )
 {
-    /* SAFE { */
-    WriteGuard aWriteLock(m_aLock);
-
+    SolarMutexGuard g;
     // delete all old information! Otherwhise we mix it with the new one ...
     impl_reset();
     // take over the new information
     m_sService = sService;
     m_eMode    = E_SERVICE;
-
-    aWriteLock.unlock();
-    /* } SAFE */
 }
 
-//________________________________
 /**
     @short      initialize this instance with new job values.
-    @descr      It reads automaticly all properties of the specified
+    @descr      It reads automatically all properties of the specified
                 job (using it's alias name) and "register it" for the
                 given event. This registration will not be validated against
                 the underlying configuration! (That must be done from outside.
                 Because the caller must have the configuration already open to
                 get the values for sEvent and sAlias! And doing so it can perform
-                only, if the time stanp values are readed outside too.
+                only, if the time stamp values are readed outside too.
                 Further it make no sense to initialize and start a disabled job.
                 So this initialization method will be called for enabled jobs only.)
 
@@ -255,18 +205,12 @@ void JobData::setEvent( const OUString& sEvent ,
     // share code to read all job properties!
     setAlias(sAlias);
 
-    /* SAFE { */
-    WriteGuard aWriteLock(m_aLock);
-
+    SolarMutexGuard g;
     // take over the new information - which differ against set on of method setAlias()!
     m_sEvent = sEvent;
     m_eMode  = E_EVENT;
-
-    aWriteLock.unlock();
-    /* } SAFE */
 }
 
-//________________________________
 /**
     @short      set the new job specific arguments
     @descr      If a job finish his work, it can give us a new list of arguments (which
@@ -280,8 +224,7 @@ void JobData::setEvent( const OUString& sEvent ,
  */
 void JobData::setJobConfig( const css::uno::Sequence< css::beans::NamedValue >& lArguments )
 {
-    /* SAFE { */
-    WriteGuard aWriteLock(m_aLock);
+    SolarMutexGuard g;
 
     // update member
     m_lArguments = lArguments;
@@ -290,12 +233,12 @@ void JobData::setJobConfig( const css::uno::Sequence< css::beans::NamedValue >&
     if (m_eMode==E_ALIAS)
     {
         // It doesn't matter if this config object was already opened before.
-        // It doesn nothing here then ... or it change the mode automaticly, if
+        // It doesn nothing here then ... or it change the mode automatically, if
         // it was opened using another one before.
-        OUString sKey(OUString::createFromAscii(JOBCFG_ROOT));
-        sKey += ::utl::wrapConfigurationElementName(m_sAlias);
-
-        ConfigAccess aConfig(m_xContext, sKey);
+        ConfigAccess aConfig(
+            m_xContext,
+            ("/org.openoffice.Office.Jobs/Jobs/"
+             + utl::wrapConfigurationElementName(m_sAlias)));
         aConfig.open(ConfigAccess::E_READWRITE);
         if (aConfig.getMode()==ConfigAccess::E_CLOSED)
             return;
@@ -309,7 +252,7 @@ void JobData::setJobConfig( const css::uno::Sequence< css::beans::NamedValue >&
 
             for (sal_Int32 i=0; i<nCount; ++i)
             {
-                lNames [i] = m_lArguments[i].Name ;
+                lNames [i] = m_lArguments[i].Name;
                 lValues[i] = m_lArguments[i].Value;
             }
 
@@ -317,12 +260,8 @@ void JobData::setJobConfig( const css::uno::Sequence< css::beans::NamedValue >&
         }
         aConfig.close();
     }
-
-    aWriteLock.unlock();
-    /* } SAFE */
 }
 
-//________________________________
 /**
     @short      set a new excution result
     @descr      Every executed job can have returned a result.
@@ -337,8 +276,7 @@ void JobData::setJobConfig( const css::uno::Sequence< css::beans::NamedValue >&
  */
 void JobData::setResult( const JobResult& aResult )
 {
-    /* SAFE { */
-    WriteGuard aWriteLock(m_aLock);
+    SolarMutexGuard g;
 
     // overwrite the last saved result
     m_aLastExecutionResult = aResult;
@@ -346,28 +284,20 @@ void JobData::setResult( const JobResult& aResult )
     // Don't use his information to update
     // e.g. the arguments of this job. It must be done
     // from outside! Here we save this information only.
-
-    aWriteLock.unlock();
-    /* } SAFE */
 }
 
-//________________________________
 /**
     @short  set a new environment descriptor for this job
-    @descr  It must(!) be done everytime this container is initialized
+    @descr  It must(!) be done every time this container is initialized
             with new job datas e.g.: setAlias()/setEvent()/setService() ...
             Otherwhise the environment will be unknown!
  */
 void JobData::setEnvironment( EEnvironment eEnvironment )
 {
-    /* SAFE { */
-    WriteGuard aWriteLock(m_aLock);
+    SolarMutexGuard g;
     m_eEnvironment = eEnvironment;
-    aWriteLock.unlock();
-    /* } SAFE */
 }
 
-//________________________________
 /**
     @short      these functions provides access to our internal members
     @descr      These member represent any information about the job
@@ -375,29 +305,20 @@ void JobData::setEnvironment( EEnvironment eEnvironment )
  */
 JobData::EMode JobData::getMode() const
 {
-    /* SAFE { */
-    ReadGuard aReadLock(m_aLock);
+    SolarMutexGuard g;
     return m_eMode;
-    /* } SAFE */
 }
 
-//________________________________
-
 JobData::EEnvironment JobData::getEnvironment() const
 {
-    /* SAFE { */
-    ReadGuard aReadLock(m_aLock);
+    SolarMutexGuard g;
     return m_eEnvironment;
-    /* } SAFE */
 }
 
-//________________________________
-
 OUString JobData::getEnvironmentDescriptor() const
 {
     OUString sDescriptor;
-    /* SAFE { */
-    ReadGuard aReadLock(m_aLock);
+    SolarMutexGuard g;
     switch(m_eEnvironment)
     {
         case E_EXECUTION :
@@ -414,104 +335,81 @@ OUString JobData::getEnvironmentDescriptor() const
         default:
             break;
     }
-    /* } SAFE */
     return sDescriptor;
 }
 
-//________________________________
-
 OUString JobData::getService() const
 {
-    /* SAFE { */
-    ReadGuard aReadLock(m_aLock);
+    SolarMutexGuard g;
     return m_sService;
-    /* } SAFE */
 }
 
-//________________________________
-
 OUString JobData::getEvent() const
 {
-    /* SAFE { */
-    ReadGuard aReadLock(m_aLock);
+    SolarMutexGuard g;
     return m_sEvent;
-    /* } SAFE */
 }
 
-//________________________________
-
 css::uno::Sequence< css::beans::NamedValue > JobData::getJobConfig() const
 {
-    /* SAFE { */
-    ReadGuard aReadLock(m_aLock);
+    SolarMutexGuard g;
     return m_lArguments;
-    /* } SAFE */
 }
 
-//________________________________
-
 css::uno::Sequence< css::beans::NamedValue > JobData::getConfig() const
 {
-    /* SAFE { */
-    ReadGuard aReadLock(m_aLock);
+    SolarMutexGuard g;
     css::uno::Sequence< css::beans::NamedValue > lConfig;
     if (m_eMode==E_ALIAS)
     {
         lConfig.realloc(3);
         sal_Int32 i = 0;
 
-        lConfig[i].Name = OUString::createFromAscii(PROP_ALIAS);
+        lConfig[i].Name = "Alias";
         lConfig[i].Value <<= m_sAlias;
         ++i;
 
-        lConfig[i].Name = OUString::createFromAscii(PROP_SERVICE);
+        lConfig[i].Name = "Service";
         lConfig[i].Value <<= m_sService;
         ++i;
 
-        lConfig[i].Name = OUString::createFromAscii(PROP_CONTEXT);
+        lConfig[i].Name = "Context";
         lConfig[i].Value <<= m_sContext;
         ++i;
     }
-    aReadLock.unlock();
-    /* } SAFE */
     return lConfig;
 }
 
-//________________________________
 /**
     @short  return information, if this job is part of the global configuration package
             org.openoffice.Office.Jobs
     @descr  Because jobs can be executed by the dispatch framework using an uno service name
-            directly - an executed job must not have any configuration realy. Such jobs
+            directly - an executed job must not have any configuration really. Such jobs
             must provide the right interfaces only! But after finishing jobs can return
             some information (e.g. for updating her configuration ...). We must know
             if such request is valid or not then.
 
     @return sal_True if the represented job is part of the underlying configuration package.
  */
-sal_Bool JobData::hasConfig() const
+bool JobData::hasConfig() const
 {
-    /* SAFE { */
-    ReadGuard aReadLock(m_aLock);
+    SolarMutexGuard g;
     return (m_eMode==E_ALIAS || m_eMode==E_EVENT);
-    /* } SAFE */
 }
 
-//________________________________
 /**
     @short      mark a job as non startable for further requests
     @descr      We don't remove the configuration entry! We set a timestamp value only.
-                And there exist two of them: one for an administrator ... and one for the
+                And there exist two of them: one for an administrator... and one for the
                 current user. We change it for the user layer only. So this JobDispatch can't be
-                started any more ... till the administrator change his timestamp.
+                started any more... till the administrator change his timestamp.
                 That can be useful for post setup scenarios, which must run one time only.
 
-                Note: This method don't do anything, if ths represented job doesn't have a configuration!
+                Note: This method don't do anything, if this represented job doesn't have a configuration!
  */
 void JobData::disableJob()
 {
-    /* SAFE { */
-    WriteGuard aWriteLock(m_aLock);
+    SolarMutexGuard g;
 
     // No configuration - not used from EXECUTOR and not triggered from an event => no chance!
     if (m_eMode!=E_EVENT)
@@ -519,16 +417,13 @@ void JobData::disableJob()
 
     // update the configuration
     // It doesn't matter if this config object was already opened before.
-    // It doesn nothing here then ... or it change the mode automaticly, if
+    // It doesn nothing here then ... or it change the mode automatically, if
     // it was opened using another one before.
-    OUStringBuffer sKey(256);
-    sKey.appendAscii(JobData::EVENTCFG_ROOT                       );
-    sKey.append     (::utl::wrapConfigurationElementName(m_sEvent));
-    sKey.appendAscii(JobData::EVENTCFG_PATH_JOBLIST               );
-    sKey.appendAscii("/"                                          );
-    sKey.append     (::utl::wrapConfigurationElementName(m_sAlias));
-
-    ConfigAccess aConfig(m_xContext, sKey.makeStringAndClear());
+    ConfigAccess aConfig(
+        m_xContext,
+        ("/org.openoffice.Office.Jobs/Events/"
+         + utl::wrapConfigurationElementName(m_sEvent) + "/JobList/"
+         + utl::wrapConfigurationElementName(m_sAlias)));
     aConfig.open(ConfigAccess::E_READWRITE);
     if (aConfig.getMode()==ConfigAccess::E_CLOSED)
         return;
@@ -539,19 +434,15 @@ void JobData::disableJob()
         // Convert and write the user timestamp to the configuration.
         css::uno::Any aValue;
         aValue <<= Converter::convert_DateTime2ISO8601(DateTime( DateTime::SYSTEM));
-        xPropSet->setPropertyValue(OUString::createFromAscii(EVENTCFG_PROP_USERTIME), aValue);
+        xPropSet->setPropertyValue("UserTime", aValue);
     }
 
     aConfig.close();
-
-    aWriteLock.unlock();
-    /* } SAFE */
 }
 
-//________________________________
 /**
  */
-sal_Bool isEnabled( const OUString& sAdminTime ,
+bool isEnabled( const OUString& sAdminTime ,
                     const OUString& sUserTime  )
 {
     /*Attention!
@@ -559,14 +450,14 @@ sal_Bool isEnabled( const OUString& sAdminTime ,
         we have to encode all '?' signs. Otherwhise e.g. "??-" will be translated
         to "~" ...
      */
-    static OUString PATTERN_ISO8601("\?\?\?\?-\?\?-\?\?*");
+    static const char PATTERN_ISO8601[] = "\?\?\?\?-\?\?-\?\?*";
     WildCard aISOPattern(PATTERN_ISO8601);
 
-    sal_Bool bValidAdmin = aISOPattern.Matches(sAdminTime);
-    sal_Bool bValidUser  = aISOPattern.Matches(sUserTime );
+    bool bValidAdmin = aISOPattern.Matches(sAdminTime);
+    bool bValidUser  = aISOPattern.Matches(sUserTime );
 
     // We check for "isEnabled()" here only.
-    // Note further: ISO8601 formated strings can be compared as strings directly!
+    // Note further: ISO8601 formatted strings can be compared as strings directly!
     //               FIXME: this is not true! "T1215" is the same time as "T12:15" or "T121500"
     return (
             (!bValidAdmin && !bValidUser                         ) ||
@@ -574,12 +465,11 @@ sal_Bool isEnabled( const OUString& sAdminTime ,
            );
 }
 
-//________________________________
 /**
  */
 void JobData::appendEnabledJobsForEvent( const css::uno::Reference< css::uno::XComponentContext >&              rxContext,
                                          const OUString&                                                 sEvent ,
-                                               ::comphelper::SequenceAsVector< JobData::TJob2DocEventBinding >& lJobs  )
+                                               ::std::vector< JobData::TJob2DocEventBinding >& lJobs  )
 {
     css::uno::Sequence< OUString > lAdditionalJobs = JobData::getEnabledJobsForEvent(rxContext, sEvent);
     sal_Int32                             c               = lAdditionalJobs.getLength();
@@ -592,16 +482,15 @@ void JobData::appendEnabledJobsForEvent( const css::uno::Reference< css::uno::XC
     }
 }
 
-//________________________________
 /**
  */
-sal_Bool JobData::hasCorrectContext(const OUString& rModuleIdent) const
+bool JobData::hasCorrectContext(const OUString& rModuleIdent) const
 {
     sal_Int32 nContextLen  = m_sContext.getLength();
     sal_Int32 nModuleIdLen = rModuleIdent.getLength();
 
     if ( nContextLen == 0 )
-        return sal_True;
+        return true;
 
     if ( nModuleIdLen > 0 )
     {
@@ -613,23 +502,16 @@ sal_Bool JobData::hasCorrectContext(const OUString& rModuleIdent) const
     }
     }
 
-    return sal_False;
+    return false;
 }
 
-//________________________________
 /**
  */
 css::uno::Sequence< OUString > JobData::getEnabledJobsForEvent( const css::uno::Reference< css::uno::XComponentContext >& rxContext,
                                                                        const OUString&                                    sEvent )
 {
-    // these static values may perform following loop for reading time stamp values ...
-    static OUString ADMINTIME = OUString::createFromAscii(JobData::EVENTCFG_PROP_ADMINTIME);
-    static OUString USERTIME  = OUString::createFromAscii(JobData::EVENTCFG_PROP_USERTIME );
-    static OUString ROOT      = OUString::createFromAscii(JobData::EVENTCFG_ROOT          );
-    static OUString JOBLIST   = OUString::createFromAscii(JobData::EVENTCFG_PATH_JOBLIST  );
-
     // create a config access to "/org.openoffice.Office.Jobs/Events"
-    ConfigAccess aConfig(rxContext,ROOT);
+    ConfigAccess aConfig(rxContext, "/org.openoffice.Office.Jobs/Events");
     aConfig.open(ConfigAccess::E_READONLY);
     if (aConfig.getMode()==ConfigAccess::E_CLOSED)
         return css::uno::Sequence< OUString >();
@@ -639,8 +521,7 @@ css::uno::Sequence< OUString > JobData::getEnabledJobsForEvent( const css::uno::
         return css::uno::Sequence< OUString >();
 
     // check if the given event exist inside list of registered ones
-    OUString sPath(sEvent);
-    sPath += JOBLIST;
+    OUString sPath(sEvent + "/JobList");
     if (!xEventRegistry->hasByHierarchicalName(sPath))
         return css::uno::Sequence< OUString >();
 
@@ -676,10 +557,10 @@ css::uno::Sequence< OUString > JobData::getEnabledJobsForEvent( const css::uno::
         }
 
         OUString sAdminTime;
-        xJob->getPropertyValue(ADMINTIME) >>= sAdminTime;
+        xJob->getPropertyValue("AdminTime") >>= sAdminTime;
 
         OUString sUserTime;
-        xJob->getPropertyValue(USERTIME) >>= sUserTime;
+        xJob->getPropertyValue("UserTime") >>= sUserTime;
 
         if (!isEnabled(sAdminTime, sUserTime))
             continue;
@@ -694,7 +575,6 @@ css::uno::Sequence< OUString > JobData::getEnabledJobsForEvent( const css::uno::
     return lEnabledJobs;
 }
 
-//________________________________
 /**
     @short      reset all internal structures
     @descr      If someone recycles this instance, he can switch from one
@@ -704,21 +584,18 @@ css::uno::Sequence< OUString > JobData::getEnabledJobsForEvent( const css::uno::
                 But note: that does not set defaults for internal used members, which
                 does not relate to any job property! e.g. the reference to the global
                 uno service manager. Such information is used for internal processes only
-                and are neccessary for our work.
+                and are necessary for our work.
  */
 void JobData::impl_reset()
 {
-    /* SAFE { */
-    WriteGuard aWriteLock(m_aLock);
+    SolarMutexGuard g;
     m_eMode        = E_UNKNOWN_MODE;
     m_eEnvironment = E_UNKNOWN_ENVIRONMENT;
-    m_sAlias       = "";
-    m_sService     = "";
-    m_sContext     = "";
-    m_sEvent       = "";
+    m_sAlias.clear();
+    m_sService.clear();
+    m_sContext.clear();
+    m_sEvent.clear();
     m_lArguments   = css::uno::Sequence< css::beans::NamedValue >();
-    aWriteLock.unlock();
-    /* } SAFE */
 }
 
 } // namespace framework
