@@ -17,77 +17,149 @@
  *   the License at http://www.apache.org/licenses/LICENSE-2.0 .
  */
 
-#include <services/sessionlistener.hxx>
-#include <services/desktop.hxx>
-#include <threadhelp/readguard.hxx>
-#include <threadhelp/resetableguard.hxx>
-#include <protocols.h>
-#include <services.h>
+#include <sal/types.h>
 
-#include <osl/thread.h>
+#include <services/desktop.hxx>
+#include <classes/filtercache.hxx>
+#include <protocols.h>
+#include <general.h>
 
 #include <vcl/svapp.hxx>
 #include <unotools/tempfile.hxx>
-#include <com/sun/star/lang/XSingleServiceFactory.hpp>
-#include <com/sun/star/lang/XComponent.hpp>
-#include <com/sun/star/container/XNameAccess.hpp>
-#include <com/sun/star/container/XNameContainer.hpp>
 #include <com/sun/star/beans/NamedValue.hpp>
 #include <com/sun/star/beans/PropertyValue.hpp>
-#include <com/sun/star/beans/PropertyState.hpp>
-#include <com/sun/star/beans/XPropertySet.hpp>
-#include <com/sun/star/frame/AutoRecovery.hpp>
-#include <com/sun/star/frame/XFramesSupplier.hpp>
-#include <com/sun/star/frame/XStorable.hpp>
-#include <com/sun/star/frame/XComponentLoader.hpp>
-#include <com/sun/star/frame/XDispatch.hpp>
+#include <com/sun/star/frame/theAutoRecovery.hpp>
 #include <com/sun/star/frame/Desktop.hpp>
-#include <com/sun/star/util/XModifiable.hpp>
-#include <com/sun/star/util/XChangesBatch.hpp>
+#include <com/sun/star/frame/FeatureStateEvent.hpp>
+#include <com/sun/star/frame/XDispatch.hpp>
+#include <com/sun/star/frame/XSessionManagerListener2.hpp>
+#include <com/sun/star/frame/XSessionManagerClient.hpp>
+#include <com/sun/star/frame/XStatusListener.hpp>
+#include <com/sun/star/lang/EventObject.hpp>
+#include <com/sun/star/lang/XInitialization.hpp>
 #include <com/sun/star/util/URLTransformer.hpp>
 #include <com/sun/star/util/XURLTransformer.hpp>
 #include <com/sun/star/util/URL.hpp>
-#include <osl/time.h>
-#include <comphelper/processfactory.hxx>
+#include <cppuhelper/implbase.hxx>
+#include <cppuhelper/supportsservice.hxx>
 #include <unotools/pathoptions.hxx>
-#include <stdio.h>
 
 #include <com/sun/star/uno/Any.hxx>
-
 #include <com/sun/star/uno/Sequence.hxx>
 
+using namespace css;
 using namespace com::sun::star::uno;
 using namespace com::sun::star::util;
-using namespace com::sun::star::frame;
-using namespace com::sun::star::lang;
 using namespace com::sun::star::beans;
-using namespace com::sun::star::container;
+using namespace framework;
 
+namespace {
 
-namespace framework{
+/// @HTML
+/** @short  implements flat/deep detection of file/stream formats and provides
+            further read/write access to the global office type configuration.
 
-// XInterface, XTypeProvider, XServiceInfo
+    @descr  Using of this class makes it possible to get information about the
+            format type of a given URL or stream. The returned internal type name
+            can be used to get more information about this format. Further this
+            class provides full access to the configuration data and following
+            implementations will support some special query modes.
 
-DEFINE_XSERVICEINFO_ONEINSTANCESERVICE_2(
-       SessionListener,
-       cppu::OWeakObject,
-       "com.sun.star.frame.SessionListener",
-       IMPLEMENTATIONNAME_SESSIONLISTENER)
+    @author     as96863
 
-DEFINE_INIT_SERVICE(SessionListener,
-                    {
-                        /* Add special code for initialization here, if you have to use your own instance
-                           during your ctor is still in progress! */
-                    }
-                   )
+    @docdate    10.03.2003 by as96863
+
+    @todo       <ul>
+                    <li>implementation of query mode</li>
+                    <li>simple restore mechanism of last consistent cache state,
+                        if flush failed</li>
+                </ul>
+ */
+typedef cppu::WeakImplHelper<
+    css::lang::XInitialization,
+    css::frame::XSessionManagerListener2,
+    css::frame::XStatusListener,
+    css::lang::XServiceInfo> SessionListener_BASE;
+
+class SessionListener : public SessionListener_BASE
+{
+private:
+    osl::Mutex m_aMutex;
+
+    /** reference to the uno service manager, which created this service.
+        It can be used to create own needed helper services. */
+    css::uno::Reference< css::uno::XComponentContext > m_xContext;
+
+    css::uno::Reference< css::frame::XSessionManagerClient > m_rSessionManager;
+
+    // restore handling
+    bool m_bRestored;
+
+    bool m_bSessionStoreRequested;
+
+    bool m_bAllowUserInteractionOnQuit;
+    bool m_bTerminated;
+
+    // in case of synchronous call the caller should do saveDone() call himself!
+    void StoreSession( bool bAsync );
+
+    // let session quietly close the documents, remove lock files, store configuration and etc.
+    void QuitSessionQuietly();
+
+public:
+    SessionListener( const css::uno::Reference< css::uno::XComponentContext >& xContext );
+
+    virtual ~SessionListener();
+
+    virtual OUString SAL_CALL getImplementationName()
+        throw (css::uno::RuntimeException, std::exception) override
+    {
+        return OUString("com.sun.star.comp.frame.SessionListener");
+    }
+
+    virtual sal_Bool SAL_CALL supportsService(OUString const & ServiceName)
+        throw (css::uno::RuntimeException, std::exception) override
+    {
+        return cppu::supportsService(this, ServiceName);
+    }
+
+    virtual css::uno::Sequence<OUString> SAL_CALL getSupportedServiceNames()
+        throw (css::uno::RuntimeException, std::exception) override
+    {
+        css::uno::Sequence< OUString > aSeq { "com.sun.star.frame.SessionListener" };
+        return aSeq;
+    }
+
+    virtual void SAL_CALL disposing(const css::lang::EventObject&) throw (css::uno::RuntimeException, std::exception) override;
+
+    // XInitialization
+    virtual void SAL_CALL initialize(const css::uno::Sequence< css::uno::Any  >& args) throw (css::uno::RuntimeException, std::exception) override;
+
+    // XSessionManagerListener
+    virtual void SAL_CALL doSave( sal_Bool bShutdown, sal_Bool bCancelable )
+        throw (css::uno::RuntimeException, std::exception) override;
+    virtual void SAL_CALL approveInteraction( sal_Bool bInteractionGranted )
+        throw (css::uno::RuntimeException, std::exception) override;
+   virtual void SAL_CALL shutdownCanceled()
+        throw (css::uno::RuntimeException, std::exception) override;
+   virtual sal_Bool SAL_CALL doRestore()
+        throw (css::uno::RuntimeException, std::exception) override;
+
+    // XSessionManagerListener2
+    virtual void SAL_CALL doQuit()
+        throw (css::uno::RuntimeException, std::exception) override;
+
+    // XStatusListener
+    virtual void SAL_CALL statusChanged(const css::frame::FeatureStateEvent& event)
+        throw (css::uno::RuntimeException, std::exception) override;
+};
 
 SessionListener::SessionListener(const css::uno::Reference< css::uno::XComponentContext >& rxContext )
-        : ThreadHelpBase      (&Application::GetSolarMutex())
-        , m_xContext          (rxContext                    )
-        , m_bRestored( sal_False )
-        , m_bSessionStoreRequested( sal_False )
-        , m_bAllowUserInteractionOnQuit( sal_False )
-        , m_bTerminated( sal_False )
+        : m_xContext( rxContext )
+        , m_bRestored( false )
+        , m_bSessionStoreRequested( false )
+        , m_bAllowUserInteractionOnQuit( false )
+        , m_bTerminated( false )
 {
     SAL_INFO("fwk.session", "SessionListener::SessionListener");
 }
@@ -102,18 +174,18 @@ SessionListener::~SessionListener()
     }
 }
 
-void SessionListener::StoreSession( sal_Bool bAsync )
+void SessionListener::StoreSession( bool bAsync )
 {
     SAL_INFO("fwk.session", "SessionListener::StoreSession");
-    ResetableGuard aGuard(m_aLock);
+    osl::MutexGuard g(m_aMutex);
     try
     {
-        // xd create SERVICENAME_AUTORECOVERY -> XDispatch
+        // xd create SERVICENAME_AUTORECOVERY -> frame::XDispatch
         // xd->dispatch("vnd.sun.star.autorecovery:/doSessionSave, async=bAsync
         // on stop event m_rSessionManager->saveDone(this); in case of asynchronous call
         // in case of synchronous call the caller should do saveDone() call himself!
 
-        css::uno::Reference< XDispatch > xDispatch = css::frame::AutoRecovery::create( m_xContext );
+        css::uno::Reference< frame::XDispatch > xDispatch = css::frame::theAutoRecovery::get( m_xContext );
         css::uno::Reference< XURLTransformer > xURLTransformer = URLTransformer::create( m_xContext );
         URL aURL;
         aURL.Complete = "vnd.sun.star.autorecovery:/doSessionSave";
@@ -126,7 +198,7 @@ void SessionListener::StoreSession( sal_Bool bAsync )
         Sequence< PropertyValue > args(1);
         args[0] = PropertyValue(OUString("DispatchAsynchron"),-1,makeAny(bAsync),PropertyState_DIRECT_VALUE);
         xDispatch->dispatch(aURL, args);
-    } catch (const com::sun::star::uno::Exception& e) {
+    } catch (const css::uno::Exception& e) {
         SAL_WARN("fwk.session",e.Message);
         // save failed, but tell manager to go on if we havent yet dispatched the request
         // in case of synchronous saving the notification is done by the caller
@@ -138,14 +210,14 @@ void SessionListener::StoreSession( sal_Bool bAsync )
 void SessionListener::QuitSessionQuietly()
 {
     SAL_INFO("fwk.session", "SessionListener::QuitSessionQuietly");
-    ResetableGuard aGuard(m_aLock);
+    osl::MutexGuard g(m_aMutex);
     try
     {
-        // xd create SERVICENAME_AUTORECOVERY -> XDispatch
+        // xd create SERVICENAME_AUTORECOVERY -> frame::XDispatch
         // xd->dispatch("vnd.sun.star.autorecovery:/doSessionQuietQuit, async=false
         // it is done synchronously to avoid conflict with normal quit process
 
-        css::uno::Reference< XDispatch > xDispatch = css::frame::AutoRecovery::create( m_xContext );
+        css::uno::Reference< frame::XDispatch > xDispatch = css::frame::theAutoRecovery::get( m_xContext );
         css::uno::Reference< XURLTransformer > xURLTransformer = URLTransformer::create( m_xContext );
         URL aURL;
         aURL.Complete = "vnd.sun.star.autorecovery:/doSessionQuietQuit";
@@ -154,18 +226,18 @@ void SessionListener::QuitSessionQuietly()
         Sequence< PropertyValue > args(1);
         args[0] = PropertyValue(OUString("DispatchAsynchron"),-1,makeAny(sal_False),PropertyState_DIRECT_VALUE);
         xDispatch->dispatch(aURL, args);
-    } catch (const com::sun::star::uno::Exception& e) {
+    } catch (const css::uno::Exception& e) {
         SAL_WARN("fwk.session",e.Message);
     }
 }
 
-void SAL_CALL SessionListener::disposing(const com::sun::star::lang::EventObject&) throw (RuntimeException)
+void SAL_CALL SessionListener::disposing(const css::lang::EventObject&) throw (RuntimeException, std::exception)
 {
     SAL_INFO("fwk.session", "SessionListener::disposing");
 }
 
 void SAL_CALL SessionListener::initialize(const Sequence< Any  >& args)
-    throw (RuntimeException)
+    throw (RuntimeException, std::exception)
 {
     SAL_INFO("fwk.session", "SessionListener::initialize");
 
@@ -189,7 +261,7 @@ void SAL_CALL SessionListener::initialize(const Sequence< Any  >& args)
         }
     }
     if (!m_rSessionManager.is())
-        m_rSessionManager = css::uno::Reference< XSessionManagerClient >
+        m_rSessionManager = css::uno::Reference< frame::XSessionManagerClient >
             (m_xContext->getServiceManager()->createInstanceWithContext(aSMgr, m_xContext), UNO_QUERY);
 
     if (m_rSessionManager.is())
@@ -198,19 +270,19 @@ void SAL_CALL SessionListener::initialize(const Sequence< Any  >& args)
     }
 }
 
-void SAL_CALL SessionListener::statusChanged(const FeatureStateEvent& event)
-    throw (css::uno::RuntimeException)
+void SAL_CALL SessionListener::statusChanged(const frame::FeatureStateEvent& event)
+    throw (css::uno::RuntimeException, std::exception)
 {
    SAL_INFO("fwk.session", "SessionListener::statusChanged");
    if ( event.FeatureURL.Complete == "vnd.sun.star.autorecovery:/doSessionRestore" )
     {
-        if (event.FeatureDescriptor.equalsAscii("update"))
-            m_bRestored = sal_True; // a document was restored
+        if (event.FeatureDescriptor == "update")
+            m_bRestored = true; // a document was restored
 
     }
     else if ( event.FeatureURL.Complete == "vnd.sun.star.autorecovery:/doSessionSave" )
     {
-        if (event.FeatureDescriptor.equalsAscii("stop"))
+        if (event.FeatureDescriptor == "stop")
         {
             if (m_rSessionManager.is())
                 m_rSessionManager->saveDone(this); // done with save
@@ -218,15 +290,14 @@ void SAL_CALL SessionListener::statusChanged(const FeatureStateEvent& event)
     }
 }
 
-
 sal_Bool SAL_CALL SessionListener::doRestore()
-    throw (RuntimeException)
+    throw (RuntimeException, std::exception)
 {
     SAL_INFO("fwk.session", "SessionListener::doRestore");
-    ResetableGuard aGuard(m_aLock);
-    m_bRestored = sal_False;
+    osl::MutexGuard g(m_aMutex);
+    m_bRestored = false;
     try {
-        css::uno::Reference< XDispatch > xDispatch = css::frame::AutoRecovery::create( m_xContext );
+        css::uno::Reference< frame::XDispatch > xDispatch = css::frame::theAutoRecovery::get( m_xContext );
 
         URL aURL;
         aURL.Complete = "vnd.sun.star.autorecovery:/doSessionRestore";
@@ -235,27 +306,26 @@ sal_Bool SAL_CALL SessionListener::doRestore()
         Sequence< PropertyValue > args;
         xDispatch->addStatusListener(this, aURL);
         xDispatch->dispatch(aURL, args);
-        m_bRestored = sal_True;
+        m_bRestored = true;
 
-    } catch (const com::sun::star::uno::Exception& e) {
+    } catch (const css::uno::Exception& e) {
         SAL_WARN("fwk.session",e.Message);
     }
 
     return m_bRestored;
 }
 
-
 void SAL_CALL SessionListener::doSave( sal_Bool bShutdown, sal_Bool /*bCancelable*/ )
-    throw (RuntimeException)
+    throw (RuntimeException, std::exception)
 {
     SAL_INFO("fwk.session", "SessionListener::doSave");
     if (bShutdown)
     {
-        m_bSessionStoreRequested = sal_True; // there is no need to protect it with mutex
+        m_bSessionStoreRequested = true; // there is no need to protect it with mutex
         if ( m_bAllowUserInteractionOnQuit && m_rSessionManager.is() )
             m_rSessionManager->queryInteraction( static_cast< css::frame::XSessionManagerListener* >( this ) );
         else
-            StoreSession( sal_True );
+            StoreSession( true );
     }
     // we don't have anything to do so tell the session manager we're done
     else if( m_rSessionManager.is() )
@@ -263,11 +333,11 @@ void SAL_CALL SessionListener::doSave( sal_Bool bShutdown, sal_Bool /*bCancelabl
 }
 
 void SAL_CALL SessionListener::approveInteraction( sal_Bool bInteractionGranted )
-    throw (RuntimeException)
+    throw (RuntimeException, std::exception)
 {
     SAL_INFO("fwk.session", "SessionListener::approveInteraction");
     // do AutoSave as the first step
-    ResetableGuard aGuard(m_aLock);
+    osl::MutexGuard g(m_aMutex);
 
     if ( bInteractionGranted )
     {
@@ -275,7 +345,7 @@ void SAL_CALL SessionListener::approveInteraction( sal_Bool bInteractionGranted
         try
         {
             // first of all let the session be stored to be sure that we lose no information
-            StoreSession( sal_False );
+            StoreSession( false );
 
             css::uno::Reference< css::frame::XDesktop2 > xDesktop = css::frame::Desktop::create( m_xContext );
             // honestly: how many implementations of XDesktop will we ever have?
@@ -303,7 +373,7 @@ void SAL_CALL SessionListener::approveInteraction( sal_Bool bInteractionGranted
         }
         catch( const css::uno::Exception& )
         {
-            StoreSession( sal_True );
+            StoreSession( true );
             m_rSessionManager->interactionDone( this );
         }
 
@@ -312,20 +382,20 @@ void SAL_CALL SessionListener::approveInteraction( sal_Bool bInteractionGranted
     }
     else
     {
-        StoreSession( sal_True );
+        StoreSession( true );
     }
 }
 
 void SessionListener::shutdownCanceled()
-    throw (RuntimeException)
+    throw (RuntimeException, std::exception)
 {
     SAL_INFO("fwk.session", "SessionListener::shutdownCanceled");
     // set the state back
-    m_bSessionStoreRequested = sal_False; // there is no need to protect it with mutex
+    m_bSessionStoreRequested = false; // there is no need to protect it with mutex
 }
 
 void SessionListener::doQuit()
-    throw (RuntimeException)
+    throw (RuntimeException, std::exception)
 {
     SAL_INFO("fwk.session", "SessionListener::doQuit");
     if ( m_bSessionStoreRequested && !m_bTerminated )
@@ -337,4 +407,12 @@ void SessionListener::doQuit()
 
 }
 
+extern "C" SAL_DLLPUBLIC_EXPORT css::uno::XInterface * SAL_CALL
+com_sun_star_comp_frame_SessionListener_get_implementation(
+    css::uno::XComponentContext *context,
+    css::uno::Sequence<css::uno::Any> const &)
+{
+    return cppu::acquire(new SessionListener(context));
+}
+
 /* vim:set shiftwidth=4 softtabstop=4 expandtab: */
