@@ -17,9 +17,7 @@
  *   the License at http://www.apache.org/licenses/LICENSE-2.0 .
  */
 
-#include "uiconfiguration/uicategorydescription.hxx"
-#include <threadhelp/resetableguard.hxx>
-#include "services.h"
+#include <uielement/uicommanddescription.hxx>
 
 #include "properties.h"
 
@@ -31,17 +29,17 @@
 #include <com/sun/star/container/XNameAccess.hpp>
 #include <com/sun/star/container/XNameContainer.hpp>
 #include <com/sun/star/container/XContainer.hpp>
+#include <com/sun/star/lang/XServiceInfo.hpp>
 
 #include <rtl/ustrbuf.hxx>
-#include <cppuhelper/implbase2.hxx>
+#include <cppuhelper/implbase.hxx>
+#include <cppuhelper/supportsservice.hxx>
 #include <unotools/configmgr.hxx>
 
 #include <vcl/mnemonic.hxx>
 #include <comphelper/sequence.hxx>
 
-//_________________________________________________________________________________________________________________
-//  Defines
-//_________________________________________________________________________________________________________________
+#include <unordered_map>
 
 using namespace com::sun::star::uno;
 using namespace com::sun::star::lang;
@@ -49,100 +47,82 @@ using namespace com::sun::star::beans;
 using namespace com::sun::star::configuration;
 using namespace com::sun::star::container;
 using namespace ::com::sun::star::frame;
+using namespace framework;
 
-//_________________________________________________________________________________________________________________
-//  Namespace
-//_________________________________________________________________________________________________________________
-
-struct ModuleToCategory
-{
-    const char* pModuleId;
-    const char* pCommands;
-};
+namespace {
 
 static const char GENERIC_MODULE_NAME[]                     = "generic";
 static const char CONFIGURATION_ROOT_ACCESS[]               = "/org.openoffice.Office.UI.";
 static const char CONFIGURATION_CATEGORY_ELEMENT_ACCESS[]   = "/Commands/Categories";
 static const char CONFIGURATION_PROPERTY_NAME[]             = "Name";
 
-namespace framework
-{
-
-//*****************************************************************************************************************
-//  Configuration access class for PopupMenuControllerFactory implementation
-//*****************************************************************************************************************
-
-class ConfigurationAccess_UICategory : // Order is necessary for right initialization!
-                                        private ThreadHelpBase                           ,
-                                        public  ::cppu::WeakImplHelper2<XNameAccess,XContainerListener>
+class ConfigurationAccess_UICategory : public ::cppu::WeakImplHelper<XNameAccess,XContainerListener>
 {
+    osl::Mutex aMutex;
     public:
                                   ConfigurationAccess_UICategory( const OUString& aModuleName, const Reference< XNameAccess >& xGenericUICommands, const Reference< XComponentContext >& rxContext );
         virtual                   ~ConfigurationAccess_UICategory();
 
         // XNameAccess
-        virtual ::com::sun::star::uno::Any SAL_CALL getByName( const OUString& aName )
-            throw (::com::sun::star::container::NoSuchElementException, ::com::sun::star::lang::WrappedTargetException, ::com::sun::star::uno::RuntimeException);
+        virtual css::uno::Any SAL_CALL getByName( const OUString& aName )
+            throw (css::container::NoSuchElementException, css::lang::WrappedTargetException, css::uno::RuntimeException, std::exception) override;
 
-        virtual ::com::sun::star::uno::Sequence< OUString > SAL_CALL getElementNames()
-            throw (::com::sun::star::uno::RuntimeException);
+        virtual css::uno::Sequence< OUString > SAL_CALL getElementNames()
+            throw (css::uno::RuntimeException, std::exception) override;
 
         virtual sal_Bool SAL_CALL hasByName( const OUString& aName )
-            throw (::com::sun::star::uno::RuntimeException);
+            throw (css::uno::RuntimeException, std::exception) override;
 
         // XElementAccess
-        virtual ::com::sun::star::uno::Type SAL_CALL getElementType()
-            throw (::com::sun::star::uno::RuntimeException);
+        virtual css::uno::Type SAL_CALL getElementType()
+            throw (css::uno::RuntimeException, std::exception) override;
 
         virtual sal_Bool SAL_CALL hasElements()
-            throw (::com::sun::star::uno::RuntimeException);
+            throw (css::uno::RuntimeException, std::exception) override;
 
         // container.XContainerListener
-        virtual void SAL_CALL     elementInserted( const ContainerEvent& aEvent ) throw(RuntimeException);
-        virtual void SAL_CALL     elementRemoved ( const ContainerEvent& aEvent ) throw(RuntimeException);
-        virtual void SAL_CALL     elementReplaced( const ContainerEvent& aEvent ) throw(RuntimeException);
+        virtual void SAL_CALL     elementInserted( const ContainerEvent& aEvent ) throw(RuntimeException, std::exception) override;
+        virtual void SAL_CALL     elementRemoved ( const ContainerEvent& aEvent ) throw(RuntimeException, std::exception) override;
+        virtual void SAL_CALL     elementReplaced( const ContainerEvent& aEvent ) throw(RuntimeException, std::exception) override;
 
         // lang.XEventListener
-        virtual void SAL_CALL disposing( const EventObject& aEvent ) throw(RuntimeException);
+        virtual void SAL_CALL disposing( const EventObject& aEvent ) throw(RuntimeException, std::exception) override;
 
     protected:
         Any                       getUINameFromID( const OUString& rId );
         Any                       getUINameFromCache( const OUString& rId );
         Sequence< OUString > getAllIds();
-        sal_Bool                  fillCache();
+        bool                  fillCache();
 
     private:
-        typedef ::boost::unordered_map< OUString,
-                                 OUString,
-                                 OUStringHash,
-                                 ::std::equal_to< OUString > > IdToInfoCache;
+        typedef std::unordered_map< OUString,
+                                    OUString,
+                                    OUStringHash,
+                                    std::equal_to< OUString > > IdToInfoCache;
 
-        sal_Bool initializeConfigAccess();
+        bool initializeConfigAccess();
 
-        OUString                     m_aConfigCategoryAccess;
-        OUString                     m_aPropUIName;
+        OUString                          m_aConfigCategoryAccess;
+        OUString                          m_aPropUIName;
         Reference< XNameAccess >          m_xGenericUICategories;
         Reference< XMultiServiceFactory > m_xConfigProvider;
         Reference< XNameAccess >          m_xConfigAccess;
         Reference< XContainerListener >   m_xConfigListener;
-        sal_Bool                          m_bConfigAccessInitialized;
-        sal_Bool                          m_bCacheFilled;
+        bool                              m_bConfigAccessInitialized;
+        bool                              m_bCacheFilled;
         IdToInfoCache                     m_aIdCache;
 };
 
-//*****************************************************************************************************************
 //  XInterface, XTypeProvider
-//*****************************************************************************************************************
 
 ConfigurationAccess_UICategory::ConfigurationAccess_UICategory( const OUString& aModuleName, const Reference< XNameAccess >& rGenericUICategories, const Reference< XComponentContext >& rxContext ) :
-    ThreadHelpBase(),
     m_aConfigCategoryAccess( CONFIGURATION_ROOT_ACCESS ),
     m_aPropUIName( CONFIGURATION_PROPERTY_NAME ),
     m_xGenericUICategories( rGenericUICategories ),
-    m_bConfigAccessInitialized( sal_False ),
-    m_bCacheFilled( sal_False )
+    m_bConfigAccessInitialized( false ),
+    m_bCacheFilled( false )
 {
-    // Create configuration hierachical access name
+    // Create configuration hierarchical access name
     m_aConfigCategoryAccess += aModuleName;
     m_aConfigCategoryAccess += CONFIGURATION_CATEGORY_ELEMENT_ACCESS;
 
@@ -152,7 +132,7 @@ ConfigurationAccess_UICategory::ConfigurationAccess_UICategory( const OUString&
 ConfigurationAccess_UICategory::~ConfigurationAccess_UICategory()
 {
     // SAFE
-    ResetableGuard aLock( m_aLock );
+    osl::MutexGuard g(aMutex);
     Reference< XContainer > xContainer( m_xConfigAccess, UNO_QUERY );
     if ( xContainer.is() )
         xContainer->removeContainerListener(m_xConfigListener);
@@ -160,13 +140,13 @@ ConfigurationAccess_UICategory::~ConfigurationAccess_UICategory()
 
 // XNameAccess
 Any SAL_CALL ConfigurationAccess_UICategory::getByName( const OUString& rId )
-throw ( NoSuchElementException, WrappedTargetException, RuntimeException)
+throw ( NoSuchElementException, WrappedTargetException, RuntimeException, std::exception)
 {
-    ResetableGuard aLock( m_aLock );
+    osl::MutexGuard g(aMutex);
     if ( !m_bConfigAccessInitialized )
     {
         initializeConfigAccess();
-        m_bConfigAccessInitialized = sal_True;
+        m_bConfigAccessInitialized = true;
         fillCache();
     }
 
@@ -180,37 +160,37 @@ throw ( NoSuchElementException, WrappedTargetException, RuntimeException)
 }
 
 Sequence< OUString > SAL_CALL ConfigurationAccess_UICategory::getElementNames()
-throw ( RuntimeException )
+throw ( RuntimeException, std::exception )
 {
     return getAllIds();
 }
 
 sal_Bool SAL_CALL ConfigurationAccess_UICategory::hasByName( const OUString& rId )
-throw (::com::sun::star::uno::RuntimeException)
+throw (css::uno::RuntimeException, std::exception)
 {
     return getByName( rId ).hasValue();
 }
 
 // XElementAccess
 Type SAL_CALL ConfigurationAccess_UICategory::getElementType()
-throw ( RuntimeException )
+throw ( RuntimeException, std::exception )
 {
-    return( ::getCppuType( (const OUString*)NULL ) );
+    return( cppu::UnoType<OUString>::get());
 }
 
 sal_Bool SAL_CALL ConfigurationAccess_UICategory::hasElements()
-throw ( RuntimeException )
+throw ( RuntimeException, std::exception )
 {
     // There must be global categories!
     return sal_True;
 }
 
-sal_Bool ConfigurationAccess_UICategory::fillCache()
+bool ConfigurationAccess_UICategory::fillCache()
 {
     SAL_INFO( "fwk", "framework (cd100003) ::ConfigurationAccess_UICategory::fillCache" );
 
     if ( m_bCacheFilled )
-        return sal_True;
+        return true;
 
     sal_Int32            i( 0 );
     OUString        aUIName;
@@ -228,17 +208,17 @@ sal_Bool ConfigurationAccess_UICategory::fillCache()
                 m_aIdCache.insert( IdToInfoCache::value_type( aNameSeq[i], aUIName ));
             }
         }
-        catch ( const com::sun::star::lang::WrappedTargetException& )
+        catch ( const css::lang::WrappedTargetException& )
         {
         }
-        catch ( const com::sun::star::container::NoSuchElementException& )
+        catch ( const css::container::NoSuchElementException& )
         {
         }
     }
 
-    m_bCacheFilled = sal_True;
+    m_bCacheFilled = true;
 
-    return sal_True;
+    return true;
 }
 
 Any ConfigurationAccess_UICategory::getUINameFromID( const OUString& rId )
@@ -257,19 +237,19 @@ Any ConfigurationAccess_UICategory::getUINameFromID( const OUString& rId )
                 {
                     return m_xGenericUICategories->getByName( rId );
                 }
-                catch ( const com::sun::star::lang::WrappedTargetException& )
+                catch ( const css::lang::WrappedTargetException& )
                 {
                 }
-                catch ( const com::sun::star::container::NoSuchElementException& )
+                catch ( const css::container::NoSuchElementException& )
                 {
                 }
             }
         }
     }
-    catch( const com::sun::star::container::NoSuchElementException& )
+    catch( const css::container::NoSuchElementException& )
     {
     }
-    catch ( const com::sun::star::lang::WrappedTargetException& )
+    catch ( const css::lang::WrappedTargetException& )
     {
     }
 
@@ -290,12 +270,12 @@ Any ConfigurationAccess_UICategory::getUINameFromCache( const OUString& rId )
 Sequence< OUString > ConfigurationAccess_UICategory::getAllIds()
 {
     // SAFE
-    ResetableGuard aLock( m_aLock );
+    osl::MutexGuard g(aMutex);
 
     if ( !m_bConfigAccessInitialized )
     {
         initializeConfigAccess();
-        m_bConfigAccessInitialized = sal_True;
+        m_bConfigAccessInitialized = true;
         fillCache();
     }
 
@@ -323,10 +303,10 @@ Sequence< OUString > ConfigurationAccess_UICategory::getAllIds()
 
             return aNameSeq;
         }
-        catch( const com::sun::star::container::NoSuchElementException& )
+        catch( const css::container::NoSuchElementException& )
         {
         }
-        catch ( const com::sun::star::lang::WrappedTargetException& )
+        catch ( const css::lang::WrappedTargetException& )
         {
         }
     }
@@ -334,7 +314,7 @@ Sequence< OUString > ConfigurationAccess_UICategory::getAllIds()
     return Sequence< OUString >();
 }
 
-sal_Bool ConfigurationAccess_UICategory::initializeConfigAccess()
+bool ConfigurationAccess_UICategory::initializeConfigAccess()
 {
     Sequence< Any > aArgs( 1 );
     PropertyValue   aPropValue;
@@ -345,7 +325,8 @@ sal_Bool ConfigurationAccess_UICategory::initializeConfigAccess()
         aPropValue.Value <<= m_aConfigCategoryAccess;
         aArgs[0] <<= aPropValue;
 
-        m_xConfigAccess = Reference< XNameAccess >( m_xConfigProvider->createInstanceWithArguments(SERVICENAME_CFGREADACCESS,aArgs ),UNO_QUERY );
+        m_xConfigAccess.set( m_xConfigProvider->createInstanceWithArguments(
+                    "com.sun.star.configuration.ConfigurationAccess", aArgs ),UNO_QUERY );
         if ( m_xConfigAccess.is() )
         {
             // Add as container listener
@@ -357,7 +338,7 @@ sal_Bool ConfigurationAccess_UICategory::initializeConfigAccess()
             }
         }
 
-        return sal_True;
+        return true;
     }
     catch ( const WrappedTargetException& )
     {
@@ -366,28 +347,28 @@ sal_Bool ConfigurationAccess_UICategory::initializeConfigAccess()
     {
     }
 
-    return sal_False;
+    return false;
 }
 
 // container.XContainerListener
-void SAL_CALL ConfigurationAccess_UICategory::elementInserted( const ContainerEvent& ) throw(RuntimeException)
+void SAL_CALL ConfigurationAccess_UICategory::elementInserted( const ContainerEvent& ) throw(RuntimeException, std::exception)
 {
 }
 
-void SAL_CALL ConfigurationAccess_UICategory::elementRemoved ( const ContainerEvent& ) throw(RuntimeException)
+void SAL_CALL ConfigurationAccess_UICategory::elementRemoved ( const ContainerEvent& ) throw(RuntimeException, std::exception)
 {
 }
 
-void SAL_CALL ConfigurationAccess_UICategory::elementReplaced( const ContainerEvent& ) throw(RuntimeException)
+void SAL_CALL ConfigurationAccess_UICategory::elementReplaced( const ContainerEvent& ) throw(RuntimeException, std::exception)
 {
 }
 
 // lang.XEventListener
-void SAL_CALL ConfigurationAccess_UICategory::disposing( const EventObject& aEvent ) throw(RuntimeException)
+void SAL_CALL ConfigurationAccess_UICategory::disposing( const EventObject& aEvent ) throw(RuntimeException, std::exception)
 {
     // SAFE
     // remove our reference to the config access
-    ResetableGuard aLock( m_aLock );
+    osl::MutexGuard g(aMutex);
 
     Reference< XInterface > xIfac1( aEvent.Source, UNO_QUERY );
     Reference< XInterface > xIfac2( m_xConfigAccess, UNO_QUERY );
@@ -395,17 +376,32 @@ void SAL_CALL ConfigurationAccess_UICategory::disposing( const EventObject& aEve
         m_xConfigAccess.clear();
 }
 
-//*****************************************************************************************************************
-//  XInterface, XTypeProvider, XServiceInfo
-//*****************************************************************************************************************
+class UICategoryDescription :  public UICommandDescription
+{
+public:
+    UICategoryDescription( const css::uno::Reference< css::uno::XComponentContext >& rxContext );
+    virtual ~UICategoryDescription();
 
-DEFINE_XSERVICEINFO_ONEINSTANCESERVICE_2  ( UICategoryDescription                  ,
-                                            ::cppu::OWeakObject                    ,
-                                            "com.sun.star.ui.UICategoryDescription",
-                                            OUString("com.sun.star.comp.framework.UICategoryDescription")
-                                        )
+    virtual OUString SAL_CALL getImplementationName()
+        throw (css::uno::RuntimeException, std::exception) override
+    {
+        return OUString("com.sun.star.comp.framework.UICategoryDescription");
+    }
 
-DEFINE_INIT_SERVICE                     (   UICategoryDescription, {} )
+    virtual sal_Bool SAL_CALL supportsService(OUString const & ServiceName)
+        throw (css::uno::RuntimeException, std::exception) override
+    {
+        return cppu::supportsService(this, ServiceName);
+    }
+
+    virtual css::uno::Sequence<OUString> SAL_CALL getSupportedServiceNames()
+        throw (css::uno::RuntimeException, std::exception) override
+    {
+        css::uno::Sequence< OUString > aSeq { "com.sun.star.ui.UICategoryDescription" };
+        return aSeq;
+    }
+
+};
 
 UICategoryDescription::UICategoryDescription( const Reference< XComponentContext >& rxContext ) :
     UICommandDescription(rxContext,true)
@@ -428,11 +424,32 @@ UICategoryDescription::UICategoryDescription( const Reference< XComponentContext
 UICategoryDescription::~UICategoryDescription()
 {
 }
-Reference< XNameAccess > UICategoryDescription::impl_createConfigAccess(const OUString& _sName)
-{
-    return new ConfigurationAccess_UICategory( _sName, m_xGenericUICommands, m_xContext );
+
+struct Instance {
+    explicit Instance(
+        css::uno::Reference<css::uno::XComponentContext> const & context):
+        instance(static_cast<cppu::OWeakObject *>(
+                    new UICategoryDescription(context)))
+    {
+    }
+
+    css::uno::Reference<css::uno::XInterface> instance;
+};
+
+struct Singleton:
+    public rtl::StaticWithArg<
+        Instance, css::uno::Reference<css::uno::XComponentContext>, Singleton>
+{};
+
 }
 
-} // namespace framework
+extern "C" SAL_DLLPUBLIC_EXPORT css::uno::XInterface * SAL_CALL
+com_sun_star_comp_framework_UICategoryDescription_get_implementation(
+    css::uno::XComponentContext *context,
+    css::uno::Sequence<css::uno::Any> const &)
+{
+    return cppu::acquire(static_cast<cppu::OWeakObject *>(
+                Singleton::get(context).instance.get()));
+}
 
 /* vim:set shiftwidth=4 softtabstop=4 expandtab: */
