@@ -66,28 +66,21 @@
 #include <unotools/localfilehelper.hxx>
 #include <toolkit/helper/vclunohelper.hxx>
 #include <vcl/svapp.hxx>
+#include <vcl/sysdata.hxx>
 #include <vcl/window.hxx>
 #include <vcl/menu.hxx>
 #include <vcl/settings.hxx>
+#include <vcl/commandinfoprovider.hxx>
 #include <osl/mutex.hxx>
 #include <osl/file.hxx>
-#include <cppuhelper/implbase1.hxx>
+#include <cppuhelper/implbase.hxx>
 #include <cppuhelper/queryinterface.hxx>
 #include <svtools/acceleratorexecute.hxx>
 #include <svtools/miscopt.hxx>
 #include <uielement/menubarmerger.hxx>
+#include <boost/noncopyable.hpp>
 #include <tools/urlobj.hxx>
 
-// Be careful removing this "bad" construct. There are serious problems
-// with #define STRICT and including windows.h. Changing this needs some
-// redesign on other projects, too. Especially sal/main.h which defines
-// HINSTANCE depending on STRICT!!!!!!!!!!!!!!!
-struct SystemMenuData
-{
-    unsigned long nSize;
-    long          hMenu;
-};
-
 using namespace ::cppu;
 using namespace ::com::sun::star;
 using namespace ::com::sun::star::uno;
@@ -125,7 +118,7 @@ static sal_Int16 getImageTypeFromBools( bool bBig )
 {
     sal_Int16 n( 0 );
     if ( bBig )
-        n |= ::com::sun::star::ui::ImageType::SIZE_LARGE;
+        n |= css::ui::ImageType::SIZE_LARGE;
     return n;
 }
 
@@ -135,12 +128,13 @@ MenuBarManager::MenuBarManager(
     const Reference< XURLTransformer >& _xURLTransformer,
     const Reference< XDispatchProvider >& rDispatchProvider,
     const OUString& rModuleIdentifier,
-    Menu* pMenu, bool bDelete, bool bDeleteChildren ):
+    Menu* pMenu, bool bDelete, bool bDeleteChildren, bool bHasMenuBar ):
     OWeakObject()
     , m_bDisposed( false )
     , m_bRetrieveImages( false )
     , m_bAcceleratorCfg( false )
     , m_bModuleIdentified( false )
+    , m_bHasMenuBar( bHasMenuBar )
     , m_aListenerContainer( m_mutex )
     , m_xContext(rxContext)
     , m_xURLTransformer(_xURLTransformer)
@@ -163,6 +157,7 @@ MenuBarManager::MenuBarManager(
     , m_bRetrieveImages( true )
     , m_bAcceleratorCfg( false )
     , m_bModuleIdentified( false )
+    , m_bHasMenuBar( true )
     , m_aListenerContainer( m_mutex )
     , m_xContext(rxContext)
     , m_xURLTransformer(_xURLTransformer)
@@ -175,12 +170,12 @@ Any SAL_CALL MenuBarManager::queryInterface( const Type & rType ) throw ( Runtim
 {
     Any a = ::cppu::queryInterface(
                 rType ,
-                (static_cast< ::com::sun::star::frame::XStatusListener* >(this)),
-                (static_cast< ::com::sun::star::frame::XFrameActionListener* >(this)),
-                (static_cast< ::com::sun::star::ui::XUIConfigurationListener* >(this)),
-                (static_cast< XEventListener* >((XStatusListener *)this)),
+                (static_cast< css::frame::XStatusListener* >(this)),
+                (static_cast< css::frame::XFrameActionListener* >(this)),
+                (static_cast< css::ui::XUIConfigurationListener* >(this)),
+                (static_cast< XEventListener* >(static_cast<XStatusListener *>(this))),
                 (static_cast< XComponent* >(this)),
-                (static_cast< ::com::sun::star::awt::XSystemDependentMenuPeer* >(this)));
+                (static_cast< css::awt::XSystemDependentMenuPeer* >(this)));
 
     if ( a.hasValue() )
         return a;
@@ -203,20 +198,20 @@ Any SAL_CALL MenuBarManager::getMenuHandle( const Sequence< sal_Int8 >& /*Proces
     SolarMutexGuard aSolarGuard;
 
     if ( m_bDisposed )
-        throw com::sun::star::lang::DisposedException();
+        throw css::lang::DisposedException();
 
     Any a;
 
     if ( m_pVCLMenu )
     {
         SystemMenuData aSystemMenuData;
-        aSystemMenuData.nSize = sizeof( SystemMenuData );
 
         m_pVCLMenu->GetSystemMenuData( &aSystemMenuData );
 #ifdef _WIN32
         if( SystemType == SystemDependent::SYSTEM_WIN32 )
         {
-            a <<= (long) aSystemMenuData.hMenu;
+            a <<= sal_Int64(
+                reinterpret_cast<sal_IntPtr>(aSystemMenuData.hMenu));
         }
 #else
         (void) SystemType;
@@ -261,7 +256,7 @@ void MenuBarManager::Destroy()
         if ( m_bDeleteMenu )
         {
             delete m_pVCLMenu;
-            m_pVCLMenu = 0;
+            m_pVCLMenu = nullptr;
         }
     }
 }
@@ -335,7 +330,7 @@ void SAL_CALL MenuBarManager::removeEventListener( const Reference< XEventListen
     m_aListenerContainer.removeInterface( cppu::UnoType<XEventListener>::get(), xListener );
 }
 
-void SAL_CALL MenuBarManager::elementInserted( const ::com::sun::star::ui::ConfigurationEvent& Event )
+void SAL_CALL MenuBarManager::elementInserted( const css::ui::ConfigurationEvent& Event )
 throw (RuntimeException, std::exception)
 {
     SolarMutexGuard g;
@@ -351,13 +346,13 @@ throw (RuntimeException, std::exception)
         RequestImages();
 }
 
-void SAL_CALL MenuBarManager::elementRemoved( const ::com::sun::star::ui::ConfigurationEvent& Event )
+void SAL_CALL MenuBarManager::elementRemoved( const css::ui::ConfigurationEvent& Event )
 throw (RuntimeException, std::exception)
 {
     elementInserted(Event);
 }
 
-void SAL_CALL MenuBarManager::elementReplaced( const ::com::sun::star::ui::ConfigurationEvent& Event )
+void SAL_CALL MenuBarManager::elementReplaced( const css::ui::ConfigurationEvent& Event )
 throw (RuntimeException, std::exception)
 {
     elementInserted(Event);
@@ -370,7 +365,7 @@ throw ( RuntimeException, std::exception )
     SolarMutexGuard g;
 
     if ( m_bDisposed )
-        throw com::sun::star::lang::DisposedException();
+        throw css::lang::DisposedException();
 
     if ( Action.Action == FrameAction_CONTEXT_CHANGED )
     {
@@ -391,6 +386,7 @@ throw ( RuntimeException, std::exception )
     OUString aFeatureURL = Event.FeatureURL.Complete;
 
     SolarMutexGuard aSolarGuard;
+    if ( m_bHasMenuBar )
     {
         vcl::MenuInvalidator::Invalidated();
     }
@@ -427,7 +423,7 @@ throw ( RuntimeException, std::exception )
                 if ( Event.State >>= bCheckmark )
                 {
                     // Checkmark or RadioButton
-                    m_pVCLMenu->ShowItem( pMenuItemHandler->nItemId, true );
+                    m_pVCLMenu->ShowItem( pMenuItemHandler->nItemId );
                     m_pVCLMenu->CheckItem( pMenuItemHandler->nItemId, bCheckmark );
 
                     MenuItemBits nBits = m_pVCLMenu->GetItemBits( pMenuItemHandler->nItemId );
@@ -442,7 +438,7 @@ throw ( RuntimeException, std::exception )
                     if ( !aEnumPart.isEmpty() && aURL.GetProtocol() == INetProtocol::Uno )
                     {
                         // Checkmark or RadioButton
-                        m_pVCLMenu->ShowItem( pMenuItemHandler->nItemId, true );
+                        m_pVCLMenu->ShowItem( pMenuItemHandler->nItemId );
                         m_pVCLMenu->CheckItem( pMenuItemHandler->nItemId, aItemText == aEnumPart );
 
                         MenuItemBits nBits = m_pVCLMenu->GetItemBits( pMenuItemHandler->nItemId );
@@ -473,7 +469,7 @@ throw ( RuntimeException, std::exception )
                             aItemText = aTmp;
                         }
 
-                        m_pVCLMenu->ShowItem( pMenuItemHandler->nItemId, true );
+                        m_pVCLMenu->ShowItem( pMenuItemHandler->nItemId );
                         m_pVCLMenu->SetItemText( pMenuItemHandler->nItemId, aItemText );
                     }
                 }
@@ -483,7 +479,7 @@ throw ( RuntimeException, std::exception )
                     m_pVCLMenu->ShowItem( pMenuItemHandler->nItemId, aVisibilityStatus.bVisible );
                 }
                 else
-                    m_pVCLMenu->ShowItem( pMenuItemHandler->nItemId, true );
+                    m_pVCLMenu->ShowItem( pMenuItemHandler->nItemId );
             }
 
             if ( Event.Requery )
@@ -508,7 +504,7 @@ MenuBarManager::MenuItemHandler* MenuBarManager::GetMenuItemHandler( sal_uInt16
             return pItemHandler;
     }
 
-    return 0;
+    return nullptr;
 }
 
 // Helper to set request images flag
@@ -557,14 +553,14 @@ void MenuBarManager::RemoveListener()
             {
                 {
                     // Remove popup menu from menu structure
-                    m_pVCLMenu->SetPopupMenu( pItemHandler->nItemId, 0 );
+                    m_pVCLMenu->SetPopupMenu( pItemHandler->nItemId, nullptr );
                 }
 
-                Reference< com::sun::star::lang::XEventListener > xEventListener( pItemHandler->xPopupMenuController, UNO_QUERY );
+                Reference< css::lang::XEventListener > xEventListener( pItemHandler->xPopupMenuController, UNO_QUERY );
                 if ( xEventListener.is() )
                 {
                     EventObject aEventObject;
-                    aEventObject.Source = (OWeakObject *)this;
+                    aEventObject.Source = static_cast<OWeakObject *>(this);
                     xEventListener->disposing( aEventObject );
                 }
 
@@ -606,12 +602,12 @@ void MenuBarManager::RemoveListener()
     {
     }
 
-    m_xFrame = 0;
+    m_xFrame = nullptr;
 }
 
 void SAL_CALL MenuBarManager::disposing( const EventObject& Source ) throw ( RuntimeException, std::exception )
 {
-    MenuItemHandler* pMenuItemDisposing = NULL;
+    MenuItemHandler* pMenuItemDisposing = nullptr;
 
     SolarMutexGuard g;
 
@@ -645,14 +641,14 @@ void SAL_CALL MenuBarManager::disposing( const EventObject& Source ) throw ( Run
             pMenuItemDisposing->xMenuItemDispatch.clear();
             if ( pMenuItemDisposing->xPopupMenu.is() )
             {
-                Reference< com::sun::star::lang::XEventListener > xEventListener( pMenuItemDisposing->xPopupMenuController, UNO_QUERY );
+                Reference< css::lang::XEventListener > xEventListener( pMenuItemDisposing->xPopupMenuController, UNO_QUERY );
                 if ( xEventListener.is() )
                     xEventListener->disposing( Source );
 
                 {
                     // Remove popup menu from menu structure as we release our reference to
                     // the controller.
-                    m_pVCLMenu->SetPopupMenu( pMenuItemDisposing->nItemId, 0 );
+                    m_pVCLMenu->SetPopupMenu( pMenuItemDisposing->nItemId, nullptr );
                 }
 
                 pMenuItemDisposing->xPopupMenuController.clear();
@@ -713,28 +709,28 @@ static void lcl_CheckForChildren(Menu* pMenu, sal_uInt16 nItemId)
 namespace {
 
 class QuietInteractionContext:
-    public cppu::WeakImplHelper1< com::sun::star::uno::XCurrentContext >,
+    public cppu::WeakImplHelper< css::uno::XCurrentContext >,
     private boost::noncopyable
 {
 public:
     QuietInteractionContext(
-        com::sun::star::uno::Reference< com::sun::star::uno::XCurrentContext >
+        css::uno::Reference< css::uno::XCurrentContext >
             const & context):
         context_(context) {}
 
 private:
     virtual ~QuietInteractionContext() {}
 
-    virtual com::sun::star::uno::Any SAL_CALL getValueByName(
+    virtual css::uno::Any SAL_CALL getValueByName(
         OUString const & Name)
-        throw (com::sun::star::uno::RuntimeException, std::exception) SAL_OVERRIDE
+        throw (css::uno::RuntimeException, std::exception) override
     {
         return Name != JAVA_INTERACTION_HANDLER_NAME && context_.is()
             ? context_->getValueByName(Name)
-            : com::sun::star::uno::Any();
+            : css::uno::Any();
     }
 
-    com::sun::star::uno::Reference< com::sun::star::uno::XCurrentContext >
+    css::uno::Reference< css::uno::XCurrentContext >
         context_;
 };
 
@@ -744,9 +740,9 @@ IMPL_LINK_TYPED( MenuBarManager, Activate, Menu *, pMenu, bool )
 {
     if ( pMenu == m_pVCLMenu )
     {
-        com::sun::star::uno::ContextLayer layer(
+        css::uno::ContextLayer layer(
             new QuietInteractionContext(
-                com::sun::star::uno::getCurrentContext()));
+                css::uno::getCurrentContext()));
 
         // set/unset hiding disabled menu entries
         bool bDontHide           = SvtMenuOptions().IsEntryHidingEnabled();
@@ -800,6 +796,7 @@ IMPL_LINK_TYPED( MenuBarManager, Activate, Menu *, pMenu, bool )
         }
 
         // Try to set accelerator keys
+        if ( m_bHasMenuBar )
         {
             RetrieveShortcuts( m_aMenuItemHandlerVector );
             std::vector< MenuItemHandler* >::iterator p;
@@ -814,7 +811,7 @@ IMPL_LINK_TYPED( MenuBarManager, Activate, Menu *, pMenu, bool )
                     vcl::KeyCode aKeyCode( KEY_F1 );
                     pMenu->SetAccelKey( pMenuItemHandler->nItemId, aKeyCode );
                 }
-                else if ( pMenu->GetPopupMenu( pMenuItemHandler->nItemId ) == 0 )
+                else if ( pMenu->GetPopupMenu( pMenuItemHandler->nItemId ) == nullptr )
                     pMenu->SetAccelKey( pMenuItemHandler->nItemId, pMenuItemHandler->aKeyCode );
             }
         }
@@ -826,7 +823,7 @@ IMPL_LINK_TYPED( MenuBarManager, Activate, Menu *, pMenu, bool )
         if ( m_xDispatchProvider.is() )
             xDispatchProvider = m_xDispatchProvider;
         else
-            xDispatchProvider = Reference< XDispatchProvider >( m_xFrame, UNO_QUERY );
+            xDispatchProvider.set( m_xFrame, UNO_QUERY );
 
         if ( xDispatchProvider.is() )
         {
@@ -875,7 +872,8 @@ IMPL_LINK_TYPED( MenuBarManager, Activate, Menu *, pMenu, bool )
                             if ( !pMenuItemHandler->xPopupMenuController.is() &&
                                  m_xPopupMenuControllerFactory->hasController( aItemCommand, m_aModuleIdentifier ) )
                             {
-                                bPopupMenu = CreatePopupMenuController( pMenuItemHandler );
+                                if( xMenuItemDispatch.is() || !pMenuItemHandler->aMenuItemURL.equalsAscii( ".uno:RecentFileList") )
+                                    bPopupMenu = CreatePopupMenuController( pMenuItemHandler );
                             }
                             else if ( pMenuItemHandler->xPopupMenuController.is() )
                             {
@@ -897,7 +895,8 @@ IMPL_LINK_TYPED( MenuBarManager, Activate, Menu *, pMenu, bool )
                                 {
                                     xMenuItemDispatch->addStatusListener( static_cast< XStatusListener* >( this ), aTargetURL );
                                     xMenuItemDispatch->removeStatusListener( static_cast< XStatusListener* >( this ), aTargetURL );
-                                    xMenuItemDispatch->addStatusListener( static_cast< XStatusListener* >( this ), aTargetURL );
+                                    if ( m_bHasMenuBar )
+                                        xMenuItemDispatch->addStatusListener( static_cast< XStatusListener* >( this ), aTargetURL );
                                 }
                             }
                             else if ( !bPopupMenu )
@@ -970,7 +969,7 @@ IMPL_LINK_NOARG_TYPED( MenuBarManager, AsyncSettingsHdl, Timer*, void)
     }
 }
 
-IMPL_LINK( MenuBarManager, Select, Menu *, pMenu )
+IMPL_LINK_TYPED( MenuBarManager, Select, Menu *, pMenu, bool )
 {
     URL                     aTargetURL;
     Sequence<PropertyValue> aArgs;
@@ -989,7 +988,7 @@ IMPL_LINK( MenuBarManager, Select, Menu *, pMenu )
             {
                 // window list menu item selected
 
-                Reference< XDesktop2 > xDesktop = Desktop::create( m_xContext );
+                Reference< XDesktop2 > xDesktop = css::frame::Desktop::create( m_xContext );
 
                 sal_uInt16 nTaskId = START_ITEMID_WINDOWLIST;
                 Reference< XIndexAccess > xList( xDesktop->getFrames(), UNO_QUERY );
@@ -1002,7 +1001,7 @@ IMPL_LINK( MenuBarManager, Select, Menu *, pMenu )
                     {
                         vcl::Window* pWin = VCLUnoHelper::GetWindow( xFrame->getContainerWindow() );
                         pWin->GrabFocus();
-                        pWin->ToTop( TOTOP_RESTOREWHENMIN );
+                        pWin->ToTop( ToTopFlags::RestoreWhenMin );
                         break;
                     }
 
@@ -1037,7 +1036,7 @@ IMPL_LINK( MenuBarManager, Select, Menu *, pMenu )
         xDispatch->dispatch( aTargetURL, aArgs );
     }
 
-    return 1;
+    return true;
 }
 
 IMPL_LINK_NOARG_TYPED(MenuBarManager, Highlight, Menu *, bool)
@@ -1090,7 +1089,12 @@ bool MenuBarManager::MustBeHidden( PopupMenu* pPopupMenu, const Reference< XURLT
 
 OUString MenuBarManager::RetrieveLabelFromCommand(const OUString& rCmdURL)
 {
-    return framework::RetrieveLabelFromCommand(rCmdURL, m_xContext, m_xUICommandLabels,m_xFrame,m_aModuleIdentifier,m_bModuleIdentified,"Label");
+    if ( !m_bHasMenuBar )
+    {
+        // This is a context menu, prefer "PopupLabel" over "Label".
+        return vcl::CommandInfoProvider::Instance().GetPopupLabelForCommand(rCmdURL, m_xFrame);
+    }
+    return vcl::CommandInfoProvider::Instance().GetMenuLabelForCommand(rCmdURL, m_xFrame);
 }
 
 bool MenuBarManager::CreatePopupMenuController( MenuItemHandler* pMenuItemHandler )
@@ -1168,7 +1172,6 @@ void MenuBarManager::FillMenuManager( Menu* pMenu, const Reference< XFrame >& rF
         framework::AddonMenuManager::MergeAddonHelpMenu( rFrame, static_cast<MenuBar *>(pMenu), m_xContext );
     }
 
-    OUString    aEmpty;
     bool    bAccessibilityEnabled( Application::GetSettings().GetMiscSettings().GetEnableATToolSupport() );
     sal_uInt16 nItemCount = pMenu->GetItemCount();
     OUString aItemCommand;
@@ -1208,7 +1211,7 @@ void MenuBarManager::FillMenuManager( Menu* pMenu, const Reference< XFrame >& rF
             if (!pMenu->GetHelpCommand(nItemId).isEmpty())
             {
                 aModuleIdentifier = pMenu->GetHelpCommand( nItemId );
-                pMenu->SetHelpCommand( nItemId, aEmpty );
+                pMenu->SetHelpCommand( nItemId, "" );
             }
 
             if ( m_xPopupMenuControllerFactory.is() &&
@@ -1223,7 +1226,7 @@ void MenuBarManager::FillMenuManager( Menu* pMenu, const Reference< XFrame >& rF
                 VCLXPopupMenu* pVCLXPopupMenu = new VCLXPopupMenu;
                 PopupMenu* pNewPopupMenu = static_cast<PopupMenu *>(pVCLXPopupMenu->GetMenu());
                 pMenu->SetPopupMenu( nItemId, pNewPopupMenu );
-                pItemHandler->xPopupMenu = Reference< com::sun::star::awt::XPopupMenu >( (OWeakObject *)pVCLXPopupMenu, UNO_QUERY );
+                pItemHandler->xPopupMenu.set( static_cast<OWeakObject *>(pVCLXPopupMenu), UNO_QUERY );
                 pItemHandler->aMenuItemURL = aItemCommand;
                 m_aMenuItemHandlerVector.push_back( pItemHandler );
                 delete pPopup;
@@ -1302,7 +1305,7 @@ void MenuBarManager::FillMenuManager( Menu* pMenu, const Reference< XFrame >& rF
                 }
                 else
                 {
-                    MenuBarManager* pSubMenuMgr = new MenuBarManager( m_xContext, rFrame, m_xURLTransformer,rDispatchProvider, aModuleIdentifier, pPopup, bDeleteChildren, bDeleteChildren );
+                    MenuBarManager* pSubMenuMgr = new MenuBarManager( m_xContext, rFrame, m_xURLTransformer,rDispatchProvider, aModuleIdentifier, pPopup, bDeleteChildren, bDeleteChildren, m_bHasMenuBar );
                     AddMenu(pSubMenuMgr,aItemCommand,nItemId);
                 }
             }
@@ -1353,7 +1356,7 @@ void MenuBarManager::FillMenuManager( Menu* pMenu, const Reference< XFrame >& rF
                 VCLXPopupMenu* pVCLXPopupMenu = new VCLXPopupMenu;
                 PopupMenu* pPopupMenu = static_cast<PopupMenu *>(pVCLXPopupMenu->GetMenu());
                 pMenu->SetPopupMenu( pItemHandler->nItemId, pPopupMenu );
-                pItemHandler->xPopupMenu = Reference< com::sun::star::awt::XPopupMenu >( (OWeakObject *)pVCLXPopupMenu, UNO_QUERY );
+                pItemHandler->xPopupMenu.set( static_cast<OWeakObject *>(pVCLXPopupMenu), UNO_QUERY );
 
                 if ( bAccessibilityEnabled && CreatePopupMenuController( pItemHandler ) )
                 {
@@ -1367,7 +1370,7 @@ void MenuBarManager::FillMenuManager( Menu* pMenu, const Reference< XFrame >& rF
         }
     }
 
-    if ( bAccessibilityEnabled )
+    if ( m_bHasMenuBar && bAccessibilityEnabled )
     {
         RetrieveShortcuts( m_aMenuItemHandlerVector );
         std::vector< MenuItemHandler* >::iterator p;
@@ -1382,7 +1385,7 @@ void MenuBarManager::FillMenuManager( Menu* pMenu, const Reference< XFrame >& rF
                 vcl::KeyCode aKeyCode( KEY_F1 );
                 pMenu->SetAccelKey( pMenuItemHandler->nItemId, aKeyCode );
             }
-            else if ( pMenu->GetPopupMenu( pMenuItemHandler->nItemId ) == 0 )
+            else if ( pMenu->GetPopupMenu( pMenuItemHandler->nItemId ) == nullptr )
                 pMenu->SetAccelKey( pMenuItemHandler->nItemId, pMenuItemHandler->aKeyCode );
         }
     }
@@ -1399,7 +1402,7 @@ void MenuBarManager::impl_RetrieveShortcutsFromConfiguration(
     {
         try
         {
-            com::sun::star::awt::KeyEvent aKeyEvent;
+            css::awt::KeyEvent aKeyEvent;
             Sequence< Any > aSeqKeyCode = rAccelCfg->getPreferredKeyEventsForCommandList( rCommands );
             for ( sal_Int32 i = 0; i < aSeqKeyCode.getLength(); i++ )
             {
@@ -1501,7 +1504,10 @@ void MenuBarManager::RetrieveShortcuts( std::vector< MenuItemHandler* >& aMenuSh
         const sal_uInt32 nCount = aMenuShortCuts.size();
         for ( sal_uInt32 i = 0; i < nCount; ++i )
         {
-            aSeq[i] = aMenuShortCuts[i]->aMenuItemURL;
+            rtl::OUString aItemURL = aMenuShortCuts[i]->aMenuItemURL;
+            if( aItemURL.isEmpty() && aMenuShortCuts[i]->xSubMenuManager.is())
+                aItemURL = "-"; // tdf#99527 prevent throw in case of empty commands
+            aSeq[i] = aItemURL;
             aMenuShortCuts[i]->aKeyCode = aEmptyKeyCode;
         }
 
@@ -1529,7 +1535,7 @@ void MenuBarManager::RetrieveImageManagers()
                 if ( xSupplier.is() )
                 {
                     Reference< XUIConfigurationManager > xDocUICfgMgr( xSupplier->getUIConfigurationManager(), UNO_QUERY );
-                    m_xDocImageManager = Reference< XImageManager >( xDocUICfgMgr->getImageManager(), UNO_QUERY );
+                    m_xDocImageManager.set( xDocUICfgMgr->getImageManager(), UNO_QUERY );
                     m_xDocImageManager->addConfigurationListener(
                                             Reference< XUIConfigurationListener >(
                                                 static_cast< OWeakObject* >( this ), UNO_QUERY ));
@@ -1648,7 +1654,7 @@ void MenuBarManager::FillMenu(
                         aProp[i].Value >>= bEnabled;
                 }
 
-                if ( nType == ::com::sun::star::ui::ItemType::DEFAULT )
+                if ( nType == css::ui::ItemType::DEFAULT )
                 {
                     pMenu->InsertItem( nId, aLabel );
                     pMenu->SetItemCommand( nId, aCommandURL );
@@ -1656,11 +1662,11 @@ void MenuBarManager::FillMenu(
                     if ( nStyle )
                     {
                         MenuItemBits nBits = pMenu->GetItemBits( nId );
-                        if ( nStyle & ::com::sun::star::ui::ItemStyle::ICON )
+                        if ( nStyle & css::ui::ItemStyle::ICON )
                            nBits |= MenuItemBits::ICON;
-                        if ( nStyle & ::com::sun::star::ui::ItemStyle::TEXT )
+                        if ( nStyle & css::ui::ItemStyle::TEXT )
                            nBits |= MenuItemBits::TEXT;
-                        if ( nStyle & ::com::sun::star::ui::ItemStyle::RADIO_CHECK )
+                        if ( nStyle & css::ui::ItemStyle::RADIO_CHECK )
                            nBits |= MenuItemBits::RADIOCHECK;
                         pMenu->SetItemBits( nId, nBits );
                     }
@@ -1923,7 +1929,7 @@ void MenuBarManager::Init(const Reference< XFrame >& rFrame,Menu* pAddonMenu,boo
 
             Reference< XStatusListener > xSubMenuManager( static_cast< OWeakObject *>( pSubMenuManager ), UNO_QUERY );
 
-            // store menu item command as we later have to know which menu is active (see Acivate handler)
+            // store menu item command as we later have to know which menu is active (see Activate handler)
             pSubMenuManager->m_aMenuItemCommand = aItemCommand;
 
             MenuItemHandler* pMenuItemHandler = new MenuItemHandler(
@@ -1957,7 +1963,7 @@ void MenuBarManager::Init(const Reference< XFrame >& rFrame,Menu* pAddonMenu,boo
                         VCLXPopupMenu* pVCLXPopupMenu = new VCLXPopupMenu;
                         PopupMenu* pCtlPopupMenu = static_cast<PopupMenu *>(pVCLXPopupMenu->GetMenu());
                         pAddonMenu->SetPopupMenu( pMenuItemHandler->nItemId, pCtlPopupMenu );
-                        pMenuItemHandler->xPopupMenu = Reference< com::sun::star::awt::XPopupMenu >( (OWeakObject *)pVCLXPopupMenu, UNO_QUERY );
+                        pMenuItemHandler->xPopupMenu.set( static_cast<OWeakObject *>(pVCLXPopupMenu), UNO_QUERY );
 
                     }
                 }
