@@ -19,7 +19,6 @@
 
 #include <uielement/newmenucontroller.hxx>
 
-#include <threadhelp/resetableguard.hxx>
 #include "services.h"
 #include <classes/resource.hrc>
 #include <classes/fwkresid.hxx>
@@ -30,24 +29,25 @@
 #include <com/sun/star/awt/XDevice.hpp>
 #include <com/sun/star/beans/PropertyValue.hpp>
 #include <com/sun/star/awt/MenuItemStyle.hpp>
-#include <com/sun/star/ui/ModuleUIConfigurationManagerSupplier.hpp>
+#include <com/sun/star/ui/theModuleUIConfigurationManagerSupplier.hpp>
 #include <com/sun/star/ui/XUIConfigurationManagerSupplier.hpp>
 #include <com/sun/star/ui/GlobalAcceleratorConfiguration.hpp>
 #include <com/sun/star/frame/ModuleManager.hpp>
 
 #include <vcl/svapp.hxx>
 #include <vcl/i18nhelp.hxx>
+#include <vcl/settings.hxx>
 #include <rtl/ustrbuf.hxx>
-#include <cppuhelper/implbase1.hxx>
 #include <osl/file.hxx>
 #include <svtools/menuoptions.hxx>
 #include <svtools/acceleratorexecute.hxx>
 #include <unotools/moduleoptions.hxx>
 #include <osl/mutex.hxx>
+#include <memory>
 
-//_________________________________________________________________________________________________________________
 //  Defines
-//_________________________________________________________________________________________________________________
+#define aSlotNewDocDirect ".uno:AddDirect"
+#define aSlotAutoPilot ".uno:AutoPilotMenu"
 
 using namespace com::sun::star::uno;
 using namespace com::sun::star::lang;
@@ -68,7 +68,7 @@ DEFINE_XSERVICEINFO_MULTISERVICE_2      (   NewMenuController
 
 DEFINE_INIT_SERVICE                     (   NewMenuController, {} )
 
-void NewMenuController::setMenuImages( PopupMenu* pPopupMenu, sal_Bool bSetImages )
+void NewMenuController::setMenuImages( PopupMenu* pPopupMenu, bool bSetImages )
 {
     sal_uInt16 nItemCount = pPopupMenu->GetItemCount();
     Image               aImage;
@@ -81,19 +81,20 @@ void NewMenuController::setMenuImages( PopupMenu* pPopupMenu, sal_Bool bSetImage
         {
             if ( bSetImages )
             {
-                sal_Bool        bImageSet( sal_False );
+                bool        bImageSet( false );
                 OUString aImageId;
 
-                AddInfoForId::const_iterator pInfo = m_aAddInfoForItem.find( nItemId );
-                if ( pInfo != m_aAddInfoForItem.end() )
-                    aImageId = pInfo->second.aImageId; // Retrieve image id for menu item
+                sal_uIntPtr nAttributePtr = pPopupMenu->GetUserValue(sal::static_int_cast<sal_uInt16>(i));
+                MenuAttributes* pAttributes = reinterpret_cast<MenuAttributes *>(nAttributePtr);
+                if (pAttributes)
+                    aImageId = pAttributes->aImageId;
 
                 if ( !aImageId.isEmpty() )
                 {
                     aImage = GetImageFromURL( xFrame, aImageId, false );
                     if ( !!aImage )
                     {
-                        bImageSet = sal_True;
+                        bImageSet = true;
                         pPopupMenu->SetItemImage( nItemId, aImage );
                     }
                 }
@@ -114,11 +115,11 @@ void NewMenuController::setMenuImages( PopupMenu* pPopupMenu, sal_Bool bSetImage
     }
 }
 
-void NewMenuController::determineAndSetNewDocAccel( PopupMenu* pPopupMenu, const KeyCode& rKeyCode )
+void NewMenuController::determineAndSetNewDocAccel( PopupMenu* pPopupMenu, const vcl::KeyCode& rKeyCode )
 {
     sal_uInt16        nCount( pPopupMenu->GetItemCount() );
     sal_uInt16        nId( 0 );
-    sal_Bool      bFound( sal_False );
+    bool      bFound( false );
     OUString aCommand;
 
     if ( !m_aEmptyDocURL.isEmpty() )
@@ -128,13 +129,13 @@ void NewMenuController::determineAndSetNewDocAccel( PopupMenu* pPopupMenu, const
         for ( sal_uInt32 i = 0; i < sal_uInt32( nCount ); i++ )
         {
             nId = pPopupMenu->GetItemId( sal_uInt16( i ));
-            if ( nId != 0 && pPopupMenu->GetItemType( nId ) != MENUITEM_SEPARATOR )
+            if ( nId != 0 && pPopupMenu->GetItemType( nId ) != MenuItemType::SEPARATOR )
             {
                 aCommand = pPopupMenu->GetItemCommand( nId );
                 if ( aCommand.startsWith( m_aEmptyDocURL ) )
                 {
                     pPopupMenu->SetAccelKey( nId, rKeyCode );
-                    bFound = sal_True;
+                    bFound = true;
                     break;
                 }
             }
@@ -150,7 +151,7 @@ void NewMenuController::determineAndSetNewDocAccel( PopupMenu* pPopupMenu, const
             for ( sal_uInt32 i = 0; i < sal_uInt32( nCount ); i++ )
             {
                 nId = pPopupMenu->GetItemId( sal_uInt16( i ));
-                if ( nId != 0 && pPopupMenu->GetItemType( nId ) != MENUITEM_SEPARATOR )
+                if ( nId != 0 && pPopupMenu->GetItemType( nId ) != MenuItemType::SEPARATOR )
                 {
                     aCommand = pPopupMenu->GetItemCommand( nId );
                     if ( aCommand.indexOf( aDefaultModuleName ) >= 0 )
@@ -175,7 +176,7 @@ void NewMenuController::setAccelerators( PopupMenu* pPopupMenu )
         if ( !m_bAcceleratorCfg )
         {
             // Retrieve references on demand
-            m_bAcceleratorCfg = sal_True;
+            m_bAcceleratorCfg = true;
             if ( !xDocAccelCfg.is() )
             {
                 Reference< XController > xController = m_xFrame->getController();
@@ -202,7 +203,7 @@ void NewMenuController::setAccelerators( PopupMenu* pPopupMenu )
             if ( !xModuleAccelCfg.is() )
             {
                 Reference< XModuleUIConfigurationManagerSupplier > xModuleCfgMgrSupplier =
-                    ModuleUIConfigurationManagerSupplier::create( m_xContext );
+                    theModuleUIConfigurationManagerSupplier::get( m_xContext );
                 Reference< XUIConfigurationManager > xUICfgMgr = xModuleCfgMgrSupplier->getUIConfigurationManager( m_aModuleIdentifier );
                 if ( xUICfgMgr.is() )
                 {
@@ -218,15 +219,15 @@ void NewMenuController::setAccelerators( PopupMenu* pPopupMenu )
             }
         }
 
-        KeyCode                         aEmptyKeyCode;
+        vcl::KeyCode                    aEmptyKeyCode;
         sal_uInt32                      nItemCount( pPopupMenu->GetItemCount() );
-        std::vector< KeyCode >          aMenuShortCuts;
+        std::vector< vcl::KeyCode >     aMenuShortCuts;
         std::vector< OUString >    aCmds;
         std::vector< sal_uInt32 >       aIds;
         for ( sal_uInt32 i = 0; i < nItemCount; i++ )
         {
             sal_uInt16 nId( pPopupMenu->GetItemId( sal_uInt16( i )));
-            if ( nId & ( pPopupMenu->GetItemType( nId ) != MENUITEM_SEPARATOR ))
+            if ( nId && ( pPopupMenu->GetItemType( nId ) != MenuItemType::SEPARATOR ))
             {
                 aIds.push_back( nId );
                 aMenuShortCuts.push_back( aEmptyKeyCode );
@@ -276,13 +277,13 @@ void NewMenuController::setAccelerators( PopupMenu* pPopupMenu )
 void NewMenuController::retrieveShortcutsFromConfiguration(
     const Reference< XAcceleratorConfiguration >& rAccelCfg,
     const Sequence< OUString >& rCommands,
-    std::vector< KeyCode >& aMenuShortCuts )
+    std::vector< vcl::KeyCode >& aMenuShortCuts )
 {
     if ( rAccelCfg.is() )
     {
         try
         {
-            com::sun::star::awt::KeyEvent aKeyEvent;
+            css::awt::KeyEvent aKeyEvent;
             Sequence< Any > aSeqKeyCode = rAccelCfg->getPreferredKeyEventsForCommandList( rCommands );
             for ( sal_Int32 i = 0; i < aSeqKeyCode.getLength(); i++ )
             {
@@ -296,12 +297,12 @@ void NewMenuController::retrieveShortcutsFromConfiguration(
     }
 }
 
-NewMenuController::NewMenuController( const ::com::sun::star::uno::Reference< ::com::sun::star::uno::XComponentContext >& xContext ) :
+NewMenuController::NewMenuController( const css::uno::Reference< css::uno::XComponentContext >& xContext ) :
     svt::PopupMenuControllerBase( xContext ),
-    m_bShowImages( sal_True ),
-    m_bNewMenu( sal_False ),
-    m_bModuleIdentified( sal_False ),
-    m_bAcceleratorCfg( sal_False ),
+    m_bShowImages( true ),
+    m_bNewMenu( false ),
+    m_bModuleIdentified( false ),
+    m_bAcceleratorCfg( false ),
     m_aTargetFrame( "_default" ),
     m_xContext( xContext )
 {
@@ -314,61 +315,64 @@ NewMenuController::~NewMenuController()
 // private function
 void NewMenuController::fillPopupMenu( Reference< css::awt::XPopupMenu >& rPopupMenu )
 {
-    VCLXPopupMenu* pPopupMenu    = (VCLXPopupMenu *)VCLXMenu::GetImplementation( rPopupMenu );
-    PopupMenu*     pVCLPopupMenu = 0;
+    VCLXPopupMenu* pPopupMenu    = static_cast<VCLXPopupMenu *>(VCLXMenu::GetImplementation( rPopupMenu ));
+    PopupMenu*     pVCLPopupMenu = nullptr;
 
     SolarMutexGuard aSolarMutexGuard;
 
     resetPopupMenu( rPopupMenu );
     if ( pPopupMenu )
-        pVCLPopupMenu = (PopupMenu *)pPopupMenu->GetMenu();
+        pVCLPopupMenu = static_cast<PopupMenu *>(pPopupMenu->GetMenu());
 
     if ( pVCLPopupMenu )
     {
         MenuConfiguration aMenuCfg( m_xContext );
-        BmkMenu* pSubMenu( 0 );
+        std::unique_ptr<BmkMenu> pSubMenu;
 
+        Reference< XDispatchProvider > xDispatchProvider( m_xFrame, UNO_QUERY );
+        URL aTargetURL;
+        aTargetURL.Complete = rtl::OUString::createFromAscii(m_bNewMenu ? aSlotNewDocDirect : aSlotAutoPilot);
+        m_xURLTransformer->parseStrict( aTargetURL );
+        Reference< XDispatch > xMenuItemDispatch = xDispatchProvider->queryDispatch( aTargetURL, OUString(), 0 );
+        if(xMenuItemDispatch == nullptr)
+            return;
         if ( m_bNewMenu )
-            pSubMenu = (BmkMenu*)aMenuCfg.CreateBookmarkMenu( m_xFrame, BOOKMARK_NEWMENU );
+            pSubMenu.reset(static_cast<BmkMenu*>(aMenuCfg.CreateBookmarkMenu( m_xFrame, BOOKMARK_NEWMENU )));
         else
-            pSubMenu = (BmkMenu*)aMenuCfg.CreateBookmarkMenu( m_xFrame, BOOKMARK_WIZARDMENU );
+            pSubMenu.reset(static_cast<BmkMenu*>(aMenuCfg.CreateBookmarkMenu( m_xFrame, BOOKMARK_WIZARDMENU )));
 
         // copy entries as we have to use the provided popup menu
         *pVCLPopupMenu = *pSubMenu;
 
         Image           aImage;
-        AddInfo         aAddInfo;
 
         // retrieve additional parameters from bookmark menu and
-        // store it in a boost::unordered_map.
+        // store it in a unordered_map.
         for ( sal_uInt16 i = 0; i < pSubMenu->GetItemCount(); i++ )
         {
             sal_uInt16 nItemId = pSubMenu->GetItemId( sal::static_int_cast<sal_uInt16>( i ) );
             if (( nItemId != 0 ) &&
-                ( pSubMenu->GetItemType( nItemId ) != MENUITEM_SEPARATOR ))
+                ( pSubMenu->GetItemType( nItemId ) != MenuItemType::SEPARATOR ))
             {
-                MenuConfiguration::Attributes* pBmkAttributes = (MenuConfiguration::Attributes *)(pSubMenu->GetUserValue( nItemId ));
-                if ( pBmkAttributes != 0 )
+                sal_uIntPtr nAttributePtr = pSubMenu->GetUserValue(nItemId);
+                if (nAttributePtr)
                 {
-                    aAddInfo.aTargetFrame = pBmkAttributes->aTargetFrame;
-                    aAddInfo.aImageId     = pBmkAttributes->aImageId;
-
-                    m_aAddInfoForItem.insert( AddInfoForId::value_type( nItemId, aAddInfo ));
+                    MenuAttributes* pAttributes = reinterpret_cast<MenuAttributes *>(nAttributePtr);
+                    pAttributes->acquire();
+                    pVCLPopupMenu->SetUserValue(nItemId, nAttributePtr, MenuAttributes::ReleaseAttribute);
                 }
             }
         }
 
         if ( m_bShowImages )
             setMenuImages( pVCLPopupMenu, m_bShowImages );
-
-        delete pSubMenu;
     }
 }
 
 // XEventListener
-void SAL_CALL NewMenuController::disposing( const EventObject& ) throw ( RuntimeException )
+void SAL_CALL NewMenuController::disposing( const EventObject& ) throw ( RuntimeException, std::exception )
 {
-    Reference< css::awt::XMenuListener > xHolder(( OWeakObject *)this, UNO_QUERY );
+    Reference< css::awt::XMenuListener > xHolder(static_cast<OWeakObject *>(this), UNO_QUERY );
 
     osl::MutexGuard aLock( m_aMutex );
     m_xFrame.clear();
@@ -376,17 +380,17 @@ void SAL_CALL NewMenuController::disposing( const EventObject& ) throw ( Runtime
     m_xContext.clear();
 
     if ( m_xPopupMenu.is() )
-        m_xPopupMenu->removeMenuListener( Reference< css::awt::XMenuListener >(( OWeakObject *)this, UNO_QUERY ));
+        m_xPopupMenu->removeMenuListener( Reference< css::awt::XMenuListener >(static_cast<OWeakObject *>(this), UNO_QUERY ));
     m_xPopupMenu.clear();
 }
 
 // XStatusListener
-void SAL_CALL NewMenuController::statusChanged( const FeatureStateEvent& ) throw ( RuntimeException )
+void SAL_CALL NewMenuController::statusChanged( const FeatureStateEvent& ) throw ( RuntimeException, std::exception )
 {
 }
 
 // XMenuListener
-void SAL_CALL NewMenuController::itemSelected( const css::awt::MenuEvent& rEvent ) throw (RuntimeException)
+void SAL_CALL NewMenuController::itemSelected( const css::awt::MenuEvent& rEvent ) throw (RuntimeException, std::exception)
 {
     Reference< css::awt::XPopupMenu > xPopupMenu;
     Reference< XDispatch >            xDispatch;
@@ -396,7 +400,7 @@ void SAL_CALL NewMenuController::itemSelected( const css::awt::MenuEvent& rEvent
 
     osl::ClearableMutexGuard aLock( m_aMutex );
     xPopupMenu          = m_xPopupMenu;
-    xDispatchProvider   = Reference< XDispatchProvider >( m_xFrame, UNO_QUERY );
+    xDispatchProvider.set( m_xFrame, UNO_QUERY );
     xContext     = m_xContext;
     xURLTransformer     = m_xURLTransformer;
     aLock.clear();
@@ -406,13 +410,19 @@ void SAL_CALL NewMenuController::itemSelected( const css::awt::MenuEvent& rEvent
 
     if ( xPopupMenu.is() && xDispatchProvider.is() )
     {
-        VCLXPopupMenu* pPopupMenu = (VCLXPopupMenu *)VCLXPopupMenu::GetImplementation( xPopupMenu );
+        VCLXPopupMenu* pPopupMenu = static_cast<VCLXPopupMenu *>(VCLXPopupMenu::GetImplementation( xPopupMenu ));
         if ( pPopupMenu )
         {
+            OUString aTargetFrame( m_aTargetFrame );
+
             {
                 SolarMutexGuard aSolarMutexGuard;
-                PopupMenu* pVCLPopupMenu = (PopupMenu *)pPopupMenu->GetMenu();
-                aTargetURL.Complete = pVCLPopupMenu->GetItemCommand( rEvent.MenuId );
+                PopupMenu* pVCLPopupMenu = static_cast<PopupMenu *>(pPopupMenu->GetMenu());
+                aTargetURL.Complete = pVCLPopupMenu->GetItemCommand(rEvent.MenuId);
+                sal_uIntPtr nAttributePtr = pVCLPopupMenu->GetUserValue(rEvent.MenuId);
+                MenuAttributes* pAttributes = reinterpret_cast<MenuAttributes *>(nAttributePtr);
+                if (pAttributes)
+                    aTargetFrame = pAttributes->aTargetFrame;
             }
 
             xURLTransformer->parseStrict( aTargetURL );
@@ -420,11 +430,6 @@ void SAL_CALL NewMenuController::itemSelected( const css::awt::MenuEvent& rEvent
             aArgsList[0].Name = "Referer";
             aArgsList[0].Value = makeAny( OUString( "private:user" ));
 
-            OUString aTargetFrame( m_aTargetFrame );
-            AddInfoForId::const_iterator pItem = m_aAddInfoForItem.find( rEvent.MenuId );
-            if ( pItem != m_aAddInfoForItem.end() )
-                aTargetFrame = pItem->second.aTargetFrame;
-
             xDispatch = xDispatchProvider->queryDispatch( aTargetURL, aTargetFrame, 0 );
         }
     }
@@ -438,22 +443,22 @@ void SAL_CALL NewMenuController::itemSelected( const css::awt::MenuEvent& rEvent
         pNewDocument->xDispatch  = xDispatch;
         pNewDocument->aTargetURL = aTargetURL;
         pNewDocument->aArgSeq    = aArgsList;
-        Application::PostUserEvent( STATIC_LINK(0, NewMenuController, ExecuteHdl_Impl), pNewDocument );
+        Application::PostUserEvent( LINK(nullptr, NewMenuController, ExecuteHdl_Impl), pNewDocument );
     }
 }
 
-void SAL_CALL NewMenuController::itemActivated( const css::awt::MenuEvent& ) throw (RuntimeException)
+void SAL_CALL NewMenuController::itemActivated( const css::awt::MenuEvent& ) throw (RuntimeException, std::exception)
 {
     SolarMutexGuard aSolarMutexGuard;
     if ( m_xFrame.is() && m_xPopupMenu.is() )
     {
-        VCLXPopupMenu* pPopupMenu = (VCLXPopupMenu *)VCLXPopupMenu::GetImplementation( m_xPopupMenu );
+        VCLXPopupMenu* pPopupMenu = static_cast<VCLXPopupMenu *>(VCLXPopupMenu::GetImplementation( m_xPopupMenu ));
         if ( pPopupMenu )
         {
             const StyleSettings& rSettings = Application::GetSettings().GetStyleSettings();
-            sal_Bool bShowImages( rSettings.GetUseImagesInMenus() );
+            bool bShowImages( rSettings.GetUseImagesInMenus() );
 
-            PopupMenu* pVCLPopupMenu = (PopupMenu *)pPopupMenu->GetMenu();
+            PopupMenu* pVCLPopupMenu = static_cast<PopupMenu *>(pPopupMenu->GetMenu());
 
             if ( m_bShowImages != bShowImages )
             {
@@ -478,7 +483,7 @@ void NewMenuController::impl_setPopupMenu()
     try
     {
         m_aModuleIdentifier = xModuleManager->identify( m_xFrame );
-        m_bModuleIdentified = sal_True;
+        m_bModuleIdentified = true;
 
         if ( !m_aModuleIdentifier.isEmpty() )
         {
@@ -507,11 +512,11 @@ void NewMenuController::impl_setPopupMenu()
 }
 
 // XInitialization
-void SAL_CALL NewMenuController::initialize( const Sequence< Any >& aArguments ) throw ( Exception, RuntimeException )
+void SAL_CALL NewMenuController::initialize( const Sequence< Any >& aArguments ) throw ( Exception, RuntimeException, std::exception )
 {
     osl::MutexGuard aLock( m_aMutex );
 
-    sal_Bool bInitalized( m_bInitialized );
+    bool bInitalized( m_bInitialized );
     if ( !bInitalized )
     {
         svt::PopupMenuControllerBase::initialize( aArguments );
@@ -521,13 +526,14 @@ void SAL_CALL NewMenuController::initialize( const Sequence< Any >& aArguments )
             const StyleSettings& rSettings = Application::GetSettings().GetStyleSettings();
 
             m_bShowImages   = rSettings.GetUseImagesInMenus();
-            m_bNewMenu      = m_aCommandURL == ".uno:AddDirect";
+            m_bNewMenu      = m_aCommandURL == aSlotNewDocDirect;
         }
     }
 }
 
-IMPL_STATIC_LINK_NOINSTANCE( NewMenuController, ExecuteHdl_Impl, NewDocument*, pNewDocument )
+IMPL_STATIC_LINK_TYPED( NewMenuController, ExecuteHdl_Impl, void*, p, void )
 {
+    NewDocument* pNewDocument = static_cast<NewDocument*>(p);
 /*  i62706: Don't catch all exceptions. We hide all problems here and are not able
             to handle them on higher levels.
     try
@@ -538,7 +544,6 @@ IMPL_STATIC_LINK_NOINSTANCE( NewMenuController, ExecuteHdl_Impl, NewDocument*, p
         // elements if a component gets detached from its frame!
         pNewDocument->xDispatch->dispatch( pNewDocument->aTargetURL, pNewDocument->aArgSeq );
     delete pNewDocument;
-    return 0;
 }
 
 }
