@@ -685,6 +685,8 @@ static bool checkMapping( const OUString& rStr1, const OUString& rStr2 )
     if (rStr1 == "ku-IQ"       ) return rStr2 == "ckb-IQ";
     if (rStr1 == "ku-IR"       ) return rStr2 == "ckb-IR";
     if (rStr1 == "eu"          ) return rStr2 == "eu-ES";
+    if (rStr1 == "crk-Latn-CN" ) return rStr2 == "crk-Latn-CA";
+    if (rStr1 == "crk-Cans-CN" ) return rStr2 == "crk-Cans-CA";
     return rStr1 == rStr2;
 }
 
