@@ -18,15 +18,16 @@
  */
 
 #include <com/sun/star/uno/XComponentContext.hpp>
-#include <boost/scoped_ptr.hpp>
 #include <i18nlangtag/languagetag.hxx>
 #include <i18nlangtag/languagetagicu.hxx>
+#include <sal/log.hxx>
 #include <cppuhelper/supportsservice.hxx>
 #include <string.h>
 #include "ordinalsuffix.hxx"
 
 #include <unicode/rbnf.h>
 #include <unicode/normlzr.h>
+#include <memory>
 
 using namespace ::com::sun::star::i18n;
 using namespace ::com::sun::star::uno;
@@ -78,7 +79,7 @@ uno::Sequence< OUString > SAL_CALL OrdinalSuffixService::getOrdinalSuffix( sal_I
     if (!U_SUCCESS(nCode))
         return retValue;
 
-    boost::scoped_ptr<NumberFormat> xNumberFormat(icu::NumberFormat::createInstance(aIcuLocale, nCode));
+    std::unique_ptr<NumberFormat> xNumberFormat(icu::NumberFormat::createInstance(aIcuLocale, nCode));
     if (!U_SUCCESS(nCode))
         return retValue;
 
@@ -135,9 +136,9 @@ uno::Sequence< OUString > SAL_CALL OrdinalSuffixService::getOrdinalSuffix( sal_I
 
 const sal_Char cOrdinalSuffix[] = "com.sun.star.i18n.OrdinalSuffix";
 
-OUString SAL_CALL OrdinalSuffixService::getImplementationName(void) throw( RuntimeException, std::exception )
+OUString SAL_CALL OrdinalSuffixService::getImplementationName() throw( RuntimeException, std::exception )
 {
-    return OUString::createFromAscii(cOrdinalSuffix);
+    return OUString(cOrdinalSuffix);
 }
 
 sal_Bool SAL_CALL OrdinalSuffixService::supportsService( const OUString& rServiceName) throw( RuntimeException, std::exception )
@@ -145,10 +146,9 @@ sal_Bool SAL_CALL OrdinalSuffixService::supportsService( const OUString& rServic
     return cppu::supportsService(this, rServiceName);
 }
 
-Sequence< OUString > SAL_CALL OrdinalSuffixService::getSupportedServiceNames(void) throw( RuntimeException, std::exception )
+Sequence< OUString > SAL_CALL OrdinalSuffixService::getSupportedServiceNames() throw( RuntimeException, std::exception )
 {
-    Sequence< OUString > aRet(1);
-    aRet[0] = OUString::createFromAscii(cOrdinalSuffix);
+    Sequence< OUString > aRet { cOrdinalSuffix };
     return aRet;
 }
 
