@@ -26,6 +26,7 @@
 #include <com/sun/star/linguistic2/ConversionDictionaryList.hpp>
 #include <rtl/ustrbuf.hxx>
 #include <unicode/uchar.h>
+#include <memory>
 
 using namespace com::sun::star::lang;
 using namespace com::sun::star::i18n;
@@ -40,11 +41,12 @@ namespace com { namespace sun { namespace star { namespace i18n {
 #define SCRIPT_HANGUL   2
 
 TextConversion_ko::TextConversion_ko( const Reference < XComponentContext >& xContext )
+    : TextConversionService("com.sun.star.i18n.TextConversion_ko")
 {
     Reference < XInterface > xI;
 
     xI = xContext->getServiceManager()->createInstanceWithContext(
-        OUString("com.sun.star.i18n.ConversionDictionary_ko"), xContext);
+        "com.sun.star.i18n.ConversionDictionary_ko", xContext);
 
     if ( xI.is() )
         xCD.set( xI, UNO_QUERY );
@@ -76,8 +78,6 @@ TextConversion_ko::TextConversion_ko( const Reference < XComponentContext >& xCo
         maxLeftLength = xCD->getMaxCharCount(ConversionDirection_FROM_LEFT);
         maxRightLength = xCD->getMaxCharCount(ConversionDirection_FROM_RIGHT);
     }
-
-    implementationName = "com.sun.star.i18n.TextConversion_ko";
 }
 
 sal_Int16 SAL_CALL checkScriptType(sal_Unicode c)
@@ -124,16 +124,16 @@ const sal_Unicode* getHanja2HangulData();
 #endif
 
 Sequence< OUString > SAL_CALL
-TextConversion_ko::getCharConversions(const OUString& aText, sal_Int32 nStartPos, sal_Int32 nLength, sal_Bool toHanja)
+TextConversion_ko::getCharConversions(const OUString& aText, sal_Int32 nStartPos, sal_Int32 nLength, bool toHanja)
 {
     sal_Unicode ch;
     Sequence< OUString > output;
 #ifndef DISABLE_DYNLOADING
-    const sal_Unicode* (*getHangul2HanjaData)() = (const sal_Unicode* (*)())getFunctionBySymbol("getHangul2HanjaData");
-    const Hangul_Index* (*getHangul2HanjaIndex)() = (const Hangul_Index* (*)()) getFunctionBySymbol("getHangul2HanjaIndex");
-    sal_Int16 (*getHangul2HanjaIndexCount)() = (sal_Int16 (*)()) getFunctionBySymbol("getHangul2HanjaIndexCount");
-    const sal_uInt16* (*getHanja2HangulIndex)() = (const sal_uInt16* (*)()) getFunctionBySymbol("getHanja2HangulIndex");
-    const sal_Unicode* (*getHanja2HangulData)() = (const sal_Unicode* (*)()) getFunctionBySymbol("getHanja2HangulData");
+    const sal_Unicode* (*getHangul2HanjaData)() = reinterpret_cast<const sal_Unicode* (*)()>(getFunctionBySymbol("getHangul2HanjaData"));
+    const Hangul_Index* (*getHangul2HanjaIndex)() = reinterpret_cast<const Hangul_Index* (*)()>(getFunctionBySymbol("getHangul2HanjaIndex"));
+    sal_Int16 (*getHangul2HanjaIndexCount)() = reinterpret_cast<sal_Int16 (*)()>(getFunctionBySymbol("getHangul2HanjaIndexCount"));
+    const sal_uInt16* (*getHanja2HangulIndex)() = reinterpret_cast<const sal_uInt16* (*)()>(getFunctionBySymbol("getHanja2HangulIndex"));
+    const sal_Unicode* (*getHanja2HangulData)() = reinterpret_cast<const sal_Unicode* (*)()>(getFunctionBySymbol("getHanja2HangulData"));
 #else
 #pragma GCC diagnostic push
 #ifdef __clang__
@@ -167,7 +167,7 @@ TextConversion_ko::getCharConversions(const OUString& aText, sal_Int32 nStartPos
         }
     } else if (! toHanja && getHanja2HangulIndex && getHanja2HangulData)
     {
-        sal_Unicode *newStr = new sal_Unicode[nLength+1];
+        std::unique_ptr<sal_Unicode[]> newStr(new sal_Unicode[nLength+1]);
         sal_Int32 count = 0;
         while (count < nLength)
         {
@@ -184,9 +184,8 @@ TextConversion_ko::getCharConversions(const OUString& aText, sal_Int32 nStartPos
         if (count > 0)
         {
             output.realloc(1);
-            output[0] = OUString(newStr, count);
+            output[0] = OUString(newStr.get(), count);
         }
-        delete[] newStr;
     }
 #if defined(DISABLE_DYNLOADING)
 #pragma GCC diagnostic pop
@@ -219,7 +218,7 @@ static Sequence< OUString >& operator += (Sequence< OUString > &rSeq1, Sequence<
 TextConversionResult SAL_CALL
 TextConversion_ko::getConversions( const OUString& aText, sal_Int32 nStartPos, sal_Int32 nLength,
     const Locale& aLocale, sal_Int16 nConversionType, sal_Int32 nConversionOptions)
-    throw(  RuntimeException, IllegalArgumentException, NoSupportException )
+    throw(  RuntimeException, IllegalArgumentException, NoSupportException, std::exception )
 {
     TextConversionResult result;
     Sequence <OUString> candidates;
@@ -237,7 +236,7 @@ TextConversion_ko::getConversions( const OUString& aText, sal_Int32 nStartPos, s
 
         sal_Int16 scriptType = SCRIPT_OTHERS;
         sal_Int32 len = 1;
-        sal_Bool toHanja = (nConversionType == TextConversionType::TO_HANJA);
+        bool toHanja = (nConversionType == TextConversionType::TO_HANJA);
         // FROM_LEFT:  Hangul -> Hanja
         // FROM_RIGHT: Hanja  -> Hangul
         ConversionDirection eDirection = toHanja ? ConversionDirection_FROM_LEFT : ConversionDirection_FROM_RIGHT;
@@ -275,7 +274,7 @@ TextConversion_ko::getConversions( const OUString& aText, sal_Int32 nStartPos, s
                             // clear reference (when there is no user dictionary) in order
                             // to not always have to catch this exception again
                             // in further calls. (save time)
-                            xCDL = 0;
+                            xCDL = nullptr;
                         }
                         catch (...) {
                             // catch all other exceptions to allow
@@ -309,7 +308,7 @@ TextConversion_ko::getConversions( const OUString& aText, sal_Int32 nStartPos, s
 OUString SAL_CALL
 TextConversion_ko::getConversion( const OUString& aText, sal_Int32 nStartPos, sal_Int32 nLength,
     const Locale& aLocale, sal_Int16 nConversionType, sal_Int32 nConversionOptions)
-    throw(  RuntimeException, IllegalArgumentException, NoSupportException )
+    throw(  RuntimeException, IllegalArgumentException, NoSupportException, std::exception )
 {
     sal_Int32 length = aText.getLength() - nStartPos;
 
@@ -343,7 +342,7 @@ TextConversion_ko::getConversion( const OUString& aText, sal_Int32 nStartPos, sa
 OUString SAL_CALL
 TextConversion_ko::getConversionWithOffset( const OUString& aText, sal_Int32 nStartPos, sal_Int32 nLength,
     const Locale& rLocale, sal_Int16 nConversionType, sal_Int32 nConversionOptions, Sequence<sal_Int32>& offset)
-    throw(  RuntimeException, IllegalArgumentException, NoSupportException )
+    throw(  RuntimeException, IllegalArgumentException, NoSupportException, std::exception )
 {
     offset.realloc(0);
     return getConversion(aText, nStartPos, nLength, rLocale, nConversionType, nConversionOptions);
@@ -351,7 +350,7 @@ TextConversion_ko::getConversionWithOffset( const OUString& aText, sal_Int32 nSt
 
 sal_Bool SAL_CALL
 TextConversion_ko::interactiveConversion( const Locale& /*rLocale*/, sal_Int16 /*nTextConversionType*/, sal_Int32 /*nTextConversionOptions*/ )
-    throw(  RuntimeException, IllegalArgumentException, NoSupportException )
+    throw(  RuntimeException, IllegalArgumentException, NoSupportException, std::exception )
 {
     return sal_True;
 }
