@@ -21,10 +21,9 @@
 #include <idlc/astbasetype.hxx>
 #include <idlc/astinterface.hxx>
 #include <idlc/errorhandler.hxx>
+#include <osl/diagnose.h>
 
 
-using namespace ::rtl;
-
 bool isGlobal(const OString& scopedName)
 {
     return scopedName.isEmpty() || scopedName.startsWith(":");
@@ -43,14 +42,14 @@ AstScope::~AstScope()
 
 AstDeclaration* AstScope::addDeclaration(AstDeclaration* pDecl)
 {
-    AstDeclaration* pDeclaration = NULL;
+    AstDeclaration* pDeclaration = nullptr;
 
-    if ((pDeclaration = lookupForAdd(pDecl)) != NULL)
+    if ((pDeclaration = lookupForAdd(pDecl)) != nullptr)
     {
         if ( pDecl->hasAncestor(pDeclaration) )
         {
-            idlc()->error()->error2(EIDL_REDEF_SCOPE, pDecl, pDeclaration);
-            return NULL;
+            ErrorHandler::error2(EIDL_REDEF_SCOPE, pDecl, pDeclaration);
+            return nullptr;
         }
         if ( (pDecl->getNodeType() == pDeclaration->getNodeType()) &&
              (pDecl->getNodeType() == NT_sequence
@@ -60,7 +59,7 @@ AstDeclaration* AstScope::addDeclaration(AstDeclaration* pDecl)
         }
         if ( (pDeclaration->getNodeType() == NT_interface)
              && (pDecl->getNodeType() == NT_interface)
-             && !((AstInterface*)pDeclaration)->isDefined() )
+             && !(static_cast<AstInterface*>(pDeclaration)->isDefined()) )
         {
             m_declarations.push_back(pDecl);
             return pDecl;
@@ -76,8 +75,8 @@ AstDeclaration* AstScope::addDeclaration(AstDeclaration* pDecl)
             return pDecl;
         }
 
-        idlc()->error()->error2(EIDL_REDEF_SCOPE, scopeAsDecl(this), pDecl);
-        return NULL;
+        ErrorHandler::error2(EIDL_REDEF_SCOPE, scopeAsDecl(this), pDecl);
+        return nullptr;
     }
 
     m_declarations.push_back(pDecl);
@@ -88,12 +87,11 @@ sal_uInt16 AstScope::getNodeCount(NodeType nodeType)
 {
     DeclList::const_iterator iter = getIteratorBegin();
     DeclList::const_iterator end = getIteratorEnd();
-    AstDeclaration* pDecl = NULL;
     sal_uInt16 count = 0;
 
     while ( iter != end )
     {
-        pDecl = *iter;
+        AstDeclaration* pDecl = *iter;
         if ( pDecl->getNodeType() == nodeType )
             count++;
         ++iter;
@@ -103,17 +101,17 @@ sal_uInt16 AstScope::getNodeCount(NodeType nodeType)
 
 AstDeclaration* AstScope::lookupByName(const OString& scopedName)
 {
-    AstDeclaration* pDecl = NULL;
-    AstScope*       pScope = NULL;
+    AstDeclaration* pDecl = nullptr;
+    AstScope*       pScope = nullptr;
     if (scopedName.isEmpty())
-        return NULL;
+        return nullptr;
 
     // If name starts with "::" start look up in global scope
     if ( isGlobal(scopedName) )
     {
         pDecl = scopeAsDecl(this);
         if ( !pDecl )
-            return NULL;
+            return nullptr;
 
         pScope = pDecl->getScope();
         // If this is the global scope ...
@@ -148,7 +146,7 @@ AstDeclaration* AstScope::lookupByName(const OString& scopedName)
             if ( pScope )
                    pDecl = pScope->lookupByName(scopedName);
             else
-                pDecl = NULL;
+                pDecl = nullptr;
 
              // Special case for scope which is an interface. We
              // have to look in the inherited interfaces as well.
@@ -180,14 +178,14 @@ AstDeclaration* AstScope::lookupByName(const OString& scopedName)
         {
             // last try if is not the global scope and the scopeName isn't specify global too
             pDecl = scopeAsDecl(this);
-            if ( pDecl && (pDecl->getLocalName() != "") )
+            if ( pDecl && !pDecl->getLocalName().isEmpty() )
             {
                 pScope = pDecl->getScope();
                 if ( pScope )
                     pDecl = pScope->lookupByName(scopedName);
             } else
             {
-                pDecl = NULL;
+                pDecl = nullptr;
             }
         }
 
@@ -200,29 +198,28 @@ AstDeclaration* AstScope::lookupByNameLocal(const OString& name) const
 {
     DeclList::const_iterator iter(m_declarations.begin());
     DeclList::const_iterator end(m_declarations.end());
-    AstDeclaration* pDecl = NULL;
 
     while ( iter != end )
     {
-        pDecl = *iter;
+        AstDeclaration* pDecl = *iter;
         if ( pDecl->getLocalName() == name )
             return pDecl;
         ++iter;
     }
-    return NULL;
+    return nullptr;
 }
 
 AstDeclaration* AstScope::lookupInInherited(const OString& scopedName) const
 {
-    AstInterface* pInterface = (AstInterface*)this;
+    const AstInterface* pInterface = dynamic_cast<const AstInterface*>(this);
 
     if ( !pInterface )
-        return NULL;
+        return nullptr;
 
     // Can't look in an interface which was not yet defined
     if ( !pInterface->getScope() )
     {
-        idlc()->error()->forwardLookupError(pInterface, scopedName);
+        ErrorHandler::forwardLookupError(pInterface, scopedName);
     }
 
     // OK, loop through inherited interfaces. Stop when you find it
@@ -242,17 +239,17 @@ AstDeclaration* AstScope::lookupInInherited(const OString& scopedName) const
         ++iter;
     }
     // Not found
-    return NULL;
+    return nullptr;
 }
 
 AstDeclaration* AstScope::lookupPrimitiveType(ExprType type)
 {
-    AstDeclaration* pDecl = NULL;
-    AstScope*       pScope = NULL;
+    AstDeclaration* pDecl = nullptr;
+    AstScope*       pScope = nullptr;
     OString         typeName;
     pDecl = scopeAsDecl(this);
     if ( !pDecl )
-        return NULL;
+        return nullptr;
     pScope = pDecl->getScope();
     if ( pScope)
         return pScope->lookupPrimitiveType(type);
@@ -313,19 +310,19 @@ AstDeclaration* AstScope::lookupPrimitiveType(ExprType type)
 
     if ( pDecl && (pDecl->getNodeType() == NT_predefined) )
     {
-        AstBaseType* pBaseType = (AstBaseType*)pDecl;
+        AstBaseType* pBaseType = static_cast<AstBaseType*>(pDecl);
 
         if ( pBaseType->getExprType() == type )
             return pDecl;
     }
 
-    return NULL;
+    return nullptr;
 }
 
 AstDeclaration* AstScope::lookupForAdd(AstDeclaration* pDecl)
 {
     if ( !pDecl )
-        return NULL;
+        return nullptr;
 
     AstDeclaration* pRetDecl = lookupByNameLocal(pDecl->getLocalName());
 
