@@ -24,7 +24,6 @@
 #include <idlc/astservice.hxx>
 #include <idlc/astconstants.hxx>
 #include <idlc/astexception.hxx>
-#include <idlc/astunion.hxx>
 #include <idlc/astenum.hxx>
 #include <idlc/astinterface.hxx>
 #include <idlc/astoperation.hxx>
@@ -39,67 +38,63 @@
 #include <osl/file.hxx>
 #include <osl/thread.h>
 
-using namespace ::rtl;
+#include <algorithm>
 
 AstDeclaration* SAL_CALL scopeAsDecl(AstScope* pScope)
 {
-    if (pScope == NULL) return NULL;
+    if (pScope == nullptr) return nullptr;
 
     switch( pScope->getScopeNodeType() )
     {
         case NT_service:
         case NT_singleton:
-            return (AstService*)(pScope);
+            return static_cast<AstService*>(pScope);
         case NT_module:
         case NT_root:
-            return (AstModule*)(pScope);
+            return static_cast<AstModule*>(pScope);
         case NT_constants:
-            return (AstConstants*)(pScope);
+            return static_cast<AstConstants*>(pScope);
         case NT_interface:
-            return (AstInterface*)(pScope);
+            return static_cast<AstInterface*>(pScope);
         case NT_operation:
-            return (AstOperation*)(pScope);
+            return static_cast<AstOperation*>(pScope);
         case NT_exception:
-            return (AstException*)(pScope);
-        case NT_union:
-            return (AstUnion*)(pScope);
+            return static_cast<AstException*>(pScope);
         case NT_struct:
-            return (AstStruct*)(pScope);
+            return static_cast<AstStruct*>(pScope);
         case NT_enum:
-            return (AstEnum*)(pScope);
+            return static_cast<AstEnum*>(pScope);
         default:
-            return NULL;
+            return nullptr;
     }
 }
 
 AstScope* SAL_CALL declAsScope(AstDeclaration* pDecl)
 {
-    if (pDecl == NULL) return NULL;
+    if (pDecl == nullptr) return nullptr;
 
     switch(pDecl->getNodeType())
     {
         case NT_interface:
-            return (AstInterface*)(pDecl);
+            return static_cast<AstInterface*>(pDecl);
         case NT_service:
         case NT_singleton:
-            return (AstService*)(pDecl);
+            return static_cast<AstService*>(pDecl);
         case NT_module:
         case NT_root:
-            return (AstModule*)(pDecl);
+            return static_cast<AstModule*>(pDecl);
         case NT_constants:
-            return (AstConstants*)(pDecl);
+            return static_cast<AstConstants*>(pDecl);
         case NT_exception:
-            return (AstException*)(pDecl);
-        case NT_union:
-            return (AstUnion*)(pDecl);
+            return static_cast<AstException*>(pDecl);
         case NT_struct:
-            return (AstStruct*)(pDecl);
+            return static_cast<AstStruct*>(pDecl);
         case NT_enum:
-            return (AstEnum*)(pDecl);
+            return static_cast<AstEnum*>(pDecl);
         case NT_operation:
-            return (AstOperation*)(pDecl);
+            return static_cast<AstOperation*>(pDecl);
         default:
-            return NULL;
+            return nullptr;
    }
 }
 
@@ -125,28 +120,28 @@ static void SAL_CALL predefineXInterface(AstModule* pRoot)
     pParentScope = pModule;
 
     // define XInterface
-    AstInterface* pInterface = new AstInterface(OString("XInterface"), NULL, pParentScope);
+    AstInterface* pInterface = new AstInterface(OString("XInterface"), nullptr, pParentScope);
     pInterface->setDefined();
     pInterface->setPredefined(true);
     pInterface->setPublished();
     pParentScope->addDeclaration(pInterface);
 
     // define XInterface::queryInterface
-    AstOperation* pOp = new AstOperation((AstType*)(pRoot->lookupPrimitiveType(ET_any)),
+    AstOperation* pOp = new AstOperation(static_cast<AstType*>(pRoot->lookupPrimitiveType(ET_any)),
                                          OString("queryInterface"), pInterface);
     AstParameter* pParam = new AstParameter(DIR_IN, false,
-                                            (AstType*)(pRoot->lookupPrimitiveType(ET_type)),
+                                            static_cast<AstType*>(pRoot->lookupPrimitiveType(ET_type)),
                                             OString("aType"), pOp);
     pOp->addDeclaration(pParam);
     pInterface->addMember(pOp);
 
     // define XInterface::acquire
-    pOp = new AstOperation((AstType*)(pRoot->lookupPrimitiveType(ET_void)),
+    pOp = new AstOperation(static_cast<AstType*>(pRoot->lookupPrimitiveType(ET_void)),
                            OString("acquire"), pInterface);
     pInterface->addMember(pOp);
 
     // define XInterface::release
-    pOp = new AstOperation((AstType*)(pRoot->lookupPrimitiveType(ET_void)),
+    pOp = new AstOperation(static_cast<AstType*>(pRoot->lookupPrimitiveType(ET_void)),
                            OString("release"), pInterface);
     pInterface->addMember(pOp);
 }
@@ -204,8 +199,8 @@ static void SAL_CALL initializePredefinedTypes(AstModule* pRoot)
 
 Idlc::Idlc(Options* pOptions)
     : m_pOptions(pOptions)
-    , m_bIsDocValid(sal_False)
-    , m_bIsInMainfile(sal_True)
+    , m_bIsDocValid(false)
+    , m_bIsInMainfile(true)
     , m_published(false)
     , m_errorCount(0)
     , m_warningCount(0)
@@ -216,27 +211,22 @@ Idlc::Idlc(Options* pOptions)
 {
     m_pScopes = new AstStack();
     // init root object after construction
-    m_pRoot = NULL;
+    m_pRoot = nullptr;
     m_pErrorHandler = new ErrorHandler();
     m_bGenerateDoc = m_pOptions->isValid("-C");
 }
 
 Idlc::~Idlc()
 {
-    if (m_pRoot)
-        delete m_pRoot;
-    if (m_pScopes)
-        delete m_pScopes;
-    if (m_pErrorHandler)
-        delete m_pErrorHandler;
+    delete m_pRoot;
+    delete m_pScopes;
+    delete m_pErrorHandler;
 }
 
 void Idlc::init()
 {
-    if ( m_pRoot )
-        delete m_pRoot;
-
-    m_pRoot = new AstModule(NT_root, OString(), NULL);
+    delete m_pRoot;
+    m_pRoot = new AstModule(NT_root, OString(), nullptr);
 
     // push the root node on the stack
     m_pScopes->push(m_pRoot);
@@ -246,8 +236,8 @@ void Idlc::init()
 
 void Idlc::reset()
 {
-    m_bIsDocValid = sal_False;
-    m_bIsInMainfile = sal_True;
+    m_bIsDocValid = false;
+    m_bIsInMainfile = true;
     m_published = false;
 
     m_errorCount = 0;
@@ -255,16 +245,15 @@ void Idlc::reset()
     m_lineNumber = 0;
     m_parseState = PS_NoState;
 
-    m_fileName = OString();
-    m_mainFileName = OString();
-    m_realFileName = OString();
-    m_documentation = OString();
+    m_fileName.clear();
+    m_mainFileName.clear();
+    m_realFileName.clear();
+    m_documentation.clear();
 
     m_pScopes->clear();
-    if ( m_pRoot)
-        delete m_pRoot;
+    delete m_pRoot;
 
-    m_pRoot = new AstModule(NT_root, OString(), NULL);
+    m_pRoot = new AstModule(NT_root, OString(), nullptr);
 
     // push the root node on the stack
     m_pScopes->push(m_pRoot);
@@ -359,7 +348,7 @@ Idlc::dumpDeps(OString const& rDepFile, OString const& rTarget)
     return ::osl::FileBase::E_None == rc;
 }
 
-static Idlc* pStaticIdlc = NULL;
+static Idlc* pStaticIdlc = nullptr;
 
 Idlc* SAL_CALL idlc()
 {
@@ -368,17 +357,14 @@ Idlc* SAL_CALL idlc()
 
 Idlc* SAL_CALL setIdlc(Options* pOptions)
 {
-    if ( pStaticIdlc )
-    {
-        delete pStaticIdlc;
-    }
+    delete pStaticIdlc;
     pStaticIdlc = new Idlc(pOptions);
     pStaticIdlc->init();
     return pStaticIdlc;
 }
 
 AstDeclaration const * resolveTypedefs(AstDeclaration const * type) {
-    if (type != 0) {
+    if (type != nullptr) {
         while (type->getNodeType() == NT_typedef) {
             type = static_cast< AstTypeDef const * >(type)->getBaseType();
         }
@@ -391,8 +377,8 @@ AstDeclaration const * deconstructAndResolveTypedefs(
 {
     *rank = 0;
     for (;;) {
-        if (type == 0) {
-            return 0;
+        if (type == nullptr) {
+            return nullptr;
         }
         switch (type->getNodeType()) {
         case NT_typedef:
