@@ -46,7 +46,7 @@ extern "C" {
     about these JREs as well as starting the VMs.</dd>
     <dt>UNO_JAVA_JFW_USER_DATA</dt>
     <dd>The file contains settings for a particular user. One can use the macro
-    $SYSUSERCONFIG in the URL which expands to a directory whery the user's data are
+    $SYSUSERCONFIG in the URL which expands to a directory where the user's data are
     kept. On UNIX this would be the home directory and on Windows some sub-directory
     of the &quot;Documents and Settings&quot; folder.The content of this file is an
     implementation detail and may change in the future.</dd>
@@ -72,12 +72,12 @@ extern "C" {
     necessary to specify the bootstrap parameter <code>UNO_JAVA_JFW_SHARED_DATA</code>.
     </p>
 
-    <p>Setting the class path used by a Java VM should not be necesarry. The locations
+    <p>Setting the class path used by a Java VM should not be necessary. The locations
     of Jar files should be known by a class loader. If a jar file depends on another
     jar file then it can be referenced in the manifest file of the first jar. However,
     a user may add jars to the class path by using this API. If it becomes necessary
     to add files to the class path which is to be used by all users then one can use
-    the bootrap parameter UNO_JAVA_JFW_CLASSPATH_URLS. The value contains of file URLs
+    the bootstrap parameter UNO_JAVA_JFW_CLASSPATH_URLS. The value contains of file URLs
     which must be separated by spaces.</p>
 
 
@@ -104,7 +104,7 @@ extern "C" {
     <p>
     regcomp -env:UNO_JAVA_JFW_JREHOME=file:///d:/j2re1.4.2
     -env:&quot;UNO_JAVA_JFW_CLASSPATH=d:\\solver\\bin\\classes.jar;d:\\solver\\bin\\jurt.jar&quot;
-    -env:UNO_JAVA_JFW_PLUGIN=file:\\solver\\bin\\libsunjavaplugin.dll -register ....
+    -register ....
     </p>
     <p>Additionall parameters for the Java VM can be provided. For every parameter
     a separate bootstrap parameter must be specified. The names are
@@ -137,10 +137,6 @@ extern "C" {
     environment variable CLASSPATH. If this variable and UNO_JAVA_JFW_CLASSPATH are
     set then the class path is composed from UNO_JAVA_JFW_CLASSPATH and the environment
     variable CLASSPATH.</dd>
-    <dt>UNO_JAVA_JFW_PLUGIN</dt>
-    <dd>Specified a file URL to a plugin library. If this variable is provided
-    then a javavendors.xml is ignored. It must be provided if no
-    javavendors.xml is available.</dd>
     <dt>UNO_JAVA_JFW_PARAMETER_X</dt>
     <dd>Specifies a parameter for the Java VM. The X is replaced by
     non-negative natural numbers starting with 1.</dd>
@@ -167,7 +163,7 @@ extern "C" {
     <dd>This is a unofficial variable which was introduced to workaround external issues.
     It may be removed in the future. By setting it to 1, the framework will not try to
     find out if the system is configured to use accessibility tools or if a JRE has an
-    accessibiliy bridge installed</dd>
+    accessible bridge installed</dd>
     <dt>JFW_PLUGIN_FORCE_ACCESSIBILITY</dt>
     <dd>This is a unofficial variable which was introduced to workaround external issues.
     It may be removed in the future. By setting it to 1, the framework will override a
@@ -201,7 +197,6 @@ typedef enum _javaFrameworkError
     JFW_E_NEED_RESTART,
     JFW_E_RUNNING_JVM,
     JFW_E_JAVA_DISABLED,
-    JFW_E_NO_PLUGIN,
     JFW_E_NOT_RECOGNIZED,
     JFW_E_FAILED_VERSION,
     JFW_E_NO_JAVA_FOUND,
@@ -284,7 +279,7 @@ JVMFWK_DLLPUBLIC void SAL_CALL jfw_freeJavaInfo(JavaInfo *pInfo);
    <code>rtl_uString</code> members is determined
    by the respective comparison function (see
    <code>OUString::equals</code>).
-   Similiarly the equality of the <code>sal_Sequence</code> is
+   Similarly the equality of the <code>sal_Sequence</code> is
    also determined by a comparison
    function (see <code>rtl::ByteSequence::operator ==</code>). </p>
    <p>
@@ -303,7 +298,7 @@ JVMFWK_DLLPUBLIC sal_Bool SAL_CALL jfw_areEqualJavaInfo(
 /** determines if a Java Virtual Machine is already running.
 
     <p>As long as the office and the JREs only support one
-    Virtual Machine per process the Java settings, particulary the
+    Virtual Machine per process the Java settings, particularly the
     selected Java, are not effective immediately after changing when
     a VM has already been running. That is, if a JRE A was used to start
     a VM and then a JRE B is selected, then JRE B will only be used
@@ -325,19 +320,14 @@ JVMFWK_DLLPUBLIC javaFrameworkError SAL_CALL jfw_isVMRunning(sal_Bool *bRunning)
 /** detects a suitable JRE and configures the framework to use it.
 
     <p>Which JREs can be used is determined by the file javavendors.xml,
-    which contains version requirements, as well as information about available
-    plug-in libraries. Only these libraries are responsible for locating JRE
-    installations.</p>
+    which contains version requirements.</p>
     <p>
-    JREs can be provided by different vendors. In order to find the JREs of
-    a certain vendor a plug-in library must be provided. There must be only one
-    library for one vendor. The names of locations of those libraries have to
-    be put into the javavendors.xml file.<br/>
-    The function uses the plug-in libraries to obtain information about JRE
-    installation and checks if they there is one among them that supports
+    JREs can be provided by different vendors.
+    The function obtains information about JRE installations and checks if
+    there is one among them that supports
     a set of features (currently only accessibilty is possible). If none was
     found then it also uses a list of paths, which have been registered
-    by <code>jfw_addJRELocation</code> or <code>jfw_setJRELocations</code>
+    by <code>jfw_addJRELocation</code>
     to find JREs. Found JREs are examined in the same way.</p>
     <p>
     A JRE installation is only selected if it meets the version requirements.
@@ -347,27 +337,36 @@ JVMFWK_DLLPUBLIC javaFrameworkError SAL_CALL jfw_isVMRunning(sal_Bool *bRunning)
     <p>
     While determining a proper JRE this function takes into account if a
     user requires support for assistive technology tools. If user
-    need that support they have to set up their system accordingly. When support
-    for assistive technology is required, then the lists of
+    need that support they have to set up their system accordingly.</p>
+    <p>
+    If the JAVA_HOME environment variable is set, this function prefers
+    the JRE which the variable refers to over other JREs.
+    If JAVA_HOME is not set or does not refer to a suitable JRE,
+    the PATH environment variable is inspected and the respective JREs
+    are checked for their suitability next.</p>
+    <p>
+    When support for assistive technology is required, then the
     <code>JavaInfo</code> objects,
-    which are provided by the <code>getJavaInfo</code> functions of the plug-ins, are
-    examined for a suitable JRE. That is, the <code>JavaInfo</code> objects
-    from the list
-    obtained from the first plug-in, are examined. If no <code>JavaInfo</code>
-    object has the flag
+    which are provided by the <code>getJavaInfo</code> functions, are
+    examined for a suitable JRE.
+    That is, the <code>JavaInfo</code> object that refers to the JRE referred to
+    by JAVA_HOME is examined. If it does not have the flag
     <code>JFW_FEATURE_ACCESSBRIDGE</code> in the member <code>nFeatures</code>
-    then the
-    next plug-in is used to obtain a list of <code>JavaInfo</code> objects.
+    then the <JavaInfo></code> objects that are related to the PATH variable
+    are examined.
+    If no suitable <code>JavaInfo</code> object is found, all <code>JavaInfo</code>
+    objects - representing Java installations on the system -, are examined.
+    As long as no <code>JavaInfo</code> object has the flag
+    <code>JFW_FEATURE_ACCESSBRIDGE</code> in the member <code>nFeatures</code>, more
+    <code>JavaInfo</code> objects are examined.
     This goes on until a <code>JavaInfo</code> object was found which
-    represents a suitable JRE. Or neither plug-in provided such a
-    <code>JavaInfo</code> object. In that case the first
-    <code>JavaInfo</code> object from the first plug-in is used to determine
-    the JRE which is to be used.</p>
+    represents a suitable JRE. Or no such <code>JavaInfo</code> object was found.
+    In that case the first <code>JavaInfo</code> object that was detected
+    by the algorithm described above is used to determine the JRE which is to be used.</p>
     <p>
     If there is no need for the support of assistive technology tools then
-    the first <code>JavaInfo</code> object from the list obtained by the
-    first plug-in is used. If this plug-in does not find any JREs then the
-    next plug-in is used, and so on.</p>
+    the first <code>JavaInfo</code> object that is detected by the algorithm
+    as described above is used.</p>
 
     @param ppInfo
     [out] a <code>JavaInfo</code> pointer, representing the selected JRE.
@@ -380,7 +379,6 @@ JVMFWK_DLLPUBLIC javaFrameworkError SAL_CALL jfw_isVMRunning(sal_Bool *bRunning)
     @return
     JFW_E_NONE function ran successfully.<br/>
     JFW_E_ERROR an error occurred. <br/>
-    JFW_E_NO_PLUGIN a plug-in library could not be found.<br/>
     JFW_E_NO_JAVA_FOUND no JRE was found that meets the requirements.</br>
     JFW_E_DIRECT_MODE the function cannot be used in this mode. </br>
     JFW_E_CONFIGURATION mode was not properly set or their prerequisites
@@ -388,13 +386,13 @@ JVMFWK_DLLPUBLIC javaFrameworkError SAL_CALL jfw_isVMRunning(sal_Bool *bRunning)
  */
 JVMFWK_DLLPUBLIC javaFrameworkError SAL_CALL jfw_findAndSelectJRE(JavaInfo **pInfo);
 
-/** provides information about all availabe JRE installations.
+/** provides information about all available JRE installations.
 
     <p>The function determines dynamically what JREs are available. It uses
     the plug-in libraries to provide lists of available <code>JavaInfo</code>
     objects where each object represents a JRE (see vendorplugin.h,
     getAllJavaInfos). It also uses a list of paths, which have been registered
-    by <code>jfw_addJRELocation</code> or <code>jfw_setJRELocations</code>.
+    by <code>jfw_addJRELocation</code>.
     It is checked if the path still contains a valid JRE and if so the respective
     <code>JavaInfo</code> object will be appended to the array unless there is
     already an equal object.</p>
@@ -411,7 +409,6 @@ JVMFWK_DLLPUBLIC javaFrameworkError SAL_CALL jfw_findAndSelectJRE(JavaInfo **pIn
     JFW_E_NONE function ran successfully.<br/>
     JFW_E_INVALID_ARG at least on of the parameters was NULL<br/>
     JFW_E_ERROR an error occurred. <br/>
-    JFW_E_NO_PLUGIN a plug-in library could not be found.<br/>
     JFW_E_CONFIGURATION mode was not properly set or their prerequisites
     were not met.
 */
@@ -443,7 +440,6 @@ JVMFWK_DLLPUBLIC javaFrameworkError SAL_CALL jfw_findAllJREs(
    JFW_E_ERROR an error occurred. <br/>
    JFW_E_CONFIGURATION mode was not properly set or their prerequisites
    were not met.</br>
-   JFW_E_NO_PLUGIN a plug-in library could not be found.<br/>
    JFW_E_NOT_RECOGNIZED neither plug-in library could detect a JRE. <br/>
    JFW_E_FAILED_VERSION a JRE was detected but if failed the version
    requirements as determined by the javavendors.xml
@@ -500,8 +496,6 @@ JVMFWK_DLLPUBLIC javaFrameworkError SAL_CALL jfw_getJavaInfoByPath(
     JFW_E_ERROR an error occurred. <br/>
     JFW_E_CONFIGURATION mode was not properly set or their prerequisites
     were not met.</br>
-    JFW_E_NO_PLUGIN the plug-in library responsible for creating the VM
-    could not be found.<br/>
     JFW_E_JAVA_DISABLED the use of Java is currently disabled. <br/>
     JFW_E_NO_SELECT there is no JRE selected yet. <br/>
     JFW_E_RUNNIN_JVM there is already a VM running.<br/>
@@ -729,62 +723,9 @@ JVMFWK_DLLPUBLIC javaFrameworkError SAL_CALL jfw_getUserClassPath(rtl_uString **
     JFW_E_CONFIGURATION mode was not properly set or their prerequisites
     were not met.<br/>
     JFW_E_DIRECT_MODE the function cannot be used in this mode.
-    @see jfw_setJRELocations
  */
 JVMFWK_DLLPUBLIC javaFrameworkError SAL_CALL jfw_addJRELocation(rtl_uString * sLocation);
 
-/** saves the locations of a number of JREs.
-
-    <p>
-    The function does not verify if the paths points to JRE. However,
-    it makes sure that every path is unique. That is, if the array
-    contains strings which are the same then only one is stored.</p>
-    <p>
-    If <code>arLocations</code> is NULL or it has the length null (nSize = 0)
-    then all previously stored paths are deleted. Otherwise,
-    the old values are overwritten.</p>
-
-    @param arLocations
-    [in] array of paths to locations of JREs.
-
-    @param nSize
-    [in] the size of the array <code>arLocations</code>
-
-    @return
-    JFW_E_NONE function ran successfully.<br/>
-    JFW_E_INVALIDARG arLocation is NULL and nSize is not null.<br/>
-    JFW_E_ERROR An error occurred.<br/>
-    JFW_E_CONFIGURATION mode was not properly set or their prerequisites
-    were not met.<br/>
-    JFW_E_DIRECT_MODE the function cannot be used in this mode.
-    @see jfw_addJRELocations
- */
-JVMFWK_DLLPUBLIC javaFrameworkError SAL_CALL jfw_setJRELocations(
-    rtl_uString ** arLocations, sal_Int32 nSize);
-/** obtains an array containing paths to JRE installations.
-
-    <p>
-    It is not guaranteed that the returned paths represent
-    a valid JRE. One can use <code>jfw_getJavaInfoByPath</code> to check this.
-    </p>
-
-    @param parLocations
-    [out] on return it contains the array of paths.
-    @param pSize
-    [out] on return it contains the size of the array <code>parLocations</code>.
-
-    @return
-    JFW_E_NONE function ran successfully.<br/>
-    JFW_E_INVALIDARG parLocation is NULL or pSize is NULL.<br/>
-    JFW_E_ERROR An error occurred.<br/>
-    JFW_E_CONFIGURATION mode was not properly set or their prerequisites
-    were not met.<br/>
-    JFW_E_DIRECT_MODE the function cannot be used in this mode.
- */
-JVMFWK_DLLPUBLIC javaFrameworkError SAL_CALL jfw_getJRELocations(
-    rtl_uString *** parLocations, sal_Int32 * pSize);
-
-
 /** checks if the installation of the jre still exists.
 
     This function checks if the JRE described by pInfo still
@@ -801,7 +742,6 @@ JVMFWK_DLLPUBLIC javaFrameworkError SAL_CALL jfw_getJRELocations(
     JFW_E_NONE the function ran successfully.</br>
     JFW_E_ERROR an error occurred during execution.</br>
     JFW_E_INVALID_ARG pInfo contains invalid data</br>
-    JFW_E_NO_PLUGIN a plug-in library could not be found.<br/>
  */
 JVMFWK_DLLPUBLIC javaFrameworkError SAL_CALL jfw_existJRE(const JavaInfo *pInfo, sal_Bool *exist);
 
