@@ -17,10 +17,11 @@
  */
 
 package com.sun.star.lib.uno.helper;
+
 import java.util.Iterator;
 import java.util.ListIterator;
-import java.util.NoSuchElementException;
 import java.util.Collection;
+
 import com.sun.star.lang.EventObject;
 import com.sun.star.lang.XEventListener;
 import com.sun.star.uno.UnoRuntime;
@@ -39,7 +40,7 @@ import com.sun.star.uno.UnoRuntime;
  * All methods are thread-safe. The same holds true for
  * iterators, issued by this class. Several iterators can exist at the same time and can also
  * be modified (java.util.ListIterator.add, java.util.ListIterator.remove etc.). To make this work,
- * the InterfaceContainer provides the iterators with copys of the list's data.
+ * the InterfaceContainer provides the iterators with copies of the list's data.
  * The add and remove calls on the iterator modify the data in the iterator's list as well as
  * in InterfaceContainer. Modification on InterfaceContainer, however, are not
  * synchronized with existing iterators. For example
@@ -72,7 +73,7 @@ import com.sun.star.uno.UnoRuntime;
  *  is removed.
  *  ListIterator.set is not supported.
  *
- * A lot of  methods resemble those of the  to java.util.List interface, allthough
+ * A lot of  methods resemble those of the  to java.util.List interface, although
  * this class does not implement it. However, the list iterators returned, for example by
  * the listIterator method implement the java.util.ListIterator interface.
  * Implementing the List interface would mean to support all none - optional methods as
@@ -81,13 +82,13 @@ import com.sun.star.uno.UnoRuntime;
  * list have to cause changes in the main list. This is a problem, since this class is to be
  * used in a multi-threaded environment. The sub list could work on a copy as the iterators
  * do, but all the functions which work on an given index could not be properly supported.
- * Unfortunatly, the List interface documentation states that all optional methods implemented
+ * Unfortunately, the List interface documentation states that all optional methods implemented
  * by the list have to be implemented in the sub list. That would mean to do without all those
- * critical methods, allthough they might work well in the "main list" (as opposed to sub list).
+ * critical methods, although they might work well in the "main list" (as opposed to sub list).
  */
 public class InterfaceContainer implements Cloneable
 {
-    final boolean DEBUG= false;
+    static final boolean DEBUG= false;
     /**
      * The array buffer into which the elements of the ArrayList are stored.
      * The capacity of the ArrayList is the length of this array buffer.
@@ -100,7 +101,6 @@ public class InterfaceContainer implements Cloneable
     private int size;
 
 
-    //private ArrayList data= new ArrayList();
     /** Creates a new instance of InterfaceContainer */
     public InterfaceContainer()
     {
@@ -315,7 +315,7 @@ public class InterfaceContainer implements Cloneable
             while (it.hasNext())
             {
                 Object obj= it.next();
-                if (false == contains(obj))
+                if (!contains(obj))
                 {
                     retVal= false;
                     break;
@@ -353,29 +353,31 @@ public class InterfaceContainer implements Cloneable
      */
     synchronized public int indexOf(Object elem)
     {
+        if (elementData == null || elem == null) {
+            return -1;
+        }
+
         int index= -1;
-        if (elementData != null && elem != null)
+
+        for (int i = 0; i < size; i++)
+        {
+            if (elem == elementData[i])
+            {
+                index= i;
+                break;
+            }
+        }
+
+        if (index == -1)
         {
             for (int i = 0; i < size; i++)
             {
-                if (elem == elementData[i])
+                if (UnoRuntime.areSame(elem, elementData[i]))
                 {
                     index= i;
                     break;
                 }
             }
-
-            if (index == -1)
-            {
-                for (int i = 0; i < size; i++)
-                {
-                    if (UnoRuntime.areSame(elem, elementData[i]))
-                    {
-                        index= i;
-                        break;
-                    }
-                }
-            }
         }
         return index;
     }
@@ -409,28 +411,30 @@ public class InterfaceContainer implements Cloneable
      */
     synchronized public int lastIndexOf(Object elem)
     {
+        if (elementData == null || elem == null) {
+            return -1;
+        }
+
         int index= -1;
-        if (elementData != null && elem != null)
+
+        for (int i = size-1; i >= 0; i--)
+        {
+            if (elem == elementData[i])
+            {
+                index= i;
+                break;
+            }
+        }
+        if (index == -1)
         {
             for (int i = size-1; i >= 0; i--)
             {
-                if (elem == elementData[i])
+                if (UnoRuntime.areSame(elem, elementData[i]))
                 {
                     index= i;
                     break;
                 }
             }
-            if (index == -1)
-            {
-                for (int i = size-1; i >= 0; i--)
-                {
-                    if (UnoRuntime.areSame(elem, elementData[i]))
-                    {
-                        index= i;
-                        break;
-                    }
-                }
-            }
         }
         return index;
     }
@@ -441,6 +445,7 @@ public class InterfaceContainer implements Cloneable
      *
      * @return  a clone of this <tt>List</tt> instance.
      */
+    @Override
     synchronized public Object clone()
     {
         Object ret= null;
@@ -460,7 +465,7 @@ public class InterfaceContainer implements Cloneable
     }
 
     /** The iterator keeps a copy of the list. Changes to InterfaceContainer do not
-     *  affect the data of the iterator. Conversly, changes to the iterator are effect
+     *  affect the data of the iterator. Conversely, changes to the iterator are effect
      *  InterfaceContainer.
      */
     synchronized public ListIterator listIterator(int index)
@@ -535,52 +540,50 @@ public class InterfaceContainer implements Cloneable
 
     synchronized public boolean retainAll(Collection collection)
     {
+        if (elementData == null || collection == null) {
+            return false;
+        }
+
         boolean retVal= false;
-        if (elementData != null && collection != null)
+        // iterate over data
+        Object[] arRetained= new Object[size];
+        int indexRetained= 0;
+        for(int i= 0; i < size; i++)
         {
-            // iterate over data
-            Object[] arRetained= new Object[size];
-            int indexRetained= 0;
-            for(int i= 0; i < size; i++)
+            Object curElem= elementData[i];
+            // try to find the element in collection
+            Iterator itColl= collection.iterator();
+            boolean bExists= false;
+            while (itColl.hasNext())
             {
-                Object curElem= elementData[i];
-                // try to find the element in collection
-                Iterator itColl= collection.iterator();
-                boolean bExists= false;
+                if (curElem == itColl.next())
+                {
+                    // current element is in collection
+                    bExists= true;
+                    break;
+                }
+            }
+            if (!bExists)
+            {
+                itColl= collection.iterator();
                 while (itColl.hasNext())
                 {
-                    if (curElem == itColl.next())
+                    Object o= itColl.next();
+                    if (o != null && UnoRuntime.areSame(o, curElem))
                     {
-                        // current element is in collection
                         bExists= true;
                         break;
                     }
                 }
-                if (bExists == false)
-                {
-                    itColl= collection.iterator();
-                    while (itColl.hasNext())
-                    {
-                        Object o= itColl.next();
-                        if (o != null)
-                        {
-                            if (UnoRuntime.areSame(o, curElem))
-                            {
-                                bExists= true;
-                                break;
-                            }
-                        }
-                    }
-                }
-                if (bExists == true)
-                    arRetained[indexRetained++]= curElem;
-            }
-            retVal= size != indexRetained;
-            if (indexRetained > 0)
-            {
-                elementData= arRetained;
-                size= indexRetained;
             }
+            if (bExists)
+                arRetained[indexRetained++]= curElem;
+        }
+        retVal= size != indexRetained;
+        if (indexRetained > 0)
+        {
+            elementData= arRetained;
+            size= indexRetained;
         }
         return retVal;
     }
@@ -757,7 +760,9 @@ public class InterfaceContainer implements Cloneable
             }
             catch(java.lang.IndexOutOfBoundsException e)
             {
-                throw new java.util.NoSuchElementException();
+                java.util.NoSuchElementException ex2 = new java.util.NoSuchElementException();
+                ex2.initCause(e);
+                throw ex2;
             }
         }
 
@@ -823,7 +828,9 @@ public class InterfaceContainer implements Cloneable
                 return previous;
             } catch(IndexOutOfBoundsException e)
             {
-                throw new NoSuchElementException();
+                java.util.NoSuchElementException ex2 = new java.util.NoSuchElementException();
+                ex2.initCause(e);
+                throw ex2;
             }
         }
 
