@@ -67,6 +67,7 @@
 
 #include <osl/file.h>
 #include <osl/file.hxx>
+#include <tools/stream.hxx>
 #include <vcl/svapp.hxx>
 #include <xmloff/attrlist.hxx>
 #include <com/sun/star/io/IOException.hpp>
@@ -79,7 +80,7 @@
 
 #include <sfx2/docfile.hxx>
 
-#include <boost/scoped_ptr.hpp>
+#include <memory>
 
 using namespace ::cppu;
 using namespace ::com::sun::star::lang;
@@ -109,13 +110,13 @@ using namespace OpenStormBento;
     pCompressed->Read(buffer, 16);
     aDecompressed->Write(buffer, 16);
 
-    boost::scoped_ptr<LwpSvStream> aLwpStream(new LwpSvStream(pCompressed));
+    std::unique_ptr<LwpSvStream> aLwpStream(new LwpSvStream(pCompressed));
     LtcBenContainer* pBentoContainer;
     sal_uLong ulRet = BenOpenContainer(aLwpStream.get(), &pBentoContainer);
     if (ulRet != BenErr_OK)
         return false;
 
-    boost::scoped_ptr<LtcUtBenValueStream> aWordProData(pBentoContainer->FindValueStreamWithPropertyName("WordProData"));
+    std::unique_ptr<LtcUtBenValueStream> aWordProData(pBentoContainer->FindValueStreamWithPropertyName("WordProData"));
 
     if (!aWordProData.get())
         return false;
@@ -146,24 +147,24 @@ using namespace OpenStormBento;
  */
  bool GetLwpSvStream(SvStream *pStream, LwpSvStream * & pLwpSvStream)
 {
-    SvStream * pDecompressed = NULL;
+    SvStream * pDecompressed = nullptr;
 
-    sal_uInt32 nTag;
     pStream->Seek(0x10);
+    sal_uInt32 nTag(0);
     pStream->ReadUInt32( nTag );
     if (nTag != 0x3750574c) // "LWP7"
     {
         // small file, needs decompression
         if (!Decompress(pStream, pDecompressed))
         {
-            pLwpSvStream = NULL;
+            pLwpSvStream = nullptr;
             return true;
         }
         pStream->Seek(0);
         pDecompressed->Seek(0);
     }
 
-    pLwpSvStream = NULL;
+    pLwpSvStream = nullptr;
     bool bCompressed = false;
     if (pDecompressed)
     {
@@ -181,10 +182,10 @@ int ReadWordproFile(SvStream &rStream, uno::Reference<css::xml::sax::XDocumentHa
 {
     try
     {
-        LwpSvStream *pRawLwpSvStream = NULL;
-        boost::scoped_ptr<LwpSvStream> aLwpSvStream;
-        boost::scoped_ptr<LwpSvStream> aCompressedLwpSvStream;
-        boost::scoped_ptr<SvStream> aDecompressed;
+        LwpSvStream *pRawLwpSvStream = nullptr;
+        std::unique_ptr<LwpSvStream> aLwpSvStream;
+        std::unique_ptr<LwpSvStream> aCompressedLwpSvStream;
+        std::unique_ptr<SvStream> aDecompressed;
         if (GetLwpSvStream(&rStream, pRawLwpSvStream) && pRawLwpSvStream)
         {
             SvStream *pDecompressed = pRawLwpSvStream->GetStream();
@@ -203,7 +204,7 @@ int ReadWordproFile(SvStream &rStream, uno::Reference<css::xml::sax::XDocumentHa
 
         aLwpSvStream.reset(pRawLwpSvStream);
 
-        boost::scoped_ptr<IXFStream> pStrm(new XFSaxStream(xHandler));
+        std::unique_ptr<IXFStream> pStrm(new XFSaxStream(xHandler));
         Lwp9Reader reader(aLwpSvStream.get(), pStrm.get());
         //Reset all static objects,because this function may be called many times.
         XFGlobalReset();
