@@ -57,10 +57,7 @@
  * @file
  *  For LWP filter architecture prototype
  ************************************************************************/
-/*************************************************************************
- * Change History
- Jan 2005           Created
- ************************************************************************/
+
 #include "lwpglobalmgr.hxx"
 #include "lwpfribtext.hxx"
 #include "lwpcharsetmgr.hxx"
@@ -98,7 +95,7 @@ void LwpFribText::Read(LwpObjectStream* pObjStrm, sal_uInt16 len)
                 rEncode = LwpCharSetMgr::GetInstance()->
                                               GetTextCharEncoding(m_pModifiers->CodePage);
             else
-                rEncode = LwpCharSetMgr::GetInstance()->GetTextCharEncoding();
+                rEncode = LwpCharSetMgr::GetTextCharEncoding();
         }
         LwpTools::QuickReadUnicode(pObjStrm, m_Content, len, rEncode);
     }
@@ -143,7 +140,7 @@ LwpFribDocVar::~LwpFribDocVar()
     if (m_pName)
     {
         delete m_pName;
-        m_pName = NULL;
+        m_pName = nullptr;
     }
 }
 /**
@@ -159,8 +156,6 @@ void LwpFribDocVar::Read(LwpObjectStream* pObjStrm, sal_uInt16 /*len*/)
 
 /**
  * @short:   register style for doc field (text style,date style)
- * @param:
- * @param:
  */
 void LwpFribDocVar::RegisterStyle(LwpFoundry* pFoundry)
 {
@@ -171,7 +166,6 @@ void LwpFribDocVar::RegisterStyle(LwpFoundry* pFoundry)
     case DATECREATED:
     case DATELASTREVISION:
     {
-//      m_TimeStyle = LwpTools::RegisterDefaultTimeStyle();
         RegisterDefaultTimeStyle();
     }
         break;
@@ -185,8 +179,6 @@ void LwpFribDocVar::RegisterStyle(LwpFoundry* pFoundry)
 
 /**
  * @short:   register default time style for doc field
- * @param:
- * @param:
  */
 void LwpFribDocVar::RegisterDefaultTimeStyle()
 {
@@ -205,7 +197,7 @@ void LwpFribDocVar::RegisterDefaultTimeStyle()
     pDateStyle->AddSecond(true,0);
 
     XFStyleManager* pXFStyleManager = LwpGlobalMgr::GetInstance()->GetXFStyleManager();
-    m_TimeStyle = pXFStyleManager->AddStyle(pDateStyle)->GetStyleName();
+    m_TimeStyle = pXFStyleManager->AddStyle(pDateStyle).m_pStyle->GetStyleName();
 }
 void LwpFribDocVar::RegisterTotalTimeStyle()
 {
@@ -213,17 +205,15 @@ void LwpFribDocVar::RegisterTotalTimeStyle()
     pTimeStyle->SetTruncate(false);
     pTimeStyle->AddMinute();
     XFStyleManager* pXFStyleManager = LwpGlobalMgr::GetInstance()->GetXFStyleManager();
-    m_TimeStyle = pXFStyleManager->AddStyle(pTimeStyle)->GetStyleName();
+    m_TimeStyle = pXFStyleManager->AddStyle(pTimeStyle).m_pStyle->GetStyleName();
 }
 
 /**
  * @short:   convert the doc info field
- * @param:
- * @param:
  */
 void LwpFribDocVar::XFConvert(XFContentContainer* pXFPara)
 {
-    XFContent* pContent=NULL;
+    XFContent* pContent=nullptr;
     switch(m_nType)
     {
     case FILENAME:
@@ -400,8 +390,6 @@ void LwpFribDocVar::XFConvert(XFContentContainer* pXFPara)
 }
 /**
  * @short:   Read unicode
- * @param:
- * @param:
  */
 void LwpFribUnicode::Read(LwpObjectStream* pObjStrm, sal_uInt16 len)
 {
@@ -413,7 +401,7 @@ void LwpFribUnicode::Read(LwpObjectStream* pObjStrm, sal_uInt16 len)
                 rEncode = LwpCharSetMgr::GetInstance()->
                                           GetTextCharEncoding(m_pModifiers->CodePage);
         else
-                rEncode = LwpCharSetMgr::GetInstance()->GetTextCharEncoding();
+                rEncode = LwpCharSetMgr::GetTextCharEncoding();
 
         LwpTools::QuickReadUnicode(pObjStrm, m_Content, len, rEncode);
 
@@ -435,8 +423,6 @@ void LwpFribUnicode::XFConvert(XFContentContainer* pXFPara,LwpStory* pStory)
 
 /**
  * @short:   Read page number
- * @param:
- * @param:
  */
 void LwpFribPageNumber::Read(LwpObjectStream* pObjStrm, sal_uInt16 /*len*/)
 {
