@@ -57,10 +57,6 @@
  * @file
  *  For LWP filter architecture prototype - table cell numerics format
  */
-/*************************************************************************
- * Change History
- Mar 2005           Created
- ************************************************************************/
 
 #include "lwpoverride.hxx"
 #include "lwptblcell.hxx"
@@ -70,16 +66,15 @@
 #include "lwptablelayout.hxx"
 #include <osl/thread.h>
 #include <rtl/ustrbuf.hxx>
-#include <boost/scoped_array.hpp>
+#include <memory>
 
 LwpFormulaArg::~LwpFormulaArg()
 {
 }
 
-//////////////////////////////////////////////////////////////////
  LwpFormulaInfo::LwpFormulaInfo(LwpObjectHeader &objHdr, LwpSvStream* pStrm)
     : LwpCellList(objHdr, pStrm)
-    , m_bSupported(sal_True)
+    , m_bSupported(true)
     , m_nFormulaRow(0)
 {}
 
@@ -90,7 +85,7 @@ LwpFormulaInfo::~LwpFormulaInfo()
         {
             LwpFormulaArg* pArg=m_aStack.back();
             m_aStack.pop_back();
-            delete pArg; pArg=NULL;
+            delete pArg; pArg=nullptr;
         }
     }catch (...)
     {
@@ -98,34 +93,24 @@ LwpFormulaInfo::~LwpFormulaInfo()
     }
 }
 
-/**
-*
-*   @date   03/26/2005
-*   @param
-*   @param
-*   @return sal_Bool.
-*/
-sal_Bool LwpFormulaInfo::ReadConst()
+bool LwpFormulaInfo::ReadConst()
 {
     double Constant = m_pObjStrm->QuickReadDouble();
 
     m_aStack.push_back( new LwpFormulaConst(Constant) );
 
-    return sal_True;
+    return true;
 }
+
 /**
 *   Need more effort for unicode.
-*   @date   03/26/2005
-*   @param
-*   @param
-*   @return sal_Bool.
 */
-sal_Bool LwpFormulaInfo::ReadText()
+bool LwpFormulaInfo::ReadText()
 {
     m_pObjStrm->QuickReadInt16(); //Disk Size
     sal_uInt16 nStrLen = m_pObjStrm->QuickReadInt16();
 
-    boost::scoped_array<char> pBuf(new char[nStrLen+1]);
+    std::unique_ptr<char[]> pBuf(new char[nStrLen+1]);
     m_pObjStrm->QuickRead( pBuf.get(), nStrLen );
     *(pBuf.get()+nStrLen)='\0';
     OUString aText;
@@ -134,20 +119,14 @@ sal_Bool LwpFormulaInfo::ReadText()
     aText += "\"";
 
     m_aStack.push_back(new LwpFormulaText(aText));
-    return sal_True;
+    return true;
 }
-/**
-*
-*   @date   03/26/2005
-*   @param
-*   @param
-*   @return sal_Bool.
-*/
-sal_Bool LwpFormulaInfo::ReadCellID()
+
+bool LwpFormulaInfo::ReadCellID()
 {
     LwpRowSpecifier RowSpecifier;
     LwpColumnSpecifier ColumnSpecifier;
-    sal_Bool readSucceeded = true;
+    bool readSucceeded = true;
 
     RowSpecifier.QuickRead(m_pObjStrm);
     ColumnSpecifier.QuickRead(m_pObjStrm);
@@ -156,24 +135,18 @@ sal_Bool LwpFormulaInfo::ReadCellID()
                                                 RowSpecifier.RowID(m_nFormulaRow)) );
     return readSucceeded;
 }
-/**
-*
-*   @date   03/26/2005
-*   @param
-*   @param
-*   @return sal_Bool.
-*/
-sal_Bool LwpFormulaInfo::ReadCellRange()
+
+bool LwpFormulaInfo::ReadCellRange()
 {
-    sal_Bool readSucceeded = sal_True;
+    bool readSucceeded = true;
     if (!ReadCellID( )) // start
         readSucceeded = false;
-    LwpFormulaCellAddr* pStartCellAddr = (LwpFormulaCellAddr*)m_aStack.back();
+    LwpFormulaCellAddr* pStartCellAddr = static_cast<LwpFormulaCellAddr*>(m_aStack.back());
     m_aStack.pop_back();
 
     if (!ReadCellID()) // end
         readSucceeded = false;
-    LwpFormulaCellAddr* pEndCellAddr = (LwpFormulaCellAddr*)m_aStack.back();
+    LwpFormulaCellAddr* pEndCellAddr = static_cast<LwpFormulaCellAddr*>(m_aStack.back());
     m_aStack.pop_back();
 
     m_aStack.push_back( new LwpFormulaCellRangeAddr(pStartCellAddr->GetCol(),
@@ -188,22 +161,22 @@ sal_Bool LwpFormulaInfo::ReadCellRange()
 
 /**
 *   Read expression from wordpro file
-*   @date   03/26/2005
-*   @param
-*   @param
-*   @return sal_Bool.
 */
-sal_Bool LwpFormulaInfo::ReadExpression()
+bool LwpFormulaInfo::ReadExpression()
 {
     sal_uInt16 TokenType, DiskLength;
-    sal_Bool readSucceeded = sal_True;
+    bool readSucceeded = true;
 
     /* Read the compiled expression length */
-//  Len = m_pObjStrm->QuickReaduInt16();
     m_pObjStrm->SeekRel(2);
 
-    while ((TokenType = m_pObjStrm->QuickReaduInt16()) != TK_END)
+    bool bError = false;
+    while ((TokenType = m_pObjStrm->QuickReaduInt16(&bError)) != TK_END)
     {
+
+        if (bError)
+            throw std::runtime_error("error reading expression");
+
         // Get the disk length of this token
         DiskLength = m_pObjStrm->QuickReaduInt16();
 
@@ -217,7 +190,7 @@ sal_Bool LwpFormulaInfo::ReadExpression()
 
             case TK_CELLID:
                 if (!ReadCellID())
-                    readSucceeded = sal_False;
+                    readSucceeded = false;
                 break;
 
             case TK_CELLRANGE:
@@ -233,7 +206,7 @@ sal_Bool LwpFormulaInfo::ReadExpression()
                 {
                     LwpFormulaFunc* pFunc = new LwpFormulaFunc(TokenType);
                     if (!ReadArguments(*pFunc))
-                        readSucceeded = sal_False;
+                        readSucceeded = false;
                     m_aStack.push_back(pFunc);
                 }
                 break;
@@ -253,24 +226,34 @@ sal_Bool LwpFormulaInfo::ReadExpression()
             case TK_NOT:
                 m_pObjStrm->SeekRel(DiskLength); // extensible for future
 
+                if (m_aStack.size() >= 2)
                 {//binary operator
                     LwpFormulaOp* pOp = new LwpFormulaOp(TokenType);
                     pOp->AddArg(m_aStack.back()); m_aStack.pop_back();
                     pOp->AddArg(m_aStack.back()); m_aStack.pop_back();
                     m_aStack.push_back(pOp);
                 }
+                else
+                {
+                    readSucceeded = false;
+                }
                 break;
             case TK_UNARY_MINUS:
+                if (!m_aStack.empty())
                 {
                     LwpFormulaUnaryOp* pOp = new LwpFormulaUnaryOp(TokenType);
                     pOp->AddArg(m_aStack.back()); m_aStack.pop_back();
                     m_aStack.push_back(pOp);
                 }
+                else
+                {
+                    readSucceeded = false;
+                }
                 break;
             default:
                 // We don't know what to do with this token, so eat it.
                 m_pObjStrm->SeekRel(DiskLength);
-                readSucceeded = sal_False;
+                readSucceeded = false;
                 break;
         }
         MarkUnsupported(TokenType);
@@ -278,13 +261,6 @@ sal_Bool LwpFormulaInfo::ReadExpression()
     return readSucceeded;
 }
 
-/**
-*
-*   @date   03/26/2005
-*   @param
-*   @param
-*   @return
-*/
 void LwpFormulaInfo::MarkUnsupported(sal_uInt16 TokenType)
 {
     switch(TokenType)
@@ -293,7 +269,7 @@ void LwpFormulaInfo::MarkUnsupported(sal_uInt16 TokenType)
     case TK_COUNT:
     case TK_NOT:
         {
-            m_bSupported = sal_False;//Not supported formulas
+            m_bSupported = false;//Not supported formulas
         }
         break;
     default:
@@ -302,23 +278,20 @@ void LwpFormulaInfo::MarkUnsupported(sal_uInt16 TokenType)
 }
 /**
 *   Read arguments of functions from wordpro file
-*   @date   03/26/2005
 *   @param  LwpFormulaFunc& aFunc, functions object
-*   @return sal_Bool.
 */
-sal_Bool LwpFormulaInfo::ReadArguments(LwpFormulaFunc& aFunc)
+bool LwpFormulaInfo::ReadArguments(LwpFormulaFunc& aFunc)
 {
     sal_uInt16 NumberOfArguments = m_pObjStrm->QuickReaduInt16();
     sal_uInt16 ArgumentDiskLength, Count;
     sal_uInt8 ArgumentType;
-    sal_Bool bArgument = sal_False;
-    sal_Bool readSucceeded = sal_True;
+    bool readSucceeded = true;
 
     for (Count = 0; Count < NumberOfArguments; Count++)
     {
         ArgumentType = (sal_uInt8) m_pObjStrm->QuickReaduInt16(); // written as lushort
         ArgumentDiskLength = m_pObjStrm->QuickReaduInt16();
-        bArgument = sal_True;
+        bool bArgument = true;
 
         switch(ArgumentType)
         {
@@ -343,9 +316,9 @@ sal_Bool LwpFormulaInfo::ReadArguments(LwpFormulaFunc& aFunc)
                 break;
 
             default:
-                bArgument = sal_False;
+                bArgument = false;
                 m_pObjStrm->SeekRel(ArgumentDiskLength);
-                readSucceeded = sal_False;
+                readSucceeded = false;
                 break;
         }
 
@@ -358,28 +331,20 @@ sal_Bool LwpFormulaInfo::ReadArguments(LwpFormulaFunc& aFunc)
     return readSucceeded;
 }
 
-/**
-*
-*   @date   03/26/2005
-*   @param
-*   @param
-*   @return
-*/
 void LwpFormulaInfo::Read()
 {
     LwpCellList::Read();
     {
-        LwpRowList* pRowList =(LwpRowList*)cParent.obj();
+        LwpRowList* pRowList = dynamic_cast<LwpRowList*>(cParent.obj().get());
         if (pRowList)
         {
             m_nFormulaRow = pRowList->GetRowID();
         }
         else
         {
-            assert(false);
+            SAL_WARN("lwp", "missing row list");
         }
     }
-//  sal_uInt8 cFlags = (sal_uInt8) m_pObjStrm->QuickReaduInt16(); // written as a sal_uInt16
     m_pObjStrm->SeekRel(2);//flags, size in file: sal_uInt16
 
     LwpNotifyListPersistent cNotifyList;
@@ -392,10 +357,6 @@ void LwpFormulaInfo::Read()
 
 /**
 *   Make the formula string.
-*   @date   03/26/2005
-*   @param
-*   @param
-*   @return sal_Bool.
 */
 OUString  LwpFormulaInfo::Convert(LwpTableLayout* pCellsMap)
 {
@@ -417,10 +378,6 @@ OUString  LwpFormulaInfo::Convert(LwpTableLayout* pCellsMap)
 
 /**
 *   Fill the XFCell content
-*   @date   03/26/2005
-*   @param
-*   @param
-*   @return sal_Bool.
 */
 void LwpFormulaInfo::Convert(XFCell * pCell,LwpTableLayout* pCellsMap)
 {
@@ -433,15 +390,6 @@ void LwpFormulaInfo::Convert(XFCell * pCell,LwpTableLayout* pCellsMap)
     LwpCellList::Convert(pCell);
 }
 
-//////////////////////////////////////////////////////////////////
-
-/**
-*
-*   @date   03/26/2005
-*   @param
-*   @param
-*   @return sal_Bool.
-*/
 LwpFormulaConst::LwpFormulaConst(double dVal)
 {
     m_dVal = dVal;
@@ -452,51 +400,23 @@ OUString LwpFormulaConst::ToString(LwpTableLayout* /*pCellsMap*/)
     return OUString::number(m_dVal);
 }
 
-/**
-*
-*   @date   03/26/2005
-*   @param
-*   @param
-*   @return
-*/
-LwpFormulaText::LwpFormulaText( OUString aText)
+LwpFormulaText::LwpFormulaText( const OUString& aText)
 {
     m_aText = aText;
 }
 
-/**
-*
-*   @date   03/26/2005
-*   @param
-*   @param
-*   @return
-*/
 LwpFormulaCellAddr::LwpFormulaCellAddr(sal_Int16 aCol, sal_Int16 aRow)
 {
     m_aCol = aCol;
     m_aRow = aRow;
 }
 
-/**
-*
-*   @date   03/26/2005
-*   @param
-*   @param
-*   @return String
-*/
 OUString LwpFormulaCellAddr::ToString(LwpTableLayout* pCellsMap)
 {
     OUString aCellAddr = "<" + LwpFormulaTools::GetCellAddr(m_aRow,m_aCol,pCellsMap) + ">";
     return aCellAddr;
 }
 
-/**
-*
-*   @date   03/26/2005
-*   @param
-*   @param
-*   @return
-*/
 LwpFormulaCellRangeAddr::LwpFormulaCellRangeAddr(sal_Int16 aStartCol,
                                                  sal_Int16 aStartRow,
                                                  sal_Int16 aEndCol,
@@ -510,10 +430,6 @@ LwpFormulaCellRangeAddr::LwpFormulaCellRangeAddr(sal_Int16 aStartCol,
 
 /**
 *   Convert the cell range into a string
-*   @date   03/26/2005
-*   @param
-*   @param
-*   @return String.
 */
 OUString LwpFormulaCellRangeAddr::ToString(LwpTableLayout* pCellsMap)
 {
@@ -524,25 +440,11 @@ OUString LwpFormulaCellRangeAddr::ToString(LwpTableLayout* pCellsMap)
     return aCellAddr;
 }
 
-/**
-*
-*   @date   03/26/2005
-*   @param
-*   @param
-*   @return
-*/
 LwpFormulaFunc::LwpFormulaFunc(sal_uInt16 nTokenType)
 {
     m_nTokenType = nTokenType;
 }
 
-/**
-*
-*   @date   03/26/2005
-*   @param
-*   @param
-*   @return
-*/
 LwpFormulaFunc::~LwpFormulaFunc()
 {
     try
@@ -551,45 +453,30 @@ LwpFormulaFunc::~LwpFormulaFunc()
         {
             LwpFormulaArg* pArg = m_aArgs.back();
             m_aArgs.pop_back();
-            delete pArg;pArg=NULL;
+            delete pArg;pArg=nullptr;
         }
     }catch (...) {
         assert(false);
     }
 
 }
-/**
-*
-*   @date   03/26/2005
-*   @param
-*   @param
-*   @return
-*/
 void LwpFormulaFunc::AddArg(LwpFormulaArg* pArg)
 {
     m_aArgs.push_back(pArg);
 }
 /**
 *   Convert the functions to a string, which is a argument of other formula
-*   @date   03/26/2005
-*   @param
-*   @param
-*   @return  String.
 */
 OUString LwpFormulaFunc::ToArgString(LwpTableLayout* pCellsMap)
 {
     OUStringBuffer aFormula;
-    aFormula.append(static_cast<sal_Unicode>('('));
+    aFormula.append('(');
     aFormula.append(ToString(pCellsMap));
-    aFormula.append(static_cast<sal_Unicode>(')'));
+    aFormula.append(')');
     return aFormula.makeStringAndClear();
 }
 /**
 *   Convert the function to a formula string.
-*   @date   03/26/2005
-*   @param
-*   @param
-*   @return sal_Bool.
 */
 OUString LwpFormulaFunc::ToString(LwpTableLayout* pCellsMap)
 {
@@ -600,7 +487,7 @@ OUString LwpFormulaFunc::ToString(LwpTableLayout* pCellsMap)
     aFormula += " ";//Append a blank space
 
     //Append args
-    vector<LwpFormulaArg*>::iterator aItr;
+    std::vector<LwpFormulaArg*>::iterator aItr;
     for (aItr=m_aArgs.begin();aItr!=m_aArgs.end();++aItr)
     {
         aFormula += (*aItr)->ToArgString(pCellsMap) + "|"; //separator
@@ -621,17 +508,13 @@ OUString LwpFormulaFunc::ToString(LwpTableLayout* pCellsMap)
 
 /**
 *   Convert the formula in operators to a string : e.g. 1+2+3
-*   @date   03/26/2005
-*   @param
-*   @param
-*   @return sal_Bool.
 */
 OUString LwpFormulaOp::ToString(LwpTableLayout* pCellsMap)
 {
     OUString aFormula;
     if (2==m_aArgs.size())
     {
-        vector<LwpFormulaArg*>::iterator aItr = m_aArgs.end();
+        std::vector<LwpFormulaArg*>::iterator aItr = m_aArgs.end();
         --aItr;
 
         aFormula += (*aItr)->ToArgString(pCellsMap) + " ";
@@ -651,10 +534,6 @@ OUString LwpFormulaOp::ToString(LwpTableLayout* pCellsMap)
 
 /**
 *   convert the formula in unary operators into string : e.g. -2
-*   @date   03/26/2005
-*   @param
-*   @param
-*   @return sal_Bool.
 */
 OUString LwpFormulaUnaryOp::ToString(LwpTableLayout* pCellsMap)
 {
@@ -664,7 +543,7 @@ OUString LwpFormulaUnaryOp::ToString(LwpTableLayout* pCellsMap)
         OUString aFuncName = LwpFormulaTools::GetName(m_nTokenType);
         aFormula += aFuncName;
 
-        vector<LwpFormulaArg*>::iterator aItr = m_aArgs.begin();
+        std::vector<LwpFormulaArg*>::iterator aItr = m_aArgs.begin();
         aFormula += (*aItr)->ToArgString(pCellsMap);
     }
     else
@@ -675,10 +554,6 @@ OUString LwpFormulaUnaryOp::ToString(LwpTableLayout* pCellsMap)
 }
 /**
 *   Get token name
-*   @date   03/26/2005
-*   @param
-*   @param
-*   @return String.
 */
 OUString LwpFormulaTools::GetName(sal_uInt16 nTokenType)
 {
@@ -754,10 +629,6 @@ OUString LwpFormulaTools::GetName(sal_uInt16 nTokenType)
 
 /**
 *   Get cell address in String
-*   @date   03/26/2005
-*   @param
-*   @param
-*   @return String.
 */
 OUString LwpFormulaTools::GetCellAddr(sal_Int16 nRow, sal_Int16 nCol, LwpTableLayout* pCellsMap)
 {
