@@ -66,63 +66,61 @@
 #include "xfbgimage.hxx"
 
 XFParaStyle::XFParaStyle()
+    : m_eAlignType(enumXFAlignNone)
+    , m_eLastLineAlign(enumXFAlignNone)
+    , m_bJustSingleWord(false)
+    , m_bKeepWithNext(false)
+    , m_fTextIndent(0)
+    , m_pBorders(nullptr)
+    , m_pBGImage(nullptr)
+    , m_nPageNumber(0)
+    , m_bNumberLines(true)
+    , m_nLineNumberRestart(0)
+    , m_nFlag(0)
+    , m_bNumberRight(false)
 {
-    //init member variables:
-    m_nFlag = 0;
-    m_eAlignType = enumXFAlignNone;
-    m_eLastLineAlign = enumXFAlignNone;
-    m_bJustSingleWord = sal_False;
-    m_bKeepWithNext = sal_False;
-    m_nPageNumber = 0;
-    m_fTextIndent = 0;
-
-    m_pFont = NULL;
-    m_pBorders = NULL;
-    m_pBGImage = NULL;
-
-    m_nLineNumberRestart = 0;
-    m_bNumberLines = sal_True;
-    m_bNumberRight = sal_False;
 }
 
-XFParaStyle::XFParaStyle(const XFParaStyle& other) : XFStyle(other)
+
+XFParaStyle::XFParaStyle(const XFParaStyle& other)
+    : XFStyle(other)
+    , m_eAlignType(other.m_eAlignType)
+    , m_eLastLineAlign(other.m_eLastLineAlign)
+    , m_bJustSingleWord(other.m_bJustSingleWord)
+    , m_bKeepWithNext(other.m_bKeepWithNext)
+    , m_fTextIndent(other.m_fTextIndent)
+    , m_aBackColor(other.m_aBackColor)
+    , m_aMargin(other.m_aMargin)
+    , m_aPadding(other.m_aPadding)
+    , m_pFont(other.m_pFont)
+    , m_aShadow(other.m_aShadow)
+    , m_aDropcap(other.m_aDropcap)
+    , m_aLineHeight(other.m_aLineHeight)
+    , m_aBreaks(other.m_aBreaks)
+    , m_nPageNumber(other.m_nPageNumber)
+    , m_bNumberLines(other.m_bNumberLines)
+    , m_nLineNumberRestart(other.m_nLineNumberRestart)
+    , m_nFlag(other.m_nFlag)
+    , m_bNumberRight(other.m_bNumberRight)
 {
     m_strParentStyleName = other.m_strParentStyleName;
-    m_nFlag = other.m_nFlag;
-    m_eAlignType = other.m_eAlignType;
-    m_fTextIndent = other.m_fTextIndent;
-    m_bNumberLines = other.m_bNumberLines;
-    m_nLineNumberRestart = other.m_nLineNumberRestart;
-    m_bNumberRight = other.m_bNumberRight;
-
-    if( other.m_pFont )
-        m_pFont = other.m_pFont;
-    else
-        m_pFont = NULL;
 
     if( other.m_pBorders )
         m_pBorders = new XFBorders(*other.m_pBorders);
     else
-        m_pBorders = NULL;
-    m_aBackColor = other.m_aBackColor;
+        m_pBorders = nullptr;
+
     if( other.m_pBGImage )
         m_pBGImage = new XFBGImage(*other.m_pBGImage);
     else
-        m_pBGImage = NULL;
+        m_pBGImage = nullptr;
 
-    m_aShadow = other.m_aShadow;
-    m_aMargin = other.m_aMargin;
-    m_aDropcap = other.m_aDropcap;
-    m_aLineHeight = other.m_aLineHeight;
-    m_aPadding = other.m_aPadding;
-    m_aBreaks = other.m_aBreaks;
-
-    for (size_t i=0; i<other.m_aTabs.GetCount(); ++i)
+    for (size_t i = 0; i < other.m_aTabs.GetCount(); ++i)
     {
-        const IXFStyle *pStyle = other.m_aTabs.Item(i);
+        const IXFStyle* pStyle = other.m_aTabs.Item(i);
         if( pStyle )
         {
-            const XFTabStyle *pTabStyle = dynamic_cast<const XFTabStyle*>(pStyle);
+            const XFTabStyle* pTabStyle = dynamic_cast<const XFTabStyle*>(pStyle);
             if( pTabStyle )
             {
                 XFTabStyle *pCopyStyle = new XFTabStyle(*pTabStyle);
@@ -138,32 +136,31 @@ XFParaStyle& XFParaStyle::operator=(const XFParaStyle& other)
     if (this != &other)
     {
         // first , clean member
-        delete(m_pBGImage);
+        delete m_pBGImage;
         m_aTabs.Reset();
 
         m_strParentStyleName = other.m_strParentStyleName;
         m_nFlag = other.m_nFlag;
         m_eAlignType = other.m_eAlignType;
         m_eLastLineAlign = other.m_eLastLineAlign;
+        m_bJustSingleWord = other.m_bJustSingleWord;
+        m_bKeepWithNext = other.m_bKeepWithNext;
         m_fTextIndent = other.m_fTextIndent;
         m_bNumberLines = other.m_bNumberLines;
         m_nLineNumberRestart = other.m_nLineNumberRestart;
         m_bNumberRight = other.m_bNumberRight;
 
-        if( other.m_pFont )
-            m_pFont = other.m_pFont;
-        else
-            m_pFont = NULL;
+        m_pFont = other.m_pFont;
 
         if( other.m_pBorders )
             m_pBorders = new XFBorders(*other.m_pBorders);
         else
-            m_pBorders = NULL;
+            m_pBorders = nullptr;
         m_aBackColor = other.m_aBackColor;
         if( other.m_pBGImage )
             m_pBGImage = new XFBGImage(*other.m_pBGImage);
         else
-            m_pBGImage = NULL;
+            m_pBGImage = nullptr;
 
         m_aShadow = other.m_aShadow;
         m_aMargin = other.m_aMargin;
@@ -191,10 +188,8 @@ XFParaStyle& XFParaStyle::operator=(const XFParaStyle& other)
 
 XFParaStyle::~XFParaStyle()
 {
-    if( m_pBorders )
-        delete m_pBorders;
-    if( m_pBGImage )
-        delete m_pBGImage;
+    delete m_pBorders;
+    delete m_pBGImage;
 }
 
 enumXFStyle XFParaStyle::GetStyleFamily()
@@ -202,7 +197,7 @@ enumXFStyle XFParaStyle::GetStyleFamily()
     return enumXFStylePara;
 }
 
-void    XFParaStyle::SetFont(XFFont *pFont)
+void    XFParaStyle::SetFont(rtl::Reference<XFFont> const & pFont)
 {
     m_pFont = pFont;
 }
@@ -239,15 +234,13 @@ void    XFParaStyle::SetBackColor(XFColor& color)
 
 void    XFParaStyle::SetBackImage(XFBGImage *image)
 {
-    if( m_pBGImage )
-        delete m_pBGImage;
+    delete m_pBGImage;
     m_pBGImage = image;
 }
 
 void    XFParaStyle::SetBorders(XFBorders *pBorders)
 {
-    if( m_pBorders )
-        delete m_pBorders;
+    delete m_pBorders;
     m_pBorders = pBorders;
 }
 
@@ -303,102 +296,100 @@ void    XFParaStyle::AddTabStyle(enumXFTab type, double len, sal_Unicode leader,
 /**
  *Affirm whether two XFParaStyle objects are equal.
  */
-sal_Bool    XFParaStyle::Equal(IXFStyle *pStyle)
+bool    XFParaStyle::Equal(IXFStyle *pStyle)
 {
     if( this == pStyle )
-        return sal_True;
+        return true;
     if( !pStyle || pStyle->GetStyleFamily() != enumXFStylePara )
-        return sal_False;
+        return false;
 
-    XFParaStyle *pOther = (XFParaStyle*)(pStyle);
-    if( !pOther )
-        return sal_False;
+    XFParaStyle *pOther = static_cast<XFParaStyle*>(pStyle);
 
     if( m_nFlag != pOther->m_nFlag )
-        return sal_False;
+        return false;
     if( m_strParentStyleName != pOther->m_strParentStyleName )
-        return sal_False;
+        return false;
     if( m_strMasterPage != pOther->m_strMasterPage )
-        return sal_False;
+        return false;
     if( m_fTextIndent != pOther->m_fTextIndent )
-        return sal_False;
+        return false;
     if( m_bJustSingleWord != pOther->m_bJustSingleWord )
-        return sal_False;
+        return false;
     if( m_bKeepWithNext != pOther->m_bKeepWithNext )
-        return sal_False;
+        return false;
     //line number:
     if( m_bNumberLines != pOther->m_bNumberLines )
-        return sal_False;
+        return false;
     if( m_nLineNumberRestart != pOther->m_nLineNumberRestart )
-        return sal_False;
+        return false;
     //align:
     if( m_eAlignType != pOther->m_eAlignType )
-        return sal_False;
+        return false;
     //last line align:
     if( m_eLastLineAlign != pOther->m_eLastLineAlign )
-        return sal_False;
+        return false;
 
     //shadow:
     if( m_aShadow != pOther->m_aShadow )
-        return sal_False;
+        return false;
     //margin:
     if( m_aMargin != pOther->m_aMargin )
-        return sal_False;
+        return false;
 
     if( m_aPadding != pOther->m_aPadding )
-        return sal_False;
+        return false;
 
     //dropcap:
     if( m_aDropcap != pOther->m_aDropcap )
-        return sal_False;
+        return false;
     //line height:
     if( m_aLineHeight != pOther->m_aLineHeight )
-        return sal_False;
+        return false;
     //breaks:
     if( m_aBreaks != pOther->m_aBreaks )
-        return sal_False;
+        return false;
     if( m_nPageNumber != pOther->m_nPageNumber )
-        return sal_False;
+        return false;
     if( m_aTabs != pOther->m_aTabs )
-        return sal_False;
+        return false;
 
     //font:
-    if( m_pFont )
+    if( m_pFont.is() )
     {
-        if( !pOther->m_pFont )
-            return sal_False;
+        if( !pOther->m_pFont.is() )
+            return false;
         if(*m_pFont != *pOther->m_pFont )
-            return sal_False;
+            return false;
     }
-    else if( pOther->m_pFont )
-        return sal_False;
+    else if( pOther->m_pFont.is() )
+        return false;
 
     //border:
     if( m_pBorders )
     {
         if( !pOther->m_pBorders )
-            return sal_False;
+            return false;
         if( *m_pBorders != *pOther->m_pBorders )
-            return sal_False;
+            return false;
     }
     else if( pOther->m_pBorders )
-        return sal_False;
+        return false;
 
     if( m_pBGImage )
     {
         if( !pOther->m_pBGImage )
-            return sal_False;
+            return false;
         if( *m_pBGImage != *pOther->m_pBGImage )
-            return sal_False;
+            return false;
     }
     else if( pOther->m_pBGImage )
-        return sal_False;//add end
+        return false;//add end
 
     //number right
     if (    m_bNumberRight  != pOther->m_bNumberRight)
-        return sal_False;
+        return false;
 
-    return sal_True;
+    return true;
 }
 
 void    XFParaStyle::ToXml(IXFStream *pStrm)
@@ -408,14 +399,14 @@ void    XFParaStyle::ToXml(IXFStream *pStrm)
 
     pAttrList->Clear();
     if( !style.isEmpty() )
-        pAttrList->AddAttribute(A2OUSTR("style:name"),GetStyleName());
-    pAttrList->AddAttribute(A2OUSTR("style:family"), A2OUSTR("paragraph"));
+        pAttrList->AddAttribute("style:name",GetStyleName());
+    pAttrList->AddAttribute("style:family", "paragraph");
     if( !GetParentStyleName().isEmpty() )
-        pAttrList->AddAttribute(A2OUSTR("style:parent-style-name"),GetParentStyleName());
+        pAttrList->AddAttribute("style:parent-style-name",GetParentStyleName());
 
     if( !m_strMasterPage.isEmpty() )
-        pAttrList->AddAttribute(A2OUSTR("style:master-page-name"),m_strMasterPage);
-    pStrm->StartElement(A2OUSTR("style:style"));
+        pAttrList->AddAttribute("style:master-page-name",m_strMasterPage);
+    pStrm->StartElement("style:style");
 
     //Paragraph properties:
     pAttrList->Clear();
@@ -423,7 +414,7 @@ void    XFParaStyle::ToXml(IXFStream *pStrm)
     //text indent:
     if( m_fTextIndent )
     {
-        pAttrList->AddAttribute(A2OUSTR("fo:text-indent"), DoubleToOUString(m_fTextIndent) + A2OUSTR("cm") );
+        pAttrList->AddAttribute("fo:text-indent", OUString::number(m_fTextIndent) + "cm" );
     }
     //padding:
     m_aPadding.ToXml(pStrm);
@@ -433,26 +424,26 @@ void    XFParaStyle::ToXml(IXFStream *pStrm)
     //text align:
     if( m_eAlignType != enumXFAlignNone )
     {
-        pAttrList->AddAttribute(A2OUSTR("fo:text-align"), GetAlignName(m_eAlignType) );
+        pAttrList->AddAttribute("fo:text-align", GetAlignName(m_eAlignType) );
     }
     //last line align:
     if( m_eLastLineAlign != enumXFAlignNone )
     {
-        pAttrList->AddAttribute(A2OUSTR("fo:fo:text-align-last"), GetAlignName(m_eLastLineAlign) );
+        pAttrList->AddAttribute("fo:fo:text-align-last", GetAlignName(m_eLastLineAlign) );
         if( m_bJustSingleWord )
-            pAttrList->AddAttribute(A2OUSTR("style:justify-single-word"), A2OUSTR("true") );
+            pAttrList->AddAttribute("style:justify-single-word", "true" );
     }
     //line number:
     if( m_bNumberLines )
     {
-        pAttrList->AddAttribute( A2OUSTR("text:number-lines"), A2OUSTR("true") );
-        pAttrList->AddAttribute( A2OUSTR("text:line-number"), Int32ToOUString(m_nLineNumberRestart) );
+        pAttrList->AddAttribute( "text:number-lines", "true" );
+        pAttrList->AddAttribute( "text:line-number", OUString::number(m_nLineNumberRestart) );
     }
     else
     {
-        pAttrList->AddAttribute( A2OUSTR("text:number-lines"), A2OUSTR("false") );
+        pAttrList->AddAttribute( "text:number-lines", "false" );
         assert(m_nLineNumberRestart>0);
-        pAttrList->AddAttribute( A2OUSTR("text:line-number"), A2OUSTR("0") );
+        pAttrList->AddAttribute( "text:line-number", "0" );
     }
 
     //shadow:
@@ -466,22 +457,22 @@ void    XFParaStyle::ToXml(IXFStream *pStrm)
     //background color:
     if( m_nFlag&XFPARA_FLAG_BACKCOLOR && m_aBackColor.IsValid() )
     {
-        pAttrList->AddAttribute(A2OUSTR("fo:background-color"), m_aBackColor.ToString() );
+        pAttrList->AddAttribute("fo:background-color", m_aBackColor.ToString() );
     }
     //Font properties:
-    if( m_pFont )
+    if( m_pFont.is() )
         m_pFont->ToXml(pStrm);
 
     //page number:
     if( m_nPageNumber )
-        pAttrList->AddAttribute(A2OUSTR("fo:page-number"), Int32ToOUString(m_nPageNumber) );
+        pAttrList->AddAttribute("fo:page-number", OUString::number(m_nPageNumber) );
     //page breaks:
     m_aBreaks.ToXml(pStrm);
 
     if( m_bKeepWithNext )
-        pAttrList->AddAttribute(A2OUSTR("fo:fo:keep-with-next"), A2OUSTR("true") );
+        pAttrList->AddAttribute("fo:fo:keep-with-next", "true" );
 
-    pStrm->StartElement(A2OUSTR("style:properties"));
+    pStrm->StartElement("style:properties");
 
     //dropcap:
     m_aDropcap.ToXml(pStrm);
@@ -490,18 +481,18 @@ void    XFParaStyle::ToXml(IXFStream *pStrm)
     if( m_aTabs.GetCount() > 0 )
     {
         pAttrList->Clear();
-        pStrm->StartElement( A2OUSTR("style:tab-stops") );
+        pStrm->StartElement( "style:tab-stops" );
         m_aTabs.ToXml(pStrm);
-        pStrm->EndElement( A2OUSTR("style:tab-stops") );
+        pStrm->EndElement( "style:tab-stops" );
     }
 
     //background color:
     if( m_pBGImage )
         m_pBGImage->ToXml(pStrm);
 
-    pStrm->EndElement(A2OUSTR("style:properties"));
+    pStrm->EndElement("style:properties");
 
-    pStrm->EndElement(A2OUSTR("style:style"));
+    pStrm->EndElement("style:style");
 }
 
 XFDefaultParaStyle::XFDefaultParaStyle()
@@ -514,22 +505,21 @@ enumXFStyle XFDefaultParaStyle::GetStyleFamily()
     return enumXFStyleDefaultPara;
 }
 
-
 void XFDefaultParaStyle::ToXml(IXFStream * pStrm)
 {
     IXFAttrList *pAttrList = pStrm->GetAttrList();
     pAttrList->Clear();
-    pAttrList->AddAttribute(A2OUSTR("style:family"), A2OUSTR("paragraph"));
-    pStrm->StartElement(A2OUSTR("style:default-style"));
+    pAttrList->AddAttribute("style:family", "paragraph");
+    pStrm->StartElement("style:default-style");
 
     //Paragraph properties:
     pAttrList->Clear();
 
-    pAttrList->AddAttribute(A2OUSTR("style:tab-stop-distance"), DoubleToOUString(m_fTabDistance) + A2OUSTR("cm") );
+    pAttrList->AddAttribute("style:tab-stop-distance", OUString::number(m_fTabDistance) + "cm" );
 
-    pStrm->StartElement(A2OUSTR("style:properties"));
-    pStrm->EndElement(A2OUSTR("style:properties"));
-    pStrm->EndElement(A2OUSTR("style:default-style"));
+    pStrm->StartElement("style:properties");
+    pStrm->EndElement("style:properties");
+    pStrm->EndElement("style:default-style");
 }
 
 /* vim:set shiftwidth=4 softtabstop=4 expandtab: */
