@@ -70,7 +70,7 @@ class SalesFilter implements XActionListener, XPropertyChangeListener, XResetLis
         m_nPreviousFilterIndex = -1;
         initFilterDates();
 
-        // -------------------------------------------------------------
+
         // remember the components
         m_aDocument = aDocument;
         m_xSalesForm = xSalesForm;
@@ -81,26 +81,26 @@ class SalesFilter implements XActionListener, XPropertyChangeListener, XResetLis
 
         try
         {
-            // ----------------------------------------------------------
+
             // init control models
-            m_xFilterList.setPropertyValue( "Dropdown", new Boolean( true ) );
-            m_xFilterList.setPropertyValue( "LineCount", new Short( (short)11 ) );
+            m_xFilterList.setPropertyValue( "Dropdown", Boolean.TRUE );
+            m_xFilterList.setPropertyValue( "LineCount", Short.valueOf( (short)11 ) );
             m_xFilterList.setPropertyValue( "StringItemList", new String[] { "ever (means no filter)", "this morning", "1 week ago", "1 month ago", "1 year ago", "<other>" } );
-            m_xFilterList.setPropertyValue( "DefaultSelection", new Short[] { new Short( (short)0 ) } );
+            m_xFilterList.setPropertyValue( "DefaultSelection", new Short[] { Short.valueOf( (short)0 ) } );
 
             m_xApplyFilter.setPropertyValue( "Label", "Apply Filter" );
 
             updateFilterControl();
             updateApplyButton();
 
-            // ----------------------------------------------------------
+
             // add as listener to the events which require action
 
             // want to know about changed selection
             m_xFilterList.addPropertyChangeListener( "SelectedItems", this );
             m_xManualFilter.addPropertyChangeListener( "Date", this );
 
-            // want to know about the date field beeing reset
+            // want to know about the date field being reset
             XReset xReset = UNO.queryReset( m_xManualFilter );
             xReset.addResetListener( this );
 
@@ -121,7 +121,7 @@ class SalesFilter implements XActionListener, XPropertyChangeListener, XResetLis
        = helper
        ================================================================== */
     /* ------------------------------------------------------------------ */
-    protected void initFilterDates()
+    private void initFilterDates()
     {
         m_aFilterDates.clear();
         java.util.Date aNowAndHere = new java.util.Date();
@@ -162,7 +162,7 @@ class SalesFilter implements XActionListener, XPropertyChangeListener, XResetLis
     /** translates a date from the AWT Toolkit format to a java.util.date, or
         vice versa.
     */
-    protected Object translateDate( Object aDate ) throws java.lang.Exception
+    private Object translateDate( Object aDate ) throws java.lang.Exception
     {
         Object aReturn = null;
 
@@ -175,7 +175,7 @@ class SalesFilter implements XActionListener, XPropertyChangeListener, XResetLis
             nDate = nDate * 100 + aCalDate.get( Calendar.MONTH ) + 1;
             nDate = nDate * 100 + aCalDate.get( Calendar.DAY_OF_MONTH );
 
-            aReturn = new Integer( nDate );
+            aReturn = Integer.valueOf( nDate );
         }
         else if ( aDate.getClass().equals( Class.forName( "java.lang.Integer" ) ) )
         {
@@ -201,7 +201,7 @@ class SalesFilter implements XActionListener, XPropertyChangeListener, XResetLis
     /** translates the given date into the ODBC date notation, which then can be used
         for setting a filter at a row set
     */
-    protected String getOdbcDate( Object aDate ) throws java.lang.Exception
+    private String getOdbcDate( Object aDate ) throws java.lang.Exception
     {
         String sOdbcDate = "";
         if ( null != aDate )
@@ -214,20 +214,20 @@ class SalesFilter implements XActionListener, XPropertyChangeListener, XResetLis
                 GregorianCalendar aCal = new GregorianCalendar();
                 aCal.setTime( (java.util.Date)aDate );
 
-                sOdbcDate += new String( "{D '" );
-                sOdbcDate += (new Integer( aCal.get( Calendar.YEAR ) ) ).toString();
+                sOdbcDate += "{D '";
+                sOdbcDate += (Integer.valueOf( aCal.get( Calendar.YEAR ) ) ).toString();
                 sOdbcDate += "-";
 
                 int nMonth = aCal.get( Calendar.MONTH ) + 1;
                 if ( nMonth < 10 )
                     sOdbcDate += "0";
-                sOdbcDate += (new Integer( nMonth ) ).toString();
+                sOdbcDate += (Integer.valueOf( nMonth ) ).toString();
                 sOdbcDate += "-";
 
                 int nDay = aCal.get( Calendar.DAY_OF_MONTH );
                 if ( nDay < 10 )
                     sOdbcDate += "0";
-                sOdbcDate += (new Integer( nDay ) ).toString();
+                sOdbcDate += (Integer.valueOf( nDay ) ).toString();
                 sOdbcDate += "'}";
             }
         }
@@ -235,11 +235,11 @@ class SalesFilter implements XActionListener, XPropertyChangeListener, XResetLis
     }
 
     /* ------------------------------------------------------------------ */
-    protected void updateApplyButton()
+    private void updateApplyButton()
     {
         try
         {
-            m_xApplyFilter.setPropertyValue( "Enabled", new Boolean( m_bSettingsDirty ) );
+            m_xApplyFilter.setPropertyValue( "Enabled", Boolean.valueOf( m_bSettingsDirty ) );
         }
         catch ( com.sun.star.uno.Exception e )
         {
@@ -251,7 +251,7 @@ class SalesFilter implements XActionListener, XPropertyChangeListener, XResetLis
     /* ------------------------------------------------------------------ */
     /** creates a normalized calendar object from the given java.util.Date
     */
-    protected GregorianCalendar getCalendarObject( java.util.Date aDate )
+    private GregorianCalendar getCalendarObject( java.util.Date aDate )
     {
         // the date part
         GregorianCalendar aReturn = null;
@@ -270,7 +270,7 @@ class SalesFilter implements XActionListener, XPropertyChangeListener, XResetLis
     }
 
     /* ------------------------------------------------------------------ */
-    final protected short getCurrentSelectedFilter( ) throws com.sun.star.uno.Exception
+    final private short getCurrentSelectedFilter( ) throws com.sun.star.uno.Exception
     {
         short[] aSelected = (short[])m_xFilterList.getPropertyValue( "SelectedItems" );
         if ( 0 < aSelected.length )
@@ -282,13 +282,13 @@ class SalesFilter implements XActionListener, XPropertyChangeListener, XResetLis
     /** checks if the given filter index referes to the "<other>" entry which
         allows the user to manually enter a date
     */
-    final protected boolean isManualFilter( short nFilterIndex )
+    final private boolean isManualFilter( short nFilterIndex )
     {
         return ( 5 == nFilterIndex );
     }
 
     /* ------------------------------------------------------------------ */
-    protected void updateFilterControl()
+    private void updateFilterControl()
     {
         try
         {
@@ -306,7 +306,7 @@ class SalesFilter implements XActionListener, XPropertyChangeListener, XResetLis
 
                 // custom filter?
                 boolean bCustomFilter = isManualFilter( m_nPreviousFilterIndex );
-                m_xManualFilter.setPropertyValue( "Enabled", new Boolean( bCustomFilter ) );
+                m_xManualFilter.setPropertyValue( "Enabled", Boolean.valueOf( bCustomFilter ) );
                 if ( bCustomFilter )
                     m_aDocument.getCurrentView().grabControlFocus( m_xManualFilter );
 
@@ -336,7 +336,7 @@ class SalesFilter implements XActionListener, XPropertyChangeListener, XResetLis
         seems to always return false, as well as . Thus here is a method which compare two calendars,
         restricted to their date part</p>
     */
-    protected boolean equalDate( Calendar aLHS, Calendar aRHS )
+    private boolean equalDate( Calendar aLHS, Calendar aRHS )
     {
         if ( ( null == aLHS ) != ( null == aRHS ) )
             // only one of them is null
@@ -356,7 +356,7 @@ class SalesFilter implements XActionListener, XPropertyChangeListener, XResetLis
         @return
             the index of the newly added date filter in the filter list
     */
-    protected short addCurrentFilter( ) throws java.lang.Exception
+    private short addCurrentFilter( ) throws java.lang.Exception
     {
         // the current string items
         String[] aOldFilterItems = (String[])m_xFilterList.getPropertyValue( "StringItemList" );
@@ -383,7 +383,7 @@ class SalesFilter implements XActionListener, XPropertyChangeListener, XResetLis
 
         if ( aFilterItems.size() > 10 ) // (6 standard items + 5 user defined items)
         {
-            // the first (and thus oldes) user defined item
+            // the first (and thus oldest) user defined item
             aFilterItems.remove( 6 );
             // keep our date vector synchron
             m_aFilterDates.remove( 6 );
@@ -405,7 +405,7 @@ class SalesFilter implements XActionListener, XPropertyChangeListener, XResetLis
     }
 
     /* ------------------------------------------------------------------ */
-    protected void executeCurrentFilter()
+    private void executeCurrentFilter()
     {
         try
         {
@@ -430,7 +430,7 @@ class SalesFilter implements XActionListener, XPropertyChangeListener, XResetLis
                 sCompleteFilter += sOdbcDate;
             }
             m_xSalesForm.setPropertyValue( "Filter", sCompleteFilter );
-            m_xSalesForm.setPropertyValue( "ApplyFilter", new Boolean( true ) );
+            m_xSalesForm.setPropertyValue( "ApplyFilter", Boolean.TRUE );
 
             // and reload the form
             XLoadable xLoad = UnoRuntime.queryInterface(
@@ -504,4 +504,4 @@ class SalesFilter implements XActionListener, XPropertyChangeListener, XResetLis
         // not interested in
     }
 
-};
+}
