@@ -60,7 +60,7 @@ public class CalcAddins {
  * of the service description. It implements the needed interfaces.
  * @implements XCalcAddins, XAddIn, XServiceName, XServiceInfo, XTypeProvider
  */
-    static public class _CalcAddins extends WeakBase implements
+    public static class _CalcAddins extends WeakBase implements
                                             XCalcAddins,
                                             XAddIn,
                                             XServiceName,
@@ -69,9 +69,9 @@ public class CalcAddins {
 
 /** The component will be registered under this name.
  */
-        static private final String __serviceName = "org.openoffice.sheet.addin.CalcAddins";
+        private static final String __serviceName = "org.openoffice.sheet.addin.CalcAddins";
 
-        static private final String ADDIN_SERVICE = "com.sun.star.sheet.AddIn";
+        private static final String ADDIN_SERVICE = "com.sun.star.sheet.AddIn";
 
         private Locale aFuncLoc;
 
@@ -83,15 +83,12 @@ public class CalcAddins {
             "getMySecondValue"
         };
 
-        private static final short shortINVALID = -1;
-
 /** TO DO:
  * For each of your methods you should make up a new constant with a different value.
  */
         private static final short shortGETMYFIRSTVALUE = 0;
         private static final short shortGETMYSECONDVALUE = 1;
 
-
 /** TO DO:
  * This is where you implement all methods of your interface. The parameters have to
  * be the same as in your IDL file and their types have to be the correct
@@ -107,13 +104,12 @@ public class CalcAddins {
             com.sun.star.beans.XPropertySet xOptions,
             int intDummy
         ) {
-            return( 2 + intDummy );
+            return 2 + intDummy;
         }
 
-
         // Implement method from interface XServiceName
         public String getServiceName() {
-            return( __serviceName );
+            return __serviceName;
         }
 
         // Implement methods from interface XServiceInfo
@@ -123,12 +119,12 @@ public class CalcAddins {
         }
 
         public String getImplementationName() {
-            return( _CalcAddins.class.getName() );
+            return _CalcAddins.class.getName();
         }
 
         public String[] getSupportedServiceNames() {
             String[] stringSupportedServiceNames = { ADDIN_SERVICE, __serviceName };
-            return( stringSupportedServiceNames );
+            return stringSupportedServiceNames;
         }
 
         // Implement methods from interface XAddIn
@@ -157,7 +153,7 @@ public class CalcAddins {
                     }
                     break;
             }
-            return( stringReturn );
+            return stringReturn;
         }
 
         public String getDisplayFunctionName(String stringProgrammaticName) {
@@ -175,15 +171,15 @@ public class CalcAddins {
                     break;
             }
 
-            return( stringReturn );
+            return stringReturn;
         }
 
         public String getProgrammaticCategoryName(String p1) {
-            return( "Add-In" );
+            return "Add-In";
         }
 
         public String getDisplayCategoryName(String p1) {
-            return( "Add-In" );
+            return "Add-In";
         }
 
         public String getFunctionDescription(String stringProgrammaticName) {
@@ -201,7 +197,7 @@ public class CalcAddins {
                     break;
             }
 
-            return( stringReturn );
+            return stringReturn;
         }
 
         public String getArgumentDescription(String stringProgrammaticFunctionName,int intArgument) {
@@ -229,16 +225,16 @@ public class CalcAddins {
                     }
                     break;
             }
-            return( stringReturn );
+            return stringReturn;
         }
 
         public String getProgrammaticFuntionName(String p1) {
-            return( "" );
+            return "";
         }
 
         // Implement methods from interface XLocalizable
         public Locale getLocale() {
-            return( aFuncLoc );
+            return aFuncLoc;
         }
 
         public void setLocale(Locale p1) {
@@ -249,11 +245,11 @@ public class CalcAddins {
         private short getFunctionID( String stringProgrammaticName ) {
             for ( int i = 0; i < stringFunctionName.length; i++ ) {
                 if ( stringProgrammaticName.equals( stringFunctionName[ i ] ) ) {
-                    return( ( short ) i );
+                    return ( short ) i;
                 }
             }
 
-            return( -1 );
+            return -1;
         }
     }
 
@@ -281,22 +277,4 @@ public class CalcAddins {
         return xSingleServiceFactory;
     }
 
-    /**
-     * Writes the service information into the given registry key.
-     * This method is called by the <code>JavaLoader</code>
-     * <p>
-     * @return  returns true if the operation succeeded
-     * @param   regKey       the registryKey
-     * @see                  com.sun.star.comp.loader.JavaLoader
-     */
-    // This method not longer necessary since OOo 3.4 where the component registration
-    // was changed to passive component registration. For more details see
-    // http://wiki.openoffice.org/wiki/Passive_Component_Registration
-
-//     public static boolean __writeRegistryServiceInfo(XRegistryKey regKey) {
-//         return FactoryHelper.writeRegistryServiceInfo(_CalcAddins.class.getName(),
-//         _CalcAddins.__serviceName, regKey)
-//         && FactoryHelper.writeRegistryServiceInfo(_CalcAddins.class.getName(),
-//         _CalcAddins.ADDIN_SERVICE, regKey);
-//     }
 }
