@@ -22,7 +22,7 @@
 #include "diagramdefinitioncontext.hxx"
 #include "diagramfragmenthandler.hxx"
 #include "datamodelcontext.hxx"
-#include "oox/drawingml/colorchoicecontext.hxx"
+#include "drawingml/colorchoicecontext.hxx"
 
 using namespace ::oox::core;
 using namespace ::com::sun::star::xml::sax;
@@ -32,10 +32,10 @@ namespace oox { namespace drawingml {
 
 DiagramDataFragmentHandler::DiagramDataFragmentHandler( XmlFilterBase& rFilter,
                                                         const OUString& rFragmentPath,
-                                                        const DiagramDataPtr pDataPtr )
+                                                        const DiagramDataPtr& rDataPtr )
     throw( )
     : FragmentHandler2( rFilter, rFragmentPath )
-    , mpDataPtr( pDataPtr )
+    , mpDataPtr( rDataPtr )
 {
 }
 
@@ -45,12 +45,11 @@ DiagramDataFragmentHandler::~DiagramDataFragmentHandler( ) throw ()
 }
 
 void SAL_CALL DiagramDataFragmentHandler::endDocument()
-    throw (SAXException, RuntimeException)
+    throw (SAXException, RuntimeException, std::exception)
 {
 
 }
 
-
 ContextHandlerRef
 DiagramDataFragmentHandler::onCreateContext( ::sal_Int32 aElement,
                                              const AttributeList& )
@@ -66,14 +65,12 @@ DiagramDataFragmentHandler::onCreateContext( ::sal_Int32 aElement,
     return this;
 }
 
-///////////////////
-
 DiagramLayoutFragmentHandler::DiagramLayoutFragmentHandler( XmlFilterBase& rFilter,
                                                         const OUString& rFragmentPath,
-                                                        const DiagramLayoutPtr pDataPtr )
+                                                        const DiagramLayoutPtr& rDataPtr )
     throw( )
     : FragmentHandler2( rFilter, rFragmentPath )
-    , mpDataPtr( pDataPtr )
+    , mpDataPtr( rDataPtr )
 {
 }
 
@@ -83,12 +80,11 @@ DiagramLayoutFragmentHandler::~DiagramLayoutFragmentHandler( ) throw ()
 }
 
 void SAL_CALL DiagramLayoutFragmentHandler::endDocument()
-    throw (SAXException, RuntimeException)
+    throw (SAXException, RuntimeException, std::exception)
 {
 
 }
 
-
 ContextHandlerRef
 DiagramLayoutFragmentHandler::onCreateContext( ::sal_Int32 aElement,
                                                const AttributeList& rAttribs )
@@ -104,8 +100,6 @@ DiagramLayoutFragmentHandler::onCreateContext( ::sal_Int32 aElement,
     return this;
 }
 
-///////////////////////
-
 DiagramQStylesFragmentHandler::DiagramQStylesFragmentHandler( XmlFilterBase& rFilter,
                                                               const OUString& rFragmentPath,
                                                               DiagramQStyleMap& rStylesMap ) :
@@ -134,11 +128,11 @@ DiagramQStylesFragmentHandler::DiagramQStylesFragmentHandler( XmlFilterBase& rFi
     switch( getCurrentElement() )
     {
         case XML_ROOT_CONTEXT:
-            return nElement == DGM_TOKEN(styleDef) ? this : NULL;
+            return nElement == DGM_TOKEN(styleDef) ? this : nullptr;
         case DGM_TOKEN(styleDef):
-            return nElement == DGM_TOKEN(styleLbl) ? this : NULL;
+            return nElement == DGM_TOKEN(styleLbl) ? this : nullptr;
         case DGM_TOKEN(styleLbl):
-            return nElement == DGM_TOKEN(style) ? this : NULL;
+            return nElement == DGM_TOKEN(style) ? this : nullptr;
         case DGM_TOKEN(style):
         {
             switch( nElement )
@@ -156,14 +150,13 @@ DiagramQStylesFragmentHandler::DiagramQStylesFragmentHandler( XmlFilterBase& rFi
                     return createStyleMatrixContext(nElement,rAttribs,
                                                     maStyleEntry.maTextStyle);
             }
-            return 0;
+            return nullptr;
         }
     }
 
-    return 0;
+    return nullptr;
 }
 
-
 void DiagramQStylesFragmentHandler::onStartElement( const AttributeList& rAttribs )
 {
     if( getCurrentElement() == DGM_TOKEN( styleLbl ) )
@@ -173,8 +166,6 @@ void DiagramQStylesFragmentHandler::onStartElement( const AttributeList& rAttrib
     }
 }
 
-/////////////////////
-
 void DiagramQStylesFragmentHandler::onEndElement( )
 {
     if( getCurrentElement() == DGM_TOKEN(styleLbl) )
@@ -199,9 +190,9 @@ ColorFragmentHandler::ColorFragmentHandler( ::oox::core::XmlFilterBase& rFilter,
     switch( getCurrentElement() )
     {
         case XML_ROOT_CONTEXT:
-            return nElement == DGM_TOKEN(colorsDef) ? this : NULL;
+            return nElement == DGM_TOKEN(colorsDef) ? this : nullptr;
         case DGM_TOKEN(colorsDef):
-            return nElement == DGM_TOKEN(styleLbl) ? this : NULL;
+            return nElement == DGM_TOKEN(styleLbl) ? this : nullptr;
         case DGM_TOKEN(styleLbl):
         {
             switch( nElement )
@@ -228,10 +219,9 @@ ColorFragmentHandler::ColorFragmentHandler( ::oox::core::XmlFilterBase& rFilter,
         }
     }
 
-    return 0;
+    return nullptr;
 }
 
-
 void ColorFragmentHandler::onStartElement( const AttributeList& rAttribs )
 {
     if( getCurrentElement() == DGM_TOKEN(styleLbl) )
@@ -247,7 +237,6 @@ void ColorFragmentHandler::onEndElement( )
         mrColorsMap[maColorName] = maColorEntry;
 }
 
-
 } }
 
 /* vim:set shiftwidth=4 softtabstop=4 expandtab: */
