@@ -17,10 +17,12 @@
  *   the License at http://www.apache.org/licenses/LICENSE-2.0 .
  */
 
-#include <iterator>
-#include <boost/utility.hpp>
+#include <oox/drawingml/fillproperties.hxx>
 
-#include "oox/drawingml/fillproperties.hxx"
+#include <iterator>
+#include <boost/next_prior.hpp>
+
+#include <drawingml/graphicproperties.hxx>
 
 #include <com/sun/star/lang/XMultiServiceFactory.hpp>
 #include <com/sun/star/beans/XPropertySet.hpp>
@@ -33,11 +35,13 @@
 #include <com/sun/star/drawing/Hatch.hpp>
 #include <com/sun/star/drawing/RectanglePoint.hpp>
 #include <com/sun/star/graphic/XGraphicTransformer.hpp>
+#include <oox/core/fragmenthandler.hxx>
 #include "oox/helper/graphichelper.hxx"
 #include "oox/drawingml/drawingmltypes.hxx"
 #include "oox/drawingml/shapepropertymap.hxx"
 #include "oox/token/tokens.hxx"
 #include <rtl/math.hxx>
+#include <osl/diagnose.h>
 
 using namespace ::com::sun::star;
 using namespace ::com::sun::star::drawing;
@@ -52,8 +56,6 @@ using ::com::sun::star::geometry::IntegerRectangle2D;
 namespace oox {
 namespace drawingml {
 
-// ============================================================================
-
 namespace {
 
 Reference< XGraphic > lclCheckAndApplyDuotoneTransform( const BlipFillProperties& aBlipProps, Reference< XGraphic > xGraphic,
@@ -109,7 +111,6 @@ Reference< XGraphic > applyBrightnessContrast( Reference< XGraphic > xGraphic, s
     return xGraphic;
 }
 
-
 BitmapMode lclGetBitmapMode( sal_Int32 nToken )
 {
     OSL_ASSERT((nToken & sal_Int32(0xFFFF0000))==0);
@@ -163,8 +164,6 @@ const awt::Size lclGetOriginalSize( const GraphicHelper& rGraphicHelper, const R
 
 } // namespace
 
-// ============================================================================
-
 void GradientFillProperties::assignUsed( const GradientFillProperties& rSourceProps )
 {
     if( !rSourceProps.maGradientStops.empty() )
@@ -178,8 +177,6 @@ void GradientFillProperties::assignUsed( const GradientFillProperties& rSourcePr
     moRotateWithShape.assignIfUsed( rSourceProps.moRotateWithShape );
 }
 
-// ============================================================================
-
 void PatternFillProperties::assignUsed( const PatternFillProperties& rSourceProps )
 {
     maPattFgColor.assignIfUsed( rSourceProps.maPattFgColor );
@@ -187,8 +184,6 @@ void PatternFillProperties::assignUsed( const PatternFillProperties& rSourceProp
     moPattPreset.assignIfUsed( rSourceProps.moPattPreset );
 }
 
-// ============================================================================
-
 void BlipFillProperties::assignUsed( const BlipFillProperties& rSourceProps )
 {
     if( rSourceProps.mxGraphic.is() )
@@ -209,10 +204,9 @@ void BlipFillProperties::assignUsed( const BlipFillProperties& rSourceProps )
     maColorChangeTo.assignIfUsed( rSourceProps.maColorChangeTo );
     maDuotoneColors[0].assignIfUsed( rSourceProps.maDuotoneColors[0] );
     maDuotoneColors[1].assignIfUsed( rSourceProps.maDuotoneColors[1] );
+    maEffect.assignUsed( rSourceProps.maEffect );
 }
 
-// ============================================================================
-
 void FillProperties::assignUsed( const FillProperties& rSourceProps )
 {
     moFillType.assignIfUsed( rSourceProps.moFillType );
@@ -270,8 +264,8 @@ static drawing::Hatch createHatch( sal_Int32 nHatchToken, sal_Int32 nColor )
         case XML_pct90:      aHatch.Style = drawing::HatchStyle_TRIPLE; aHatch.Distance = 50;  aHatch.Angle = 450;  break;
         case XML_horz:       aHatch.Style = drawing::HatchStyle_SINGLE; aHatch.Distance = 100; aHatch.Angle = 0;    break;
         case XML_vert:       aHatch.Style = drawing::HatchStyle_SINGLE; aHatch.Distance = 100; aHatch.Angle = 900;  break;
-        case XML_ltHorz:     aHatch.Style = drawing::HatchStyle_SINGLE; aHatch.Distance = 150; aHatch.Angle = 0;    break;
-        case XML_ltVert:     aHatch.Style = drawing::HatchStyle_SINGLE; aHatch.Distance = 150; aHatch.Angle = 900;  break;
+        case XML_ltHorz:     aHatch.Style = drawing::HatchStyle_SINGLE; aHatch.Distance = 50;  aHatch.Angle = 0;    break;
+        case XML_ltVert:     aHatch.Style = drawing::HatchStyle_SINGLE; aHatch.Distance = 50;  aHatch.Angle = 900;  break;
         case XML_dkHorz:     aHatch.Style = drawing::HatchStyle_SINGLE; aHatch.Distance = 25;  aHatch.Angle = 0;    break;
         case XML_dkVert:     aHatch.Style = drawing::HatchStyle_SINGLE; aHatch.Distance = 25;  aHatch.Angle = 900;  break;
         case XML_narHorz:    aHatch.Style = drawing::HatchStyle_SINGLE; aHatch.Distance = 50;  aHatch.Angle = 0;    break;
@@ -281,26 +275,26 @@ static drawing::Hatch createHatch( sal_Int32 nHatchToken, sal_Int32 nColor )
         case XML_cross:      aHatch.Style = drawing::HatchStyle_DOUBLE; aHatch.Distance = 100; aHatch.Angle = 0;    break;
         case XML_dnDiag:     aHatch.Style = drawing::HatchStyle_SINGLE; aHatch.Distance = 100; aHatch.Angle = 1350; break;
         case XML_upDiag:     aHatch.Style = drawing::HatchStyle_SINGLE; aHatch.Distance = 100; aHatch.Angle = 450;  break;
-        case XML_ltDnDiag:   aHatch.Style = drawing::HatchStyle_SINGLE; aHatch.Distance = 150; aHatch.Angle = 1350; break;
-        case XML_ltUpDiag:   aHatch.Style = drawing::HatchStyle_SINGLE; aHatch.Distance = 150; aHatch.Angle = 450;  break;
+        case XML_ltDnDiag:   aHatch.Style = drawing::HatchStyle_SINGLE; aHatch.Distance = 50;  aHatch.Angle = 1350; break;
+        case XML_ltUpDiag:   aHatch.Style = drawing::HatchStyle_SINGLE; aHatch.Distance = 50;  aHatch.Angle = 450;  break;
         case XML_dkDnDiag:   aHatch.Style = drawing::HatchStyle_SINGLE; aHatch.Distance = 50;  aHatch.Angle = 1350; break;
         case XML_dkUpDiag:   aHatch.Style = drawing::HatchStyle_SINGLE; aHatch.Distance = 50;  aHatch.Angle = 450;  break;
-        case XML_wdDnDiag:   aHatch.Style = drawing::HatchStyle_SINGLE; aHatch.Distance = 200; aHatch.Angle = 1350; break;
-        case XML_wdUpDiag:   aHatch.Style = drawing::HatchStyle_SINGLE; aHatch.Distance = 200; aHatch.Angle = 450;  break;
+        case XML_wdDnDiag:   aHatch.Style = drawing::HatchStyle_SINGLE; aHatch.Distance = 100; aHatch.Angle = 1350; break;
+        case XML_wdUpDiag:   aHatch.Style = drawing::HatchStyle_SINGLE; aHatch.Distance = 100; aHatch.Angle = 450;  break;
         case XML_dashDnDiag: aHatch.Style = drawing::HatchStyle_SINGLE; aHatch.Distance = 150; aHatch.Angle = 1350; break;
         case XML_dashUpDiag: aHatch.Style = drawing::HatchStyle_SINGLE; aHatch.Distance = 150; aHatch.Angle = 450;  break;
         case XML_diagCross:  aHatch.Style = drawing::HatchStyle_DOUBLE; aHatch.Distance = 100; aHatch.Angle = 450;  break;
         case XML_smCheck:    aHatch.Style = drawing::HatchStyle_DOUBLE; aHatch.Distance = 50;  aHatch.Angle = 450;  break;
         case XML_lgCheck:    aHatch.Style = drawing::HatchStyle_DOUBLE; aHatch.Distance = 100; aHatch.Angle = 450;  break;
-        case XML_smGrid:     aHatch.Style = drawing::HatchStyle_DOUBLE; aHatch.Distance = 150; aHatch.Angle = 0;    break;
-        case XML_lgGrid:     aHatch.Style = drawing::HatchStyle_DOUBLE; aHatch.Distance = 250; aHatch.Angle = 0;    break;
+        case XML_smGrid:     aHatch.Style = drawing::HatchStyle_DOUBLE; aHatch.Distance = 50;  aHatch.Angle = 0;    break;
+        case XML_lgGrid:     aHatch.Style = drawing::HatchStyle_DOUBLE; aHatch.Distance = 100; aHatch.Angle = 0;    break;
         case XML_dotGrid:    aHatch.Style = drawing::HatchStyle_DOUBLE; aHatch.Distance = 400; aHatch.Angle = 0;    break;
         case XML_smConfetti: aHatch.Style = drawing::HatchStyle_SINGLE; aHatch.Distance = 200; aHatch.Angle = 600;  break;
         case XML_lgConfetti: aHatch.Style = drawing::HatchStyle_SINGLE; aHatch.Distance = 100; aHatch.Angle = 600;  break;
         case XML_horzBrick:  aHatch.Style = drawing::HatchStyle_DOUBLE; aHatch.Distance = 300; aHatch.Angle = 0;    break;
         case XML_diagBrick:  aHatch.Style = drawing::HatchStyle_DOUBLE; aHatch.Distance = 300; aHatch.Angle = 450;  break;
-        case XML_solidDmnd:  aHatch.Style = drawing::HatchStyle_DOUBLE; aHatch.Distance = 150; aHatch.Angle = 450;  break;
-        case XML_openDmnd:   aHatch.Style = drawing::HatchStyle_DOUBLE; aHatch.Distance = 200; aHatch.Angle = 450;  break;
+        case XML_solidDmnd:  aHatch.Style = drawing::HatchStyle_DOUBLE; aHatch.Distance = 100; aHatch.Angle = 450;  break;
+        case XML_openDmnd:   aHatch.Style = drawing::HatchStyle_DOUBLE; aHatch.Distance = 100; aHatch.Angle = 450;  break;
         case XML_dotDmnd:    aHatch.Style = drawing::HatchStyle_DOUBLE; aHatch.Distance = 300; aHatch.Angle = 450;  break;
         case XML_plaid:      aHatch.Style = drawing::HatchStyle_TRIPLE; aHatch.Distance = 200; aHatch.Angle = 900;  break;
         case XML_sphere:     aHatch.Style = drawing::HatchStyle_TRIPLE; aHatch.Distance = 100; aHatch.Angle = 0;    break;
@@ -371,7 +365,6 @@ void FillProperties::pushToPropMap( ShapePropertyMap& rPropMap,
                     if ( !maGradientProps.moRotateWithShape.get( false ) )
                         nShapeRotation = 0;
 
-                    sal_Int32 nDmlAngle = 0;
                     if( maGradientProps.moGradientPath.has() )
                     {
                         aGradient.Style = (maGradientProps.moGradientPath.get() == XML_circle) ? awt::GradientStyle_ELLIPTICAL : awt::GradientStyle_RECT;
@@ -383,7 +376,6 @@ void FillProperties::pushToPropMap( ShapePropertyMap& rPropMap,
                         aGradient.YOffset = getLimitedValue< sal_Int16, sal_Int32 >( nCenterY / PER_PERCENT, 30, 70 );
                         ::std::swap( aGradient.StartColor, aGradient.EndColor );
                         ::std::swap( nStartTrans, nEndTrans );
-                        nDmlAngle = nShapeRotation;
                     }
                     else
                     {
@@ -418,7 +410,7 @@ void FillProperties::pushToPropMap( ShapePropertyMap& rPropMap,
                                     bSymmetric = false;
                                 else
                                 {
-                                    aItA++;
+                                    ++aItA;
                                     aItZ = boost::prior(aItZ);
                                 }
                             }
@@ -446,7 +438,7 @@ void FillProperties::pushToPropMap( ShapePropertyMap& rPropMap,
                                  ", number of stops: " << aGradientStops.size());
                         for (GradientFillProperties::GradientStopMap::iterator p(aGradientStops.begin());
                              p != aGradientStops.end();
-                             p++)
+                             ++p)
                             SAL_INFO("oox.drawingml.gradient", "  " << std::distance(aGradientStops.begin(), p) << ": " <<
                                      p->first << ": " <<
                                      std::hex << p->second.getColor( rGraphicHelper, nPhClr ) << std::dec <<
@@ -459,7 +451,7 @@ void FillProperties::pushToPropMap( ShapePropertyMap& rPropMap,
                         GradientFillProperties::GradientStopMap::iterator aIt(aGradientStops.begin());
                         double nWidestWidth = -1;
                         GradientFillProperties::GradientStopMap::iterator aWidestSegmentStart;
-                        aIt++;
+                        ++aIt;
                         while( aIt != aGradientStops.end() )
                         {
                             if( aIt->first - boost::prior(aIt)->first > nWidestWidth )
@@ -467,7 +459,7 @@ void FillProperties::pushToPropMap( ShapePropertyMap& rPropMap,
                                 nWidestWidth = aIt->first - boost::prior(aIt)->first;
                                 aWidestSegmentStart = boost::prior(aIt);
                             }
-                            aIt++;
+                            ++aIt;
                         }
                         assert( nWidestWidth > 0 );
 
@@ -519,7 +511,7 @@ void FillProperties::pushToPropMap( ShapePropertyMap& rPropMap,
                                 nShapeRotation = 180*60000 - nShapeRotation;
                             }
 
-                            aGradientStops.erase( aWidestSegmentStart );
+                            aGradientStops.erase( aWidestSegmentStart++ );
 
                             // Look for which is widest now
                             aIt = boost::next(aGradientStops.begin());
@@ -531,7 +523,7 @@ void FillProperties::pushToPropMap( ShapePropertyMap& rPropMap,
                                     nWidestWidth = aIt->first - boost::prior(aIt)->first;
                                     aWidestSegmentStart = boost::prior(aIt);
                                 }
-                                aIt++;
+                                ++aIt;
                             }
                         }
                         SAL_INFO("oox.drawingml.gradient", "widest segment start: " << aWidestSegmentStart->first << ", border: " << nBorder);
@@ -540,7 +532,7 @@ void FillProperties::pushToPropMap( ShapePropertyMap& rPropMap,
                         // Now we have a potential border and a largest segment. Use those.
 
                         aGradient.Style = bSymmetric ? awt::GradientStyle_AXIAL : awt::GradientStyle_LINEAR;
-                        nDmlAngle = maGradientProps.moShadeAngle.get( 0 ) - nShapeRotation;
+                        sal_Int32 nDmlAngle = maGradientProps.moShadeAngle.get( 0 ) - nShapeRotation;
                         // convert DrawingML angle (in 1/60000 degrees) to API angle (in 1/10 degrees)
                         aGradient.Angle = static_cast< sal_Int16 >( (4500 - (nDmlAngle / (PER_DEGREE / 10))) % 3600 );
                         Color aStartColor, aEndColor;
@@ -562,7 +554,7 @@ void FillProperties::pushToPropMap( ShapePropertyMap& rPropMap,
                         }
 
                         SAL_INFO("oox.drawingml.gradient", "start color: " << std::hex << aStartColor.getColor( rGraphicHelper, nPhClr ) << std::dec <<
-                                 "@" << (100-aStartColor.getTransparency()) << "%" <<
+                                 "@" << (100-aStartColor.getTransparency()) << "%"
                                  ", end color: " << std::hex << aEndColor.getColor( rGraphicHelper, nPhClr ) << std::dec <<
                                  "@" << (100-aEndColor.getTransparency()) << "%");
 
@@ -641,6 +633,24 @@ void FillProperties::pushToPropMap( ShapePropertyMap& rPropMap,
                                 rPropMap.setProperty( SHAPEPROP_FillBitmapOffsetY, nTileOffsetY );
                             }
                         }
+                        else if ( eBitmapMode == BitmapMode_STRETCH && maBlipProps.moFillRect.has() )
+                        {
+                            geometry::IntegerRectangle2D aFillRect( maBlipProps.moFillRect.get() );
+                            awt::Size aOriginalSize( rGraphicHelper.getOriginalSize( xGraphic ) );
+                            if ( aOriginalSize.Width && aOriginalSize.Height )
+                            {
+                                text::GraphicCrop aGraphCrop( 0, 0, 0, 0 );
+                                if ( aFillRect.X1 )
+                                    aGraphCrop.Left = static_cast< sal_Int32 >( ( static_cast< double >( aOriginalSize.Width ) * aFillRect.X1 ) / 100000 );
+                                if ( aFillRect.Y1 )
+                                    aGraphCrop.Top = static_cast< sal_Int32 >( ( static_cast< double >( aOriginalSize.Height ) * aFillRect.Y1 ) / 100000 );
+                                if ( aFillRect.X2 )
+                                    aGraphCrop.Right = static_cast< sal_Int32 >( ( static_cast< double >( aOriginalSize.Width ) * aFillRect.X2 ) / 100000 );
+                                if ( aFillRect.Y2 )
+                                    aGraphCrop.Bottom = static_cast< sal_Int32 >( ( static_cast< double >( aOriginalSize.Height ) * aFillRect.Y2 ) / 100000 );
+                                rPropMap.setProperty(PROP_GraphicCrop, aGraphCrop);
+                            }
+                        }
                     }
                 }
             break;
@@ -680,34 +690,43 @@ void FillProperties::pushToPropMap( ShapePropertyMap& rPropMap,
     }
 }
 
-// ============================================================================
-
 void GraphicProperties::pushToPropMap( PropertyMap& rPropMap, const GraphicHelper& rGraphicHelper, sal_Int32 nPhClr ) const
 {
     sal_Int16 nBrightness = getLimitedValue< sal_Int16, sal_Int32 >( maBlipProps.moBrightness.get( 0 ) / PER_PERCENT, -100, 100 );
     sal_Int16 nContrast = getLimitedValue< sal_Int16, sal_Int32 >( maBlipProps.moContrast.get( 0 ) / PER_PERCENT, -100, 100 );
+    ColorMode eColorMode = ColorMode_STANDARD;
+
+    switch( maBlipProps.moColorEffect.get( XML_TOKEN_INVALID ) )
+    {
+        case XML_biLevel:   eColorMode = ColorMode_MONO;    break;
+        case XML_grayscl:   eColorMode = ColorMode_GREYS;   break;
+    }
+
     if( maBlipProps.mxGraphic.is() )
     {
         // created transformed graphic
         Reference< XGraphic > xGraphic = lclCheckAndApplyDuotoneTransform( maBlipProps, maBlipProps.mxGraphic, rGraphicHelper, nPhClr );
         xGraphic = lclCheckAndApplyChangeColorTransform( maBlipProps, xGraphic, rGraphicHelper, nPhClr );
 
-        // MSO uses a different algorithm for contrast+brightness, LO applies contrast before brightness,
-        // while MSO apparently applies half of brightness before contrast and half after. So if only
-        // contrast or brightness need to be altered, the result is the same, but if both are involved,
-        // there's no way to map that, so just force a conversion of the image.
-        if( nBrightness != 0 && nContrast != 0 )
+        if (eColorMode == ColorMode_STANDARD && nBrightness == 70 && nContrast == -70)
+            // map MSO 'washout' to our Watermark colormode
+            eColorMode = ColorMode_WATERMARK;
+        else if( nBrightness != 0 && nContrast != 0 )
         {
+            // MSO uses a different algorithm for contrast+brightness, LO applies contrast before brightness,
+            // while MSO apparently applies half of brightness before contrast and half after. So if only
+            // contrast or brightness need to be altered, the result is the same, but if both are involved,
+            // there's no way to map that, so just force a conversion of the image.
             xGraphic = applyBrightnessContrast( xGraphic, nBrightness, nContrast );
             nBrightness = 0;
             nContrast = 0;
         }
-        rPropMap[ PROP_Graphic ] <<= xGraphic;
+        rPropMap.setProperty(PROP_Graphic, xGraphic);
 
         // do we still need to set GraphicURL as well? (TODO)
         OUString aGraphicUrl = rGraphicHelper.createGraphicObject( xGraphic );
         if( !aGraphicUrl.isEmpty() )
-            rPropMap[ PROP_GraphicURL ] <<= aGraphicUrl;
+            rPropMap.setProperty(PROP_GraphicURL, aGraphicUrl);
 
         // cropping
         if ( maBlipProps.moClipRect.has() )
@@ -718,39 +737,237 @@ void GraphicProperties::pushToPropMap( PropertyMap& rPropMap, const GraphicHelpe
             {
                 text::GraphicCrop aGraphCrop( 0, 0, 0, 0 );
                 if ( oClipRect.X1 )
-                    aGraphCrop.Left = static_cast< sal_Int32 >( ( static_cast< double >( aOriginalSize.Width ) * oClipRect.X1 ) / 100000 );
+                    aGraphCrop.Left = rtl::math::round( ( static_cast< double >( aOriginalSize.Width ) * oClipRect.X1 ) / 100000 );
                 if ( oClipRect.Y1 )
-                    aGraphCrop.Top = static_cast< sal_Int32 >( ( static_cast< double >( aOriginalSize.Height ) * oClipRect.Y1 ) / 100000 );
+                    aGraphCrop.Top = rtl::math::round( ( static_cast< double >( aOriginalSize.Height ) * oClipRect.Y1 ) / 100000 );
                 if ( oClipRect.X2 )
-                    aGraphCrop.Right = static_cast< sal_Int32 >( ( static_cast< double >( aOriginalSize.Width ) * oClipRect.X2 ) / 100000 );
+                    aGraphCrop.Right = rtl::math::round( ( static_cast< double >( aOriginalSize.Width ) * oClipRect.X2 ) / 100000 );
                 if ( oClipRect.Y2 )
-                    aGraphCrop.Bottom = static_cast< sal_Int32 >( ( static_cast< double >( aOriginalSize.Height ) * oClipRect.Y2 ) / 100000 );
-                rPropMap[ PROP_GraphicCrop ] <<= aGraphCrop;
+                    aGraphCrop.Bottom = rtl::math::round( ( static_cast< double >( aOriginalSize.Height ) * oClipRect.Y2 ) / 100000 );
+                rPropMap.setProperty(PROP_GraphicCrop, aGraphCrop);
             }
         }
     }
-
-    // color effect
-    ColorMode eColorMode = ColorMode_STANDARD;
-    switch( maBlipProps.moColorEffect.get( XML_TOKEN_INVALID ) )
-    {
-        case XML_biLevel:   eColorMode = ColorMode_MONO;    break;
-        case XML_grayscl:   eColorMode = ColorMode_GREYS;   break;
-    }
-    rPropMap[ PROP_GraphicColorMode ] <<= eColorMode;
+    rPropMap.setProperty(PROP_GraphicColorMode, eColorMode);
 
     // brightness and contrast
     if( nBrightness != 0 )
-        rPropMap[ PROP_AdjustLuminance ] <<= nBrightness;
+        rPropMap.setProperty(PROP_AdjustLuminance, nBrightness);
     if( nContrast != 0 )
-        rPropMap[ PROP_AdjustContrast ] <<= nContrast;
+        rPropMap.setProperty(PROP_AdjustContrast, nContrast);
 
     // Media content
-    if( !maAudio.msEmbed.isEmpty() )
-        rPropMap[ PROP_MediaURL ] <<= maAudio.msEmbed;
+    assert(m_xMediaStream.is() != m_sMediaPackageURL.isEmpty());
+    if (m_xMediaStream.is() && !m_sMediaPackageURL.isEmpty())
+    {
+        rPropMap.setProperty(PROP_PrivateStream, m_xMediaStream);
+        rPropMap.setProperty(PROP_MediaURL, m_sMediaPackageURL);
+    }
 }
 
-// ============================================================================
+bool ArtisticEffectProperties::isEmpty() const
+{
+    return msName.isEmpty();
+}
+
+css::beans::PropertyValue ArtisticEffectProperties::getEffect()
+{
+    css::beans::PropertyValue pRet;
+    if( msName.isEmpty() )
+        return pRet;
+
+    css::uno::Sequence< css::beans::PropertyValue > aSeq( maAttribs.size() + 1 );
+    sal_uInt32 i = 0;
+    for( std::map< OUString, css::uno::Any >::iterator it = maAttribs.begin(); it != maAttribs.end(); ++it )
+    {
+        aSeq[i].Name = it->first;
+        aSeq[i].Value = it->second;
+        i++;
+    }
+
+    if( mrOleObjectInfo.maEmbeddedData.hasElements() )
+    {
+        css::uno::Sequence< css::beans::PropertyValue > aGraphicSeq( 2 );
+        aGraphicSeq[0].Name = "Id";
+        aGraphicSeq[0].Value = uno::makeAny( mrOleObjectInfo.maProgId );
+        aGraphicSeq[1].Name = "Data";
+        aGraphicSeq[1].Value = uno::makeAny( mrOleObjectInfo.maEmbeddedData );
+
+        aSeq[i].Name = "OriginalGraphic";
+        aSeq[i].Value = uno::makeAny( aGraphicSeq );
+    }
+
+    pRet.Name = msName;
+    pRet.Value = css::uno::Any( aSeq );
+
+    return pRet;
+}
+
+void ArtisticEffectProperties::assignUsed( const ArtisticEffectProperties& rSourceProps )
+{
+    if( !rSourceProps.isEmpty() )
+    {
+        msName = rSourceProps.msName;
+        maAttribs = rSourceProps.maAttribs;
+    }
+}
+
+OUString ArtisticEffectProperties::getEffectString( sal_Int32 nToken )
+{
+    switch( nToken )
+    {
+        // effects
+        case OOX_TOKEN( a14, artisticBlur ):                return OUString( "artisticBlur" );
+        case OOX_TOKEN( a14, artisticCement ):              return OUString( "artisticCement" );
+        case OOX_TOKEN( a14, artisticChalkSketch ):         return OUString( "artisticChalkSketch" );
+        case OOX_TOKEN( a14, artisticCrisscrossEtching ):   return OUString( "artisticCrisscrossEtching" );
+        case OOX_TOKEN( a14, artisticCutout ):              return OUString( "artisticCutout" );
+        case OOX_TOKEN( a14, artisticFilmGrain ):           return OUString( "artisticFilmGrain" );
+        case OOX_TOKEN( a14, artisticGlass ):               return OUString( "artisticGlass" );
+        case OOX_TOKEN( a14, artisticGlowDiffused ):        return OUString( "artisticGlowDiffused" );
+        case OOX_TOKEN( a14, artisticGlowEdges ):           return OUString( "artisticGlowEdges" );
+        case OOX_TOKEN( a14, artisticLightScreen ):         return OUString( "artisticLightScreen" );
+        case OOX_TOKEN( a14, artisticLineDrawing ):         return OUString( "artisticLineDrawing" );
+        case OOX_TOKEN( a14, artisticMarker ):              return OUString( "artisticMarker" );
+        case OOX_TOKEN( a14, artisticMosiaicBubbles ):      return OUString( "artisticMosiaicBubbles" );
+        case OOX_TOKEN( a14, artisticPaintStrokes ):        return OUString( "artisticPaintStrokes" );
+        case OOX_TOKEN( a14, artisticPaintBrush ):          return OUString( "artisticPaintBrush" );
+        case OOX_TOKEN( a14, artisticPastelsSmooth ):       return OUString( "artisticPastelsSmooth" );
+        case OOX_TOKEN( a14, artisticPencilGrayscale ):     return OUString( "artisticPencilGrayscale" );
+        case OOX_TOKEN( a14, artisticPencilSketch ):        return OUString( "artisticPencilSketch" );
+        case OOX_TOKEN( a14, artisticPhotocopy ):           return OUString( "artisticPhotocopy" );
+        case OOX_TOKEN( a14, artisticPlasticWrap ):         return OUString( "artisticPlasticWrap" );
+        case OOX_TOKEN( a14, artisticTexturizer ):          return OUString( "artisticTexturizer" );
+        case OOX_TOKEN( a14, artisticWatercolorSponge ):    return OUString( "artisticWatercolorSponge" );
+        case OOX_TOKEN( a14, artisticBrightnessContrast ):  return OUString( "artisticBrightnessContrast" );
+        case OOX_TOKEN( a14, artisticColorTemperature ):    return OUString( "artisticColorTemperature" );
+        case OOX_TOKEN( a14, artisticSaturation ):          return OUString( "artisticSaturation" );
+        case OOX_TOKEN( a14, artisticSharpenSoften ):       return OUString( "artisticSharpenSoften" );
+
+        // attributes
+        case XML_visible:           return OUString( "visible" );
+        case XML_trans:             return OUString( "trans" );
+        case XML_crackSpacing:      return OUString( "crackSpacing" );
+        case XML_pressure:          return OUString( "pressure" );
+        case XML_numberOfShades:    return OUString( "numberOfShades" );
+        case XML_grainSize:         return OUString( "grainSize" );
+        case XML_intensity:         return OUString( "intensity" );
+        case XML_smoothness:        return OUString( "smoothness" );
+        case XML_gridSize:          return OUString( "gridSize" );
+        case XML_pencilSize:        return OUString( "pencilSize" );
+        case XML_size:              return OUString( "size" );
+        case XML_brushSize:         return OUString( "brushSize" );
+        case XML_scaling:           return OUString( "scaling" );
+        case XML_detail:            return OUString( "detail" );
+        case XML_bright:            return OUString( "bright" );
+        case XML_contrast:          return OUString( "contrast" );
+        case XML_colorTemp:         return OUString( "colorTemp" );
+        case XML_sat:               return OUString( "sat" );
+        case XML_amount:            return OUString( "amount" );
+    }
+    SAL_WARN( "oox.drawingml", "ArtisticEffectProperties::getEffectString - unexpected token" );
+    return OUString();
+}
+
+sal_Int32 ArtisticEffectProperties::getEffectToken( const OUString& sName )
+{
+    // effects
+    if( sName == "artisticBlur" )
+        return XML_artisticBlur;
+    else if( sName == "artisticCement" )
+        return XML_artisticCement;
+    else if( sName == "artisticChalkSketch" )
+        return XML_artisticChalkSketch;
+    else if( sName == "artisticCrisscrossEtching" )
+        return XML_artisticCrisscrossEtching;
+    else if( sName == "artisticCutout" )
+        return XML_artisticCutout;
+    else if( sName == "artisticFilmGrain" )
+        return XML_artisticFilmGrain;
+    else if( sName == "artisticGlass" )
+        return XML_artisticGlass;
+    else if( sName == "artisticGlowDiffused" )
+        return XML_artisticGlowDiffused;
+    else if( sName == "artisticGlowEdges" )
+        return XML_artisticGlowEdges;
+    else if( sName == "artisticLightScreen" )
+        return XML_artisticLightScreen;
+    else if( sName == "artisticLineDrawing" )
+        return XML_artisticLineDrawing;
+    else if( sName == "artisticMarker" )
+        return XML_artisticMarker;
+    else if( sName == "artisticMosiaicBubbles" )
+        return XML_artisticMosiaicBubbles;
+    else if( sName == "artisticPaintStrokes" )
+        return XML_artisticPaintStrokes;
+    else if( sName == "artisticPaintBrush" )
+        return XML_artisticPaintBrush;
+    else if( sName == "artisticPastelsSmooth" )
+        return XML_artisticPastelsSmooth;
+    else if( sName == "artisticPencilGrayscale" )
+        return XML_artisticPencilGrayscale;
+    else if( sName == "artisticPencilSketch" )
+        return XML_artisticPencilSketch;
+    else if( sName == "artisticPhotocopy" )
+        return XML_artisticPhotocopy;
+    else if( sName == "artisticPlasticWrap" )
+        return XML_artisticPlasticWrap;
+    else if( sName == "artisticTexturizer" )
+        return XML_artisticTexturizer;
+    else if( sName == "artisticWatercolorSponge" )
+        return XML_artisticWatercolorSponge;
+    else if( sName == "artisticBrightnessContrast" )
+        return XML_artisticBrightnessContrast;
+    else if( sName == "artisticColorTemperature" )
+        return XML_artisticColorTemperature;
+    else if( sName == "artisticSaturation" )
+        return XML_artisticSaturation;
+    else if( sName == "artisticSharpenSoften" )
+        return XML_artisticSharpenSoften;
+
+    // attributes
+    else if( sName == "visible" )
+        return XML_visible;
+    else if( sName == "trans" )
+        return XML_trans;
+    else if( sName == "crackSpacing" )
+        return XML_crackSpacing;
+    else if( sName == "pressure" )
+        return XML_pressure;
+    else if( sName == "numberOfShades" )
+        return XML_numberOfShades;
+    else if( sName == "grainSize" )
+        return XML_grainSize;
+    else if( sName == "intensity" )
+        return XML_intensity;
+    else if( sName == "smoothness" )
+        return XML_smoothness;
+    else if( sName == "gridSize" )
+        return XML_gridSize;
+    else if( sName == "pencilSize" )
+        return XML_pencilSize;
+    else if( sName == "size" )
+        return XML_size;
+    else if( sName == "brushSize" )
+        return XML_brushSize;
+    else if( sName == "scaling" )
+        return XML_scaling;
+    else if( sName == "detail" )
+        return XML_detail;
+    else if( sName == "bright" )
+        return XML_bright;
+    else if( sName == "contrast" )
+        return XML_contrast;
+    else if( sName == "colorTemp" )
+        return XML_colorTemp;
+    else if( sName == "sat" )
+        return XML_sat;
+    else if( sName == "amount" )
+        return XML_amount;
+
+    SAL_WARN( "oox.drawingml", "ArtisticEffectProperties::getEffectToken - unexpected token name" );
+    return XML_none;
+}
 
 } // namespace drawingml
 } // namespace oox
