@@ -19,11 +19,11 @@
 
 #include <osl/diagnose.h>
 #include "oox/helper/attributelist.hxx"
-#include "oox/drawingml/guidcontext.hxx"
-#include "oox/drawingml/table/tablecontext.hxx"
-#include "oox/drawingml/table/tableproperties.hxx"
-#include "oox/drawingml/table/tablestylecontext.hxx"
-#include "oox/drawingml/table/tablerowcontext.hxx"
+#include "drawingml/guidcontext.hxx"
+#include "drawingml/table/tablecontext.hxx"
+#include "drawingml/table/tableproperties.hxx"
+#include "drawingml/table/tablestylecontext.hxx"
+#include "drawingml/table/tablerowcontext.hxx"
 
 using namespace ::oox::core;
 using namespace ::com::sun::star;
@@ -48,18 +48,18 @@ TableContext::onCreateContext( ::sal_Int32 aElementToken, const AttributeList& r
     {
     case A_TOKEN( tblPr ):              // CT_TableProperties
         {
-            mrTableProperties.isRtl() = rAttribs.getBool( XML_rtl, sal_False );
-            mrTableProperties.isFirstRow() = rAttribs.getBool( XML_firstRow, sal_False );
-            mrTableProperties.isFirstCol() = rAttribs.getBool( XML_firstCol, sal_False );
-            mrTableProperties.isLastRow() = rAttribs.getBool( XML_lastRow, sal_False );
-            mrTableProperties.isLastCol() = rAttribs.getBool( XML_lastCol, sal_False );
-            mrTableProperties.isBandRow() = rAttribs.getBool( XML_bandRow, sal_False );
-            mrTableProperties.isBandCol() = rAttribs.getBool( XML_bandCol, sal_False );
+            mrTableProperties.isRtl() = rAttribs.getBool( XML_rtl, false );
+            mrTableProperties.isFirstRow() = rAttribs.getBool( XML_firstRow, false );
+            mrTableProperties.isFirstCol() = rAttribs.getBool( XML_firstCol, false );
+            mrTableProperties.isLastRow() = rAttribs.getBool( XML_lastRow, false );
+            mrTableProperties.isLastCol() = rAttribs.getBool( XML_lastCol, false );
+            mrTableProperties.isBandRow() = rAttribs.getBool( XML_bandRow, false );
+            mrTableProperties.isBandCol() = rAttribs.getBool( XML_bandCol, false );
         }
         break;
     case A_TOKEN( tableStyle ):         // CT_TableStyle
         {
-            boost::shared_ptr< TableStyle >& rTableStyle = mrTableProperties.getTableStyle();
+            std::shared_ptr< TableStyle >& rTableStyle = mrTableProperties.getTableStyle();
             rTableStyle.reset( new TableStyle() );
             return new TableStyleContext( *this, rAttribs, *rTableStyle );
         }
