@@ -31,6 +31,7 @@
 #include <com/sun/star/uno/XComponentContext.hpp>
 #include <comphelper/configurationhelper.hxx>
 #include <comphelper/string.hxx>
+#include <osl/diagnose.h>
 #include <rtl/tencinfo.h>
 #include <rtl/ustrbuf.h>
 #include "oox/helper/binaryinputstream.hxx"
@@ -47,8 +48,6 @@
 namespace oox {
 namespace ole {
 
-// ============================================================================
-
 using namespace ::com::sun::star::container;
 using namespace ::com::sun::star::document;
 using namespace ::com::sun::star::embed;
@@ -61,8 +60,6 @@ using namespace ::com::sun::star::uno;
 
 using ::comphelper::ConfigurationHelper;
 
-// ============================================================================
-
 namespace {
 
 bool lclReadConfigItem( const Reference< XInterface >& rxConfigAccess, const OUString& rItemName )
@@ -81,8 +78,6 @@ bool lclReadConfigItem( const Reference< XInterface >& rxConfigAccess, const OUS
 
 } // namespace
 
-// ----------------------------------------------------------------------------
-
 VbaFilterConfig::VbaFilterConfig( const Reference< XComponentContext >& rxContext, const OUString& rConfigCompName )
 {
     OSL_ENSURE( rxContext.is(), "VbaFilterConfig::VbaFilterConfig - missing component context" );
@@ -117,8 +112,6 @@ bool VbaFilterConfig::isExportVba() const
     return lclReadConfigItem( mxConfigAccess, "Save" );
 }
 
-// ============================================================================
-
 VbaMacroAttacherBase::VbaMacroAttacherBase( const OUString& rMacroName ) :
     maMacroName( rMacroName )
 {
@@ -140,8 +133,6 @@ void VbaMacroAttacherBase::resolveAndAttachMacro( const Reference< XVBAMacroReso
     }
 }
 
-// ============================================================================
-
 VbaProject::VbaProject( const Reference< XComponentContext >& rxContext,
         const Reference< XModel >& rxDocModel, const OUString& rConfigCompName ) :
     VbaFilterConfig( rxContext, rConfigCompName ),
@@ -157,15 +148,14 @@ VbaProject::~VbaProject()
 {
 }
 
-
 bool VbaProject::importVbaProject( StorageBase& rVbaPrjStrg )
 {
    // create GraphicHelper
-   Reference< ::com::sun::star::frame::XFrame > xFrame;
+   Reference< css::frame::XFrame > xFrame;
    if ( mxDocModel.is() )
    {
-       Reference< ::com::sun::star::frame::XController > xController =  mxDocModel->getCurrentController();
-       xFrame =  xController.is() ? xController->getFrame() : NULL;
+       Reference< css::frame::XController > xController =  mxDocModel->getCurrentController();
+       xFrame =  xController.is() ? xController->getFrame() : nullptr;
    }
    StorageRef noStorage;
    // if the GraphicHelper tries to use noStorage it will of course crash
@@ -218,10 +208,6 @@ void VbaProject::prepareImport()
 {
 }
 
-void VbaProject::finalizeImport()
-{
-}
-
 // private --------------------------------------------------------------------
 
 Reference< XLibraryContainer > VbaProject::getLibraryContainer( sal_Int32 nPropId )
@@ -294,7 +280,6 @@ void VbaProject::readVbaModules( StorageBase& rVbaPrjStrg )
     sal_uInt16 nModuleCount = 0;
     bool bExecutable = isImportVbaExecutable();
 
-
     sal_uInt16 nRecId = 0;
     StreamDataSequence aRecData;
     while( VbaHelper::readDirRecord( nRecId, aRecData, aDirStrm ) && (nRecId != VBA_ID_PROJECTEND) )
@@ -304,10 +289,9 @@ void VbaProject::readVbaModules( StorageBase& rVbaPrjStrg )
         sal_Int32 nRecSize = aRecData.getLength();
         switch( nRecId )
         {
-#define OOX_ENSURE_RECORDSIZE( cond ) OSL_ENSURE( cond, "VbaProject::importVba - invalid record size" )
             case VBA_ID_PROJECTCODEPAGE:
             {
-                OOX_ENSURE_RECORDSIZE( nRecSize == 2 );
+                OSL_ENSURE( nRecSize == 2, "VbaProject::importVba - invalid record size" );
                 OSL_ENSURE( maModules.empty(), "VbaProject::importVba - unexpected PROJECTCODEPAGE record" );
                 rtl_TextEncoding eNewTextEnc = rtl_getTextEncodingFromWindowsCodePage( aRecStrm.readuInt16() );
                 OSL_ENSURE( eNewTextEnc != RTL_TEXTENCODING_DONTKNOW, "VbaProject::importVba - unknown text encoding" );
@@ -324,9 +308,9 @@ void VbaProject::readVbaModules( StorageBase& rVbaPrjStrg )
             }
             break;
             case VBA_ID_PROJECTMODULES:
-                OOX_ENSURE_RECORDSIZE( nRecSize == 2 );
+                OSL_ENSURE( nRecSize == 2, "VbaProject::importVba - invalid record size" );
                 OSL_ENSURE( maModules.empty(), "VbaProject::importVba - unexpected PROJECTMODULES record" );
-                aRecStrm >> nModuleCount;
+                nModuleCount = aRecStrm.readuInt16();
             break;
             case VBA_ID_MODULENAME:
             {
@@ -341,10 +325,9 @@ void VbaProject::readVbaModules( StorageBase& rVbaPrjStrg )
                 maModulesByStrm[ rxModule->getStreamName() ] = rxModule;
             }
             break;
-#undef OOX_ENSURE_RECORDSIZE
         }
     }
-    OSL_ENSURE( nModuleCount == maModules.size(), "VbaProject::importVba - invalid module count" );
+    SAL_WARN_IF( nModuleCount != maModules.size(), "oox", "VbaProject::importVba - invalid module count" );
 
     /*  The directory does not contain the real type of the modules, it
         distinguishes only between 'procedural' and 'document' (the latter
@@ -521,8 +504,6 @@ void VbaProject::importModulesAndForms( StorageBase& rVbaPrjStrg, const GraphicH
 
     // attach macros to registered objects
     attachMacros();
-    // virtual call, derived classes may do some more processing
-    finalizeImport();
 }
 
 void VbaProject::attachMacros()
@@ -562,8 +543,6 @@ void VbaProject::copyStorage( StorageBase& rVbaPrjStrg )
     }
 }
 
-// ============================================================================
-
 } // namespace ole
 } // namespace oox
 
