@@ -19,11 +19,13 @@
 
 #include <sal/config.h>
 
+#include <com/sun/star/lang/XMultiServiceFactory.hpp>
 #include <com/sun/star/uno/XComponentContext.hpp>
+#include <osl/diagnose.h>
 #include "oox/ppt/pptimport.hxx"
 #include "oox/drawingml/chart/chartconverter.hxx"
 #include "oox/dump/pptxdumper.hxx"
-#include "oox/drawingml/table/tablestylelistfragmenthandler.hxx"
+#include "drawingml/table/tablestylelistfragmenthandler.hxx"
 #include "oox/helper/graphichelper.hxx"
 #include "oox/ole/vbaproject.hxx"
 
@@ -58,7 +60,7 @@ uno::Reference< uno::XInterface > SAL_CALL PowerPointImport_createInstance( cons
 }
 
 #if OSL_DEBUG_LEVEL > 0
-XmlFilterBase* PowerPointImport::mpDebugFilterBase = NULL;
+XmlFilterBase* PowerPointImport::mpDebugFilterBase = nullptr;
 #endif
 
 PowerPointImport::PowerPointImport( const Reference< XComponentContext >& rxContext ) throw( RuntimeException ) :
@@ -75,7 +77,7 @@ PowerPointImport::~PowerPointImport()
 {
 }
 
-bool PowerPointImport::importDocument() throw()
+bool PowerPointImport::importDocument()
 {
     /*  to activate the PPTX dumper, define the environment variable
         OOO_PPTXDUMPER and insert the full path to the file
@@ -89,7 +91,6 @@ bool PowerPointImport::importDocument() throw()
     maTableStyleListPath = xPresentationFragmentHandler->getFragmentPathFromFirstTypeFromOfficeDoc( "tableStyles" );
     return importFragment( xPresentationFragmentHandler );
 
-
 }
 
 bool PowerPointImport::exportDocument() throw()
@@ -114,7 +115,7 @@ sal_Int32 PowerPointImport::getSchemeColor( sal_Int32 nToken ) const
             {
                 pClrMapPtr = pMasterPersist->getClrMap();
                 if ( pClrMapPtr )
-                    bColorMapped = pClrMapPtr->getColorMap( nToken );
+                    pClrMapPtr->getColorMap( nToken );
             }
         }
         oox::drawingml::ClrSchemePtr pClrSchemePtr( mpActualSlidePersist->getClrScheme() );
@@ -138,7 +139,7 @@ sal_Int32 PowerPointImport::getSchemeColor( sal_Int32 nToken ) const
 
 const ::oox::drawingml::Theme* PowerPointImport::getCurrentTheme() const
 {
-    return mpActualSlidePersist ? mpActualSlidePersist->getTheme().get() : 0;
+    return mpActualSlidePersist ? mpActualSlidePersist->getTheme().get() : nullptr;
 }
 
 sal_Bool SAL_CALL PowerPointImport::filter( const Sequence< PropertyValue >& rDescriptor ) throw( RuntimeException, std::exception )
@@ -166,7 +167,7 @@ sal_Bool SAL_CALL PowerPointImport::filter( const Sequence< PropertyValue >& rDe
 
 ::oox::vml::Drawing* PowerPointImport::getVmlDrawing()
 {
-    return mpActualSlidePersist ? mpActualSlidePersist->getDrawing() : 0;
+    return mpActualSlidePersist ? mpActualSlidePersist->getDrawing() : nullptr;
 }
 
 const oox::drawingml::table::TableStyleListPtr PowerPointImport::getTableStyles()
@@ -191,8 +192,8 @@ class PptGraphicHelper : public GraphicHelper
 {
 public:
     explicit            PptGraphicHelper( const PowerPointImport& rFilter );
-    virtual sal_Int32   getSchemeColor( sal_Int32 nToken ) const SAL_OVERRIDE;
-    virtual drawing::FillStyle getDefaultChartAreaFillStyle() const SAL_OVERRIDE;
+    virtual sal_Int32   getSchemeColor( sal_Int32 nToken ) const override;
+    virtual sal_Int32 getDefaultChartAreaFillStyle() const override;
 private:
     const PowerPointImport& mrFilter;
 };
@@ -208,9 +209,9 @@ sal_Int32 PptGraphicHelper::getSchemeColor( sal_Int32 nToken ) const
     return mrFilter.getSchemeColor( nToken );
 }
 
-drawing::FillStyle PptGraphicHelper::getDefaultChartAreaFillStyle() const
+sal_Int32 PptGraphicHelper::getDefaultChartAreaFillStyle() const
 {
-    return drawing::FillStyle_NONE;
+    return XML_noFill;
 }
 
 } // namespace
@@ -225,7 +226,7 @@ GraphicHelper* PowerPointImport::implCreateGraphicHelper() const
     return new ::oox::ole::VbaProject( getComponentContext(), getModel(), "Impress" );
 }
 
-OUString PowerPointImport::implGetImplementationName() const
+OUString PowerPointImport::getImplementationName() throw (css::uno::RuntimeException, std::exception)
 {
     return PowerPointImport_getImplementationName();
 }
