@@ -41,7 +41,7 @@
 #include "oox/helper/attributelist.hxx"
 #include "oox/core/xmlfilterbase.hxx"
 #include "oox/drawingml/drawingmltypes.hxx"
-#include "oox/drawingml/colorchoicecontext.hxx"
+#include "drawingml/colorchoicecontext.hxx"
 #include "oox/ppt/slidetransition.hxx"
 
 #include "animvariantcontext.hxx"
@@ -70,27 +70,32 @@ namespace oox { namespace ppt {
             {
             }
 
-        sal_Int32 get()
+        Any get()
             {
                 sal_Int32 nColor;
+                Sequence< double > aHSL( 3 );
+                Any aColor;
 
                 switch( colorSpace )
                 {
                 case AnimationColorSpace::HSL:
-                    nColor = ( ( ( one * 128 ) / 360 ) & 0xff ) << 16
-                        | ( ( ( two * 128 ) / 1000 ) & 0xff ) << 8
-                        | ( ( ( three * 128 ) / 1000 )  & 0xff );
+                    aHSL[ 0 ] = double(one) / 100000;
+                    aHSL[ 1 ] = double(two) / 100000;
+                    aHSL[ 2 ] = double(three) / 100000;
+                    aColor = Any(aHSL);
                     break;
                 case AnimationColorSpace::RGB:
                     nColor = ( ( ( one * 128 ) / 1000 ) & 0xff ) << 16
                         | ( ( ( two * 128 ) / 1000 ) & 0xff ) << 8
                         | ( ( ( three * 128 ) / 1000 )  & 0xff );
+                    aColor = Any(nColor);
                     break;
                 default:
                     nColor = 0;
+                    aColor = Any( nColor );
                     break;
                 }
-                return  nColor;
+                return  aColor;
             }
 
         sal_Int16 colorSpace;
@@ -99,7 +104,6 @@ namespace oox { namespace ppt {
         sal_Int32 three;
     };
 
-
     /** CT_TLMediaNodeAudio
             CT_TLMediaNodeVideo */
     class MediaNodeContext
@@ -128,7 +132,7 @@ namespace oox { namespace ppt {
                 }
             }
 
-        virtual void onEndElement()
+        virtual void onEndElement() override
             {
                 sal_Int32 aElement = getCurrentElement();
                 if( aElement == PPT_TOKEN( audio ) )
@@ -141,7 +145,7 @@ namespace oox { namespace ppt {
                 }
             }
 
-        virtual ::oox::core::ContextHandlerRef onCreateContext( sal_Int32 aElementToken, const AttributeList& rAttribs )
+        virtual ::oox::core::ContextHandlerRef onCreateContext( sal_Int32 aElementToken, const AttributeList& rAttribs ) override
             {
                 switch ( aElementToken )
                 {
@@ -159,7 +163,6 @@ namespace oox { namespace ppt {
         bool mbFullScrn;
     };
 
-
     /** CT_TLSetBehavior
      */
     class SetTimeNodeContext
@@ -174,7 +177,7 @@ namespace oox { namespace ppt {
 
             }
 
-        ~SetTimeNodeContext() throw ()
+        virtual ~SetTimeNodeContext() throw ()
             {
                 if( maTo.hasValue() )
                 {
@@ -184,7 +187,7 @@ namespace oox { namespace ppt {
                     if( maTo >>= aString )
                     {
                         OSL_TRACE( "Magic conversion %s", OUSTRING_TO_CSTR( aString ) );
-                        maTo = makeAny( aString == "visible" ? sal_True : sal_False );
+                        maTo = makeAny( aString == "visible" );
                         if( !maTo.has<sal_Bool>() )
                             OSL_TRACE( "conversion failed" );
                     }
@@ -193,7 +196,7 @@ namespace oox { namespace ppt {
 
             }
 
-            virtual ::oox::core::ContextHandlerRef onCreateContext( sal_Int32 aElementToken, const AttributeList& rAttribs )
+            virtual ::oox::core::ContextHandlerRef onCreateContext( sal_Int32 aElementToken, const AttributeList& rAttribs ) override
             {
                 switch ( aElementToken )
                 {
@@ -235,11 +238,11 @@ namespace oox { namespace ppt {
                 }
             }
 
-        ~CmdTimeNodeContext() throw ()
+        virtual ~CmdTimeNodeContext() throw ()
             {
             }
 
-        virtual void onEndElement()
+        virtual void onEndElement() override
             {
                 if( isCurrentElement( PPT_TOKEN( cmd ) ) )
                 {
@@ -269,11 +272,11 @@ namespace oox { namespace ppt {
                             {
                                 nCommand = EffectCommands::PLAY;
                             }
-                            else if( msCommand.equalsAscii( "playFrom" ) )
+                            else if( msCommand == "playFrom" )
                             {
                                 const OUString aMediaTime( msCommand.copy( 9, msCommand.getLength() - 10 ) );
                                 rtl_math_ConversionStatus eStatus;
-                                double fMediaTime = ::rtl::math::stringToDouble( aMediaTime, (sal_Unicode)('.'), (sal_Unicode)(','), &eStatus, NULL );
+                                double fMediaTime = ::rtl::math::stringToDouble( aMediaTime, (sal_Unicode)('.'), (sal_Unicode)(','), &eStatus );
                                 if( eStatus == rtl_math_ConversionStatus_Ok )
                                 {
                                     aParamValue.Name = "MediaTime";
@@ -311,8 +314,7 @@ namespace oox { namespace ppt {
                 }
             }
 
-
-        virtual ::oox::core::ContextHandlerRef onCreateContext( sal_Int32 aElementToken, const AttributeList& rAttribs )
+        virtual ::oox::core::ContextHandlerRef onCreateContext( sal_Int32 aElementToken, const AttributeList& rAttribs ) override
             {
                 switch ( aElementToken )
                 {
@@ -330,7 +332,6 @@ namespace oox { namespace ppt {
         sal_Int32 maType;
     };
 
-
     /** CT_TLTimeNodeSequence
      */
     class SequenceTimeNodeContext
@@ -350,12 +351,11 @@ namespace oox { namespace ppt {
                 mnPrevAc = xAttribs->getOptionalValueToken( XML_prevAc, 0 );
             }
 
-        ~SequenceTimeNodeContext() throw()
+        virtual ~SequenceTimeNodeContext() throw()
             {
             }
 
-
-        virtual ::oox::core::ContextHandlerRef onCreateContext( sal_Int32 aElementToken, const AttributeList& rAttribs )
+        virtual ::oox::core::ContextHandlerRef onCreateContext( sal_Int32 aElementToken, const AttributeList& rAttribs ) override
             {
                 switch ( aElementToken )
                 {
@@ -378,7 +378,6 @@ namespace oox { namespace ppt {
         sal_Int32 mnNextAc, mnPrevAc;
     };
 
-
     /** CT_TLTimeNodeParallel
      *  CT_TLTimeNodeExclusive
      */
@@ -393,7 +392,7 @@ namespace oox { namespace ppt {
             {
             }
 
-        virtual ::oox::core::ContextHandlerRef onCreateContext( sal_Int32 aElementToken, const AttributeList& rAttribs )
+        virtual ::oox::core::ContextHandlerRef onCreateContext( sal_Int32 aElementToken, const AttributeList& rAttribs ) override
             {
                 switch ( aElementToken )
                 {
@@ -410,7 +409,6 @@ namespace oox { namespace ppt {
 
     };
 
-
     /** CT_TLAnimateColorBehavior */
     class AnimColorContext
         : public TimeNodeContext
@@ -426,11 +424,11 @@ namespace oox { namespace ppt {
             , m_byColor( AnimationColorSpace::RGB, 0, 0, 0)
             {
             }
-        ~AnimColorContext() throw()
+        virtual ~AnimColorContext() throw()
             {
             }
 
-        virtual void onEndElement()
+        virtual void onEndElement() override
             {
                 //xParentNode
                 if( isCurrentElement( mnElement ) )
@@ -444,12 +442,11 @@ namespace oox { namespace ppt {
                     if( maFromClr.isUsed() )
                         mpNode->setFrom( Any( maFromClr.getColor( rGraphicHelper ) ) );
                     if( mbHasByColor )
-                        mpNode->setBy( Any ( m_byColor.get() ) );
+                        mpNode->setBy( m_byColor.get() );
                 }
             }
 
-
-            virtual ::oox::core::ContextHandlerRef onCreateContext( sal_Int32 aElementToken, const AttributeList& rAttribs )
+            virtual ::oox::core::ContextHandlerRef onCreateContext( sal_Int32 aElementToken, const AttributeList& rAttribs ) override
             {
                 switch ( aElementToken )
                 {
@@ -497,7 +494,6 @@ namespace oox { namespace ppt {
                 return this;
             }
 
-
     private:
         sal_Int32 mnColorSpace;
         sal_Int32 mnDir;
@@ -507,7 +503,6 @@ namespace oox { namespace ppt {
         oox::drawingml::Color maFromClr;
     };
 
-
     /** CT_TLAnimateBehavior */
     class AnimContext
         : public TimeNodeContext
@@ -558,8 +553,7 @@ namespace oox { namespace ppt {
                 mnValueType = xAttribs->getOptionalValueToken( XML_valueType, 0 );
             }
 
-
-        ~AnimContext() throw ()
+        virtual ~AnimContext() throw ()
             {
                 ::std::list< TimeAnimationValue >::iterator iter, end;
                 int nKeyTimes = maTavList.size();
@@ -594,8 +588,7 @@ namespace oox { namespace ppt {
                 }
             }
 
-
-        virtual ::oox::core::ContextHandlerRef onCreateContext( sal_Int32 aElementToken, const AttributeList& rAttribs )
+        virtual ::oox::core::ContextHandlerRef onCreateContext( sal_Int32 aElementToken, const AttributeList& rAttribs ) override
             {
                 switch ( aElementToken )
                 {
@@ -614,7 +607,6 @@ namespace oox { namespace ppt {
         TimeAnimationValueList maTavList;
     };
 
-
     /** CT_TLAnimateScaleBehavior */
     class AnimScaleContext
         : public TimeNodeContext
@@ -633,11 +625,11 @@ namespace oox { namespace ppt {
                     = makeAny((sal_Int16)AnimationTransformType::SCALE);
             }
 
-        ~AnimScaleContext( ) throw( )
+        virtual ~AnimScaleContext( ) throw( )
             {
             }
 
-        virtual void onEndElement()
+        virtual void onEndElement() override
             {
                 if( isCurrentElement( mnElement ) )
                 {
@@ -656,7 +648,7 @@ namespace oox { namespace ppt {
                 }
             }
 
-        virtual ::oox::core::ContextHandlerRef onCreateContext( sal_Int32 aElementToken, const AttributeList& rAttribs )
+        virtual ::oox::core::ContextHandlerRef onCreateContext( sal_Int32 aElementToken, const AttributeList& rAttribs ) override
             {
                 switch ( aElementToken )
                 {
@@ -699,7 +691,6 @@ namespace oox { namespace ppt {
         bool mbZoomContents;
     };
 
-
     /** CT_TLAnimateRotationBehavior */
     class AnimRotContext
         : public TimeNodeContext
@@ -714,29 +705,30 @@ namespace oox { namespace ppt {
 
                 pNode->getNodeProperties()[ NP_TRANSFORMTYPE ]
                     = makeAny((sal_Int16)AnimationTransformType::ROTATE);
-                // TODO make sure the units are OK
+                // see also DFF_msofbtAnimateRotationData in
+                // sd/source/filter/ppt/pptinanimations.cxx
                 if(attribs.hasAttribute( XML_by ) )
                 {
                     sal_Int32 nBy = attribs.getInteger( XML_by, 0 );
-                    pNode->setBy( makeAny( nBy ) );
+                    pNode->setBy( makeAny( (double) nBy ) );
                 }
                 if(attribs.hasAttribute( XML_from ) )
                 {
                     sal_Int32 nFrom = attribs.getInteger( XML_from, 0 );
-                    pNode->setFrom( makeAny( nFrom ) );
+                    pNode->setFrom( makeAny( (double) nFrom ) );
                 }
                 if(attribs.hasAttribute( XML_to ) )
                 {
                     sal_Int32 nTo = attribs.getInteger( XML_to, 0 );
-                    pNode->setTo( makeAny( nTo ) );
+                    pNode->setTo( makeAny( (double) nTo ) );
                 }
             }
 
-        ~AnimRotContext( ) throw( )
+        virtual ~AnimRotContext( ) throw( )
             {
             }
 
-        virtual ::oox::core::ContextHandlerRef onCreateContext( sal_Int32 aElementToken, const AttributeList& rAttribs )
+        virtual ::oox::core::ContextHandlerRef onCreateContext( sal_Int32 aElementToken, const AttributeList& rAttribs ) override
             {
                 switch ( aElementToken )
                 {
@@ -750,8 +742,6 @@ namespace oox { namespace ppt {
             }
     };
 
-
-
     /** CT_TLAnimateMotionBehavior */
     class AnimMotionContext
         : public TimeNodeContext
@@ -791,12 +781,11 @@ namespace oox { namespace ppt {
                 // TODO make sure the units are right. Likely not.
             }
 
-        ~AnimMotionContext( ) throw()
+        virtual ~AnimMotionContext( ) throw()
             {
             }
 
-
-        virtual ::oox::core::ContextHandlerRef onCreateContext( sal_Int32 aElementToken, const AttributeList& rAttribs )
+        virtual ::oox::core::ContextHandlerRef onCreateContext( sal_Int32 aElementToken, const AttributeList& rAttribs ) override
             {
                 switch ( aElementToken )
                 {
@@ -852,7 +841,6 @@ namespace oox { namespace ppt {
         sal_Int32 mnAngle;
     };
 
-
     /** CT_TLAnimateEffectBehavior */
     class AnimEffectContext
         : public TimeNodeContext
@@ -871,18 +859,16 @@ namespace oox { namespace ppt {
                 if( !sFilter.isEmpty() )
                 {
                     SlideTransition aFilter( sFilter );
-                    aFilter.setMode( nDir == XML_out ? false : true );
+                    aFilter.setMode( nDir != XML_out );
                     pNode->setTransitionFilter( aFilter );
                 }
             }
 
-
-        ~AnimEffectContext( ) throw()
+        virtual ~AnimEffectContext( ) throw()
             {
             }
 
-
-        virtual ::oox::core::ContextHandlerRef onCreateContext( sal_Int32 aElementToken, const AttributeList& rAttribs )
+        virtual ::oox::core::ContextHandlerRef onCreateContext( sal_Int32 aElementToken, const AttributeList& rAttribs ) override
             {
                 switch ( aElementToken )
                 {
@@ -899,18 +885,14 @@ namespace oox { namespace ppt {
             }
     private:
         Any maProgress;
-        OUString msFilter;
-        OUString msPrList;
     };
 
-
-
     TimeNodeContext * TimeNodeContext::makeContext(
             FragmentHandler2& rParent, sal_Int32  aElement,
             const Reference< XFastAttributeList >& xAttribs,
             const TimeNodePtr & pNode )
     {
-        TimeNodeContext *pCtx = NULL;
+        TimeNodeContext *pCtx = nullptr;
         switch( aElement )
         {
         case PPT_TOKEN( animClr ):
@@ -956,7 +938,6 @@ namespace oox { namespace ppt {
         return pCtx;
     }
 
-
     TimeNodeContext::TimeNodeContext( FragmentHandler2& rParent, sal_Int32 aElement,
             const Reference< XFastAttributeList >& /*xAttribs*/,
             const TimeNodePtr & pNode ) throw()
@@ -966,13 +947,11 @@ namespace oox { namespace ppt {
     {
     }
 
-
     TimeNodeContext::~TimeNodeContext( ) throw()
     {
 
     }
 
-
     TimeNodeListContext::TimeNodeListContext( FragmentHandler2& rParent, TimeNodePtrList & aList )
         throw()
         : FragmentHandler2( rParent )
@@ -980,12 +959,10 @@ namespace oox { namespace ppt {
     {
     }
 
-
     TimeNodeListContext::~TimeNodeListContext( ) throw()
     {
     }
 
-
     ::oox::core::ContextHandlerRef TimeNodeListContext::onCreateContext( sal_Int32 aElementToken, const AttributeList& rAttribs )
     {
         sal_Int16 nNodeType;
@@ -1035,7 +1012,7 @@ namespace oox { namespace ppt {
 
         default:
             nNodeType = AnimationNodeType::CUSTOM;
-            OSL_TRACE( "OOX: uhandled token %x", aElementToken );
+            SAL_INFO("oox.ppt", "uhandled token " << aElementToken);
             break;
         }
 
@@ -1046,7 +1023,6 @@ namespace oox { namespace ppt {
         return pContext ? pContext : this;
     }
 
-
 } }
 
 /* vim:set shiftwidth=4 softtabstop=4 expandtab: */
