@@ -44,6 +44,7 @@
 #include <com/sun/star/text/XTextFrame.hpp>
  #include <com/sun/star/lang/XServiceInfo.hpp>
 #include <com/sun/star/text/TextContentAnchorType.hpp>
+#include <com/sun/star/text/GraphicCrop.hpp>
 #include <rtl/math.hxx>
 #include <rtl/ustrbuf.hxx>
 #include <svx/svdtrans.hxx>
@@ -106,6 +107,19 @@ awt::Rectangle lclGetAbsRect( const awt::Rectangle& rRelRect, const awt::Rectang
     return aAbsRect;
 }
 
+/// Count the crop value based on a crop fraction and a reference size.
+sal_Int32 lclConvertCrop(const OUString& rCrop, sal_uInt32 nSize)
+{
+    if (rCrop.endsWith("f"))
+    {
+        // Numeric value is specified in 1/65536-ths.
+        sal_uInt32 nCrop = rCrop.copy(0, rCrop.getLength() - 1).toUInt32();
+        return (nCrop * nSize) / 65536;
+    }
+
+    return 0;
+}
+
 } // namespace
 
 ShapeTypeModel::ShapeTypeModel():
@@ -285,12 +299,12 @@ OUString ShapeBase::getShapeName() const
 
 const ShapeType* ShapeBase::getChildTypeById( const OUString& ) const
 {
-    return 0;
+    return nullptr;
 }
 
 const ShapeBase* ShapeBase::getChildById( const OUString& ) const
 {
-    return 0;
+    return nullptr;
 }
 
 Reference< XShape > ShapeBase::convertAndInsert( const Reference< XShapes >& rxShapes, const ShapeParentAnchor* pParentAnchor ) const
@@ -317,11 +331,14 @@ Reference< XShape > ShapeBase::convertAndInsert( const Reference< XShapes >& rxS
                 sal_Int32 id = 0;
                 sal_Int32 idPos = sLinkChainName.indexOf("_x");
                 sal_Int32 seq = 0;
-                sal_Int32 seqPos = sLinkChainName.indexOf("_s",idPos);
-                if( idPos >= 0 && idPos < seqPos )
+                if (idPos >= 0)
                 {
-                    id = sLinkChainName.copy(idPos+2,seqPos-idPos+2).toInt32();
-                    seq = sLinkChainName.copy(seqPos+2).toInt32();
+                    sal_Int32 seqPos = sLinkChainName.indexOf("_s",idPos);
+                    if (idPos < seqPos)
+                    {
+                        id = sLinkChainName.copy(idPos+2,seqPos-idPos+2).toInt32();
+                        seq = sLinkChainName.copy(seqPos+2).toInt32();
+                    }
                 }
 
                 OUString s_mso_next_textbox;
@@ -429,7 +446,7 @@ Reference< XShape > ShapeBase::convertAndInsert( const Reference< XShapes >& rxS
                 /*  Notify the drawing that a new shape has been inserted. For
                     convenience, pass the rectangle that contains position and
                     size of the shape. */
-                bool bGroupChild = pParentAnchor != 0;
+                bool bGroupChild = pParentAnchor != nullptr;
                 mrDrawing.notifyXShapeInserted( xShape, aShapeRect, *this, bGroupChild );
             }
         }
@@ -536,18 +553,18 @@ void lcl_setSurround(PropertySet& rPropSet, const ShapeTypeModel& rTypeModel, co
     if (nMarginTop < -35277) // Less than 1000 points.
         aWrapType.clear();
 
-    sal_Int32 nSurround = com::sun::star::text::WrapTextMode_THROUGHT;
+    sal_Int32 nSurround = css::text::WrapTextMode_THROUGHT;
     if ( aWrapType == "square" || aWrapType == "tight" ||
          aWrapType == "through" )
     {
-        nSurround = com::sun::star::text::WrapTextMode_PARALLEL;
+        nSurround = css::text::WrapTextMode_PARALLEL;
         if ( rTypeModel.moWrapSide.get() == "left" )
-            nSurround = com::sun::star::text::WrapTextMode_LEFT;
+            nSurround = css::text::WrapTextMode_LEFT;
         else if ( rTypeModel.moWrapSide.get() == "right" )
-            nSurround = com::sun::star::text::WrapTextMode_RIGHT;
+            nSurround = css::text::WrapTextMode_RIGHT;
     }
     else if ( aWrapType == "topAndBottom" )
-        nSurround = com::sun::star::text::WrapTextMode_NONE;
+        nSurround = css::text::WrapTextMode_NONE;
 
     rPropSet.setProperty(PROP_Surround, nSurround);
 }
@@ -799,7 +816,7 @@ Reference< XShape > SimpleShape::implConvertAndInsert( const Reference< XShapes
         // The associated properties "PROP_MirroredX" and "PROP_MirroredY" have to be set here so that direction change will occur internally.
         if (bFlipX || bFlipY)
         {
-            com::sun::star::uno::Sequence< com::sun::star::beans::PropertyValue > aPropSequence (2);
+            css::uno::Sequence< css::beans::PropertyValue > aPropSequence (2);
             int nPropertyIndex = 0;
             if (bFlipX)
             {
@@ -817,7 +834,7 @@ Reference< XShape > SimpleShape::implConvertAndInsert( const Reference< XShapes
         }
     }
 
-    lcl_SetAnchorType(aPropertySet, maTypeModel, rGraphicHelper);
+    lcl_SetAnchorType(aPropertySet, maTypeModel, rGraphicHelper );
 
     return xShape;
 }
@@ -848,6 +865,25 @@ Reference< XShape > SimpleShape::createPictureObject( const Reference< XShapes >
 
         const GraphicHelper& rGraphicHelper = mrDrawing.getFilter().getGraphicHelper();
         lcl_SetAnchorType(aPropSet, maTypeModel, rGraphicHelper);
+
+        if (maTypeModel.moCropBottom.has() || maTypeModel.moCropLeft.has() || maTypeModel.moCropRight.has() || maTypeModel.moCropTop.has())
+        {
+            text::GraphicCrop aGraphicCrop;
+            uno::Reference<graphic::XGraphic> xGraphic;
+            aPropSet.getProperty(xGraphic, PROP_Graphic);
+            awt::Size aOriginalSize = rGraphicHelper.getOriginalSize(xGraphic);
+
+            if (maTypeModel.moCropBottom.has())
+                aGraphicCrop.Bottom = lclConvertCrop(maTypeModel.moCropBottom.get(), aOriginalSize.Height);
+            if (maTypeModel.moCropLeft.has())
+                aGraphicCrop.Left = lclConvertCrop(maTypeModel.moCropLeft.get(), aOriginalSize.Width);
+            if (maTypeModel.moCropRight.has())
+                aGraphicCrop.Right = lclConvertCrop(maTypeModel.moCropRight.get(), aOriginalSize.Width);
+            if (maTypeModel.moCropTop.has())
+                aGraphicCrop.Top = lclConvertCrop(maTypeModel.moCropTop.get(), aOriginalSize.Height);
+
+            aPropSet.setProperty(PROP_GraphicCrop, aGraphicCrop);
+        }
     }
     return xShape;
 }
@@ -1014,11 +1050,11 @@ Reference< XShape > BezierShape::implConvertAndInsert( const Reference< XShapes
         }
 
         aBezierCoords.Coordinates.realloc( aCoordLists.size() );
-        for ( unsigned int i = 0; i < aCoordLists.size(); i++ )
+        for ( size_t i = 0; i < aCoordLists.size(); i++ )
             aBezierCoords.Coordinates[i] = ContainerHelper::vectorToSequence( aCoordLists[i] );
 
         aBezierCoords.Flags.realloc( aFlagLists.size() );
-        for ( unsigned int i = 0; i < aFlagLists.size(); i++ )
+        for ( size_t i = 0; i < aFlagLists.size(); i++ )
             aBezierCoords.Flags[i] = ContainerHelper::vectorToSequence( aFlagLists[i] );
 
         if( !aCoordLists.front().empty() && !aCoordLists.back().empty()
