@@ -23,17 +23,23 @@
 
 using namespace ::com::sun::star;
 
+#if OSL_DEBUG_LEVEL > 0
+#define THROW_WHERE SAL_WHERE
+#else
+#define THROW_WHERE ""
+#endif
+
 WrapStreamForShare::WrapStreamForShare( const uno::Reference< io::XInputStream >& xInStream,
-                                        const SotMutexHolderRef& rMutexRef )
+                                        const rtl::Reference<SotMutexHolder>& rMutexRef )
 : m_rMutexRef( rMutexRef )
 , m_xInStream( xInStream )
 , m_nCurPos( 0 )
 {
-    m_xSeekable = uno::Reference< io::XSeekable >( m_xInStream, uno::UNO_QUERY );
-    if ( !m_rMutexRef.Is() || !m_xInStream.is() || !m_xSeekable.is() )
+    m_xSeekable.set( m_xInStream, uno::UNO_QUERY );
+    if ( !m_rMutexRef.is() || !m_xInStream.is() || !m_xSeekable.is() )
     {
         OSL_FAIL( "Wrong initialization of wrapping stream!\n" );
-        throw uno::RuntimeException(OSL_LOG_PREFIX, uno::Reference< uno::XInterface >() );
+        throw uno::RuntimeException(THROW_WHERE );
     }
 }
 
@@ -46,12 +52,10 @@ sal_Int32 SAL_CALL WrapStreamForShare::readBytes( uno::Sequence< sal_Int8 >& aDa
         throw ( io::NotConnectedException,
                 io::BufferSizeExceededException,
                 io::IOException,
-                uno::RuntimeException )
+                uno::RuntimeException, std::exception )
 {
-    ::osl::MutexGuard aGuard( m_rMutexRef->GetMutex() );
-
     if ( !m_xInStream.is() )
-        throw io::IOException(OSL_LOG_PREFIX, uno::Reference< uno::XInterface >() );
+        throw io::IOException(THROW_WHERE );
 
     m_xSeekable->seek( m_nCurPos );
 
@@ -65,12 +69,10 @@ sal_Int32 SAL_CALL WrapStreamForShare::readSomeBytes( uno::Sequence< sal_Int8 >&
         throw ( io::NotConnectedException,
                 io::BufferSizeExceededException,
                 io::IOException,
-                uno::RuntimeException )
+                uno::RuntimeException, std::exception )
 {
-    ::osl::MutexGuard aGuard( m_rMutexRef->GetMutex() );
-
     if ( !m_xInStream.is() )
-        throw io::IOException(OSL_LOG_PREFIX, uno::Reference< uno::XInterface >() );
+        throw io::IOException(THROW_WHERE );
 
     m_xSeekable->seek( m_nCurPos );
 
@@ -84,12 +86,12 @@ void SAL_CALL WrapStreamForShare::skipBytes( sal_Int32 nBytesToSkip )
         throw ( io::NotConnectedException,
                 io::BufferSizeExceededException,
                 io::IOException,
-                uno::RuntimeException )
+                uno::RuntimeException, std::exception )
 {
     ::osl::MutexGuard aGuard( m_rMutexRef->GetMutex() );
 
     if ( !m_xInStream.is() )
-        throw io::IOException(OSL_LOG_PREFIX, uno::Reference< uno::XInterface >() );
+        throw io::IOException(THROW_WHERE );
 
     m_xSeekable->seek( m_nCurPos );
 
@@ -100,12 +102,12 @@ void SAL_CALL WrapStreamForShare::skipBytes( sal_Int32 nBytesToSkip )
 sal_Int32 SAL_CALL WrapStreamForShare::available()
         throw ( io::NotConnectedException,
                 io::IOException,
-                uno::RuntimeException )
+                uno::RuntimeException, std::exception )
 {
     ::osl::MutexGuard aGuard( m_rMutexRef->GetMutex() );
 
     if ( !m_xInStream.is() )
-        throw io::IOException(OSL_LOG_PREFIX, uno::Reference< uno::XInterface >() );
+        throw io::IOException(THROW_WHERE );
 
     return m_xInStream->available();
 }
@@ -113,29 +115,29 @@ sal_Int32 SAL_CALL WrapStreamForShare::available()
 void SAL_CALL WrapStreamForShare::closeInput()
         throw ( io::NotConnectedException,
                 io::IOException,
-                uno::RuntimeException )
+                uno::RuntimeException, std::exception )
 {
     ::osl::MutexGuard aGuard( m_rMutexRef->GetMutex() );
 
     if ( !m_xInStream.is() )
-        throw io::IOException(OSL_LOG_PREFIX, uno::Reference< uno::XInterface >() );
+        throw io::IOException(THROW_WHERE );
 
     // the package is the owner so it will close the stream
     // m_xInStream->closeInput();
-    m_xInStream = uno::Reference< io::XInputStream >();
-    m_xSeekable = uno::Reference< io::XSeekable >();
+    m_xInStream.clear();
+    m_xSeekable.clear();
 }
 
 // XSeekable
 void SAL_CALL WrapStreamForShare::seek( sal_Int64 location )
         throw ( lang::IllegalArgumentException,
                 io::IOException,
-                uno::RuntimeException )
+                uno::RuntimeException, std::exception )
 {
     ::osl::MutexGuard aGuard( m_rMutexRef->GetMutex() );
 
     if ( !m_xInStream.is() )
-        throw io::IOException(OSL_LOG_PREFIX, uno::Reference< uno::XInterface >() );
+        throw io::IOException(THROW_WHERE );
 
     // let stream implementation do all the checking
     m_xSeekable->seek( location );
@@ -145,24 +147,24 @@ void SAL_CALL WrapStreamForShare::seek( sal_Int64 location )
 
 sal_Int64 SAL_CALL WrapStreamForShare::getPosition()
         throw ( io::IOException,
-                uno::RuntimeException)
+                uno::RuntimeException, std::exception)
 {
     ::osl::MutexGuard aGuard( m_rMutexRef->GetMutex() );
 
     if ( !m_xInStream.is() )
-        throw io::IOException(OSL_LOG_PREFIX, uno::Reference< uno::XInterface >() );
+        throw io::IOException(THROW_WHERE );
 
     return m_nCurPos;
 }
 
 sal_Int64 SAL_CALL WrapStreamForShare::getLength()
         throw ( io::IOException,
-                uno::RuntimeException )
+                uno::RuntimeException, std::exception )
 {
     ::osl::MutexGuard aGuard( m_rMutexRef->GetMutex() );
 
     if ( !m_xInStream.is() )
-        throw io::IOException(OSL_LOG_PREFIX, uno::Reference< uno::XInterface >() );
+        throw io::IOException(THROW_WHERE );
 
     return m_xSeekable->getLength();
 }
