@@ -25,24 +25,9 @@ import java.util.HashSet;
 import java.util.Iterator;
 
 import com.sun.star.beans.PropertyValue;
-import com.sun.star.document.XExporter;
-import com.sun.star.document.XFilter;
-import com.sun.star.document.XImporter;
-import com.sun.star.io.XActiveDataSource;
-import com.sun.star.io.XInputStream;
-import com.sun.star.io.XOutputStream;
-import com.sun.star.lang.XComponent;
-import com.sun.star.lang.XMultiServiceFactory;
-import com.sun.star.ucb.XSimpleFileAccess;
-import com.sun.star.uno.Any;
-import com.sun.star.uno.Type;
-import com.sun.star.uno.UnoRuntime;
-import com.sun.star.uno.XInterface;
-import com.sun.star.xml.sax.InputSource;
 import com.sun.star.xml.sax.XAttributeList;
 import com.sun.star.xml.sax.XDocumentHandler;
 import com.sun.star.xml.sax.XLocator;
-import com.sun.star.xml.sax.XParser;
 
 
 public class XMLTools {
@@ -57,25 +42,15 @@ public class XMLTools {
             public String Type ;
             public String Value ;
         }
-        private HashMap<String, Attribute> attrByName = new HashMap<String, Attribute>() ;
-        private ArrayList<Attribute> attributes = new ArrayList<Attribute>() ;
-        private PrintWriter log = null ;
+        private final HashMap<String, Attribute> attrByName = new HashMap<String, Attribute>() ;
+        private final ArrayList<Attribute> attributes = new ArrayList<Attribute>() ;
 
         /**
          * Creates a class instance.
          */
         public AttributeList() {}
 
-        /**
-         * Constructs a list which will report to <code>log</code>
-         * specified about each <code>XDocumentHandler</code> method
-         * call.
-         */
-        public AttributeList(PrintWriter log) {
-            this.log = log ;
-        }
-
-        public AttributeList(XAttributeList list) {
+        private AttributeList(XAttributeList list) {
             if (list == null) return ;
             for (short i = 0; i < list.getLength(); i++) {
                 add(list.getNameByIndex(i), list.getTypeByIndex(i),
@@ -98,70 +73,39 @@ public class XMLTools {
             attrByName.put(attr.Name, attr) ;
         }
 
-        /**
-         * Adds an attribute with value specified. As a type of
-         * value 'CDATA' string specified.
-         * @param name The attribute name.
-         * @param value Attribute value.
-         */
-        public void add(String name, String value) {
-            add(name, "CDATA", value) ;
-        }
 
-        /**
-         * Clears all attributes added before.
-         */
-        public void clear() {
-            attrByName.clear() ;
-            attributes.clear() ;
-        }
+
+
 
         /***************************************
         * XAttributeList methods
         ****************************************/
 
         public short getLength() {
-            if (log != null)
-                log.println("getLength() called -> " + attributes.size()) ;
             return (short) attributes.size() ;
         }
 
         public String getNameByIndex(short idx) {
             String name = attributes.get(idx).Name ;
-            if (log != null)
-                log.println("getNameByIndex(" + idx + ") called -> '" +
-                name + "'") ;
             return name ;
         }
 
         public String getTypeByIndex(short idx) {
             String type = attributes.get(idx).Type  ;
-            if (log != null)
-                log.println("getTypeByIndex(" + idx + ") called -> '" +
-                    type + "'") ;
             return type;
         }
 
         public String getTypeByName(String name) {
             String type = attrByName.get(name).Type ;
-            if (log != null)
-                log.println("getTypeByName('" + name + "') called -> '" +
-                    type + "'") ;
             return type;
         }
         public String getValueByIndex(short idx) {
             String value = attributes.get(idx).Value ;
-            if (log != null)
-                log.println("getValueByIndex(" + idx + ") called -> '" +
-                    value + "'") ;
-            return  value;
+            return value;
         }
 
         public String getValueByName(String name) {
             String value = attrByName.get(name).Value ;
-            if (log != null)
-                log.println("getValueByName('" + name + "') called -> '" +
-                    value + "'") ;
             return value;
         }
     }
@@ -170,7 +114,7 @@ public class XMLTools {
     * This class writes all XML data handled into a stream specified
     * in the constructor.
     */
-    public static class XMLWriter implements XDocumentHandler {
+    private static class XMLWriter implements XDocumentHandler {
         private PrintWriter _log = null ;
         private String align = "" ;
 
@@ -178,7 +122,7 @@ public class XMLTools {
         * Creates a SAX handler which writes all XML data
         * handled into a <code>log</code> stream specified.
         */
-        public XMLWriter(PrintWriter log) {
+        private XMLWriter(PrintWriter log) {
             _log = log ;
         }
 
@@ -248,24 +192,24 @@ public class XMLTools {
     * If any collisions found appropriate error message is
     * output into a stream specified. No XML data output, i.e.
     * no output will be performed if no errors occur.<p>
-    * After document is completed there is a way to cehck
+    * After document is completed there is a way to check
     * if the XML data and structure was valid.
     */
-    public static class XMLWellFormChecker extends XMLWriter {
-        protected boolean docStarted = false ;
-        protected boolean docEnded = false ;
-        protected ArrayList<String> tagStack = new ArrayList<String>() ;
-        protected boolean wellFormed = true ;
-        protected boolean noOtherErrors = true ;
-        protected PrintWriter log = null ;
-        protected boolean printXMLData = false ;
+    private static class XMLWellFormChecker extends XMLWriter {
+        private boolean docStarted = false ;
+        private boolean docEnded = false ;
+        ArrayList<String> tagStack = new ArrayList<String>() ;
+        private boolean wellFormed = true ;
+        private boolean noOtherErrors = true ;
+        PrintWriter log = null ;
+        private boolean printXMLData = false ;
 
-        public XMLWellFormChecker(PrintWriter log) {
+        private XMLWellFormChecker(PrintWriter log) {
             super() ;
             this.log = log ;
         }
 
-        public XMLWellFormChecker(PrintWriter log_, boolean printXMLData) {
+        private XMLWellFormChecker(PrintWriter log_, boolean printXMLData) {
             super(printXMLData ? log_ : null) ;
             this.printXMLData = printXMLData ;
             this.log = log_ ;
@@ -275,7 +219,7 @@ public class XMLTools {
          * Reset all values. This is important e.g. for test of XFilter
          * interface, where 'filter()' method istbstarted twice.
          */
-        public void reset() {
+        void reset() {
             docStarted = false ;
             docEnded = false ;
             tagStack = new ArrayList<String>() ;
@@ -284,6 +228,7 @@ public class XMLTools {
             printXMLData = false ;
         }
 
+        @Override
         public void startDocument() {
             super.startDocument();
 
@@ -294,6 +239,7 @@ public class XMLTools {
 
             docStarted = true ;
         }
+        @Override
         public void endDocument() {
             super.endDocument();
             if (!docStarted) {
@@ -302,6 +248,7 @@ public class XMLTools {
             }
             docEnded = true ;
         }
+        @Override
         public void startElement(String name, XAttributeList attr) {
             super.startElement(name, attr);
             if (attr == null) {
@@ -311,10 +258,11 @@ public class XMLTools {
             }
             tagStack.add(0, name) ;
         }
+        @Override
         public void endElement(String name) {
             super.endElement(name);
             if (wellFormed) {
-                if (tagStack.size() == 0) {
+                if (tagStack.isEmpty()) {
                     wellFormed = false ;
                     printError("No tags to close (bad closing tag </" + name + ">)") ;
                 } else {
@@ -348,7 +296,7 @@ public class XMLTools {
         * Also prints "Tag trace" in case if the full XML data isn't
         * printed.
         */
-        public void printError(String msg) {
+        void printError(String msg) {
             log.println("!!! Error: " + msg) ;
             if (printXMLData) return ;
             log.println("   Tag trace :") ;
@@ -367,9 +315,9 @@ public class XMLTools {
     * appropriate message is output.
     */
     public static class XMLTagsChecker extends XMLWellFormChecker {
-        protected HashMap<String,String> tags = new HashMap<String,String>() ;
-        protected HashMap<String,String> chars = new HashMap<String,String>() ;
-        protected boolean allOK = true ;
+        private final HashMap<String,String> tags = new HashMap<String,String>() ;
+        private final HashMap<String,String> chars = new HashMap<String,String>() ;
+        private boolean allOK = true ;
 
         public XMLTagsChecker(PrintWriter log) {
             super(log) ;
@@ -388,12 +336,7 @@ public class XMLTools {
         public void addTagEnclosed(String tag, String outerTag) {
             tags.put(tag, outerTag) ;
         }
-        /**
-        * Adds a character data which must be contained in the XML data.
-        */
-        public void addCharacters(String ch) {
-            chars.put(ch, "") ;
-        }
+
         /**
         * Adds a character data which must be contained in the XML data and
         * must be inside the tag with name <code>outerTag</code>.
@@ -402,11 +345,12 @@ public class XMLTools {
             chars.put(ch, outerTag) ;
         }
 
+        @Override
         public void startElement(String name, XAttributeList attrs) {
             super.startElement(name, attrs) ;
             if (tags.containsKey(name)) {
                 String outerTag = tags.get(name);
-                if (!outerTag.equals("")) {
+                if (outerTag.length() != 0) {
                     boolean isInTag = false ;
                     for (int i = 0; i < tagStack.size(); i++) {
                         if (outerTag.equals(tagStack.get(i))) {
@@ -424,12 +368,13 @@ public class XMLTools {
             }
         }
 
+        @Override
         public void characters(String ch) {
             super.characters(ch) ;
 
             if (chars.containsKey(ch)) {
                 String outerTag = chars.get(ch);
-                if (!outerTag.equals("")) {
+                if (outerTag.length() != 0) {
                     boolean isInTag = false ;
                     for (int i = 0; i < tagStack.size(); i++) {
                         if (outerTag.equals(tagStack.get(i))) {
@@ -452,7 +397,8 @@ public class XMLTools {
         * all necessary tags and character data was found.
         */
         public boolean checkTags() {
-            allOK &= isWellFormed() ;
+            if (!isWellFormed())
+                allOK = false ;
 
             Iterator<String> badTags = tags.keySet().iterator() ;
             Iterator<String> badChars = chars.keySet().iterator() ;
@@ -482,7 +428,7 @@ public class XMLTools {
      * name, or attribute value additionally.
      */
     public static class Tag {
-        private String name = null;
+        private final String name;
         private String[][] attrList = new String[0][3] ;
 
         /**
@@ -493,20 +439,6 @@ public class XMLTools {
             name = tagName ;
         }
 
-        /**
-         * Creates a tag with the name specified, which must have an
-         * attribute with name specified. The value of this attribute
-         * doesn't make sense.
-         * @param tagName The name of the tag.
-         * @param attrName The name of attribute which must be contained
-         * in the tag.
-         */
-        public Tag(String tagName, String attrName) {
-            name = tagName ;
-            attrList = new String[1][3] ;
-            attrList[0][0] = attrName ;
-        }
-
         /**
          * Creates a tag with the name specified, which must have an
          * attribute with the value specified. The type of value
@@ -524,46 +456,10 @@ public class XMLTools {
             attrList[0][2] = attrValue ;
         }
 
-        /**
-         * Creates a tag with the name specified, which must have
-         * attributes specified. The value of thesee attributes
-         * doesn't make sense.
-         * @param tagName The name of the tag.
-         * @param attrNames Array with names of attributes which must
-         * be contained in the tag.
-         */
-        public Tag(String tagName, String[] attrNames) {
-            name = tagName ;
-            attrList = new String[attrNames.length][3] ;
-            for (int i = 0; i < attrNames.length; i++) {
-                attrList[i][0] = attrNames[i] ;
-            }
-        }
-
-        /**
-         * Creates a tag with the name specified, which must have an
-         * attributes with their values specified. The type of all values
-         * assumed to be 'CDATA'.
-         * @param tagName The name of the tag.
-         * @param attrValues An array with attribute names and their values.
-         * <code>attrValues[N][0]</code> element contains the name of Nth
-         * attribute, and <code>attrValues[N][1]</code> element contains
-         * value of Nth attribute, if value is <code>null</code> then the
-         * attribute value can be any.
-         */
-        public Tag(String tagName, String[][] attrValues) {
-            name = tagName ;
-            attrList = new String[attrValues.length][3] ;
-            for (int i = 0; i < attrValues.length; i++) {
-                attrList[i][0] = attrValues[i][0] ;
-                attrList[i][1] = "CDATA" ;
-                attrList[i][2] = attrValues[i][1] ;
-            }
-        }
-
         /**
          * Gets tag String description.
          */
+        @Override
         public String toString() {
             String ret = "<" + name ;
             for (int i = 0; i < attrList.length; i++) {
@@ -579,7 +475,7 @@ public class XMLTools {
             return ret ;
         }
 
-        protected boolean checkAttr(int attrListIdx, XAttributeList list) {
+        private boolean checkAttr(int attrListIdx, XAttributeList list) {
             short j  = 0 ;
             int listLen = list.getLength();
             while(j < listLen) {
@@ -594,7 +490,7 @@ public class XMLTools {
 
         /**
          * Checks if this tag matches tag passed in parameters.
-         * I.e. if tag specifies only it's name it mathes if names
+         * I.e. if tag specifies only its name it matches if names
          * are equal (attributes don't make sense). If there are
          * some attributes names specified in this tag method checks
          * if all names present in attribute list <code>list</code>
@@ -602,7 +498,7 @@ public class XMLTools {
          * with values method checks if these attributes exist and
          * have appropriate values.
          */
-        public boolean isMatchTo(String tagName, XAttributeList list) {
+        private boolean isMatchTo(String tagName, XAttributeList list) {
             if (!name.equals(tagName)) return false;
             boolean result = true ;
             for (int i = 0; i < attrList.length; i++) {
@@ -620,11 +516,11 @@ public class XMLTools {
      * character data exists inside any tag specified.
      */
     public static class XMLChecker extends XMLWellFormChecker {
-        protected HashSet<String> tagSet = new HashSet<String>() ;
-        protected ArrayList<Tag[]> tags = new ArrayList<Tag[]>() ;
-        protected ArrayList<Object[]> chars = new ArrayList<Object[]>() ;
-        protected ArrayList<String> tagStack = new ArrayList<String>() ;
-        protected ArrayList<AttributeList> attrStack = new ArrayList<AttributeList>() ;
+        private final HashSet<String> tagSet = new HashSet<String>() ;
+        private final ArrayList<Tag[]> tags = new ArrayList<Tag[]>() ;
+        private final ArrayList<Object[]> chars = new ArrayList<Object[]>() ;
+        private final ArrayList<String> tagStack = new ArrayList<String>() ;
+        private final ArrayList<AttributeList> attrStack = new ArrayList<AttributeList>() ;
 
         public XMLChecker(PrintWriter log, boolean writeXML) {
             super(log, writeXML) ;
@@ -640,14 +536,13 @@ public class XMLTools {
             tagSet.add(tag.name) ;
         }
 
-        public void addCharacters(String ch) {
-            chars.add(new Object[] {ch.trim(), null}) ;
-        }
+
 
         public void addCharactersEnclosed(String ch, Tag outerTag) {
             chars.add(new Object[] {ch.trim(), outerTag}) ;
         }
 
+        @Override
         public void startElement(String name, XAttributeList attr) {
             try {
             super.startElement(name, attr);
@@ -683,6 +578,7 @@ public class XMLTools {
             }
         }
 
+        @Override
         public void characters(String ch) {
             super.characters(ch) ;
             for (int i = 0; i < chars.size(); i++) {
@@ -708,6 +604,7 @@ public class XMLTools {
             }
         }
 
+        @Override
         public void endElement(String name) {
             try {
             super.endElement(name);
@@ -744,42 +641,13 @@ public class XMLTools {
             if (!isWellFormed())
                 log.println("!!! Some errors were found in XML structure") ;
 
-            boolean result = tags.size() == 0 && chars.size() == 0 && isWellFormed();
+            boolean result = tags.isEmpty() && chars.isEmpty() && isWellFormed();
             reset();
             return result;
         }
     }
 
-    /**
-    * Creates <code>XDocumentHandler</code> implementation in form
-    * of <code>com.sun.star.xml.sax.Writer</code> service, which
-    * writes XML data into a <code>com.sun.star.io.Pipe</code>
-    * created.
-    * @return Single element array which contains the handler
-    * contained in <code>Any</code> structure.
-    */
-    public static Object[] getDocumentHandler(XMultiServiceFactory xMSF) {
-        Object[] ret = new Object[1];
-        try {
-            XInterface Writer = (XInterface) xMSF.createInstance(
-                                    "com.sun.star.xml.sax.Writer");
-            XInterface oPipe = (XInterface) xMSF.createInstance
-                ( "com.sun.star.io.Pipe" );
-            XOutputStream xPipeOutput = UnoRuntime.
-                queryInterface(XOutputStream.class, oPipe) ;
 
-            XActiveDataSource xADS = UnoRuntime.queryInterface(XActiveDataSource.class,Writer);
-            xADS.setOutputStream(xPipeOutput);
-            XDocumentHandler handler = UnoRuntime.queryInterface(XDocumentHandler.class,Writer);
-
-            Any arg = new Any(new Type(XDocumentHandler.class),handler);
-
-            ret[0] = arg;
-        } catch (com.sun.star.uno.Exception e) {
-            e.printStackTrace();
-        }
-        return ret;
-    }
 
     public static PropertyValue[] createMediaDescriptor(String[] propNames, Object[] values) {
         PropertyValue[] props = new PropertyValue[propNames.length] ;
@@ -795,131 +663,7 @@ public class XMLTools {
         return props ;
     }
 
-    /**
-     * Gets the hanlder, which writes all the XML data passed to the
-     * file specified.
-     * @param xMSF Soffice <code>ServiceManager</code> factory.
-     * @param fileURL The file URL (in form file:///<path>) to which
-     * XML data is written.
-     * @return SAX handler to which XML data has to be written.
-     */
-    public static XDocumentHandler getFileXMLWriter(XMultiServiceFactory xMSF, String fileURL)
-        throws com.sun.star.uno.Exception
-    {
-        XInterface oFacc = (XInterface)xMSF.createInstance(
-            "com.sun.star.comp.ucb.SimpleFileAccess");
-        XSimpleFileAccess xFacc = UnoRuntime.queryInterface
-            (XSimpleFileAccess.class, oFacc) ;
 
-        XInterface oWriter = (XInterface)xMSF.createInstance(
-            "com.sun.star.xml.sax.Writer");
-        XActiveDataSource xWriterDS = UnoRuntime.queryInterface(XActiveDataSource.class, oWriter);
-        XDocumentHandler xDocHandWriter = UnoRuntime.queryInterface
-            (XDocumentHandler.class, oWriter) ;
 
-        if (xFacc.exists(fileURL))
-            xFacc.kill(fileURL);
-        XOutputStream fOut = xFacc.openFileWrite(fileURL) ;
-        xWriterDS.setOutputStream(fOut);
 
-        return xDocHandWriter ;
-    }
-
-    /**
-     * Parses XML file and passes its data to the SAX handler specified.
-     * @param xMSF Soffice <code>ServiceManager</code> factory.
-     * @param fileURL XML file name (in form file:///<path>) to be parsed.
-     * @param handler SAX handler to which XML data from file will
-     * be transferred.
-     */
-    public static void parseXMLFile(XMultiServiceFactory xMSF,
-        String fileURL, XDocumentHandler handler) throws com.sun.star.uno.Exception
-    {
-        XInterface oFacc = (XInterface)xMSF.createInstance(
-            "com.sun.star.comp.ucb.SimpleFileAccess");
-        XSimpleFileAccess xFacc = UnoRuntime.queryInterface
-            (XSimpleFileAccess.class, oFacc) ;
-        XInputStream oIn = xFacc.openFileRead(fileURL) ;
-
-        XInterface oParser = (XInterface)xMSF.createInstance(
-            "com.sun.star.xml.sax.Parser");
-        XParser xParser = UnoRuntime.queryInterface(XParser.class, oParser);
-
-        xParser.setDocumentHandler(handler) ;
-        InputSource inSrc = new InputSource() ;
-        inSrc.aInputStream = oIn ;
-        xParser.parseStream(inSrc) ;
-
-        oIn.closeInput();
-    }
-
-    /**
-     * Exports document (the whole or a part) into the file specified
-     * in XML format.
-     * @param xMSF Soffice <code>ServiceManager</code> factory.
-     * @param xDoc Document to be exported.
-     * @param docType Type of document (for example 'Calc', 'Writer', 'Draw')
-     * The type must start with <b>capital</b> letter.
-     * @param exportType The type of export specifies if the whole
-     * document will be exported or one of its parts (Meta info, Styles, etc.).
-     * The following types supported (it also depends of document type) :
-     *  "" (empty string) - for the whole document ;
-     *  "Content" - only content exported ;
-     *  "Meta" - meta document info exported ;
-     *  "Settings" - view settings of document exported ;
-     *  "Styles" - document styles exported ;
-     * @param fileURL XML file name (in form file:///<path>) to be exported to.
-     */
-    public static void exportDocument(XMultiServiceFactory xMSF, XComponent xDoc,
-        String docType, String exportType, String fileURL)
-        throws com.sun.star.uno.Exception {
-
-        XDocumentHandler xDocHandWriter = XMLTools.getFileXMLWriter(xMSF, fileURL) ;
-
-        Any arg = new Any(new Type(XDocumentHandler.class), xDocHandWriter);
-        XInterface oExp = (XInterface)xMSF.createInstanceWithArguments(
-            "com.sun.star.comp." + docType + ".XML" + exportType + "Exporter",
-            new Object[] {arg});
-
-        XExporter xExp = UnoRuntime.queryInterface
-            (XExporter.class, oExp) ;
-        xExp.setSourceDocument(xDoc) ;
-
-        XFilter filter = UnoRuntime.queryInterface(XFilter.class, oExp) ;
-        filter.filter(XMLTools.createMediaDescriptor(
-            new String[] {"FilterName"},
-            new Object[] {"Custom filter"})) ;
-    }
-
-    /**
-     * Imports document (the whole or a part) from the file specified
-     * in XML format.
-     * @param xMSF Soffice <code>ServiceManager</code> factory.
-     * @param xDoc Target document to be imported.
-     * @param docType Type of document (for example 'Calc', 'Writer', 'Draw')
-     * The type must start with <b>capital</b> letter.
-     * @param importType The type of export specifies if the whole
-     * document will be exported or one of its parts (Meta info, Styles, etc.).
-     * The following types supported (it hardly depends of XML data in file) :
-     *  "" (empty string) - for the whole document ;
-     *  "Content" - only content exported ;
-     *  "Meta" - meta document info exported ;
-     *  "Settings" - view settings of document exported ;
-     *  "Styles" - document styles exported ;
-     * @param fileURL XML file name (in form file:///<path>) to be imported from.
-     */
-    public static void importDocument(XMultiServiceFactory xMSF, XComponent xDoc,
-        String docType, String importType, String fileURL)
-        throws com.sun.star.uno.Exception {
-
-        XInterface oImp = (XInterface)xMSF.createInstance(
-            "com.sun.star.comp." + docType + ".XML" + importType + "Importer");
-        XImporter xImp = UnoRuntime.queryInterface
-            (XImporter.class, oImp) ;
-        XDocumentHandler xDocHandImp = UnoRuntime.queryInterface
-            (XDocumentHandler.class, oImp) ;
-
-        xImp.setTargetDocument(xDoc) ;
-        parseXMLFile(xMSF, fileURL, xDocHandImp) ;
-    }
 }
