@@ -47,7 +47,7 @@ public class _XPropertyContainer extends MultiMethodTest {
     /**
      * object relation X<CODE>PropertyAccess.propertyNotRemovable</CODE><br>
      * This relation must be filled from the module. It contains a property which must
-     * be a property of the implementaion object.
+     * be a property of the implementation object.
      */
     private String propertyNotRemovable = null;
 
@@ -55,6 +55,7 @@ public class _XPropertyContainer extends MultiMethodTest {
      * checks if the object relation <CODE>XPropertyAccess.propertyNotRemovable</CODE>
      * is available
      */
+    @Override
     public void before() {
         propertyNotRemovable = (String) tEnv.getObjRelation("XPropertyContainer.propertyNotRemovable");
         if (propertyNotRemovable == null) {
@@ -210,7 +211,6 @@ public class _XPropertyContainer extends MultiMethodTest {
         ok &= test;
 
         tRes.tested("addProperty()", ok );
-        return;
     }
 
     /**
@@ -293,7 +293,6 @@ public class _XPropertyContainer extends MultiMethodTest {
         }
 
         tRes.tested("removeProperty()", ok );
-        return;
     }
 
 
