@@ -172,10 +172,10 @@ public class _XFrame extends MultiMethodTest {
     /**
     * Test calls the method. Then frame status (activated/deactivated) is
     * changed, and the listener is checked.<p>
-    * Has <b> OK </b> status if isDesktop() method returnes true, or if the
+    * Has <b> OK </b> status if isDesktop() method returns true, or if the
     * listener was called and frame was activated.
     */
-    public void _addFrameActionListener() {
+    public void _addFrameActionListener() throws Exception {
         boolean result = true ;
 
         oObj.addFrameActionListener(listener) ;
@@ -189,8 +189,7 @@ public class _XFrame extends MultiMethodTest {
             return;
         }
 
-        util.utils.shortWait();
-
+        waitForEventIdle();
 
         if (!listenerCalled[0]) {
             log.println("listener was not called.") ;
@@ -399,7 +398,7 @@ public class _XFrame extends MultiMethodTest {
     /**
     * At first new listener is added, then test calls the method and result
     * is checked. <p>
-    * Has <b> OK </b> status if isDesktop() method returnes true or if the
+    * Has <b> OK </b> status if isDesktop() method returns true or if the
     * listener was called and proper event past to listener.
     */
     public void _contextChanged() {
@@ -455,7 +454,7 @@ public class _XFrame extends MultiMethodTest {
     * Test calls the method, then result is checked.<p>
     * Has <b> OK </b> status if method returns true, and values, set by the
     * method are nulls, or if method returns false, and values are not changed.
-    * This method destroy the object. Therfore all other methods have to be
+    * This method destroy the object. Therefore all other methods have to be
     * executed before :
     * <ul>
     *  <li> <code> getName() </code>
