@@ -27,18 +27,14 @@ import lib.TestParameters;
 import java.io.PrintWriter;
 
 public final class DefaultProvider extends TestCase {
-    public DefaultProvider() {}
 
+    @Override
     protected TestEnvironment createTestEnvironment(
         TestParameters tParam, PrintWriter log)
     {
-        try {
-            return ProviderTestEnvironment.create(
-                AnyConverter.toObject(
-                    XInterface.class,
-                    theDefaultProvider.get(tParam.getComponentContext())));
-        } catch (com.sun.star.lang.IllegalArgumentException e) {
-            throw new RuntimeException(e);
-        }
+        return ProviderTestEnvironment.create(
+            AnyConverter.toObject(
+                XInterface.class,
+                theDefaultProvider.get(tParam.getComponentContext())));
     }
 }
