@@ -21,7 +21,6 @@ package mod._sc;
 import java.io.PrintWriter;
 import java.util.Random;
 
-import lib.StatusException;
 import lib.TestCase;
 import lib.TestEnvironment;
 import lib.TestParameters;
@@ -38,18 +37,10 @@ public class ScFunctionDescriptionObj extends TestCase {
     private XSpreadsheetDocument xSheetDoc = null;
 
     @Override
-    protected void initialize( TestParameters tParam, PrintWriter log ) {
+    protected void initialize( TestParameters tParam, PrintWriter log ) throws Exception {
         SOfficeFactory SOF = SOfficeFactory.getFactory(  tParam.getMSF() );
-
-        try {
-            log.println( "creating a Spreadsheet document" );
-            xSheetDoc = SOF.createCalcDoc(null);
-        } catch ( com.sun.star.uno.Exception e ) {
-            // Some exception occurs.FAILED
-            e.printStackTrace( log );
-            throw new StatusException( "Couldn't create document", e );
-        }
-
+        log.println( "creating a Spreadsheet document" );
+        xSheetDoc = SOF.createCalcDoc(null);
     }
 
     @Override
@@ -62,12 +53,12 @@ public class ScFunctionDescriptionObj extends TestCase {
 
 
     /**
-     *    creating a Testenvironment for the interfaces to be tested
+     *    creating a TestEnvironment for the interfaces to be tested
      */
     @Override
-    public synchronized TestEnvironment createTestEnvironment(
+    public TestEnvironment createTestEnvironment(
                                     TestParameters Param, PrintWriter log )
-                                                       throws StatusException {
+                                                       throws Exception {
 
         XInterface oObj = null;
 
@@ -75,30 +66,23 @@ public class ScFunctionDescriptionObj extends TestCase {
         // first we write what we are intend to do to log file
         log.println( "Creating a test environment" );
 
-        try {
-            log.println("Getting test object ") ;
+        log.println("Getting test object ") ;
 
-            XMultiServiceFactory oDocMSF =  Param.getMSF();
+        XMultiServiceFactory oDocMSF =  Param.getMSF();
 
-            XInterface FDs = (XInterface)oDocMSF.
-                    createInstance("com.sun.star.sheet.FunctionDescriptions");
-            XNameAccess NA = UnoRuntime.queryInterface
-                (XNameAccess.class, FDs);
+        XInterface FDs = (XInterface)oDocMSF.
+                createInstance("com.sun.star.sheet.FunctionDescriptions");
+        XNameAccess NA = UnoRuntime.queryInterface
+            (XNameAccess.class, FDs);
 
-            String names[] = NA.getElementNames();
-            Random rnd = new Random();
-            int idx = rnd.nextInt(names.length);
+        String names[] = NA.getElementNames();
+        Random rnd = new Random();
+        int idx = rnd.nextInt(names.length);
 
-            oObj = (XInterface)NA.getByName(names[idx]);
+        oObj = (XInterface)NA.getByName(names[idx]);
 
-            log.println("Creating object - " +
-                                        ((oObj == null) ? "FAILED" : "OK"));
-
-        } catch (Exception e) {
-            e.printStackTrace(log) ;
-            throw new StatusException
-                ("Error getting test object from spreadsheet document",e) ;
-        }
+        log.println("Creating object - " +
+                                    ((oObj == null) ? "FAILED" : "OK"));
 
         TestEnvironment tEnv = new TestEnvironment( oObj );
 
