@@ -17,7 +17,6 @@
  */
 package mod._toolkit;
 
-import com.sun.star.lang.XMultiServiceFactory;
 import com.sun.star.text.XTextDocument;
 import com.sun.star.uno.XInterface;
 
@@ -37,27 +36,30 @@ public class UnoControlFileControlModel extends TestCase {
     /**
     * Creates StarOffice Writer document.
     */
-    protected void initialize(TestParameters tParam, PrintWriter log) {
+    @Override
+    protected void initialize(TestParameters tParam, PrintWriter log) throws Exception {
         log.println("creating a textdocument");
         xTextDoc = WriterTools.createTextDoc(
-                           (XMultiServiceFactory) tParam.getMSF());
+                           tParam.getMSF());
     }
 
     /**
     * Disposes StarOffice Writer document.
     */
+    @Override
     protected void cleanup(TestParameters tParam, PrintWriter log) {
         log.println("    disposing xTextDoc ");
 
         util.DesktopTools.closeDoc(xTextDoc);
     }
 
-    public synchronized TestEnvironment createTestEnvironment(TestParameters Param,
+    @Override
+    public TestEnvironment createTestEnvironment(TestParameters Param,
                                                               PrintWriter log) {
         XInterface oObj = null;
 
         try {
-            oObj = (XInterface) ((XMultiServiceFactory) Param.getMSF()).createInstance(
+            oObj = (XInterface) Param.getMSF().createInstance(
                            "com.sun.star.awt.UnoControlFileControlModel");
         } catch (Exception e) {
         }
