@@ -56,7 +56,7 @@ namespace rptui
     using namespace util;
     using namespace container;
     using namespace report;
-//----------------------------------------------------------------------------
+
 ::std::mem_fun_t<uno::Reference<report::XSection> , OGroupHelper> OGroupHelper::getMemberFunction(const Reference< XSection >& _xSection)
 {
     ::std::mem_fun_t<uno::Reference<report::XSection> , OGroupHelper> pMemFunSection = ::std::mem_fun(&OGroupHelper::getFooter);
@@ -65,7 +65,7 @@ namespace rptui
         pMemFunSection = ::std::mem_fun(&OGroupHelper::getHeader);
     return pMemFunSection;
 }
-// -----------------------------------------------------------------------------
+
 ::std::mem_fun_t<uno::Reference<report::XSection> , OReportHelper> OReportHelper::getMemberFunction(const Reference< XSection >& _xSection)
 {
     uno::Reference< report::XReportDefinition> xReportDefinition(_xSection->getReportDefinition());
@@ -81,49 +81,43 @@ namespace rptui
     return pMemFunSection;
 }
 
-//------------------------------------------------------------------------------
-TYPEINIT1( OCommentUndoAction,          SdrUndoAction );
-DBG_NAME(rpt_OCommentUndoAction)
-//----------------------------------------------------------------------------
+
+
 OCommentUndoAction::OCommentUndoAction(SdrModel& _rMod,sal_uInt16 nCommentID)
     :SdrUndoAction(_rMod)
 {
-    DBG_CTOR(rpt_OCommentUndoAction,NULL);
     m_pController = static_cast< OReportModel& >( _rMod ).getController();
     if ( nCommentID )
         m_strComment = ModuleRes(nCommentID);
 }
 OCommentUndoAction::~OCommentUndoAction()
 {
-    DBG_DTOR(rpt_OCommentUndoAction,NULL);
 }
-//----------------------------------------------------------------------------
+
 void OCommentUndoAction::Undo()
 {
 }
-//----------------------------------------------------------------------------
+
 void OCommentUndoAction::Redo()
 {
 }
-DBG_NAME( rpt_OUndoContainerAction );
-//------------------------------------------------------------------------------
+
 OUndoContainerAction::OUndoContainerAction(SdrModel& _rMod
                                              ,Action _eAction
-                                             ,const uno::Reference< container::XIndexContainer > _xContainer
+                                             ,const uno::Reference< container::XIndexContainer >& rContainer
                                              ,const Reference< XInterface > & xElem
                                              ,sal_uInt16 _nCommentId)
                       :OCommentUndoAction(_rMod,_nCommentId)
                       ,m_xElement(xElem)
-                      ,m_xContainer(_xContainer)
+                      ,m_xContainer(rContainer)
                          ,m_eAction( _eAction )
 {
-    DBG_CTOR( rpt_OUndoContainerAction,NULL);
     // normalize
     if ( m_eAction == Removed )
         // we now own the element
         m_xOwnElement = m_xElement;
 }
-//------------------------------------------------------------------------------
+
 OUndoContainerAction::~OUndoContainerAction()
 {
     // if we own the object ....
@@ -139,8 +133,8 @@ OUndoContainerAction::~OUndoContainerAction()
 
 #if OSL_DEBUG_LEVEL > 0
             SvxShape* pShape = SvxShape::getImplementation( xChild );
-            SdrObject* pObject = pShape ? pShape->GetSdrObject() : NULL;
-            OSL_ENSURE( pObject ? pShape->HasSdrObjectOwnership() && !pObject->IsInserted() : true ,
+            SdrObject* pObject = pShape ? pShape->GetSdrObject() : nullptr;
+            OSL_ENSURE( pObject == nullptr || (pShape->HasSdrObjectOwnership() && !pObject->IsInserted()),
                 "OUndoContainerAction::~OUndoContainerAction: inconsistency in the shape/object ownership!" );
 #endif
             // -> dispose it
@@ -154,10 +148,9 @@ OUndoContainerAction::~OUndoContainerAction()
             }
         }
     }
-    DBG_DTOR( rpt_OUndoContainerAction,NULL);
 }
-//------------------------------------------------------------------------------
-void OUndoContainerAction::implReInsert( ) SAL_THROW( ( Exception ) )
+
+void OUndoContainerAction::implReInsert( )
 {
     if ( m_xContainer.is() )
     {
@@ -165,11 +158,11 @@ void OUndoContainerAction::implReInsert( ) SAL_THROW( ( Exception ) )
         m_xContainer->insertByIndex( m_xContainer->getCount(),uno::makeAny(m_xElement) );
     }
     // we don't own the object anymore
-    m_xOwnElement = NULL;
+    m_xOwnElement = nullptr;
 }
 
-//------------------------------------------------------------------------------
-void OUndoContainerAction::implReRemove( ) SAL_THROW( ( Exception ) )
+
+void OUndoContainerAction::implReRemove( )
 {
     OXUndoEnvironment& rEnv = static_cast< OReportModel& >( rMod ).GetUndoEnv();
     try
@@ -194,7 +187,7 @@ void OUndoContainerAction::implReRemove( ) SAL_THROW( ( Exception ) )
     m_xOwnElement = m_xElement;
 }
 
-//------------------------------------------------------------------------------
+
 void OUndoContainerAction::Undo()
 {
     if ( m_xElement.is() )
@@ -223,7 +216,7 @@ void OUndoContainerAction::Undo()
     }
 }
 
-//------------------------------------------------------------------------------
+
 void OUndoContainerAction::Redo()
 {
     if ( m_xElement.is() )
@@ -250,7 +243,7 @@ void OUndoContainerAction::Redo()
         }
     }
 }
-// -----------------------------------------------------------------------------
+
 OUndoGroupSectionAction::OUndoGroupSectionAction(SdrModel& _rMod
                                              ,Action _eAction
                                              ,::std::mem_fun_t< uno::Reference< report::XSection >
@@ -258,13 +251,13 @@ OUndoGroupSectionAction::OUndoGroupSectionAction(SdrModel& _rMod
                                              ,const uno::Reference< report::XGroup >& _xGroup
                                              ,const Reference< XInterface > & xElem
                                              ,sal_uInt16 _nCommentId)
-:OUndoContainerAction(_rMod,_eAction,NULL,xElem,_nCommentId)
+:OUndoContainerAction(_rMod,_eAction,nullptr,xElem,_nCommentId)
 ,m_aGroupHelper(_xGroup)
 ,m_pMemberFunction(_pMemberFunction)
 {
 }
-//------------------------------------------------------------------------------
-void OUndoGroupSectionAction::implReInsert( ) SAL_THROW( ( Exception ) )
+
+void OUndoGroupSectionAction::implReInsert( )
 {
     OXUndoEnvironment& rEnv = static_cast< OReportModel& >( rMod ).GetUndoEnv();
     try
@@ -277,11 +270,11 @@ void OUndoGroupSectionAction::implReInsert( ) SAL_THROW( ( Exception ) )
     catch(uno::Exception&){}
 
     // we don't own the object anymore
-    m_xOwnElement = NULL;
+    m_xOwnElement = nullptr;
 }
 
-//------------------------------------------------------------------------------
-void OUndoGroupSectionAction::implReRemove( ) SAL_THROW( ( Exception ) )
+
+void OUndoGroupSectionAction::implReRemove( )
 {
         OXUndoEnvironment& rEnv = static_cast< OReportModel& >( rMod ).GetUndoEnv();
     try
@@ -296,7 +289,7 @@ void OUndoGroupSectionAction::implReRemove( ) SAL_THROW( ( Exception ) )
     // from now on, we own this object
     m_xOwnElement = m_xElement;
 }
-//----------------------------------------------------------------------------
+
 OUndoReportSectionAction::OUndoReportSectionAction(SdrModel& _rMod
                                              ,Action _eAction
                                              ,::std::mem_fun_t< uno::Reference< report::XSection >
@@ -304,13 +297,13 @@ OUndoReportSectionAction::OUndoReportSectionAction(SdrModel& _rMod
                                              ,const uno::Reference< report::XReportDefinition >& _xReport
                                              ,const Reference< XInterface > & xElem
                                              ,sal_uInt16 _nCommentId)
-:OUndoContainerAction(_rMod,_eAction,NULL,xElem,_nCommentId)
+:OUndoContainerAction(_rMod,_eAction,nullptr,xElem,_nCommentId)
 ,m_aReportHelper(_xReport)
 ,m_pMemberFunction(_pMemberFunction)
 {
 }
-//------------------------------------------------------------------------------
-void OUndoReportSectionAction::implReInsert( ) SAL_THROW( ( Exception ) )
+
+void OUndoReportSectionAction::implReInsert( )
 {
     OXUndoEnvironment& rEnv = static_cast< OReportModel& >( rMod ).GetUndoEnv();
     try
@@ -329,11 +322,11 @@ void OUndoReportSectionAction::implReInsert( ) SAL_THROW( ( Exception ) )
     }
     catch(uno::Exception&){}
     // we don't own the object anymore
-    m_xOwnElement = NULL;
+    m_xOwnElement = nullptr;
 }
 
-//------------------------------------------------------------------------------
-void OUndoReportSectionAction::implReRemove( ) SAL_THROW( ( Exception ) )
+
+void OUndoReportSectionAction::implReRemove( )
 {
     OXUndoEnvironment& rEnv = static_cast< OReportModel& >( rMod ).GetUndoEnv();
     try
@@ -347,7 +340,7 @@ void OUndoReportSectionAction::implReRemove( ) SAL_THROW( ( Exception ) )
     // from now on, we own this object
     m_xOwnElement = m_xElement;
 }
-//------------------------------------------------------------------------------
+
 ORptUndoPropertyAction::ORptUndoPropertyAction(SdrModel& rNewMod, const PropertyChangeEvent& evt)
                      :OCommentUndoAction(rNewMod,0)
                      ,m_xObj(evt.Source, UNO_QUERY)
@@ -356,24 +349,24 @@ ORptUndoPropertyAction::ORptUndoPropertyAction(SdrModel& rNewMod, const Property
                      ,m_aOldValue(evt.OldValue)
 {
 }
-//------------------------------------------------------------------------------
+
 void ORptUndoPropertyAction::Undo()
 {
-    setProperty(sal_True);
+    setProperty(true);
 }
 
-//------------------------------------------------------------------------------
+
 void ORptUndoPropertyAction::Redo()
 {
-    setProperty(sal_False);
+    setProperty(false);
 }
-// -----------------------------------------------------------------------------
+
 Reference< XPropertySet> ORptUndoPropertyAction::getObject()
 {
     return m_xObj;
 }
-// -----------------------------------------------------------------------------
-void ORptUndoPropertyAction::setProperty(sal_Bool _bOld)
+
+void ORptUndoPropertyAction::setProperty(bool _bOld)
 {
     Reference< XPropertySet> xObj = getObject();
 
@@ -408,12 +401,12 @@ OUndoPropertyGroupSectionAction::OUndoPropertyGroupSectionAction(SdrModel& _rMod
 ,m_pMemberFunction(_pMemberFunction)
 {
 }
-// -----------------------------------------------------------------------------
+
 Reference< XPropertySet> OUndoPropertyGroupSectionAction::getObject()
 {
     return m_pMemberFunction(&m_aGroupHelper).get();
 }
-// -----------------------------------------------------------------------------
+
 OUndoPropertyReportSectionAction::OUndoPropertyReportSectionAction(SdrModel& _rMod
                                              ,const PropertyChangeEvent& evt
                                              ,::std::mem_fun_t< uno::Reference< report::XSection >
@@ -425,13 +418,13 @@ OUndoPropertyReportSectionAction::OUndoPropertyReportSectionAction(SdrModel& _rM
 ,m_pMemberFunction(_pMemberFunction)
 {
 }
-// -----------------------------------------------------------------------------
+
 Reference< XPropertySet> OUndoPropertyReportSectionAction::getObject()
 {
     return m_pMemberFunction(&m_aReportHelper).get();
 }
-//============================================================================
+
 } // rptui
-//============================================================================
+
 
 /* vim:set shiftwidth=4 softtabstop=4 expandtab: */
