@@ -58,6 +58,7 @@
 
 #include <boost/bind.hpp>
 
+#include <iterator>
 
 namespace rptxml
 {
@@ -82,8 +83,7 @@ namespace rptxml
 
     Sequence< OUString > ORptExportHelper::getSupportedServiceNames_Static(  ) throw(RuntimeException)
     {
-        Sequence< OUString > aSupported(1);
-        aSupported[0] = "com.sun.star.document.ExportFilter";
+        Sequence< OUString > aSupported { "com.sun.star.document.ExportFilter" };
         return aSupported;
     }
 
@@ -99,8 +99,7 @@ namespace rptxml
 
     Sequence< OUString > ORptContentExportHelper::getSupportedServiceNames_Static(  ) throw(RuntimeException)
     {
-        Sequence< OUString > aSupported(1);
-        aSupported[0] = "com.sun.star.document.ExportFilter";
+        Sequence< OUString > aSupported { "com.sun.star.document.ExportFilter" };
         return aSupported;
     }
 
@@ -118,8 +117,7 @@ namespace rptxml
 
     Sequence< OUString > ORptStylesExportHelper::getSupportedServiceNames_Static(  ) throw(RuntimeException)
     {
-        Sequence< OUString > aSupported(1);
-        aSupported[0] = "com.sun.star.document.ExportFilter";
+        Sequence< OUString > aSupported { "com.sun.star.document.ExportFilter" };
         return aSupported;
     }
 
@@ -136,8 +134,7 @@ namespace rptxml
 
     Sequence< OUString > ORptMetaExportHelper::getSupportedServiceNames_Static(  ) throw(RuntimeException)
     {
-        Sequence< OUString > aSupported(1);
-        aSupported[0] = "com.sun.star.document.ExportFilter";
+        Sequence< OUString > aSupported { "com.sun.star.document.ExportFilter" };
         return aSupported;
     }
 
@@ -154,8 +151,7 @@ namespace rptxml
 
     Sequence< OUString > ODBFullExportHelper::getSupportedServiceNames_Static(  ) throw(RuntimeException)
     {
-        Sequence< OUString > aSupported(1);
-        aSupported[0] = "com.sun.star.document.ExportFilter";
+        Sequence< OUString > aSupported { "com.sun.star.document.ExportFilter" };
         return aSupported;
     }
 
@@ -164,7 +160,7 @@ namespace rptxml
     class OSpecialHandleXMLExportPropertyMapper : public SvXMLExportPropertyMapper
     {
     public:
-        OSpecialHandleXMLExportPropertyMapper(const rtl::Reference< XMLPropertySetMapper >& rMapper) : SvXMLExportPropertyMapper(rMapper )
+        explicit OSpecialHandleXMLExportPropertyMapper(const rtl::Reference< XMLPropertySetMapper >& rMapper) : SvXMLExportPropertyMapper(rMapper )
         {
         }
         /** this method is called for every item that has the
@@ -174,8 +170,8 @@ namespace rptxml
                 const XMLPropertyState& /*rProperty*/,
                 const SvXMLUnitConverter& /*rUnitConverter*/,
                 const SvXMLNamespaceMap& /*rNamespaceMap*/,
-                const ::std::vector< XMLPropertyState >* /*pProperties*/ = 0,
-                sal_uInt32 /*nIdx*/ = 0 ) const SAL_OVERRIDE
+                const ::std::vector< XMLPropertyState >* /*pProperties*/ = nullptr,
+                sal_uInt32 /*nIdx*/ = 0 ) const override
         {
             // nothing to do here
         }
@@ -323,8 +319,7 @@ OUString ORptExport::getImplementationName_Static(  ) throw(uno::RuntimeExceptio
 
 uno::Sequence< OUString > ORptExport::getSupportedServiceNames_Static(  ) throw(uno::RuntimeException)
 {
-    uno::Sequence< OUString > aServices(1);
-    aServices.getArray()[0] = "com.sun.star.document.ExportFilter";
+    uno::Sequence< OUString > aServices { "com.sun.star.document.ExportFilter" };
 
     return aServices;
 }
@@ -519,7 +514,7 @@ void ORptExport::collectStyleNames(sal_Int32 _nFamily,const ::std::vector< sal_I
 
 void ORptExport::exportSectionAutoStyle(const Reference<XSection>& _xProp)
 {
-    OSL_ENSURE(_xProp != NULL,"Section is NULL -> GPF");
+    OSL_ENSURE(_xProp != nullptr,"Section is NULL -> GPF");
     exportAutoStyle(_xProp);
 
     Reference<XReportDefinition> xReport = _xProp->getReportDefinition();
@@ -842,7 +837,6 @@ void ORptExport::exportContainer(const Reference< XSection>& _xSection)
                         sal_Int32 nFormatKey = xFormattedField->getFormatKey();
                         XMLNumberFormatAttributesExportHelper aHelper(GetNumberFormatsSupplier(),*this);
                         bool bIsStandard = false;
-                        OUString sEmpty;
                         sal_Int16 nCellType = aHelper.GetCellType(nFormatKey,bIsStandard);
                         // "Standard" means "no format set, value could be anything",
                         // so don't set a format attribute in this case.
@@ -850,7 +844,7 @@ void ORptExport::exportContainer(const Reference< XSection>& _xSection)
                         if (!bIsStandard)
                         {
                             if ( nCellType == util::NumberFormat::TEXT )
-                                aHelper.SetNumberFormatAttributes(sEmpty, sEmpty);
+                                aHelper.SetNumberFormatAttributes("", "");
                             else
                                 aHelper.SetNumberFormatAttributes(nFormatKey, 0.0, false);
                         }
@@ -912,17 +906,15 @@ void ORptExport::exportContainer(const Reference< XSection>& _xSection)
                             {
                             }
 
-                            bool bPageSet = false;
                             if ( bExportData )
                             {
-                                bPageSet = exportFormula(XML_FORMULA,xReportElement->getDataField());
+                                const bool bPageSet = exportFormula(XML_FORMULA,xReportElement->getDataField());
                                 if ( bPageSet )
                                     eToken = XML_FIXED_CONTENT;
                                 else if ( eToken == XML_IMAGE )
                                     AddAttribute(XML_NAMESPACE_REPORT, XML_PRESERVE_IRI, xImage->getPreserveIRI() ? XML_TRUE : XML_FALSE );
                             }
 
-                            //if ( !bPageSet )
                             {
                                 // start <report:eToken>
                                 SvXMLElementExport aComponents(*this,XML_NAMESPACE_REPORT, eToken, false, false);
@@ -1446,12 +1438,12 @@ void ORptExport::exportParagraph(const Reference< XReportControlModel >& _xRepor
                         static const char s_sCurrent[] = "current";
                         AddAttribute(XML_NAMESPACE_TEXT, XML_SELECT_PAGE, s_sCurrent );
                         SvXMLElementExport aPageNumber(*this,XML_NAMESPACE_TEXT, XML_PAGE_NUMBER, false, false);
-                        Characters(OUString("1"));
+                        Characters("1");
                     }
                     else if ( sToken == s_sPageCount )
                     {
                         SvXMLElementExport aPageNumber(*this,XML_NAMESPACE_TEXT, XML_PAGE_COUNT, false, false);
-                        Characters(OUString("1"));
+                        Characters("1");
                     }
                     else
                     {
