@@ -76,10 +76,11 @@ using namespace ::com::sun::star::io;
 using namespace ::com::sun::star::report;
 using namespace ::com::sun::star::xml::sax;
 using namespace xmloff;
+using namespace ::com::sun::star::util;
+
     sal_Char const sXML_np__rpt[] = "_report";
     sal_Char const sXML_np___rpt[] = "__report";
 
-    using namespace ::com::sun::star::util;
 
 class RptMLMasterStylesContext_Impl:
     public XMLTextMasterStylesContext, private boost::noncopyable
@@ -88,17 +89,15 @@ class RptMLMasterStylesContext_Impl:
 
 public:
 
-    TYPEINFO_OVERRIDE();
 
     RptMLMasterStylesContext_Impl(
             ORptFilter& rImport, sal_uInt16 nPrfx,
             const OUString& rLName ,
             const uno::Reference< xml::sax::XAttributeList > & xAttrList );
     virtual ~RptMLMasterStylesContext_Impl();
-    virtual void EndElement() SAL_OVERRIDE;
+    virtual void EndElement() override;
 };
 
-TYPEINIT1( RptMLMasterStylesContext_Impl, XMLTextMasterStylesContext );
 RptMLMasterStylesContext_Impl::RptMLMasterStylesContext_Impl(
         ORptFilter& rImport, sal_uInt16 nPrfx,
         const OUString& rLName ,
@@ -204,7 +203,7 @@ sal_Int32 ReadThroughComponent(
     ,const uno::Reference<beans::XPropertySet>& _xProp)
 {
     OSL_ENSURE( xStorage.is(), "Need storage!");
-    OSL_ENSURE(NULL != pStreamName, "Please, please, give me a name!");
+    OSL_ENSURE(nullptr != pStreamName, "Please, please, give me a name!");
 
     if ( xStorage.is() )
     {
@@ -221,7 +220,7 @@ sal_Int32 ReadThroughComponent(
                 // if no stream can be opened, return immediately with OK signal
 
                 // do we even have an alternative name?
-                if ( NULL == pCompatibilityStreamName )
+                if ( nullptr == pCompatibilityStreamName )
                     return 0;
 
                 // if so, does the stream exist?
@@ -283,7 +282,7 @@ sal_Int32 ReadThroughComponent(
 
 uno::Reference< uno::XInterface > ORptImportHelper::create(uno::Reference< uno::XComponentContext > const & xContext)
 {
-    return static_cast< XServiceInfo* >(new ORptFilter(xContext, IMPORT_SETTINGS ));
+    return static_cast< XServiceInfo* >(new ORptFilter(xContext, SvXMLImportFlags::SETTINGS ));
 }
 
 OUString ORptImportHelper::getImplementationName_Static(  ) throw (RuntimeException)
@@ -293,15 +292,14 @@ OUString ORptImportHelper::getImplementationName_Static(  ) throw (RuntimeExcept
 
 Sequence< OUString > ORptImportHelper::getSupportedServiceNames_Static(  ) throw(RuntimeException)
 {
-    Sequence< OUString > aSupported(1);
-    aSupported[0] = SERVICE_IMPORTFILTER;
+    Sequence< OUString > aSupported { SERVICE_IMPORTFILTER };
     return aSupported;
 }
 
 Reference< XInterface > ORptContentImportHelper::create(const Reference< XComponentContext > & xContext)
 {
-    return static_cast< XServiceInfo* >(new ORptFilter(xContext,IMPORT_AUTOSTYLES |   IMPORT_CONTENT | IMPORT_SCRIPTS |
-        IMPORT_FONTDECLS ));
+    return static_cast< XServiceInfo* >(new ORptFilter(xContext, SvXMLImportFlags::AUTOSTYLES | SvXMLImportFlags::CONTENT | SvXMLImportFlags::SCRIPTS |
+        SvXMLImportFlags::FONTDECLS ));
 }
 
 OUString ORptContentImportHelper::getImplementationName_Static(  ) throw (RuntimeException)
@@ -311,8 +309,7 @@ OUString ORptContentImportHelper::getImplementationName_Static(  ) throw (Runtim
 
 Sequence< OUString > ORptContentImportHelper::getSupportedServiceNames_Static(  ) throw(RuntimeException)
 {
-    Sequence< OUString > aSupported(1);
-    aSupported[0] = SERVICE_IMPORTFILTER;
+    Sequence< OUString > aSupported { SERVICE_IMPORTFILTER };
     return aSupported;
 }
 
@@ -320,8 +317,8 @@ Sequence< OUString > ORptContentImportHelper::getSupportedServiceNames_Static(
 Reference< XInterface > ORptStylesImportHelper::create(Reference< XComponentContext > const & xContext)
 {
     return static_cast< XServiceInfo* >(new ORptFilter(xContext,
-        IMPORT_STYLES | IMPORT_MASTERSTYLES | IMPORT_AUTOSTYLES |
-        IMPORT_FONTDECLS ));
+        SvXMLImportFlags::STYLES | SvXMLImportFlags::MASTERSTYLES | SvXMLImportFlags::AUTOSTYLES |
+        SvXMLImportFlags::FONTDECLS ));
 }
 
 OUString ORptStylesImportHelper::getImplementationName_Static(  ) throw (RuntimeException)
@@ -331,8 +328,7 @@ OUString ORptStylesImportHelper::getImplementationName_Static(  ) throw (Runtime
 
 Sequence< OUString > ORptStylesImportHelper::getSupportedServiceNames_Static(  ) throw(RuntimeException)
 {
-    Sequence< OUString > aSupported(1);
-    aSupported[0] = SERVICE_IMPORTFILTER;
+    Sequence< OUString > aSupported { SERVICE_IMPORTFILTER };
     return aSupported;
 }
 
@@ -340,7 +336,7 @@ Sequence< OUString > ORptStylesImportHelper::getSupportedServiceNames_Static(  )
 Reference< XInterface > ORptMetaImportHelper::create(Reference< XComponentContext > const & xContext)
 {
     return static_cast< XServiceInfo* >(new ORptFilter(xContext,
-        IMPORT_META));
+        SvXMLImportFlags::META));
 }
 
 OUString ORptMetaImportHelper::getImplementationName_Static(  ) throw (RuntimeException)
@@ -350,24 +346,23 @@ OUString ORptMetaImportHelper::getImplementationName_Static(  ) throw (RuntimeEx
 
 Sequence< OUString > ORptMetaImportHelper::getSupportedServiceNames_Static(  ) throw(RuntimeException)
 {
-    Sequence< OUString > aSupported(1);
-    aSupported[0] = SERVICE_IMPORTFILTER;
+    Sequence< OUString > aSupported { SERVICE_IMPORTFILTER };
     return aSupported;
 }
 
 
 // - ORptFilter -
 
-ORptFilter::ORptFilter( const uno::Reference< XComponentContext >& _rxContext,sal_uInt16 nImportFlags )
+ORptFilter::ORptFilter( const uno::Reference< XComponentContext >& _rxContext, SvXMLImportFlags nImportFlags )
     :SvXMLImport(_rxContext, getImplementationName_Static(), nImportFlags)
 {
     GetMM100UnitConverter().SetCoreMeasureUnit(util::MeasureUnit::MM_100TH);
     GetMM100UnitConverter().SetXMLMeasureUnit(util::MeasureUnit::CM);
-    GetNamespaceMap().Add( OUString( sXML_np__rpt ),
+    GetNamespaceMap().Add( sXML_np__rpt,
                         GetXMLToken(XML_N_RPT),
                         XML_NAMESPACE_REPORT );
 
-    GetNamespaceMap().Add( OUString( sXML_np___rpt ),
+    GetNamespaceMap().Add( sXML_np___rpt,
                         GetXMLToken(XML_N_RPT_OASIS),
                         XML_NAMESPACE_REPORT );
 
@@ -375,7 +370,7 @@ ORptFilter::ORptFilter( const uno::Reference< XComponentContext >& _rxContext,sa
     m_xCellStylesPropertySetMapper = OXMLHelper::GetCellStylePropertyMap(true, false);
     m_xColumnStylesPropertySetMapper = new XMLPropertySetMapper(OXMLHelper::GetColumnStyleProps(), m_xPropHdlFactory, false);
     m_xRowStylesPropertySetMapper = new XMLPropertySetMapper(OXMLHelper::GetRowStyleProps(), m_xPropHdlFactory, false);
-    m_xTableStylesPropertySetMapper = new XMLTextPropertySetMapper( TEXT_PROP_MAP_TABLE_DEFAULTS, false );
+    m_xTableStylesPropertySetMapper = new XMLTextPropertySetMapper( TextPropMap::TABLE_DEFAULTS, false );
 }
 
 
@@ -397,8 +392,7 @@ OUString ORptFilter::getImplementationName_Static(  ) throw(uno::RuntimeExceptio
 
 uno::Sequence< OUString > ORptFilter::getSupportedServiceNames_Static(  ) throw(uno::RuntimeException)
 {
-    uno::Sequence< OUString > aServices(1);
-    aServices.getArray()[0] = SERVICE_IMPORTFILTER;
+    uno::Sequence< OUString > aServices { SERVICE_IMPORTFILTER };
 
     return aServices;
 }
@@ -406,7 +400,7 @@ uno::Sequence< OUString > ORptFilter::getSupportedServiceNames_Static(  ) throw(
 sal_Bool SAL_CALL ORptFilter::filter( const Sequence< PropertyValue >& rDescriptor )
     throw (RuntimeException, std::exception)
 {
-    Window*     pFocusWindow = Application::GetFocusWindow();
+    vcl::Window*     pFocusWindow = Application::GetFocusWindow();
     bool    bRet = false;
 
     if( pFocusWindow )
@@ -422,7 +416,7 @@ sal_Bool SAL_CALL ORptFilter::filter( const Sequence< PropertyValue >& rDescript
 }
 
 bool ORptFilter::implImport( const Sequence< PropertyValue >& rDescriptor )
-    throw (RuntimeException)
+    throw (RuntimeException, std::exception)
 {
     OUString                     sFileName;
     uno::Reference< embed::XStorage >   xStorage;
@@ -458,8 +452,8 @@ bool ORptFilter::implImport( const Sequence< PropertyValue >& rDescriptor )
     {
         uno::Reference<XComponent> xCom(GetModel(),UNO_QUERY);
 
-        SfxMediumRef pMedium = new SfxMedium(
-                sFileName, ( STREAM_READ | STREAM_NOCREATE ) );
+        tools::SvRef<SfxMedium> pMedium = new SfxMedium(
+                sFileName, ( StreamMode::READ | StreamMode::NOCREATE ) );
 
         if( pMedium )
         {
@@ -503,29 +497,29 @@ bool ORptFilter::implImport( const Sequence< PropertyValue >& rDescriptor )
 
         uno::Reference< lang::XMultiServiceFactory > xReportServiceFactory( m_xReportDefinition, uno::UNO_QUERY);
         aArgs[0] <<= beans::NamedValue(OUString("Storage"),uno::makeAny(xStorage));
-        xEmbeddedObjectResolver.set( xReportServiceFactory->createInstanceWithArguments(OUString("com.sun.star.document.ImportEmbeddedObjectResolver"),aArgs) , uno::UNO_QUERY);
+        xEmbeddedObjectResolver.set( xReportServiceFactory->createInstanceWithArguments("com.sun.star.document.ImportEmbeddedObjectResolver",aArgs) , uno::UNO_QUERY);
 
-        static const OUString s_sOld("OldFormat");
+        static const char s_sOld[] = "OldFormat";
         static comphelper::PropertyMapEntry const pMap[] =
         {
-            { OUString("OldFormat") , 1,    ::getCppuType((const sal_Bool*)0),                 beans::PropertyAttribute::BOUND,     0 },
-            { OUString("StreamName"), 0,    ::getCppuType( (OUString *)0 ),             beans::PropertyAttribute::MAYBEVOID, 0 },
-            { OUString("PrivateData"),0,    ::getCppuType( (uno::Reference<XInterface> *)0 ),  beans::PropertyAttribute::MAYBEVOID, 0 },
-            { OUString("BaseURI"),    0,    ::getCppuType( (OUString *)0 ),             beans::PropertyAttribute::MAYBEVOID, 0 },
-            { OUString("StreamRelPath"), 0, ::getCppuType( (OUString *)0 ),             beans::PropertyAttribute::MAYBEVOID, 0 },
+            { OUString("OldFormat") , 1,    cppu::UnoType<sal_Bool>::get(),                 beans::PropertyAttribute::BOUND,     0 },
+            { OUString("StreamName"), 0,    cppu::UnoType<OUString>::get(),             beans::PropertyAttribute::MAYBEVOID, 0 },
+            { OUString("PrivateData"),0,    cppu::UnoType<XInterface>::get(),  beans::PropertyAttribute::MAYBEVOID, 0 },
+            { OUString("BaseURI"),    0,    cppu::UnoType<OUString>::get(),             beans::PropertyAttribute::MAYBEVOID, 0 },
+            { OUString("StreamRelPath"), 0, cppu::UnoType<OUString>::get(),             beans::PropertyAttribute::MAYBEVOID, 0 },
             { OUString(), 0, css::uno::Type(), 0, 0 }
         };
         utl::MediaDescriptor aDescriptor(rDescriptor);
         uno::Reference<beans::XPropertySet> xProp = comphelper::GenericPropertySet_CreateInstance(new comphelper::PropertySetInfo(pMap));
-        const OUString sVal( aDescriptor.getUnpackedValueOrDefault(aDescriptor.PROP_DOCUMENTBASEURL(),OUString()) );
+        const OUString sVal( aDescriptor.getUnpackedValueOrDefault(utl::MediaDescriptor::PROP_DOCUMENTBASEURL(),OUString()) );
         xProp->setPropertyValue("BaseURI", uno::makeAny(sVal));
         const OUString sHierarchicalDocumentName( aDescriptor.getUnpackedValueOrDefault("HierarchicalDocumentName",OUString()) );
         xProp->setPropertyValue("StreamRelPath", uno::makeAny(sHierarchicalDocumentName));
 
         uno::Reference<XComponent> xModel(GetModel(),UNO_QUERY);
-        static const OUString s_sMeta("meta.xml");
-        static const OUString s_sStreamName("StreamName");
-        xProp->setPropertyValue(s_sStreamName, uno::makeAny(s_sMeta));
+        static const char s_sMeta[] = "meta.xml";
+        static const char s_sStreamName[] = "StreamName";
+        xProp->setPropertyValue(s_sStreamName, uno::makeAny(OUString(s_sMeta)));
         sal_Int32 nRet = ReadThroughComponent( xStorage
                                     ,xModel
                                     ,"meta.xml"
@@ -607,7 +601,7 @@ bool ORptFilter::implImport( const Sequence< PropertyValue >& rDescriptor )
                         // TODO/LATER: no way to transport the error outside from the filter!
                         break;
                     }
-                    // fall through intented
+                    // fall through intended
                 default:
                     {
                         // TODO/LATER: this is completely wrong! Filter code should never call ErrorHandler directly! But for now this is the only way!
@@ -626,7 +620,7 @@ SvXMLImportContext* ORptFilter::CreateContext( sal_uInt16 nPrefix,
                                       const OUString& rLocalName,
                                       const uno::Reference< xml::sax::XAttributeList >& xAttrList )
 {
-    SvXMLImportContext *pContext = 0;
+    SvXMLImportContext *pContext = nullptr;
 
     const SvXMLTokenMap& rTokenMap = GetDocElemTokenMap();
     switch( rTokenMap.Get( nPrefix, rLocalName ) )
@@ -641,13 +635,13 @@ SvXMLImportContext* ORptFilter::CreateContext( sal_uInt16 nPrefix,
                 const SvXMLStylesContext* pAutoStyles = GetAutoStyles();
                 if ( pAutoStyles )
                 {
-                    XMLPropStyleContext* pAutoStyle = PTR_CAST(XMLPropStyleContext,pAutoStyles->FindStyleChildContext(XML_STYLE_FAMILY_PAGE_MASTER,OUString("pm1")));
+                    XMLPropStyleContext* pAutoStyle = const_cast<XMLPropStyleContext*>(dynamic_cast< const XMLPropStyleContext *>(pAutoStyles->FindStyleChildContext(XML_STYLE_FAMILY_PAGE_MASTER,"pm1")));
                     if ( pAutoStyle )
                     {
                         pAutoStyle->FillPropertySet(getReportDefinition().get());
                     }
                 }
-                pContext = new OXMLReport( *this, nPrefix, rLocalName,xAttrList,getReportDefinition(),NULL );
+                pContext = new OXMLReport( *this, nPrefix, rLocalName,xAttrList,getReportDefinition(),nullptr );
             }
             break;
         case XML_TOK_DOC_STYLES:
@@ -938,26 +932,13 @@ SvXMLImportContext* ORptFilter::CreateStylesContext(const OUString& rLocalName,
     {
         pContext = new OReportStylesContext(*this, XML_NAMESPACE_OFFICE, rLocalName, xAttrList, bIsAutoStyle);
         if (bIsAutoStyle)
-            SetAutoStyles((SvXMLStylesContext*)pContext);
+            SetAutoStyles(static_cast<SvXMLStylesContext*>(pContext));
         else
-            SetStyles((SvXMLStylesContext*)pContext);
+            SetStyles(static_cast<SvXMLStylesContext*>(pContext));
     }
     return pContext;
 }
 
-SvXMLImport&         ORptFilter::getGlobalContext()
-{
-    return *this;
-}
-
-void ORptFilter::enterEventContext()
-{
-}
-
-void ORptFilter::leaveEventContext()
-{
-}
-
 SvXMLImportContext *ORptFilter::CreateFontDeclsContext(
         const OUString& rLocalName,
         const uno::Reference< xml::sax::XAttributeList > & xAttrList )
@@ -986,7 +967,7 @@ OUString ORptFilter::convertFormula(const OUString& _sFormula)
     return _sFormula;
 }
 
-void SAL_CALL ORptFilter::startDocument( void )
+void SAL_CALL ORptFilter::startDocument()
     throw( xml::sax::SAXException, uno::RuntimeException, std::exception )
 {
     m_xReportDefinition.set(GetModel(),UNO_QUERY_THROW);
@@ -1000,7 +981,7 @@ void SAL_CALL ORptFilter::startDocument( void )
     }
 }
 
-void ORptFilter::endDocument( void )
+void ORptFilter::endDocument()
     throw( xml::sax::SAXException, uno::RuntimeException, std::exception )
 {
     OSL_ENSURE( GetModel().is(), "model missing; maybe startDocument wasn't called?" );
@@ -1024,16 +1005,16 @@ void ORptFilter::removeFunction(const OUString& _sFunctionName)
     m_aFunctions.erase(_sFunctionName);
 }
 
-void ORptFilter::insertFunction(const ::com::sun::star::uno::Reference< ::com::sun::star::report::XFunction > & _xFunction)
+void ORptFilter::insertFunction(const css::uno::Reference< css::report::XFunction > & _xFunction)
 {
     m_aFunctions.insert(TGroupFunctionMap::value_type(_xFunction->getName(),_xFunction));
 }
 
 SvXMLImportContext* ORptFilter::CreateMetaContext(const OUString& rLocalName,const uno::Reference<xml::sax::XAttributeList>&)
 {
-    SvXMLImportContext* pContext = NULL;
+    SvXMLImportContext* pContext = nullptr;
 
-    if ( (getImportFlags() & IMPORT_META) )
+    if ( (getImportFlags() & SvXMLImportFlags::META) )
     {
         uno::Reference<document::XDocumentPropertiesSupplier> xDPS(GetModel(), uno::UNO_QUERY_THROW);
         pContext = new SvXMLMetaDocumentContext(*this,XML_NAMESPACE_OFFICE, rLocalName,xDPS->getDocumentProperties());
@@ -1047,7 +1028,7 @@ bool ORptFilter::isOldFormat() const
     uno::Reference<beans::XPropertySet> xProp = getImportInfo();
     if ( xProp.is() )
     {
-        const static OUString s_sOld("OldFormat");
+        static const char s_sOld[] = "OldFormat";
         if ( xProp->getPropertySetInfo()->hasPropertyByName(s_sOld))
         {
             xProp->getPropertyValue(s_sOld) >>= bOldFormat;
