@@ -33,36 +33,31 @@
 namespace rptui
 {
     using namespace ::com::sun::star;
-TYPEINIT1( OSectionView, SdrView );
 
-//----------------------------------------------------------------------------
-DBG_NAME( rpt_OSectionView )
+
 OSectionView::OSectionView( SdrModel* pModel, OReportSection* _pSectionWindow, OReportWindow* pEditor )
     :SdrView( pModel, _pSectionWindow )
     ,m_pReportWindow( pEditor )
     ,m_pSectionWindow(_pSectionWindow)
 {
-    DBG_CTOR( rpt_OSectionView,NULL);
     // SetPagePaintingAllowed(false);
     SetBufferedOutputAllowed(true);
     SetBufferedOverlayAllowed(true);
     SetPageBorderVisible(false);
     SetBordVisible();
-    SetQuickTextEditMode(sal_False);
+    SetQuickTextEditMode(false);
 }
 
-//----------------------------------------------------------------------------
+
 
 OSectionView::~OSectionView()
 {
-    DBG_DTOR( rpt_OSectionView,NULL);
 }
 
-//----------------------------------------------------------------------------
+
 
 void OSectionView::MarkListHasChanged()
 {
-    DBG_CHKTHIS( rpt_OSectionView,NULL);
     SdrView::MarkListHasChanged();
 
     if ( m_pReportWindow && m_pSectionWindow && !m_pSectionWindow->getPage()->getSpecialMode() )
@@ -73,11 +68,10 @@ void OSectionView::MarkListHasChanged()
     }
 }
 
-//----------------------------------------------------------------------------
 
-void OSectionView::MakeVisible( const Rectangle& rRect, Window& rWin )
+
+void OSectionView::MakeVisible( const Rectangle& rRect, vcl::Window& rWin )
 {
-    DBG_CHKTHIS( rpt_OSectionView,NULL);
     // visible area
     MapMode aMap( rWin.GetMapMode() );
     const Point aOrg( aMap.GetOrigin() );
@@ -128,18 +122,18 @@ void OSectionView::MakeVisible( const Rectangle& rRect, Window& rWin )
     }
     else
     {
-        rWin.Invalidate(INVALIDATE_NOERASE);
+        rWin.Invalidate(InvalidateFlags::NoErase);
     }
 }
-//------------------------------------------------------------------------------
+
 void OSectionView::Notify( SfxBroadcaster& rBC, const SfxHint& rHint )
 {
-    DBG_CHKTHIS( rpt_OSectionView,NULL);
     SdrView::Notify(rBC,rHint);
-    if ( rHint.ISA(SdrHint) )
+    const SdrHint* pSdrHint = dynamic_cast<const SdrHint*>(&rHint);
+    if ( pSdrHint )
     {
-        const SdrObject* pObj = ((SdrHint&)rHint).GetObject();
-        const SdrHintKind eKind = ((SdrHint&)rHint).GetKind();
+        const SdrObject* pObj = pSdrHint->GetObject();
+        const SdrHintKind eKind = pSdrHint->GetKind();
         // check for change of selected object
         if(HINT_OBJCHG == eKind && pObj && IsObjMarked(const_cast<SdrObject*>(pObj)))
             AdjustMarkHdl();
@@ -148,27 +142,26 @@ void OSectionView::Notify( SfxBroadcaster& rBC, const SfxHint& rHint )
     }
 }
 
-//------------------------------------------------------------------------------
+
 void OSectionView::ObjectRemovedInAliveMode( const SdrObject* _pObject )
 {
-    DBG_CHKTHIS( rpt_OSectionView,NULL);
     const SdrMarkList& rMarkedList = GetMarkedObjectList();
-    const sal_uLong nMark = rMarkedList.GetMarkCount();
+    const size_t nMark = rMarkedList.GetMarkCount();
 
-    for( sal_uLong i = 0; i < nMark; i++ )
+    for( size_t i = 0; i < nMark; ++i )
     {
         SdrObject* pSdrObj = rMarkedList.GetMark(i)->GetMarkedSdrObj();
         if (_pObject == pSdrObj)
         {
             SdrPageView*    pPgView = GetSdrPageView();
             BrkAction();
-            MarkObj( pSdrObj, pPgView, sal_True );
+            MarkObj( pSdrObj, pPgView, true );
             break;
         }
     }
 }
 
-// -----------------------------------------------------------------------------
+
 void OSectionView::SetMarkedToLayer( SdrLayerID _nLayerNo )
 {
     if (AreObjectsMarked())
@@ -178,18 +171,18 @@ void OSectionView::SetMarkedToLayer( SdrLayerID _nLayerNo )
         BegUndo( );
 
         const SdrMarkList& rMark = GetMarkedObjectList();
-        sal_uLong nCount = rMark.GetMarkCount();
-        for (sal_uLong i=0; i<nCount; i++)
+        const size_t nCount = rMark.GetMarkCount();
+        for (size_t i = 0; i<nCount; ++i)
         {
             SdrObject* pObj = rMark.GetMark(i)->GetMarkedSdrObj();
-            if ( pObj->ISA(OCustomShape) )
+            if ( dynamic_cast< const OCustomShape *>( pObj ) !=  nullptr )
             {
                 AddUndo( new SdrUndoObjectLayerChange( *pObj, pObj->GetLayer(), _nLayerNo) );
                 pObj->SetLayer( _nLayerNo );
-                OObjectBase* pBaseObj = dynamic_cast<OObjectBase*>(pObj);
+                OObjectBase& rBaseObj = dynamic_cast<OObjectBase&>(*pObj);
                 try
                 {
-                    pBaseObj->getReportComponent()->setPropertyValue(PROPERTY_OPAQUE,uno::makeAny(_nLayerNo == RPT_LAYER_FRONT));
+                    rBaseObj.getReportComponent()->setPropertyValue(PROPERTY_OPAQUE,uno::makeAny(_nLayerNo == RPT_LAYER_FRONT));
                 }
                 catch(const uno::Exception&)
                 {
@@ -205,23 +198,22 @@ void OSectionView::SetMarkedToLayer( SdrLayerID _nLayerNo )
         MarkListHasChanged();
     }
 }
-// -----------------------------------------------------------------------------
+
 bool OSectionView::OnlyShapesMarked() const
 {
     const SdrMarkList& rMark = GetMarkedObjectList();
-    const sal_uLong nCount = rMark.GetMarkCount();
+    const size_t nCount = rMark.GetMarkCount();
     if ( !nCount )
         return false;
-    sal_uLong i=0;
-    for (; i<nCount; i++)
+    for (size_t i = 0; i<nCount; ++i)
     {
         SdrObject* pObj = rMark.GetMark(i)->GetMarkedSdrObj();
-        if ( !pObj->ISA(OCustomShape) )
+        if ( dynamic_cast< const OCustomShape *>( pObj ) ==  nullptr )
         {
-            break;
+            return false;
         }
     }
-    return i == nCount;
+    return true;
 }
 
 bool OSectionView::IsDragResize() const
@@ -230,7 +222,7 @@ bool OSectionView::IsDragResize() const
     if (pDragMethod)
     {
         bool bMoveOnly = pDragMethod->getMoveOnly();
-        if (bMoveOnly == false)
+        if (!bMoveOnly)
         {
             // current marked components will be resized
             return true;
@@ -239,12 +231,12 @@ bool OSectionView::IsDragResize() const
     return false;
 }
 
-// -----------------------------------------------------------------------------
+
 short OSectionView::GetLayerIdOfMarkedObjects() const
 {
     short nRet = SHRT_MAX;
     const SdrMarkList &rMrkList = GetMarkedObjectList();
-    for ( sal_uInt16 i = 0; i < rMrkList.GetMarkCount(); ++i )
+    for ( size_t i = 0; i < rMrkList.GetMarkCount(); ++i )
     {
         const SdrObject *pObj = rMrkList.GetMark( i )->GetMarkedSdrObj();
         if ( nRet == SHRT_MAX )
@@ -260,8 +252,8 @@ short OSectionView::GetLayerIdOfMarkedObjects() const
     return nRet;
 }
 
-//============================================================================
+
 } // rptui
-//============================================================================
+
 
 /* vim:set shiftwidth=4 softtabstop=4 expandtab: */
