@@ -28,7 +28,7 @@
 
 #include "uthash.h"
 
-#include "osl/detail/android-bootstrap.h"
+#include <osl/detail/android-bootstrap.h>
 
 #undef LOGI
 
@@ -42,11 +42,11 @@ struct engine {
 };
 
 /* These are valid / used in all apps. */
-static const char *data_dir;
-static const char *cache_dir;
-static void *apk_file;
-static int apk_file_size;
-static JavaVM *the_java_vm;
+const char *data_dir;
+const char *cache_dir;
+void *apk_file;
+int apk_file_size;
+JavaVM *the_java_vm;
 
 /* Zip data structures */
 
@@ -142,7 +142,7 @@ cdir_entry_size(struct cdir_entry *entry)
         letoh16(entry->file_comment_size);
 }
 
-static int
+int
 setup_cdir(void)
 {
     struct cdir_end *dirend = (struct cdir_end *)((char *) apk_file + apk_file_size - sizeof(*dirend));
@@ -221,7 +221,7 @@ handle_one_asset(struct cdir_entry *entry)
     }
 }
 
-static int
+int
 setup_assets_tree(void)
 {
     int count = cdir_entries;
@@ -247,7 +247,7 @@ JNI_OnLoad(JavaVM* vm, void* reserved)
 
     the_java_vm = vm;
 
-    return JNI_VERSION_1_2;
+    return JNI_VERSION_1_6;
 }
 
 // public static native boolean setup(String dataDir,
@@ -348,7 +348,6 @@ get_jni_string_array(JNIEnv *env,
     return JNI_TRUE;
 }
 
-
 // public static native int getpid();
 
 __attribute__ ((visibility("default")))
@@ -362,7 +361,6 @@ Java_org_libreoffice_android_Bootstrap_getpid(JNIEnv* env,
     return getpid();
 }
 
-
 // public static native void system(String cmdline);
 
 __attribute__ ((visibility("default")))
@@ -393,14 +391,16 @@ Java_org_libreoffice_android_Bootstrap_putenv(JNIEnv* env,
                                               jstring string)
 {
     const char *s;
+    char *s_copy;
 
     (void) clazz;
 
     s = (*env)->GetStringUTFChars(env, string, NULL);
+    s_copy = strdup(s);
 
-    LOGI("putenv(%s)", s);
+    LOGI("putenv(%s)", s_copy);
 
-    putenv(s);
+    putenv(s_copy);
 
 #if 0
     {
@@ -631,201 +631,6 @@ lo_apk_lstat(const char *path,
     return -1;
 }
 
-#define UNPACK_TREE "/assets/unpack"
-#define UNPACK_TREE_GZ "/assets/gz.unpack"
-
-static int
-mkdir_p(const char *dirname)
-{
-    char *p = malloc(strlen(dirname) + 1);
-    const char *q = dirname + 1;
-    const char *slash;
-
-    do {
-        slash = strchr(q, '/');
-        if (slash == NULL)
-            slash = q + strlen(q);
-        memcpy(p, dirname, slash-dirname);
-        p[slash-dirname] = '\0';
-        if (mkdir(p, 0700) == -1 && errno != EEXIST) {
-            LOGE("mkdir_p: Could not create %s: %s", p, strerror(errno));
-            free(p);
-            return 0;
-        }
-        if (*slash)
-            q = slash + 1;
-    } while (*slash);
-
-    free(p);
-    return 1;
-}
-
-static int
-extract_gzipped(const char *filename,
-                const char *apkentry,
-                int size,
-                FILE *f)
-{
-    gzFile gzfd;
-    int gzerrno;
-    int nbytes;
-    char buf[5000];
-    int total = 0;
-    char *tmpname;
-    FILE *tmp;
-
-    tmpname = malloc(strlen(cache_dir) + strlen("/tmp.gz") + 1);
-    strcpy(tmpname, cache_dir);
-    strcat(tmpname, "/tmp.gz");
-
-    tmp = fopen(tmpname, "w+");
-    unlink(tmpname);
-
-    if (tmp == NULL) {
-        LOGE("extract_gzipped: could not create %s: %s", tmpname, strerror(errno));
-        free(tmpname);
-        return 0;
-    }
-
-    if (fwrite(apkentry, size, 1, tmp) != 1) {
-        LOGE("extract_gzipped: could not write gzipped entry to %s: %s", tmpname, strerror(errno));
-        fclose(tmp);
-        free(tmpname);
-        return 0;
-    }
-
-    free(tmpname);
-    rewind(tmp);
-
-    gzfd = gzdopen(fileno(tmp), "rb");
-    if (gzfd == NULL) {
-        LOGE("extract_gzipped: gzdopen failed");
-        fclose(tmp);
-        return 0;
-    }
-
-    while ((nbytes = gzread(gzfd, buf, sizeof(buf))) > 0) {
-        fwrite(buf, nbytes, 1, f);
-        total += nbytes;
-    }
-    if (nbytes == -1) {
-        LOGE("extract_gzipped: Could not gzread from %s: %s", filename, gzerror(gzfd, &gzerrno));
-        return total;
-    }
-    if (gzclose(gzfd) == -1) {
-        LOGE("extract_gzipped: gzclose failed");
-        return total;
-    }
-
-    return total;
-}
-
-static void
-extract_files(const char *root,
-              const char *prefix,
-              int gzipped)
-{
-    lo_apk_dir *tree = lo_apk_opendir(prefix);
-    struct dirent *dent;
-
-    if (tree == NULL)
-        return;
-
-    while ((dent = lo_apk_readdir(tree)) != NULL) {
-        if (strcmp(dent->d_name, ".") == 0 ||
-            strcmp(dent->d_name, "..") == 0)
-            continue;
-
-        if (dent->d_type == DT_DIR) {
-            char *subdir = malloc(strlen(prefix) + 1 + strlen(dent->d_name) + 1);
-            strcpy(subdir, prefix);
-            strcat(subdir, "/");
-            strcat(subdir, dent->d_name);
-            extract_files(root, subdir, gzipped);
-            free(subdir);
-        } else {
-            char *filename;
-            char *newfilename;
-            const char *apkentry;
-            size_t size;
-            struct stat st;
-            FILE *f;
-
-            filename = malloc(strlen(prefix) + 1 + strlen(dent->d_name) + 1);
-            strcpy(filename, prefix);
-            strcat(filename, "/");
-            strcat(filename, dent->d_name);
-
-            apkentry = lo_apkentry(filename, &size);
-            if (apkentry == NULL) {
-                LOGE("extract_files: Could not find %s in .apk", filename);
-                free(filename);
-                continue;
-            }
-
-            newfilename = malloc(strlen(data_dir) + 1 + strlen(prefix) - strlen(root) + strlen(dent->d_name) + 1);
-            strcpy(newfilename, data_dir);
-            strcat(newfilename, "/");
-            strcat(newfilename, prefix + strlen(root) + 1);
-
-            if (!mkdir_p(newfilename)) {
-                free(filename);
-                free(newfilename);
-                continue;
-            }
-
-            strcat(newfilename, "/");
-            strcat(newfilename, dent->d_name);
-
-            if (stat(newfilename, &st) == 0 &&
-                (gzipped || st.st_size == size)) {
-                free(filename);
-                free(newfilename);
-                continue;
-            }
-
-            f = fopen(newfilename, "w");
-            if (f == NULL) {
-                LOGE("extract_files: Could not open %s for writing: %s", newfilename, strerror(errno));
-                free(filename);
-                free(newfilename);
-                continue;
-            }
-
-            if (!gzipped) {
-                if (fwrite(apkentry, size, 1, f) != 1) {
-                    LOGE("extract_files: Could not write %d bytes to %s: %s", size, newfilename, strerror(errno));
-                } else {
-                    LOGI("extract_files: Copied %s to %s: %d bytes", filename, newfilename, size);
-                }
-            } else {
-                size = extract_gzipped(filename, apkentry, size, f);
-                LOGI("extract_files: Decompressed %s to %s: %d bytes", filename, newfilename, size);
-            }
-
-            fclose(f);
-
-            free(filename);
-            free(newfilename);
-        }
-    }
-    lo_apk_closedir(tree);
-}
-
-// static native void extract_files();
-
-__attribute__ ((visibility("default")))
-void
-Java_org_libreoffice_android_Bootstrap_extract_1files(JNIEnv* env,
-                                                      jobject clazz)
-{
-    (void) env;
-    (void) clazz;
-
-    extract_files(UNPACK_TREE, UNPACK_TREE, 0);
-    extract_files(UNPACK_TREE_GZ, UNPACK_TREE_GZ, 1);
-}
-
 /* Android's JNI works only to libraries loaded through Java's
  * System.loadLibrary(), it seems. But now with just one big app-specific .so
  * on Android, that would not be a problem, but for historical reasons, we
@@ -834,21 +639,6 @@ Java_org_libreoffice_android_Bootstrap_extract_1files(JNIEnv* env,
  * functions here in this file.
  */
 
-// public static native void initVCL();
-
-extern void InitVCLWrapper(void);
-
-__attribute__ ((visibility("default")))
-void
-Java_org_libreoffice_android_Bootstrap_initVCL(JNIEnv* env,
-                                               jobject clazz)
-{
-    (void) env;
-    (void) clazz;
-
-    InitVCLWrapper();
-}
-
 extern void osl_setCommandArgs(int, char **);
 
 __attribute__ ((visibility("default")))
@@ -1024,7 +814,7 @@ redirect_to_null(void)
 }
 
 __attribute__ ((visibility("default")))
-jboolean
+void
 Java_org_libreoffice_android_Bootstrap_redirect_1stdio(JNIEnv* env,
                                                        jobject clazz,
                                                        jboolean state)
@@ -1036,22 +826,22 @@ Java_org_libreoffice_android_Bootstrap_redirect_1stdio(JNIEnv* env,
     (void) env;
     (void) clazz;
 
-   if (state == current)
-        return current;
+    if (state == current)
+        return;
 
     if (state == JNI_FALSE) {
         if (!redirect_to_null())
-            return current;
+            return;
     } else {
         if (pipe(stdout_pipe) == -1) {
             LOGE("redirect_stdio: Could not create pipes: %s", strerror(errno));
-            return current;
+            return;
         }
         if (pipe(stderr_pipe) == -1) {
             LOGE("redirect_stdio: Could not create pipes: %s", strerror(errno));
             close(stdout_pipe[0]);
             close(stdout_pipe[1]);
-            return current;
+            return;
         }
         LOGI("redirect_stdio: stdout pipe: [%d,%d], stderr pipe: [%d,%d]",
              stdout_pipe[0], stdout_pipe[1], stderr_pipe[0], stderr_pipe[1]);
@@ -1062,7 +852,7 @@ Java_org_libreoffice_android_Bootstrap_redirect_1stdio(JNIEnv* env,
             close(stdout_pipe[1]);
             close(stderr_pipe[0]);
             close(stderr_pipe[1]);
-            return current;
+            return;
         }
 
         if (dup2(stderr_pipe[1], 2) == -1) {
@@ -1075,7 +865,7 @@ Java_org_libreoffice_android_Bootstrap_redirect_1stdio(JNIEnv* env,
             close(stdout_pipe[1]);
             close(stderr_pipe[0]);
             close(stderr_pipe[1]);
-            return current;
+            return;
         }
         close(stdout_pipe[1]);
         close(stderr_pipe[1]);
@@ -1087,98 +877,11 @@ Java_org_libreoffice_android_Bootstrap_redirect_1stdio(JNIEnv* env,
             redirect_to_null();
             close(stdout_pipe[0]);
             close(stderr_pipe[0]);
-            return current;
+            return;
         }
     }
     current = state;
-    return current;
-}
-
-__attribute__ ((visibility("default")))
-void
-Java_org_libreoffice_android_Bootstrap_twiddle_1BGR_1to_1RGBA(JNIEnv* env,
-                                                              jobject clazz,
-                                                              jbyteArray source,
-                                                              jint offset,
-                                                              jint width,
-                                                              jint height,
-                                                              jobject destination)
-{
-    jbyte *dst = (jbyte*) (*env)->GetDirectBufferAddress(env, destination);
-    void *a = (*env)->GetPrimitiveArrayCritical(env, source, NULL);
-    jbyte *src = ((jbyte *) a) + offset;
-
-    jbyte *srcp;
-    jbyte *dstp = dst;
-    int step = ((((width * 3) - 1) / 4) + 1) * 4;
-
-    int i, j;
-
-    (void) clazz;
-
-    if (height > 0) {
-        srcp = src + step * (height - 1);
-        step = -step;
-    } else {
-        srcp = src;
-    }
-
-    LOGI("twiddle: src=%p, srcp=%p, dstp=%p, step=%d", src, srcp, dstp, step);
-
-    for (i = 0; i < height; i++) {
-        for (j = 0; j < width; j++) {
-            *dstp++ = srcp[j*3+2];
-            *dstp++ = srcp[j*3+1];
-            *dstp++ = srcp[j*3+0];
-            *dstp++ = 0xFF;
-        }
-        srcp += step;
-    }
-
-    (*env)->ReleasePrimitiveArrayCritical(env, source, a, 0);
-}
-
-__attribute__ ((visibility("default")))
-void
-Java_org_libreoffice_android_Bootstrap_force_1full_1alpha_1array(JNIEnv* env,
-                                                                 jobject clazz,
-                                                                 jbyteArray array,
-                                                                 jint offset,
-                                                                 jint length)
-{
-    void *a = (*env)->GetPrimitiveArrayCritical(env, array, NULL);
-    jbyte *p = ((jbyte *) a) + offset;
-
-    int i;
-
-    (void) clazz;
-
-    for (i = 0; i < length; i += 4) {
-        p[3] = 0xFF;
-        p += 4;
-    }
-
-    (*env)->ReleasePrimitiveArrayCritical(env, array, a, 0);
-}
-
-__attribute__ ((visibility("default")))
-void
-Java_org_libreoffice_android_Bootstrap_force_1full_1alpha_1bb(JNIEnv* env,
-                                                              jobject clazz,
-                                                              jobject buffer,
-                                                              jint offset,
-                                                              jint length)
-{
-    jbyte *p = (*env)->GetDirectBufferAddress(env, buffer) + offset;
-
-    int i;
-
-    (void) clazz;
-
-    for (i = 0; i < length; i += 4) {
-        p[3] = 0xFF;
-        p += 4;
-    }
+    return;
 }
 
 __attribute__ ((visibility("default")))
