@@ -17,13 +17,12 @@
  *   the License at http://www.apache.org/licenses/LICENSE-2.0 .
  */
 
-#include "osl/time.h"
-
+#include <osl/time.h>
 
 /*
  *   mfe : maybe it would be wishful to include initialization
  *         of the global timer in dllmain or _init directly.
- *         But noneoftheless this (should) work too.
+ *         But none the less this (should) work too.
  */
 namespace osl
 {
@@ -42,10 +41,10 @@ public:
         return osl_getGlobalTimer();
     }
 
-
 };
 
 static OGlobalTimer aGlobalTimer;
 
-}
+} // namespace osl
+
 /* vim:set shiftwidth=4 softtabstop=4 expandtab: */
