@@ -22,13 +22,14 @@
 /* String-Class                                                            */
 /* ======================================================================= */
 
+#include <algorithm>
 #include <cassert>
 #include <limits>
 
-#include <string.h>
+#include <cstring>
+#include <wchar.h>
 #include <sal/log.hxx>
 #include <rtl/character.hxx>
-#include <boost/static_assert.hpp>
 
 /*
 inline void rtl_str_ImplCopy( IMPL_RTL_STRCODE* pDest,
@@ -45,18 +46,12 @@ inline void rtl_str_ImplCopy( IMPL_RTL_STRCODE* pDest,
 }
 */
 
-#define rtl_str_ImplCopy( _pDest, _pSrc, _nCount )                  \
-{                                                                   \
-    IMPL_RTL_STRCODE*       __mm_pDest      = _pDest;               \
-    const IMPL_RTL_STRCODE* __mm_pSrc       = _pSrc;                \
-    sal_Int32               __mm_nCount     = _nCount;              \
-    while ( __mm_nCount > 0 )                                       \
-    {                                                               \
-        *__mm_pDest = *__mm_pSrc;                                   \
-        __mm_pDest++;                                               \
-        __mm_pSrc++;                                                \
-        __mm_nCount--;                                              \
-    }                                                               \
+static inline void rtl_str_ImplCopy( IMPL_RTL_STRCODE* _pDest,
+                                     const IMPL_RTL_STRCODE* _pSrc,
+                                     sal_Int32 _nCount )
+{
+    // take advantage of builtin optimisations
+    memcpy( _pDest, _pSrc, _nCount * sizeof(IMPL_RTL_STRCODE));
 }
 
 /* ======================================================================= */
@@ -66,10 +61,24 @@ inline void rtl_str_ImplCopy( IMPL_RTL_STRCODE* pDest,
 sal_Int32 SAL_CALL IMPL_RTL_STRNAME( getLength )( const IMPL_RTL_STRCODE* pStr )
     SAL_THROW_EXTERN_C()
 {
-    const IMPL_RTL_STRCODE* pTempStr = pStr;
-    while( *pTempStr )
-        pTempStr++;
-    return pTempStr-pStr;
+    assert(pStr);
+#if !IMPL_RTL_IS_USTRING
+    // take advantage of builtin optimisations
+    return strlen( pStr);
+#else
+    if (sizeof(IMPL_RTL_STRCODE) == sizeof(wchar_t))
+    {
+        // take advantage of builtin optimisations
+        return wcslen(reinterpret_cast<wchar_t const *>(pStr));
+    }
+    else
+    {
+        const IMPL_RTL_STRCODE* pTempStr = pStr;
+        while( *pTempStr )
+            pTempStr++;
+        return pTempStr-pStr;
+    }
+#endif
 }
 
 /* ----------------------------------------------------------------------- */
@@ -78,16 +87,31 @@ sal_Int32 SAL_CALL IMPL_RTL_STRNAME( compare )( const IMPL_RTL_STRCODE* pStr1,
                                                 const IMPL_RTL_STRCODE* pStr2 )
     SAL_THROW_EXTERN_C()
 {
-    sal_Int32 nRet;
-    while ( ((nRet = ((sal_Int32)(IMPL_RTL_USTRCODE(*pStr1)))-
-                     ((sal_Int32)(IMPL_RTL_USTRCODE(*pStr2)))) == 0) &&
-            *pStr2 )
+    assert(pStr1);
+    assert(pStr2);
+#if !IMPL_RTL_IS_USTRING
+    // take advantage of builtin optimisations
+    return strcmp( pStr1, pStr2);
+#else
+    if (sizeof(IMPL_RTL_STRCODE) == sizeof(wchar_t))
     {
-        pStr1++;
-        pStr2++;
+        // take advantage of builtin optimisations
+        return wcscmp(reinterpret_cast<wchar_t const *>(pStr1), reinterpret_cast<wchar_t const *>(pStr2));
     }
+    else
+    {
+        sal_Int32 nRet;
+        while ( ((nRet = ((sal_Int32)(IMPL_RTL_USTRCODE(*pStr1)))-
+                         ((sal_Int32)(IMPL_RTL_USTRCODE(*pStr2)))) == 0) &&
+                *pStr2 )
+        {
+            pStr1++;
+            pStr2++;
+        }
 
-    return nRet;
+        return nRet;
+    }
+#endif
 }
 
 /* ----------------------------------------------------------------------- */
@@ -98,18 +122,37 @@ sal_Int32 SAL_CALL IMPL_RTL_STRNAME( compare_WithLength )( const IMPL_RTL_STRCOD
                                                            sal_Int32 nStr2Len )
     SAL_THROW_EXTERN_C()
 {
-    sal_Int32 nRet = nStr1Len - nStr2Len;
-    int nCount = (nRet <= 0) ? nStr1Len : nStr2Len;
+    assert(nStr1Len >= 0);
+    assert(nStr2Len >= 0);
+#if !IMPL_RTL_IS_USTRING
+    // take advantage of builtin optimisations
+    sal_Int32 nMin = std::min(nStr1Len, nStr2Len);
+    sal_Int32 nRet = strncmp(pStr1, pStr2, nMin);
+    return nRet == 0 ? nStr1Len - nStr2Len : nRet;
+#else
+    if (sizeof(IMPL_RTL_STRCODE) == sizeof(wchar_t))
+    {
+        // take advantage of builtin optimisations
+        sal_Int32 nMin = std::min(nStr1Len, nStr2Len);
+        sal_Int32 nRet = wcsncmp(reinterpret_cast<wchar_t const *>(pStr1), reinterpret_cast<wchar_t const *>(pStr2), nMin);
+        return nRet == 0 ? nStr1Len - nStr2Len : nRet;
+    }
+    else
+    {
+        sal_Int32 nRet = nStr1Len - nStr2Len;
+        int nCount = (nRet <= 0) ? nStr1Len : nStr2Len;
 
-    --pStr1;
-    --pStr2;
-    while( (--nCount >= 0) && (*++pStr1 == *++pStr2) ) ;
+        --pStr1;
+        --pStr2;
+        while( (--nCount >= 0) && (*++pStr1 == *++pStr2) ) ;
 
-    if( nCount >= 0 )
-        nRet = ((sal_Int32)(IMPL_RTL_USTRCODE( *pStr1 )))
-             - ((sal_Int32)(IMPL_RTL_USTRCODE( *pStr2 )));
+        if( nCount >= 0 )
+            nRet = ((sal_Int32)(IMPL_RTL_USTRCODE( *pStr1 )))
+                 - ((sal_Int32)(IMPL_RTL_USTRCODE( *pStr2 )));
 
-    return nRet;
+        return nRet;
+    }
+#endif
 }
 
 /* ----------------------------------------------------------------------- */
@@ -121,25 +164,49 @@ sal_Int32 SAL_CALL IMPL_RTL_STRNAME( shortenedCompare_WithLength )( const IMPL_R
                                                                     sal_Int32 nShortenedLength )
     SAL_THROW_EXTERN_C()
 {
-    const IMPL_RTL_STRCODE* pStr1End = pStr1 + nStr1Len;
-    const IMPL_RTL_STRCODE* pStr2End = pStr2 + nStr2Len;
-    sal_Int32               nRet;
-    while ( (nShortenedLength > 0) &&
-            (pStr1 < pStr1End) && (pStr2 < pStr2End) )
+    assert(nStr1Len >= 0);
+    assert(nStr2Len >= 0);
+    assert(nShortenedLength >= 0);
+#if !IMPL_RTL_IS_USTRING
+    // take advantage of builtin optimisations
+    sal_Int32 nMin = std::min(std::min(nStr1Len, nStr2Len), nShortenedLength);
+    sal_Int32 nRet = strncmp(pStr1, pStr2, nMin);
+    if (nRet == 0 && nShortenedLength > std::min(nStr1Len, nStr2Len))
+        return nStr1Len - nStr2Len;
+    return nRet;
+#else
+    if (sizeof(IMPL_RTL_STRCODE) == sizeof(wchar_t))
     {
-        nRet = ((sal_Int32)(IMPL_RTL_USTRCODE( *pStr1 )))-
-               ((sal_Int32)(IMPL_RTL_USTRCODE( *pStr2 )));
-        if ( nRet )
-            return nRet;
-
-        nShortenedLength--;
-        pStr1++;
-        pStr2++;
+        // take advantage of builtin optimisations
+        sal_Int32 nMin = std::min(std::min(nStr1Len, nStr2Len), nShortenedLength);
+        sal_Int32 nRet = wcsncmp(reinterpret_cast<wchar_t const *>(pStr1), reinterpret_cast<wchar_t const *>(pStr2), nMin);
+        if (nRet == 0 && nShortenedLength > std::min(nStr1Len, nStr2Len))
+            return nStr1Len - nStr2Len;
+        return nRet;
     }
+    else
+    {
+        const IMPL_RTL_STRCODE* pStr1End = pStr1 + nStr1Len;
+        const IMPL_RTL_STRCODE* pStr2End = pStr2 + nStr2Len;
+        sal_Int32               nRet;
+        while ( (nShortenedLength > 0) &&
+                (pStr1 < pStr1End) && (pStr2 < pStr2End) )
+        {
+            nRet = ((sal_Int32)(IMPL_RTL_USTRCODE( *pStr1 )))-
+                   ((sal_Int32)(IMPL_RTL_USTRCODE( *pStr2 )));
+            if ( nRet )
+                return nRet;
 
-    if ( nShortenedLength <= 0 )
-        return 0;
-    return nStr1Len - nStr2Len;
+            nShortenedLength--;
+            pStr1++;
+            pStr2++;
+        }
+
+        if ( nShortenedLength <= 0 )
+            return 0;
+        return nStr1Len - nStr2Len;
+    }
+#endif
 }
 
 /* ----------------------------------------------------------------------- */
@@ -150,6 +217,8 @@ sal_Int32 SAL_CALL IMPL_RTL_STRNAME( reverseCompare_WithLength )( const IMPL_RTL
                                                                   sal_Int32 nStr2Len )
     SAL_THROW_EXTERN_C()
 {
+    assert(nStr1Len >= 0);
+    assert(nStr2Len >= 0);
     const IMPL_RTL_STRCODE* pStr1Run = pStr1+nStr1Len;
     const IMPL_RTL_STRCODE* pStr2Run = pStr2+nStr2Len;
     sal_Int32               nRet;
@@ -172,6 +241,8 @@ sal_Int32 SAL_CALL IMPL_RTL_STRNAME( compareIgnoreAsciiCase )( const IMPL_RTL_ST
                                                                const IMPL_RTL_STRCODE* pStr2 )
     SAL_THROW_EXTERN_C()
 {
+    assert(pStr1);
+    assert(pStr2);
     sal_uInt32 c1;
     do
     {
@@ -197,6 +268,8 @@ sal_Int32 SAL_CALL IMPL_RTL_STRNAME( compareIgnoreAsciiCase_WithLength )( const
                                                                           sal_Int32 nStr2Len )
     SAL_THROW_EXTERN_C()
 {
+    assert(nStr1Len >= 0);
+    assert(nStr2Len >= 0);
     const IMPL_RTL_STRCODE* pStr1End = pStr1 + nStr1Len;
     const IMPL_RTL_STRCODE* pStr2End = pStr2 + nStr2Len;
     while ( (pStr1 < pStr1End) && (pStr2 < pStr2End) )
@@ -222,6 +295,9 @@ sal_Int32 SAL_CALL IMPL_RTL_STRNAME( shortenedCompareIgnoreAsciiCase_WithLength
                                                                                    sal_Int32 nShortenedLength )
     SAL_THROW_EXTERN_C()
 {
+    assert(nStr1Len >= 0);
+    assert(nStr2Len >= 0);
+    assert(nShortenedLength >= 0);
     const IMPL_RTL_STRCODE* pStr1End = pStr1 + nStr1Len;
     const IMPL_RTL_STRCODE* pStr2End = pStr2 + nStr2Len;
     while ( (nShortenedLength > 0) &&
@@ -256,51 +332,14 @@ sal_Int32 SAL_CALL IMPL_RTL_STRNAME( hashCode_WithLength )( const IMPL_RTL_STRCO
                                                             sal_Int32 nLen )
     SAL_THROW_EXTERN_C()
 {
+    assert(nLen >= 0);
     sal_uInt32 h = static_cast<sal_uInt32>(nLen);
-
-    if ( nLen < 256 )
+    while ( nLen > 0 )
     {
-        while ( nLen > 0 )
-        {
-            h = (h*37U) + IMPL_RTL_USTRCODE( *pStr );
-            pStr++;
-            nLen--;
-        }
+        h = (h*37U) + IMPL_RTL_USTRCODE( *pStr );
+        pStr++;
+        nLen--;
     }
-    else
-    {
-        sal_Int32               nSkip;
-        const IMPL_RTL_STRCODE* pEndStr = pStr+nLen-5;
-
-        /* only sample some characters */
-        /* the first 3, some characters between, and the last 5 */
-        h = (h*39U) + IMPL_RTL_USTRCODE( *pStr );
-        pStr++;
-        h = (h*39U) + IMPL_RTL_USTRCODE( *pStr );
-        pStr++;
-        h = (h*39U) + IMPL_RTL_USTRCODE( *pStr );
-        pStr++;
-
-        nSkip = nLen / 8;
-        nLen -= 8;
-        while ( nLen > 0 )
-        {
-            h = (h*39U) + IMPL_RTL_USTRCODE( *pStr );
-            pStr += nSkip;
-            nLen -= nSkip;
-        }
-
-        h = (h*39U) + IMPL_RTL_USTRCODE( *pEndStr );
-        pEndStr++;
-        h = (h*39U) + IMPL_RTL_USTRCODE( *pEndStr );
-        pEndStr++;
-        h = (h*39U) + IMPL_RTL_USTRCODE( *pEndStr );
-        pEndStr++;
-        h = (h*39U) + IMPL_RTL_USTRCODE( *pEndStr );
-        pEndStr++;
-        h = (h*39U) + IMPL_RTL_USTRCODE( *pEndStr );
-    }
-
     return static_cast<sal_Int32>(h);
 }
 
@@ -310,16 +349,32 @@ sal_Int32 SAL_CALL IMPL_RTL_STRNAME( indexOfChar )( const IMPL_RTL_STRCODE* pStr
                                                     IMPL_RTL_STRCODE c )
     SAL_THROW_EXTERN_C()
 {
-    const IMPL_RTL_STRCODE* pTempStr = pStr;
-    while ( *pTempStr )
+    assert(pStr);
+#if !IMPL_RTL_IS_USTRING
+    // take advantage of builtin optimisations
+    const IMPL_RTL_STRCODE* p = strchr(pStr, c);
+    return p ? p - pStr : -1;
+#else
+    if (sizeof(IMPL_RTL_STRCODE) == sizeof(wchar_t))
     {
-        if ( *pTempStr == c )
-            return pTempStr-pStr;
-
-        pTempStr++;
+        // take advantage of builtin optimisations
+        wchar_t const * p = wcschr(reinterpret_cast<wchar_t const *>(pStr), (wchar_t)c);
+        return p ? p - reinterpret_cast<wchar_t const *>(pStr) : -1;
     }
+    else
+    {
+        const IMPL_RTL_STRCODE* pTempStr = pStr;
+        while ( *pTempStr )
+        {
+            if ( *pTempStr == c )
+                return pTempStr-pStr;
 
-    return -1;
+            pTempStr++;
+        }
+
+        return -1;
+    }
+#endif
 }
 
 /* ----------------------------------------------------------------------- */
@@ -329,6 +384,12 @@ sal_Int32 SAL_CALL IMPL_RTL_STRNAME( indexOfChar_WithLength )( const IMPL_RTL_ST
                                                                IMPL_RTL_STRCODE c )
     SAL_THROW_EXTERN_C()
 {
+//    assert(nLen >= 0);
+#if !IMPL_RTL_IS_USTRING
+    // take advantage of builtin optimisations
+    IMPL_RTL_STRCODE* p = static_cast<IMPL_RTL_STRCODE*>(std::memchr(const_cast<IMPL_RTL_STRCODE *>(pStr), c, nLen));
+    return p ? p - pStr : -1;
+#else
     const IMPL_RTL_STRCODE* pTempStr = pStr;
     while ( nLen > 0 )
     {
@@ -340,6 +401,7 @@ sal_Int32 SAL_CALL IMPL_RTL_STRNAME( indexOfChar_WithLength )( const IMPL_RTL_ST
     }
 
     return -1;
+#endif
 }
 
 /* ----------------------------------------------------------------------- */
@@ -348,7 +410,23 @@ sal_Int32 SAL_CALL IMPL_RTL_STRNAME( lastIndexOfChar )( const IMPL_RTL_STRCODE*
                                                         IMPL_RTL_STRCODE c )
     SAL_THROW_EXTERN_C()
 {
-    return IMPL_RTL_STRNAME( lastIndexOfChar_WithLength )( pStr, IMPL_RTL_STRNAME( getLength )( pStr ), c );
+    assert(pStr);
+#if !IMPL_RTL_IS_USTRING
+    // take advantage of builtin optimisations
+    const IMPL_RTL_STRCODE* p = strrchr(pStr, c);
+    return p ? p - pStr : -1;
+#else
+    if (sizeof(IMPL_RTL_STRCODE) == sizeof(wchar_t))
+    {
+        // take advantage of builtin optimisations
+        wchar_t const * p = wcsrchr(reinterpret_cast<wchar_t const *>(pStr), (wchar_t)c);
+        return p ? p - reinterpret_cast<wchar_t const *>(pStr) : -1;
+    }
+    else
+    {
+        return IMPL_RTL_STRNAME( lastIndexOfChar_WithLength )( pStr, IMPL_RTL_STRNAME( getLength )( pStr ), c );
+    }
+#endif
 }
 
 /* ----------------------------------------------------------------------- */
@@ -358,6 +436,7 @@ sal_Int32 SAL_CALL IMPL_RTL_STRNAME( lastIndexOfChar_WithLength )( const IMPL_RT
                                                                    IMPL_RTL_STRCODE c )
     SAL_THROW_EXTERN_C()
 {
+    assert(nLen >= 0);
     pStr += nLen;
     while ( nLen > 0 )
     {
@@ -377,8 +456,25 @@ sal_Int32 SAL_CALL IMPL_RTL_STRNAME( indexOfStr )( const IMPL_RTL_STRCODE* pStr,
                                                    const IMPL_RTL_STRCODE* pSubStr )
     SAL_THROW_EXTERN_C()
 {
-    return IMPL_RTL_STRNAME( indexOfStr_WithLength )( pStr, IMPL_RTL_STRNAME( getLength )( pStr ),
-                                                      pSubStr, IMPL_RTL_STRNAME( getLength )( pSubStr ) );
+    assert(pStr);
+    assert(pSubStr);
+#if !IMPL_RTL_IS_USTRING
+    // take advantage of builtin optimisations
+    const IMPL_RTL_STRCODE* p = strstr(pStr, pSubStr);
+    return p ? p - pStr : -1;
+#else
+    if (sizeof(IMPL_RTL_STRCODE) == sizeof(wchar_t))
+    {
+        // take advantage of builtin optimisations
+        wchar_t const * p = wcsstr(reinterpret_cast<wchar_t const *>(pStr), reinterpret_cast<wchar_t const *>(pSubStr));
+        return p ? p - reinterpret_cast<wchar_t const *>(pStr) : -1;
+    }
+    else
+    {
+       return IMPL_RTL_STRNAME( indexOfStr_WithLength )( pStr, IMPL_RTL_STRNAME( getLength )( pStr ),
+                                                         pSubStr, IMPL_RTL_STRNAME( getLength )( pSubStr ) );
+    }
+#endif
 }
 
 /* ----------------------------------------------------------------------- */
@@ -389,10 +485,12 @@ sal_Int32 SAL_CALL IMPL_RTL_STRNAME( indexOfStr_WithLength )( const IMPL_RTL_STR
                                                               sal_Int32 nSubLen )
     SAL_THROW_EXTERN_C()
 {
+    assert(nStrLen >= 0);
+    assert(nSubLen >= 0);
     /* faster search for a single character */
     if ( nSubLen < 2 )
     {
-        /* an empty SubString is always not foundable */
+        /* an empty SubString is always not findable */
         if ( nSubLen == 1 )
         {
             IMPL_RTL_STRCODE        c = *pSubStr;
@@ -463,10 +561,12 @@ sal_Int32 SAL_CALL IMPL_RTL_STRNAME( lastIndexOfStr_WithLength )( const IMPL_RTL
                                                                   sal_Int32 nSubLen )
     SAL_THROW_EXTERN_C()
 {
+//    assert(nStrLen >= 0);
+    assert(nSubLen >= 0);
     /* faster search for a single character */
     if ( nSubLen < 2 )
     {
-        /* an empty SubString is always not foundable */
+        /* an empty SubString is always not findable */
         if ( nSubLen == 1 )
         {
             IMPL_RTL_STRCODE c = *pSubStr;
@@ -519,6 +619,7 @@ void SAL_CALL IMPL_RTL_STRNAME( replaceChar )( IMPL_RTL_STRCODE* pStr,
                                                IMPL_RTL_STRCODE cNew )
     SAL_THROW_EXTERN_C()
 {
+    assert(pStr);
     while ( *pStr )
     {
         if ( *pStr == cOld )
@@ -536,6 +637,7 @@ void SAL_CALL IMPL_RTL_STRNAME( replaceChar_WithLength )( IMPL_RTL_STRCODE* pStr
                                                           IMPL_RTL_STRCODE cNew )
     SAL_THROW_EXTERN_C()
 {
+    assert(nLen >= 0);
     while ( nLen > 0 )
     {
         if ( *pStr == cOld )
@@ -551,6 +653,7 @@ void SAL_CALL IMPL_RTL_STRNAME( replaceChar_WithLength )( IMPL_RTL_STRCODE* pStr
 void SAL_CALL IMPL_RTL_STRNAME( toAsciiLowerCase )( IMPL_RTL_STRCODE* pStr )
     SAL_THROW_EXTERN_C()
 {
+    assert(pStr);
     while ( *pStr )
     {
         *pStr = rtl::toAsciiLowerCase(IMPL_RTL_USTRCODE(*pStr));
@@ -565,6 +668,7 @@ void SAL_CALL IMPL_RTL_STRNAME( toAsciiLowerCase_WithLength )( IMPL_RTL_STRCODE*
                                                                sal_Int32 nLen )
     SAL_THROW_EXTERN_C()
 {
+    assert(nLen >= 0);
     while ( nLen > 0 )
     {
         *pStr = rtl::toAsciiLowerCase(IMPL_RTL_USTRCODE(*pStr));
@@ -579,6 +683,7 @@ void SAL_CALL IMPL_RTL_STRNAME( toAsciiLowerCase_WithLength )( IMPL_RTL_STRCODE*
 void SAL_CALL IMPL_RTL_STRNAME( toAsciiUpperCase )( IMPL_RTL_STRCODE* pStr )
     SAL_THROW_EXTERN_C()
 {
+    assert(pStr);
     while ( *pStr )
     {
         *pStr = rtl::toAsciiUpperCase(IMPL_RTL_USTRCODE(*pStr));
@@ -593,6 +698,7 @@ void SAL_CALL IMPL_RTL_STRNAME( toAsciiUpperCase_WithLength )( IMPL_RTL_STRCODE*
                                                                sal_Int32 nLen )
     SAL_THROW_EXTERN_C()
 {
+    assert(nLen >= 0);
     while ( nLen > 0 )
     {
         *pStr = rtl::toAsciiUpperCase(IMPL_RTL_USTRCODE(*pStr));
@@ -615,6 +721,7 @@ sal_Int32 SAL_CALL IMPL_RTL_STRNAME( trim )( IMPL_RTL_STRCODE* pStr )
 sal_Int32 SAL_CALL IMPL_RTL_STRNAME( trim_WithLength )( IMPL_RTL_STRCODE* pStr, sal_Int32 nLen )
     SAL_THROW_EXTERN_C()
 {
+    assert(nLen >= 0);
     sal_Int32 nPreSpaces    = 0;
     sal_Int32 nPostSpaces   = 0;
     sal_Int32 nIndex        = nLen-1;
@@ -659,6 +766,7 @@ sal_Int32 SAL_CALL IMPL_RTL_STRNAME( trim_WithLength )( IMPL_RTL_STRCODE* pStr,
 sal_Int32 SAL_CALL IMPL_RTL_STRNAME( valueOfBoolean )( IMPL_RTL_STRCODE* pStr, sal_Bool b )
     SAL_THROW_EXTERN_C()
 {
+    assert(pStr);
     if ( b )
     {
         *pStr = 't';
@@ -695,6 +803,7 @@ sal_Int32 SAL_CALL IMPL_RTL_STRNAME( valueOfChar )( IMPL_RTL_STRCODE* pStr,
                                                     IMPL_RTL_STRCODE c )
     SAL_THROW_EXTERN_C()
 {
+    assert(pStr);
     *pStr++ = c;
     *pStr = 0;
     return 1;
@@ -707,6 +816,7 @@ sal_Int32 SAL_CALL IMPL_RTL_STRNAME( valueOfInt32 )( IMPL_RTL_STRCODE* pStr,
                                                      sal_Int16 nRadix )
     SAL_THROW_EXTERN_C()
 {
+    assert(pStr);
     sal_Char    aBuf[RTL_STR_MAX_VALUEOFINT32];
     sal_Char*   pBuf = aBuf;
     sal_Int32   nLen = 0;
@@ -761,6 +871,7 @@ sal_Int32 SAL_CALL IMPL_RTL_STRNAME( valueOfInt64 )( IMPL_RTL_STRCODE* pStr,
                                                      sal_Int16 nRadix )
     SAL_THROW_EXTERN_C()
 {
+    assert(pStr);
     sal_Char    aBuf[RTL_STR_MAX_VALUEOFINT64];
     sal_Char*   pBuf = aBuf;
     sal_Int32   nLen = 0;
@@ -815,6 +926,7 @@ sal_Int32 SAL_CALL IMPL_RTL_STRNAME( valueOfUInt64 )( IMPL_RTL_STRCODE* pStr,
                                                       sal_Int16 nRadix )
     SAL_THROW_EXTERN_C()
 {
+    assert(pStr);
     sal_Char    aBuf[RTL_STR_MAX_VALUEOFUINT64];
     sal_Char*   pBuf = aBuf;
     sal_Int32   nLen = 0;
@@ -858,6 +970,7 @@ sal_Int32 SAL_CALL IMPL_RTL_STRNAME( valueOfUInt64 )( IMPL_RTL_STRCODE* pStr,
 sal_Bool SAL_CALL IMPL_RTL_STRNAME( toBoolean )( const IMPL_RTL_STRCODE* pStr )
     SAL_THROW_EXTERN_C()
 {
+    assert(pStr);
     if ( *pStr == '1' )
         return sal_True;
 
@@ -884,8 +997,8 @@ namespace {
     template<typename T, typename U> static inline T IMPL_RTL_STRNAME( toInt )( const IMPL_RTL_STRCODE* pStr,
                                                                      sal_Int16 nRadix )
     {
-        BOOST_STATIC_ASSERT(std::numeric_limits<T>::is_signed);
-        sal_Bool    bNeg;
+        static_assert(std::numeric_limits<T>::is_signed, "is signed");
+        bool    bNeg;
         sal_Int16   nDigit;
         U           n = 0;
 
@@ -898,14 +1011,14 @@ namespace {
 
         if ( *pStr == '-' )
         {
-            bNeg = sal_True;
+            bNeg = true;
             pStr++;
         }
         else
         {
             if ( *pStr == '+' )
                 pStr++;
-            bNeg = sal_False;
+            bNeg = false;
         }
 
         T nDiv;
@@ -957,6 +1070,7 @@ sal_Int32 SAL_CALL IMPL_RTL_STRNAME( toInt32 )( const IMPL_RTL_STRCODE* pStr,
                                                 sal_Int16 nRadix )
     SAL_THROW_EXTERN_C()
 {
+    assert(pStr);
     return IMPL_RTL_STRNAME( toInt )<sal_Int32, sal_uInt32>(pStr, nRadix);
 }
 
@@ -964,6 +1078,7 @@ sal_Int64 SAL_CALL IMPL_RTL_STRNAME( toInt64 )( const IMPL_RTL_STRCODE* pStr,
                                                 sal_Int16 nRadix )
     SAL_THROW_EXTERN_C()
 {
+    assert(pStr);
     return IMPL_RTL_STRNAME( toInt )<sal_Int64, sal_uInt64>(pStr, nRadix);
 }
 
@@ -972,7 +1087,7 @@ namespace {
     template <typename T> static inline T IMPL_RTL_STRNAME( toUInt )( const IMPL_RTL_STRCODE* pStr,
                                                                       sal_Int16 nRadix )
     {
-        BOOST_STATIC_ASSERT(!std::numeric_limits<T>::is_signed);
+        static_assert(!std::numeric_limits<T>::is_signed, "is not signed");
         sal_Int16   nDigit;
         T           n = 0;
 
@@ -1011,6 +1126,7 @@ sal_uInt32 SAL_CALL IMPL_RTL_STRNAME( toUInt32 )( const IMPL_RTL_STRCODE* pStr,
                                                   sal_Int16 nRadix )
     SAL_THROW_EXTERN_C()
 {
+    assert(pStr);
     return IMPL_RTL_STRNAME( toUInt )<sal_uInt32>(pStr, nRadix);
 }
 
@@ -1018,6 +1134,7 @@ sal_uInt64 SAL_CALL IMPL_RTL_STRNAME( toUInt64 )( const IMPL_RTL_STRCODE* pStr,
                                                   sal_Int16 nRadix )
     SAL_THROW_EXTERN_C()
 {
+    assert(pStr);
     return IMPL_RTL_STRNAME( toUInt )<sal_uInt64>(pStr, nRadix);
 }
 
@@ -1031,10 +1148,10 @@ static IMPL_RTL_STRINGDATA* IMPL_RTL_STRINGNAME( ImplAlloc )( sal_Int32 nLen )
         = (sal::static_int_cast< sal_uInt32 >(nLen)
            <= ((SAL_MAX_UINT32 - sizeof (IMPL_RTL_STRINGDATA))
                / sizeof (IMPL_RTL_STRCODE)))
-        ? (IMPL_RTL_STRINGDATA *) rtl_allocateMemory(
-            sizeof (IMPL_RTL_STRINGDATA) + nLen * sizeof (IMPL_RTL_STRCODE))
-        : NULL;
-    if (pData != NULL) {
+        ? static_cast<IMPL_RTL_STRINGDATA *>(rtl_allocateMemory(
+            sizeof (IMPL_RTL_STRINGDATA) + nLen * sizeof (IMPL_RTL_STRCODE)))
+        : nullptr;
+    if (pData != nullptr) {
         pData->refCount = 1;
         pData->length = nLen;
         pData->buffer[nLen] = 0;
@@ -1048,10 +1165,11 @@ static IMPL_RTL_STRCODE* IMPL_RTL_STRINGNAME( ImplNewCopy )( IMPL_RTL_STRINGDATA
                                                              IMPL_RTL_STRINGDATA* pStr,
                                                              sal_Int32 nCount )
 {
+    assert(nCount >= 0);
     IMPL_RTL_STRCODE*       pDest;
     const IMPL_RTL_STRCODE* pSrc;
     IMPL_RTL_STRINGDATA*    pData = IMPL_RTL_STRINGNAME( ImplAlloc )( pStr->length );
-    OSL_ASSERT(pData != NULL);
+    OSL_ASSERT(pData != nullptr);
 
     pDest   = pData->buffer;
     pSrc    = pStr->buffer;
@@ -1073,10 +1191,14 @@ static IMPL_RTL_STRCODE* IMPL_RTL_STRINGNAME( ImplNewCopy )( IMPL_RTL_STRINGDATA
 /* String-Class functions                                                  */
 /* ======================================================================= */
 
-#define IMPL_RTL_AQUIRE( pThis )                                \
-{                                                               \
-    if (!SAL_STRING_IS_STATIC (pThis))                          \
-        osl_atomic_increment( &((pThis)->refCount) );  \
+namespace {
+
+void IMPL_RTL_ACQUIRE(IMPL_RTL_STRINGDATA * pThis)
+{
+    if (!SAL_STRING_IS_STATIC (pThis))
+        osl_atomic_increment( &((pThis)->refCount) );
+}
+
 }
 
 /* ----------------------------------------------------------------------- */
@@ -1084,7 +1206,7 @@ static IMPL_RTL_STRCODE* IMPL_RTL_STRINGNAME( ImplNewCopy )( IMPL_RTL_STRINGDATA
 void SAL_CALL IMPL_RTL_STRINGNAME( acquire )( IMPL_RTL_STRINGDATA* pThis )
     SAL_THROW_EXTERN_C()
 {
-    IMPL_RTL_AQUIRE( pThis );
+    IMPL_RTL_ACQUIRE( pThis );
 }
 
 /* ----------------------------------------------------------------------- */
@@ -1096,7 +1218,7 @@ void SAL_CALL IMPL_RTL_STRINGNAME( release )( IMPL_RTL_STRINGDATA* pThis )
         return;
 
 /* OString doesn't have an 'intern' */
-#ifdef IMPL_RTL_INTERN
+#if IMPL_RTL_IS_USTRING
     if (SAL_STRING_IS_INTERN (pThis))
     {
         internRelease (pThis);
@@ -1116,10 +1238,11 @@ void SAL_CALL IMPL_RTL_STRINGNAME( release )( IMPL_RTL_STRINGDATA* pThis )
 void SAL_CALL IMPL_RTL_STRINGNAME( new )( IMPL_RTL_STRINGDATA** ppThis )
     SAL_THROW_EXTERN_C()
 {
+    assert(ppThis);
     if ( *ppThis)
         IMPL_RTL_STRINGNAME( release )( *ppThis );
 
-    *ppThis = (IMPL_RTL_STRINGDATA*) (&IMPL_RTL_EMPTYSTRING);
+    *ppThis = const_cast<IMPL_RTL_STRINGDATA*>(&IMPL_RTL_EMPTYSTRING);
 }
 
 /* ----------------------------------------------------------------------- */
@@ -1128,7 +1251,7 @@ IMPL_RTL_STRINGDATA* SAL_CALL IMPL_RTL_STRINGNAME( alloc )( sal_Int32 nLen )
     SAL_THROW_EXTERN_C()
 {
     if ( nLen < 0 )
-        return NULL;
+        return nullptr;
     else
         return IMPL_RTL_STRINGNAME( ImplAlloc )( nLen );
 }
@@ -1138,6 +1261,7 @@ IMPL_RTL_STRINGDATA* SAL_CALL IMPL_RTL_STRINGNAME( alloc )( sal_Int32 nLen )
 void SAL_CALL IMPL_RTL_STRINGNAME( new_WithLength )( IMPL_RTL_STRINGDATA** ppThis, sal_Int32 nLen )
     SAL_THROW_EXTERN_C()
 {
+    assert(ppThis);
     if ( nLen <= 0 )
         IMPL_RTL_STRINGNAME( new )( ppThis );
     else
@@ -1146,7 +1270,7 @@ void SAL_CALL IMPL_RTL_STRINGNAME( new_WithLength )( IMPL_RTL_STRINGDATA** ppThi
             IMPL_RTL_STRINGNAME( release )( *ppThis );
 
         *ppThis = IMPL_RTL_STRINGNAME( ImplAlloc )( nLen );
-        OSL_ASSERT(*ppThis != NULL);
+        OSL_ASSERT(*ppThis != nullptr);
         (*ppThis)->length   = 0;
 
         IMPL_RTL_STRCODE* pTempStr = (*ppThis)->buffer;
@@ -1160,6 +1284,8 @@ void SAL_CALL IMPL_RTL_STRINGNAME( newFromString )( IMPL_RTL_STRINGDATA** ppThis
                                                     const IMPL_RTL_STRINGDATA* pStr )
     SAL_THROW_EXTERN_C()
 {
+    assert(ppThis);
+    assert(pStr);
     IMPL_RTL_STRINGDATA* pOrg;
 
     if ( !pStr->length )
@@ -1170,7 +1296,7 @@ void SAL_CALL IMPL_RTL_STRINGNAME( newFromString )( IMPL_RTL_STRINGDATA** ppThis
 
     pOrg = *ppThis;
     *ppThis = IMPL_RTL_STRINGNAME( ImplAlloc )( pStr->length );
-    OSL_ASSERT(*ppThis != NULL);
+    OSL_ASSERT(*ppThis != nullptr);
     rtl_str_ImplCopy( (*ppThis)->buffer, pStr->buffer, pStr->length );
     RTL_LOG_STRING_NEW( *ppThis );
 
@@ -1185,6 +1311,7 @@ void SAL_CALL IMPL_RTL_STRINGNAME( newFromStr )( IMPL_RTL_STRINGDATA** ppThis,
                                                  const IMPL_RTL_STRCODE* pCharStr )
     SAL_THROW_EXTERN_C()
 {
+    assert(ppThis);
     IMPL_RTL_STRCODE*       pBuffer;
     IMPL_RTL_STRINGDATA*    pOrg;
     sal_Int32               nLen;
@@ -1207,7 +1334,7 @@ void SAL_CALL IMPL_RTL_STRINGNAME( newFromStr )( IMPL_RTL_STRINGDATA** ppThis,
 
     pOrg = *ppThis;
     *ppThis = IMPL_RTL_STRINGNAME( ImplAlloc )( nLen );
-    OSL_ASSERT(*ppThis != NULL);
+    OSL_ASSERT(*ppThis != nullptr);
     pBuffer = (*ppThis)->buffer;
     do
     {
@@ -1231,6 +1358,7 @@ void SAL_CALL IMPL_RTL_STRINGNAME( newFromStr_WithLength )( IMPL_RTL_STRINGDATA*
                                                             sal_Int32 nLen )
     SAL_THROW_EXTERN_C()
 {
+    assert(ppThis);
     IMPL_RTL_STRINGDATA* pOrg;
 
     if ( !pCharStr || (nLen <= 0) )
@@ -1241,7 +1369,7 @@ void SAL_CALL IMPL_RTL_STRINGNAME( newFromStr_WithLength )( IMPL_RTL_STRINGDATA*
 
     pOrg = *ppThis;
     *ppThis = IMPL_RTL_STRINGNAME( ImplAlloc )( nLen );
-    OSL_ASSERT(*ppThis != NULL);
+    OSL_ASSERT(*ppThis != nullptr);
     rtl_str_ImplCopy( (*ppThis)->buffer, pCharStr, nLen );
 
     RTL_LOG_STRING_NEW( *ppThis );
@@ -1259,6 +1387,7 @@ void SAL_CALL IMPL_RTL_STRINGNAME( newFromSubString )( IMPL_RTL_STRINGDATA** ppT
                                                        sal_Int32 count )
     SAL_THROW_EXTERN_C()
 {
+    assert(ppThis);
     if ( beginIndex == 0 && count == pFrom->length )
     {
         IMPL_RTL_STRINGNAME( assign )( ppThis, const_cast< IMPL_RTL_STRINGDATA * >( pFrom ) );
@@ -1283,6 +1412,9 @@ void SAL_CALL IMPL_RTL_STRINGNAME( newFromLiteral )( IMPL_RTL_STRINGDATA** ppThi
                                                      sal_Int32 allocExtra )
     SAL_THROW_EXTERN_C()
 {
+    assert(ppThis);
+    assert(nLen >= 0);
+    assert(allocExtra >= 0);
     if ( nLen + allocExtra == 0 )
     {
         IMPL_RTL_STRINGNAME( new )( ppThis );
@@ -1293,25 +1425,23 @@ void SAL_CALL IMPL_RTL_STRINGNAME( newFromLiteral )( IMPL_RTL_STRINGDATA** ppThi
         IMPL_RTL_STRINGNAME( release )( *ppThis );
 
     *ppThis = IMPL_RTL_STRINGNAME( ImplAlloc )( nLen + allocExtra );
-    assert( *ppThis != NULL );
-    if ( (*ppThis) )
-    {
-        (*ppThis)->length = nLen; // fix after possible allocExtra != 0
-        (*ppThis)->buffer[nLen] = 0;
-        IMPL_RTL_STRCODE* pBuffer = (*ppThis)->buffer;
-        sal_Int32 nCount;
-        for( nCount = nLen; nCount > 0; --nCount )
-        {
-            /* Check ASCII range */
-            SAL_WARN_IF( ((unsigned char)*pCharStr) > 127, "rtl.string",
-                        "rtl_uString_newFromLiteral - Found char > 127" );
-            SAL_WARN_IF( ((unsigned char)*pCharStr) == '\0', "rtl.string",
-                        "rtl_uString_newFromLiteral - Found embedded \\0 character" );
+    assert( *ppThis != nullptr );
 
-            *pBuffer = *pCharStr;
-            pBuffer++;
-            pCharStr++;
-        }
+    (*ppThis)->length = nLen; // fix after possible allocExtra != 0
+    (*ppThis)->buffer[nLen] = 0;
+    IMPL_RTL_STRCODE* pBuffer = (*ppThis)->buffer;
+    sal_Int32 nCount;
+    for( nCount = nLen; nCount > 0; --nCount )
+    {
+#if IMPL_RTL_IS_USTRING
+        assert(static_cast<unsigned char>(*pCharStr) < 0x80); // ASCII range
+#endif
+        SAL_WARN_IF( ((unsigned char)*pCharStr) == '\0', "rtl.string",
+                    "rtl_uString_newFromLiteral - Found embedded \\0 character" );
+
+        *pBuffer = *pCharStr;
+        pBuffer++;
+        pCharStr++;
     }
 
     RTL_LOG_STRING_NEW( *ppThis );
@@ -1323,8 +1453,9 @@ void SAL_CALL IMPL_RTL_STRINGNAME( assign )( IMPL_RTL_STRINGDATA** ppThis,
                                              IMPL_RTL_STRINGDATA* pStr )
     SAL_THROW_EXTERN_C()
 {
+    assert(ppThis);
     /* must be done at first, if pStr == *ppThis */
-    IMPL_RTL_AQUIRE( pStr );
+    IMPL_RTL_ACQUIRE( pStr );
 
     if ( *ppThis )
         IMPL_RTL_STRINGNAME( release )( *ppThis );
@@ -1337,6 +1468,7 @@ void SAL_CALL IMPL_RTL_STRINGNAME( assign )( IMPL_RTL_STRINGDATA** ppThis,
 sal_Int32 SAL_CALL IMPL_RTL_STRINGNAME( getLength )( const IMPL_RTL_STRINGDATA* pThis )
     SAL_THROW_EXTERN_C()
 {
+    assert(pThis);
     return pThis->length;
 }
 
@@ -1345,6 +1477,7 @@ sal_Int32 SAL_CALL IMPL_RTL_STRINGNAME( getLength )( const IMPL_RTL_STRINGDATA*
 IMPL_RTL_STRCODE* SAL_CALL IMPL_RTL_STRINGNAME( getStr )( IMPL_RTL_STRINGDATA * pThis )
     SAL_THROW_EXTERN_C()
 {
+    assert(pThis);
     return pThis->buffer;
 }
 
@@ -1355,23 +1488,24 @@ void SAL_CALL IMPL_RTL_STRINGNAME( newConcat )( IMPL_RTL_STRINGDATA** ppThis,
                                                 IMPL_RTL_STRINGDATA* pRight )
     SAL_THROW_EXTERN_C()
 {
+    assert(ppThis);
     IMPL_RTL_STRINGDATA* pOrg = *ppThis;
 
     /* Test for 0-Pointer - if not, change newReplaceStrAt! */
     if ( !pRight || !pRight->length )
     {
         *ppThis = pLeft;
-        IMPL_RTL_AQUIRE( pLeft );
+        IMPL_RTL_ACQUIRE( pLeft );
     }
     else if ( !pLeft || !pLeft->length )
     {
         *ppThis = pRight;
-        IMPL_RTL_AQUIRE( pRight );
+        IMPL_RTL_ACQUIRE( pRight );
     }
     else
     {
         IMPL_RTL_STRINGDATA* pTempStr = IMPL_RTL_STRINGNAME( ImplAlloc )( pLeft->length + pRight->length );
-        OSL_ASSERT(pTempStr != NULL);
+        OSL_ASSERT(pTempStr != nullptr);
         rtl_str_ImplCopy( pTempStr->buffer, pLeft->buffer, pLeft->length );
         rtl_str_ImplCopy( pTempStr->buffer+pLeft->length, pRight->buffer, pRight->length );
         *ppThis = pTempStr;
@@ -1390,6 +1524,7 @@ void SAL_CALL IMPL_RTL_STRINGNAME( ensureCapacity )( IMPL_RTL_STRINGDATA** ppThi
                                                      sal_Int32 size )
     SAL_THROW_EXTERN_C()
 {
+    assert(ppThis);
     IMPL_RTL_STRINGDATA* const pOrg = *ppThis;
     if ( pOrg->refCount == 1 && pOrg->length >= size )
         return;
@@ -1402,9 +1537,7 @@ void SAL_CALL IMPL_RTL_STRINGNAME( ensureCapacity )( IMPL_RTL_STRINGDATA** ppThi
     *ppThis = pTempStr;
     RTL_LOG_STRING_NEW( *ppThis );
 
-    /* must be done last, if pStr == *ppThis */
-    if ( pOrg )
-        IMPL_RTL_STRINGNAME( release )( pOrg );
+    IMPL_RTL_STRINGNAME( release )( pOrg );
 }
 
 /* ----------------------------------------------------------------------- */
@@ -1416,6 +1549,8 @@ void SAL_CALL IMPL_RTL_STRINGNAME( newReplaceStrAt )( IMPL_RTL_STRINGDATA** ppTh
                                                       IMPL_RTL_STRINGDATA* pNewSubStr )
     SAL_THROW_EXTERN_C()
 {
+    assert(ppThis);
+//    assert(nCount >= 0);
     /* Append? */
     if ( nIndex >= pStr->length )
     {
@@ -1465,7 +1600,7 @@ void SAL_CALL IMPL_RTL_STRINGNAME( newReplaceStrAt )( IMPL_RTL_STRINGDATA** ppTh
 
     /* Alloc New Buffer */
     *ppThis = IMPL_RTL_STRINGNAME( ImplAlloc )( nNewLen );
-    OSL_ASSERT(*ppThis != NULL);
+    OSL_ASSERT(*ppThis != nullptr);
     pBuffer = (*ppThis)->buffer;
     if ( nIndex )
     {
@@ -1493,6 +1628,8 @@ void SAL_CALL IMPL_RTL_STRINGNAME( newReplace )( IMPL_RTL_STRINGDATA** ppThis,
                                                  IMPL_RTL_STRCODE cNew )
     SAL_THROW_EXTERN_C()
 {
+    assert(ppThis);
+    assert(pStr);
     IMPL_RTL_STRINGDATA*    pOrg        = *ppThis;
     int                     bChanged    = 0;
     sal_Int32               nLen        = pStr->length;
@@ -1537,7 +1674,7 @@ void SAL_CALL IMPL_RTL_STRINGNAME( newReplace )( IMPL_RTL_STRINGDATA** ppThis,
     if ( !bChanged )
     {
         *ppThis = pStr;
-        IMPL_RTL_AQUIRE( pStr );
+        IMPL_RTL_ACQUIRE( pStr );
     }
 
     RTL_LOG_STRING_NEW( *ppThis );
@@ -1552,6 +1689,8 @@ void SAL_CALL IMPL_RTL_STRINGNAME( newToAsciiLowerCase )( IMPL_RTL_STRINGDATA**
                                                           IMPL_RTL_STRINGDATA* pStr )
     SAL_THROW_EXTERN_C()
 {
+    assert(ppThis);
+    assert(pStr);
     IMPL_RTL_STRINGDATA*    pOrg        = *ppThis;
     int                     bChanged    = 0;
     sal_Int32               nLen        = pStr->length;
@@ -1593,7 +1732,7 @@ void SAL_CALL IMPL_RTL_STRINGNAME( newToAsciiLowerCase )( IMPL_RTL_STRINGDATA**
     if ( !bChanged )
     {
         *ppThis = pStr;
-        IMPL_RTL_AQUIRE( pStr );
+        IMPL_RTL_ACQUIRE( pStr );
     }
 
     RTL_LOG_STRING_NEW( *ppThis );
@@ -1608,6 +1747,8 @@ void SAL_CALL IMPL_RTL_STRINGNAME( newToAsciiUpperCase )( IMPL_RTL_STRINGDATA**
                                                           IMPL_RTL_STRINGDATA* pStr )
     SAL_THROW_EXTERN_C()
 {
+    assert(ppThis);
+    assert(pStr);
     IMPL_RTL_STRINGDATA*    pOrg        = *ppThis;
     int                     bChanged    = 0;
     sal_Int32               nLen        = pStr->length;
@@ -1649,7 +1790,7 @@ void SAL_CALL IMPL_RTL_STRINGNAME( newToAsciiUpperCase )( IMPL_RTL_STRINGDATA**
     if ( !bChanged )
     {
         *ppThis = pStr;
-        IMPL_RTL_AQUIRE( pStr );
+        IMPL_RTL_ACQUIRE( pStr );
     }
 
     RTL_LOG_STRING_NEW( *ppThis );
@@ -1664,6 +1805,8 @@ void SAL_CALL IMPL_RTL_STRINGNAME( newTrim )( IMPL_RTL_STRINGDATA** ppThis,
                                               IMPL_RTL_STRINGDATA* pStr )
     SAL_THROW_EXTERN_C()
 {
+    assert(ppThis);
+    assert(pStr);
     IMPL_RTL_STRINGDATA*    pOrg        = *ppThis;
     const IMPL_RTL_STRCODE* pCharStr    = pStr->buffer;
     sal_Int32               nPreSpaces  = 0;
@@ -1683,15 +1826,14 @@ void SAL_CALL IMPL_RTL_STRINGNAME( newTrim )( IMPL_RTL_STRINGDATA** ppThis,
     if ( !nPreSpaces && !nPostSpaces )
     {
         *ppThis = pStr;
-        IMPL_RTL_AQUIRE( pStr );
+        IMPL_RTL_ACQUIRE( pStr );
     }
     else
     {
         nLen -= nPostSpaces+nPreSpaces;
         *ppThis = IMPL_RTL_STRINGNAME( ImplAlloc )( nLen );
-        OSL_ASSERT(*ppThis != NULL);
-        if ( *ppThis )
-            rtl_str_ImplCopy( (*ppThis)->buffer, pStr->buffer+nPreSpaces, nLen );
+        assert(*ppThis);
+        rtl_str_ImplCopy( (*ppThis)->buffer, pStr->buffer+nPreSpaces, nLen );
     }
 
     RTL_LOG_STRING_NEW( *ppThis );
@@ -1709,6 +1851,8 @@ sal_Int32 SAL_CALL IMPL_RTL_STRINGNAME( getToken )( IMPL_RTL_STRINGDATA** ppThis
                                                     sal_Int32 nIndex )
     SAL_THROW_EXTERN_C()
 {
+    assert(ppThis);
+    assert(pStr);
     const IMPL_RTL_STRCODE* pCharStr        = pStr->buffer;
     const IMPL_RTL_STRCODE* pCharStrStart;
     const IMPL_RTL_STRCODE* pOrgCharStr;
