@@ -40,11 +40,10 @@ sal_Size ImplDBCSToUnicode( const void* pData, SAL_UNUSED_PARAMETER void*,
                             sal_uInt32 nFlags, sal_uInt32* pInfo,
                             sal_Size* pSrcCvtBytes )
 {
-    unsigned char                   cLead;
     unsigned char                   cTrail;
     sal_Unicode                 cConv;
     const ImplDBCSToUniLeadTab* pLeadEntry;
-    const ImplDBCSConvertData*  pConvertData = (const ImplDBCSConvertData*)pData;
+    const ImplDBCSConvertData*  pConvertData = static_cast<const ImplDBCSConvertData*>(pData);
     const ImplDBCSToUniLeadTab* pLeadTab = pConvertData->mpToUniLeadTab;
     sal_Unicode*                pEndDestBuf;
     const char*             pEndSrcBuf;
@@ -54,13 +53,13 @@ sal_Size ImplDBCSToUnicode( const void* pData, SAL_UNUSED_PARAMETER void*,
     pEndSrcBuf  = pSrcBuf+nSrcBytes;
     while ( pSrcBuf < pEndSrcBuf )
     {
-        cLead = (unsigned char)*pSrcBuf;
+        unsigned char cLead = (unsigned char)*pSrcBuf;
 
         /* get entry for the lead byte */
         pLeadEntry = pLeadTab+cLead;
 
         /* SingleByte char? */
-        if (pLeadEntry->mpToUniTrailTab == NULL
+        if (pLeadEntry->mpToUniTrailTab == nullptr
             || cLead < pConvertData->mnLeadStart
             || cLead > pConvertData->mnLeadEnd)
         {
@@ -87,112 +86,118 @@ sal_Size ImplDBCSToUnicode( const void* pData, SAL_UNUSED_PARAMETER void*,
             /* Source buffer to small */
             if ( pSrcBuf +1 == pEndSrcBuf )
             {
-                *pInfo |= RTL_TEXTTOUNICODE_INFO_ERROR | RTL_TEXTTOUNICODE_INFO_SRCBUFFERTOSMALL;
-                break;
-            }
-
-            pSrcBuf++;
-            cTrail = (unsigned char)*pSrcBuf;
-            if ( (cTrail >= pLeadEntry->mnTrailStart) && (cTrail <= pLeadEntry->mnTrailEnd) )
-                cConv = pLeadEntry->mpToUniTrailTab[cTrail-pLeadEntry->mnTrailStart];
-            else
-                cConv = 0;
-
-            if ( !cConv )
-            {
-                /* EUDC Ranges */
-                sal_uInt16              i;
-                const ImplDBCSEUDCData* pEUDCTab = pConvertData->mpEUDCTab;
-                for ( i = 0; i < pConvertData->mnEUDCCount; i++ )
+                if ( (nFlags & RTL_TEXTTOUNICODE_FLAGS_FLUSH) == 0 )
                 {
-                    if ( (cLead >= pEUDCTab->mnLeadStart) &&
-                         (cLead <= pEUDCTab->mnLeadEnd) )
+                    *pInfo |= RTL_TEXTTOUNICODE_INFO_ERROR | RTL_TEXTTOUNICODE_INFO_SRCBUFFERTOSMALL;
+                    break;
+                }
+                cConv = 0;
+            }
+            else
+            {
+                pSrcBuf++;
+                cTrail = (unsigned char)*pSrcBuf;
+                if ( (cTrail >= pLeadEntry->mnTrailStart) && (cTrail <= pLeadEntry->mnTrailEnd) )
+                    cConv = pLeadEntry->mpToUniTrailTab[cTrail-pLeadEntry->mnTrailStart];
+                else
+                    cConv = 0;
+
+                if ( !cConv )
+                {
+                    /* EUDC Ranges */
+                    sal_uInt16              i;
+                    const ImplDBCSEUDCData* pEUDCTab = pConvertData->mpEUDCTab;
+                    for ( i = 0; i < pConvertData->mnEUDCCount; i++ )
                     {
-                        if ( (cTrail >= pEUDCTab->mnTrail1Start) &&
-                             (cTrail <= pEUDCTab->mnTrail1End) )
+                        if ( (cLead >= pEUDCTab->mnLeadStart) &&
+                             (cLead <= pEUDCTab->mnLeadEnd) )
                         {
-                            cConv = pEUDCTab->mnUniStart+
-                                    ((cLead-pEUDCTab->mnLeadStart)*pEUDCTab->mnTrailRangeCount)+
-                                    (cTrail-pEUDCTab->mnTrail1Start);
-                            break;
-                        }
-                        else
-                        {
-                            sal_uInt16 nTrailCount = pEUDCTab->mnTrail1End-pEUDCTab->mnTrail1Start+1;
-                            if ( (pEUDCTab->mnTrailCount >= 2) &&
-                                 (cTrail >= pEUDCTab->mnTrail2Start) &&
-                                 (cTrail <= pEUDCTab->mnTrail2End) )
+                            if ( (cTrail >= pEUDCTab->mnTrail1Start) &&
+                                 (cTrail <= pEUDCTab->mnTrail1End) )
                             {
                                 cConv = pEUDCTab->mnUniStart+
-                                        ((cLead-pEUDCTab->mnLeadStart)*pEUDCTab->mnTrailRangeCount)+
-                                        nTrailCount+
-                                        (cTrail-pEUDCTab->mnTrail2Start);
+                                    ((cLead-pEUDCTab->mnLeadStart)*pEUDCTab->mnTrailRangeCount)+
+                                    (cTrail-pEUDCTab->mnTrail1Start);
                                 break;
                             }
                             else
                             {
-                                nTrailCount = pEUDCTab->mnTrail2End-pEUDCTab->mnTrail2Start+1;
-                                if ( (pEUDCTab->mnTrailCount >= 3) &&
-                                     (cTrail >= pEUDCTab->mnTrail3Start) &&
-                                     (cTrail <= pEUDCTab->mnTrail3End) )
+                                sal_uInt16 nTrailCount = pEUDCTab->mnTrail1End-pEUDCTab->mnTrail1Start+1;
+                                if ( (pEUDCTab->mnTrailCount >= 2) &&
+                                     (cTrail >= pEUDCTab->mnTrail2Start) &&
+                                     (cTrail <= pEUDCTab->mnTrail2End) )
                                 {
                                     cConv = pEUDCTab->mnUniStart+
+                                        ((cLead-pEUDCTab->mnLeadStart)*pEUDCTab->mnTrailRangeCount)+
+                                        nTrailCount+
+                                        (cTrail-pEUDCTab->mnTrail2Start);
+                                    break;
+                                }
+                                else
+                                {
+                                    nTrailCount = pEUDCTab->mnTrail2End-pEUDCTab->mnTrail2Start+1;
+                                    if ( (pEUDCTab->mnTrailCount >= 3) &&
+                                         (cTrail >= pEUDCTab->mnTrail3Start) &&
+                                         (cTrail <= pEUDCTab->mnTrail3End) )
+                                    {
+                                        cConv = pEUDCTab->mnUniStart+
                                             ((cLead-pEUDCTab->mnLeadStart)*pEUDCTab->mnTrailRangeCount)+
                                             nTrailCount+
                                             (cTrail-pEUDCTab->mnTrail3Start);
-                                    break;
+                                        break;
+                                    }
                                 }
                             }
                         }
+
+                        pEUDCTab++;
                     }
 
-                    pEUDCTab++;
-                }
+                    if ( !cConv )
+                    {
+                        /* We compare the full range of the trail we defined, */
+                        /* which can often be greater than the limit. We do this */
+                        /* so that extensions that don't consider encodings */
+                        /* correctly treat double-byte characters as a single */
+                        /* character as much as possible. */
 
-                if ( !cConv )
+                        if (cLead < pConvertData->mnLeadStart
+                            || cLead > pConvertData->mnLeadEnd
+                            || cTrail < pConvertData->mnTrailStart
+                            || cTrail > pConvertData->mnTrailEnd)
+                        {
+                            *pInfo |= RTL_TEXTTOUNICODE_INFO_INVALID;
+                            if ( (nFlags & RTL_TEXTTOUNICODE_FLAGS_INVALID_MASK) == RTL_TEXTTOUNICODE_FLAGS_INVALID_ERROR )
+                            {
+                                *pInfo |= RTL_TEXTTOUNICODE_INFO_ERROR;
+                                break;
+                            }
+                            else if ( (nFlags & RTL_TEXTTOUNICODE_FLAGS_INVALID_MASK) == RTL_TEXTTOUNICODE_FLAGS_INVALID_IGNORE )
+                            {
+                                pSrcBuf++;
+                                continue;
+                            }
+                            else
+                                cConv = RTL_TEXTENC_UNICODE_REPLACEMENT_CHARACTER;
+                        }
+                    }
+                }
+            }
+            if ( !cConv )
+            {
+                *pInfo |= RTL_TEXTTOUNICODE_INFO_MBUNDEFINED;
+                if ( (nFlags & RTL_TEXTTOUNICODE_FLAGS_MBUNDEFINED_MASK) == RTL_TEXTTOUNICODE_FLAGS_MBUNDEFINED_ERROR )
                 {
-                    /* We compare the full range of the trail we defined, */
-                    /* which can often be greater than the limit. We do this */
-                    /* so that extensions that don't consider encodings */
-                    /* correctly treat double-byte characters as a single */
-                    /* character as much as possible. */
-
-                    if (cLead < pConvertData->mnLeadStart
-                        || cLead > pConvertData->mnLeadEnd
-                        || cTrail < pConvertData->mnTrailStart
-                        || cTrail > pConvertData->mnTrailEnd)
-                    {
-                        *pInfo |= RTL_TEXTTOUNICODE_INFO_INVALID;
-                        if ( (nFlags & RTL_TEXTTOUNICODE_FLAGS_INVALID_MASK) == RTL_TEXTTOUNICODE_FLAGS_INVALID_ERROR )
-                        {
-                            *pInfo |= RTL_TEXTTOUNICODE_INFO_ERROR;
-                            break;
-                        }
-                        else if ( (nFlags & RTL_TEXTTOUNICODE_FLAGS_INVALID_MASK) == RTL_TEXTTOUNICODE_FLAGS_INVALID_IGNORE )
-                        {
-                            pSrcBuf++;
-                            continue;
-                        }
-                        else
-                            cConv = RTL_TEXTENC_UNICODE_REPLACEMENT_CHARACTER;
-                    }
-                    else
-                    {
-                        *pInfo |= RTL_TEXTTOUNICODE_INFO_MBUNDEFINED;
-                        if ( (nFlags & RTL_TEXTTOUNICODE_FLAGS_MBUNDEFINED_MASK) == RTL_TEXTTOUNICODE_FLAGS_MBUNDEFINED_ERROR )
-                        {
-                            *pInfo |= RTL_TEXTTOUNICODE_INFO_ERROR;
-                            break;
-                        }
-                        else if ( (nFlags & RTL_TEXTTOUNICODE_FLAGS_MBUNDEFINED_MASK) == RTL_TEXTTOUNICODE_FLAGS_MBUNDEFINED_IGNORE )
-                        {
-                            pSrcBuf++;
-                            continue;
-                        }
-                        else
-                            cConv = RTL_TEXTENC_UNICODE_REPLACEMENT_CHARACTER;
-                    }
+                    *pInfo |= RTL_TEXTTOUNICODE_INFO_ERROR;
+                    break;
                 }
+                else if ( (nFlags & RTL_TEXTTOUNICODE_FLAGS_MBUNDEFINED_MASK) == RTL_TEXTTOUNICODE_FLAGS_MBUNDEFINED_IGNORE )
+                {
+                    pSrcBuf++;
+                    continue;
+                }
+                else
+                    cConv = RTL_TEXTENC_UNICODE_REPLACEMENT_CHARACTER;
             }
         }
 
@@ -221,10 +226,8 @@ sal_Size ImplUnicodeToDBCS( const void* pData, SAL_UNUSED_PARAMETER void*,
 {
     sal_uInt16                  cConv;
     sal_Unicode                 c;
-    unsigned char                   nHighChar;
-    unsigned char                   nLowChar;
     const ImplUniToDBCSHighTab* pHighEntry;
-    const ImplDBCSConvertData*  pConvertData = (const ImplDBCSConvertData*)pData;
+    const ImplDBCSConvertData*  pConvertData = static_cast<const ImplDBCSConvertData*>(pData);
     const ImplUniToDBCSHighTab* pHighTab = pConvertData->mpToDBCSHighTab;
     char*                   pEndDestBuf;
     const sal_Unicode*          pEndSrcBuf;
@@ -241,8 +244,8 @@ sal_Size ImplUnicodeToDBCS( const void* pData, SAL_UNUSED_PARAMETER void*,
     while ( pSrcBuf < pEndSrcBuf )
     {
         c = *pSrcBuf;
-        nHighChar = (unsigned char)((c >> 8) & 0xFF);
-        nLowChar = (unsigned char)(c & 0xFF);
+        unsigned char nHighChar = (unsigned char)((c >> 8) & 0xFF);
+        unsigned char nLowChar = (unsigned char)(c & 0xFF);
 
         /* get entry for the high byte */
         pHighEntry = pHighTab+nHighChar;
@@ -382,13 +385,12 @@ sal_Size ImplEUCJPToUnicode( const void* pData,
                              sal_uInt32 nFlags, sal_uInt32* pInfo,
                              sal_Size* pSrcCvtBytes )
 {
-    unsigned char                   c;
     unsigned char                   cLead = '\0';
     unsigned char                   cTrail = '\0';
     sal_Unicode                 cConv;
     const ImplDBCSToUniLeadTab* pLeadEntry;
     const ImplDBCSToUniLeadTab* pLeadTab;
-    const ImplEUCJPConvertData* pConvertData = (const ImplEUCJPConvertData*)pData;
+    const ImplEUCJPConvertData* pConvertData = static_cast<const ImplEUCJPConvertData*>(pData);
     sal_Unicode*                pEndDestBuf;
     const char*             pEndSrcBuf;
 
@@ -397,7 +399,7 @@ sal_Size ImplEUCJPToUnicode( const void* pData,
     pEndSrcBuf  = pSrcBuf+nSrcBytes;
     while ( pSrcBuf < pEndSrcBuf )
     {
-        c = (unsigned char)*pSrcBuf;
+        unsigned char c = (unsigned char)*pSrcBuf;
 
         /* ASCII */
         if ( c <= 0x7F )
@@ -550,7 +552,7 @@ sal_Size ImplUnicodeToEUCJP( const void* pData,
     unsigned char                   nLowChar;
     const ImplUniToDBCSHighTab* pHighEntry;
     const ImplUniToDBCSHighTab* pHighTab;
-    const ImplEUCJPConvertData* pConvertData = (const ImplEUCJPConvertData*)pData;
+    const ImplEUCJPConvertData* pConvertData = static_cast<const ImplEUCJPConvertData*>(pData);
     char*                   pEndDestBuf;
     const sal_Unicode*          pEndSrcBuf;
 
