@@ -10,10 +10,12 @@
 #include <sal/config.h>
 
 #include <com/sun/star/io/Pipe.hpp>
-#include <com/sun/star/xml/sax/FastTokenHandler.hpp>
+#include <com/sun/star/xml/sax/FastToken.hpp>
 #include <com/sun/star/xml/sax/SAXParseException.hpp>
-#include <com/sun/star/xml/sax/XFastParser.hpp>
+#include <com/sun/star/xml/sax/XFastTokenHandler.hpp>
 
+#include <cppuhelper/implbase.hxx>
+#include <sax/fastparser.hxx>
 #include <test/bootstrapfixture.hxx>
 
 using namespace css;
@@ -21,15 +23,35 @@ using namespace css::xml::sax;
 
 namespace {
 
+class DummyTokenHandler : public cppu::WeakImplHelper< xml::sax::XFastTokenHandler >
+{
+public:
+             DummyTokenHandler() {}
+    virtual ~DummyTokenHandler() {}
+
+    virtual sal_Int32 SAL_CALL getTokenFromUTF8( const uno::Sequence<sal_Int8>& )
+        throw (uno::RuntimeException, std::exception) override
+    {
+        return FastToken::DONTKNOW;
+    }
+    virtual uno::Sequence< sal_Int8 > SAL_CALL getUTF8Identifier( sal_Int32 )
+        throw (uno::RuntimeException, std::exception) override
+    {
+        CPPUNIT_ASSERT_MESSAGE( "getUTF8Identifier: unexpected call", false );
+        return uno::Sequence<sal_Int8>();
+    }
+};
+
 class ParserTest: public test::BootstrapFixture
 {
     InputSource maInput;
-    uno::Reference< XFastParser > mxParser;
+    uno::Reference< sax_fastparser::FastSaxParser > mxParser;
     uno::Reference< XFastDocumentHandler > mxDocumentHandler;
+    uno::Reference< DummyTokenHandler > mxTokenHandler;
 
 public:
-    virtual void setUp();
-    virtual void tearDown();
+    virtual void setUp() override;
+    virtual void tearDown() override;
 
     void parse();
 
@@ -38,19 +60,15 @@ public:
     CPPUNIT_TEST_SUITE_END();
 
 private:
-    uno::Reference< io::XInputStream > createStream(OString sInput);
+    uno::Reference< io::XInputStream > createStream(const OString& sInput);
 };
 
 void ParserTest::setUp()
 {
     test::BootstrapFixture::setUp();
-    mxParser.set(
-        m_xContext->getServiceManager()->createInstanceWithContext(
-            "com.sun.star.xml.sax.FastParser", m_xContext),
-        uno::UNO_QUERY );
-    CPPUNIT_ASSERT_MESSAGE("No FastParser!", mxParser.is());
-    mxParser->setTokenHandler(
-        css::xml::sax::FastTokenHandler::create(m_xContext));
+    mxTokenHandler.set( new DummyTokenHandler() );
+    mxParser.set( new sax_fastparser::FastSaxParser() );
+    mxParser->setTokenHandler( mxTokenHandler.get() );
 }
 
 void ParserTest::tearDown()
@@ -58,11 +76,11 @@ void ParserTest::tearDown()
     test::BootstrapFixture::tearDown();
 }
 
-uno::Reference< io::XInputStream > ParserTest::createStream(OString sInput)
+uno::Reference< io::XInputStream > ParserTest::createStream(const OString& sInput)
 {
     uno::Reference< io::XOutputStream > xPipe( io::Pipe::create(m_xContext) );
     uno::Reference< io::XInputStream > xInStream( xPipe, uno::UNO_QUERY );
-    uno::Sequence< sal_Int8 > aSeq( (sal_Int8*)sInput.getStr(), sInput.getLength() );
+    uno::Sequence< sal_Int8 > aSeq( reinterpret_cast<sal_Int8 const *>(sInput.getStr()), sInput.getLength() );
     xPipe->writeBytes( aSeq );
     xPipe->flush();
     xPipe->closeOutput();
