@@ -31,8 +31,7 @@
 #include <osl/time.h>
 
 #include <cppuhelper/factory.hxx>
-#include <cppuhelper/implbase1.hxx>
-#include <cppuhelper/implbase3.hxx>
+#include <cppuhelper/implbase.hxx>
 
 
 using namespace ::std;
@@ -47,10 +46,10 @@ using namespace ::com::sun::star::xml::sax;
 namespace sax_test {
 
 class OFileWriter :
-        public WeakImplHelper1< XOutputStream >
+        public WeakImplHelper< XOutputStream >
 {
 public:
-    OFileWriter( char *pcFile ) { strncpy( m_pcFile, pcFile, 256 - 1 ); m_f = 0; }
+    explicit OFileWriter( char *pcFile ) { strncpy( m_pcFile, pcFile, 256 - 1 ); m_f = 0; }
 
 
 public:
@@ -92,10 +91,10 @@ void OFileWriter::closeOutput()
 
 
 class OSaxWriterTest :
-        public WeakImplHelper1< XSimpleTest >
+        public WeakImplHelper< XSimpleTest >
 {
 public:
-    OSaxWriterTest( const Reference < XMultiServiceFactory > & rFactory ) : m_rFactory( rFactory )
+    explicit OSaxWriterTest( const Reference < XMultiServiceFactory > & rFactory ) : m_rFactory( rFactory )
     {
 
     }
@@ -144,7 +143,7 @@ private:
 *
 *----------------------------------------*/
 struct AttributeListImpl_impl;
-class AttributeListImpl : public WeakImplHelper1< XAttributeList >
+class AttributeListImpl : public WeakImplHelper< XAttributeList >
 {
 public:
     AttributeListImpl();
@@ -327,10 +326,7 @@ OUString    OSaxWriterTest_getImplementationName( ) throw  ()
 
 Sequence<OUString> OSaxWriterTest_getSupportedServiceNames( ) throw  ()
 {
-    Sequence<OUString> aRet(1);
-
-    aRet.getArray()[0] = OSaxWriterTest_getImplementationName( );
-
+    Sequence<OUString> aRet { OSaxWriterTest_getImplementationName( ) };
     return aRet;
 }
 
@@ -657,7 +653,6 @@ void OSaxWriterTest::testPerformance(const  Reference< XExtendedDocumentHandler
     // for performance testing
     sal_Int32 i2;
     OUString huhu( "huhu" );
-    OUString emptyString;
     const int ITERATIONS = 125;
     for( i2 = 0 ; i2 < ITERATIONS ; i2 ++ )
     {
@@ -665,17 +660,17 @@ void OSaxWriterTest::testPerformance(const  Reference< XExtendedDocumentHandler
                          OUString::valueOf( i2 ), rList );
         for( sal_Int32 i = 0 ; i < 450 ; i ++ )
         {
-            r->ignorableWhitespace( emptyString );
+            r->ignorableWhitespace( "" );
             r->startElement( huhu , rList );
             r->characters( testParagraph );
 
-            r->ignorableWhitespace( emptyString );
+            r->ignorableWhitespace( "" );
             r->endElement( huhu );
         }
     }
     for( i2 = ITERATIONS-1 ; i2 >= 0  ; i2-- )
     {
-        r->ignorableWhitespace( emptyString );
+        r->ignorableWhitespace( "" );
         r->endElement( OUString( "tag" ) + OUString::valueOf( i2 ) );
     }
 
