@@ -36,7 +36,7 @@
 #include <vcl/virdev.hxx>
 #include <comphelper/processfactory.hxx>
 #include <svl/PasswordHelper.hxx>
-#include "svl/sharedstringpool.hxx"
+#include <svl/sharedstringpool.hxx>
 #include <tools/tenccvt.hxx>
 #include <tools/urlobj.hxx>
 #include <rtl/crc.h>
@@ -82,6 +82,9 @@
 #include "recursionhelper.hxx"
 #include "lookupcache.hxx"
 #include "externalrefmgr.hxx"
+#include "appoptio.hxx"
+#include "scmod.hxx"
+#include "../../ui/inc/viewutil.hxx"
 #include "tabprotection.hxx"
 #include "formulaparserpool.hxx"
 #include "clipparam.hxx"
@@ -93,7 +96,10 @@
 #include "scopetools.hxx"
 #include "formulagroup.hxx"
 #include "documentlinkmgr.hxx"
+#include "interpre.hxx"
 #include <tokenstringcontext.hxx>
+#include "docsh.hxx"
+#include <listenercontext.hxx>
 
 using namespace com::sun::star;
 
@@ -109,7 +115,7 @@ struct ScLookupCacheMapImpl
     void clear()
     {
         freeCaches();
-        // Zap map.
+        // free mapping
         ScLookupCacheMap aTmp;
         aCacheMap.swap( aTmp);
     }
@@ -125,58 +131,53 @@ private:
 
 ScDocument::ScDocument( ScDocumentMode eMode, SfxObjectShell* pDocShell ) :
         mpCellStringPool(new svl::SharedStringPool(ScGlobal::pCharClass)),
-        mpFormulaGroupCxt(NULL),
-        mpUndoManager( NULL ),
-        pEditEngine( NULL ),
-        pNoteEngine( NULL ),
+        mpFormulaGroupCxt(nullptr),
+        maCalcConfig( ScInterpreter::GetGlobalConfig()),
+        mpUndoManager( nullptr ),
+        pEditEngine( nullptr ),
+        pNoteEngine( nullptr ),
         pShell( pDocShell ),
-        pPrinter( NULL ),
-        pVirtualDevice_100th_mm( NULL ),
-        pDrawLayer( NULL ),
-        pValidationList( NULL ),
-        pFormatExchangeList( NULL ),
-        pRangeName(NULL),
-        pDPCollection( NULL ),
-        pLinkManager( NULL ),
-        pFormulaTree( NULL ),
-        pEOFormulaTree( NULL ),
-        pFormulaTrack( NULL ),
-        pEOFormulaTrack( NULL ),
-        pClipData( NULL ),
-        pDetOpList(NULL),
-        pChangeTrack( NULL ),
-        pUnoBroadcaster( NULL ),
-        pUnoListenerCalls( NULL ),
-        pUnoRefUndoList( NULL ),
-        pChangeViewSettings( NULL ),
-        pScriptTypeData( NULL ),
-        pCacheFieldEditEngine( NULL ),
-        pDocProtection( NULL ),
-        mpClipParam( NULL),
-        pExternalRefMgr( NULL ),
-        mpMacroMgr( NULL ),
-        pViewOptions( NULL ),
-        pDocOptions( NULL ),
-        pExtDocOptions( NULL ),
-        pConsolidateDlgData( NULL ),
-        pRecursionHelper( NULL ),
-        pAutoNameCache( NULL ),
-        pLookupCacheMapImpl( NULL ),
-        pPreviewFont( NULL ),
-        pPreviewCellStyle( NULL ),
+        pPrinter( nullptr ),
+        pVirtualDevice_100th_mm( nullptr ),
+        pDrawLayer( nullptr ),
+        pValidationList( nullptr ),
+        pFormatExchangeList( nullptr ),
+        pRangeName(nullptr),
+        pDPCollection( nullptr ),
+        pFormulaTree( nullptr ),
+        pEOFormulaTree( nullptr ),
+        pFormulaTrack( nullptr ),
+        pEOFormulaTrack( nullptr ),
+        pClipData( nullptr ),
+        pDetOpList(nullptr),
+        pChangeTrack( nullptr ),
+        pUnoBroadcaster( nullptr ),
+        pUnoListenerCalls( nullptr ),
+        pUnoRefUndoList( nullptr ),
+        pChangeViewSettings( nullptr ),
+        pScriptTypeData( nullptr ),
+        mpAnonymousDBData( nullptr ),
+        pCacheFieldEditEngine( nullptr ),
+        pViewOptions( nullptr ),
+        pDocOptions( nullptr ),
+        pExtDocOptions( nullptr ),
+        pConsolidateDlgData( nullptr ),
+        pRecursionHelper( nullptr ),
+        pAutoNameCache( nullptr ),
+        pLookupCacheMapImpl( nullptr ),
+        pPreviewFont( nullptr ),
+        pPreviewCellStyle( nullptr ),
         nUnoObjectId( 0 ),
         nRangeOverflowType( 0 ),
         aCurTextWidthCalcPos(MAXCOL,0,0),
-        aTableOpList( 0 ),
         nFormulaCodeInTree(0),
         nXMLImportedFormulaCount( 0 ),
         nInterpretLevel(0),
         nMacroInterpretLevel(0),
         nInterpreterTableOpLevel(0),
         nSrcVer( SC_CURRENT_VERSION ),
-        nSrcMaxRow( MAXROW ),
         nFormulaTrackCount(0),
-        bHardRecalcState(false),
+        eHardRecalcState(HARDRECALCSTATE_OFF),
         nVisibleTab( 0 ),
         eLinkMode(LM_UNKNOWN),
         bAutoCalc( eMode == SCDOCMODE_DOCUMENT ),
@@ -190,7 +191,6 @@ ScDocument::ScDocument( ScDocumentMode eMode, SfxObjectShell* pDocShell ) :
         bInsertingFromOtherDoc( false ),
         bLoadingMedium( false ),
         bImportingXML( false ),
-        bXMLFromWrapper( false ),
         bCalcingAfterLoad( false ),
         bNoListening( false ),
         mbIdleEnabled(true),
@@ -200,9 +200,7 @@ ScDocument::ScDocument( ScDocumentMode eMode, SfxObjectShell* pDocShell ) :
         bInDtorClear( false ),
         bExpandRefs( false ),
         bDetectiveDirty( false ),
-        nMacroCallMode( SC_MACROCALL_ALLOWED ),
         bHasMacroFunc( false ),
-        nVisSpellState( 0 ),
         nAsianCompression(SC_ASIANCOMPRESSION_INVALID),
         nAsianKerning(SC_ASIANKERNING_INVALID),
         bPastingDrawFromOtherDoc( false ),
@@ -226,9 +224,6 @@ ScDocument::ScDocument( ScDocumentMode eMode, SfxObjectShell* pDocShell ) :
 
     if ( eMode == SCDOCMODE_DOCUMENT )
     {
-        if ( pDocShell )
-            pLinkManager = new sfx2::LinkManager( pDocShell );
-
         xPoolHelper = new ScPoolHelper( this );
 
         pBASM = new ScBroadcastAreaSlotMachine( this );
@@ -237,12 +232,12 @@ ScDocument::ScDocument( ScDocumentMode eMode, SfxObjectShell* pDocShell ) :
     }
     else
     {
-        pBASM       = NULL;
-        pChartListenerCollection = NULL;
-        pRefreshTimerControl = NULL;
+        pBASM       = nullptr;
+        pChartListenerCollection = nullptr;
+        pRefreshTimerControl = nullptr;
     }
     pDBCollection = new ScDBCollection(this);
-    pSelectionAttr = NULL;
+    pSelectionAttr = nullptr;
     pChartCollection = new ScChartCollection;
     apTemporaryChartLock.reset( new ScTemporaryChartLock(this) );
     xColNameRanges = new ScRangePairList;
@@ -251,31 +246,30 @@ ScDocument::ScDocument( ScDocumentMode eMode, SfxObjectShell* pDocShell ) :
     // languages for a visible document are set by docshell later (from options)
     SetLanguage( ScGlobal::eLnge, ScGlobal::eLnge, ScGlobal::eLnge );
 
-    aTrackTimer.SetTimeoutHdl( LINK( this, ScDocument, TrackTimeHdl ) );
-    aTrackTimer.SetTimeout( 100 );
+    aTrackIdle.SetIdleHdl( LINK( this, ScDocument, TrackTimeHdl ) );
+    aTrackIdle.SetPriority( SchedulerPriority::LOW );
 }
 
-sfx2::LinkManager*  ScDocument::GetLinkManager()  const
+sfx2::LinkManager* ScDocument::GetLinkManager()
 {
-    if ( bAutoCalc && !pLinkManager && pShell)
-    {
-        pLinkManager = new sfx2::LinkManager( pShell );
-    }
-    return pLinkManager;
+    return GetDocLinkManager().getLinkManager();
+}
+
+const sfx2::LinkManager* ScDocument::GetLinkManager() const
+{
+    return GetDocLinkManager().getExistingLinkManager();
 }
 
 sc::DocumentLinkManager& ScDocument::GetDocLinkManager()
 {
     if (!mpDocLinkMgr)
-        mpDocLinkMgr.reset(new sc::DocumentLinkManager);
+        mpDocLinkMgr.reset(new sc::DocumentLinkManager(pShell));
     return *mpDocLinkMgr;
 }
 
 const sc::DocumentLinkManager& ScDocument::GetDocLinkManager() const
 {
-    if (!mpDocLinkMgr)
-        mpDocLinkMgr.reset(new sc::DocumentLinkManager);
-    return *mpDocLinkMgr;
+    return const_cast<ScDocument*>(this)->GetDocLinkManager();
 }
 
 void ScDocument::SetStorageGrammar( formula::FormulaGrammar::Grammar eGram )
@@ -286,16 +280,8 @@ void ScDocument::SetStorageGrammar( formula::FormulaGrammar::Grammar eGram )
             "ScDocument::SetStorageGrammar: wrong storage grammar");
 
     eStorageGrammar = eGram;
-
-    // FIXME: the XML import shouldn't strip brackets, the compiler should
-    // digest them instead, which could also speedup reference recognition
-    // during import.
-
-    eXmlImportGrammar = formula::FormulaGrammar::mergeToGrammar( eGram,
-            formula::FormulaGrammar::CONV_OOO);
 }
 
-
 void ScDocument::SetDocVisible( bool bSet )
 {
     //  called from view ctor - only for a visible document,
@@ -303,7 +289,6 @@ void ScDocument::SetDocVisible( bool bSet )
     bIsVisible = bSet;
 }
 
-
 sal_uInt32 ScDocument::GetDocumentID() const
 {
     const ScDocument* pThis = this;
@@ -313,7 +298,6 @@ sal_uInt32 ScDocument::GetDocumentID() const
     return nCrc;
 }
 
-
 void ScDocument::StartChangeTracking()
 {
     if (!pChangeTrack)
@@ -323,7 +307,7 @@ void ScDocument::StartChangeTracking()
 void ScDocument::EndChangeTracking()
 {
     delete pChangeTrack;
-    pChangeTrack = NULL;
+    pChangeTrack = nullptr;
 }
 
 void ScDocument::SetChangeTrack( ScChangeTrack* pTrack )
@@ -335,14 +319,13 @@ void ScDocument::SetChangeTrack( ScChangeTrack* pTrack )
     pChangeTrack = pTrack;
 }
 
-
-IMPL_LINK_NOARG(ScDocument, TrackTimeHdl)
+IMPL_LINK_NOARG_TYPED(ScDocument, TrackTimeHdl, Idle *, void)
 {
-    if ( ScDdeLink::IsInUpdate() )      // nicht verschachteln
+    if ( ScDdeLink::IsInUpdate() )      // do not nest
     {
-        aTrackTimer.Start();            // spaeter nochmal versuchen
+        aTrackIdle.Start();            // try again later
     }
-    else if (pShell)                    // ausfuehren
+    else if (pShell)                    // execute
     {
         TrackFormulas();
         pShell->Broadcast( SfxSimpleHint( FID_DATACHANGED ) );
@@ -351,7 +334,7 @@ IMPL_LINK_NOARG(ScDocument, TrackTimeHdl)
 
         if (!pShell->IsModified())
         {
-            pShell->SetModified( true );
+            pShell->SetModified();
             SfxBindings* pBindings = GetViewBindings();
             if (pBindings)
             {
@@ -360,14 +343,17 @@ IMPL_LINK_NOARG(ScDocument, TrackTimeHdl)
             }
         }
     }
+}
 
-    return 0;
+void ScDocument::SetExpandRefs( bool bVal )
+{
+    bExpandRefs = bVal;
 }
 
 void ScDocument::StartTrackTimer()
 {
-    if (!aTrackTimer.IsActive())        // nicht ewig aufschieben
-        aTrackTimer.Start();
+    if (!aTrackIdle.IsActive())        // do not postpone for forever
+        aTrackIdle.Start();
 }
 
 ScDocument::~ScDocument()
@@ -381,20 +367,7 @@ ScDocument::~ScDocument()
     {   // To be sure there isn't anything running do it with a protector,
         // this ensures also that nothing needs the control anymore.
         ScRefreshTimerProtector aProt( GetRefreshTimerControlAddress() );
-        delete pRefreshTimerControl, pRefreshTimerControl = NULL;
-    }
-
-    // Links aufrauemen
-
-    if ( GetLinkManager() )
-    {
-        // BaseLinks freigeben
-        ::sfx2::SvLinkSources aTemp(pLinkManager->GetServers());
-        for( ::sfx2::SvLinkSources::const_iterator it = aTemp.begin(); it != aTemp.end(); ++it )
-            (*it)->Closed();
-
-        if ( pLinkManager->GetLinks().size() )
-            pLinkManager->Remove( 0, pLinkManager->GetLinks().size() );
+        delete pRefreshTimerControl, pRefreshTimerControl = nullptr;
     }
 
     mxFormulaParserPool.reset();
@@ -404,15 +377,14 @@ ScDocument::~ScDocument()
 
     ScAddInAsync::RemoveDocument( this );
     ScAddInListener::RemoveDocument( this );
-    DELETEZ( pChartListenerCollection);   // vor pBASM wg. evtl. Listener!
+    DELETEZ( pChartListenerCollection);   // before pBASM because of potential Listener!
     DELETEZ( pLookupCacheMapImpl);  // before pBASM because of listeners
-    // BroadcastAreas vor allen Zellen zerstoeren um unnoetige
-    // Einzel-EndListenings der Formelzellen zu vermeiden
+    // destroy BroadcastAreas first to avoid un-needed Single-EndListenings of Formula-Cells
     delete pBASM;       // BroadcastAreaSlotMachine
-    pBASM = NULL;
+    pBASM = nullptr;
 
     delete pUnoBroadcaster;     // broadcasted nochmal SFX_HINT_DYING
-    pUnoBroadcaster = NULL;
+    pUnoBroadcaster = nullptr;
 
     delete pUnoRefUndoList;
     delete pUnoListenerCalls;
@@ -433,24 +405,24 @@ ScDocument::~ScDocument()
     delete pChartCollection;
     DeleteDrawLayer();
     delete pFormatExchangeList;
-    delete pPrinter;
+    pPrinter.disposeAndClear();
     ImplDeleteOptions();
     delete pConsolidateDlgData;
-    delete pLinkManager;
     delete pClipData;
-    delete pDetOpList;                  // loescht auch die Eintraege
+    delete pDetOpList;                  // also deletes entries
     delete pChangeTrack;
     delete pEditEngine;
     delete pNoteEngine;
-    delete pChangeViewSettings;         // und weg damit
-    delete pVirtualDevice_100th_mm;
+    delete pChangeViewSettings;         // and delete
+    pVirtualDevice_100th_mm.disposeAndClear();
 
     delete pDPCollection;
+    delete mpAnonymousDBData;
 
     // delete the EditEngine before destroying the xPoolHelper
     delete pCacheFieldEditEngine;
 
-    if ( xPoolHelper.is() && !bIsClip )
+    if ( xPoolHelper.is() && !bIsClip && !bIsUndo)
         xPoolHelper->SourceDocumentGone();
     xPoolHelper.clear();
 
@@ -458,7 +430,7 @@ ScDocument::~ScDocument()
     delete pRecursionHelper;
 
     delete pPreviewFont;
-    OSL_POSTCOND( !pAutoNameCache, "AutoNameCache still set in dtor" );
+    SAL_WARN_IF( pAutoNameCache, "sc.core", "AutoNameCache still set in dtor" );
 
     mpFormulaGroupCxt.reset();
     mpCellStringPool.reset();
@@ -480,21 +452,21 @@ void ScDocument::InitClipPtrs( ScDocument* pSourceDoc )
 
     SharePooledResources(pSourceDoc);
 
-    //  bedingte Formate / Gueltigkeiten
-    //! Vorlagen kopieren?
+    //  conditional Formats / validations
+    // TODO: Copy Templates?
     const ScValidationDataList* pSourceValid = pSourceDoc->pValidationList;
     if ( pSourceValid )
         pValidationList = new ScValidationDataList(this, *pSourceValid);
 
-                        // Links in Stream speichern
+                        // store Links in Stream
     delete pClipData;
-    if (pSourceDoc->HasDdeLinks())
+    if (pSourceDoc->GetDocLinkManager().hasDdeLinks())
     {
         pClipData = new SvMemoryStream;
         pSourceDoc->SaveDdeLinks(*pClipData);
     }
     else
-        pClipData = NULL;
+        pClipData = nullptr;
 
     // Options pointers exist (ImplCreateOptions) for any document.
     // Must be copied for correct results in OLE objects (#i42666#).
@@ -552,7 +524,6 @@ ScNoteEditEngine& ScDocument::GetNoteEngine()
     return *pNoteEngine;
 }
 
-
 void ScDocument::ResetClip( ScDocument* pSourceDoc, const ScMarkData* pMarks )
 {
     if (bIsClip)
@@ -574,7 +545,7 @@ void ScDocument::ResetClip( ScDocument* pSourceDoc, const ScMarkData* pMarks )
                     {
                         if( i > static_cast<SCTAB>(maTabs.size()) )
                         {
-                            maTabs.resize(i, NULL );
+                            maTabs.resize(i, nullptr );
                         }
                         maTabs.push_back(new ScTable(this, i, aString));
                     }
@@ -594,7 +565,7 @@ void ScDocument::ResetClip( ScDocument* pSourceDoc, SCTAB nTab )
         InitClipPtrs(pSourceDoc);
         if (nTab >= static_cast<SCTAB>(maTabs.size()))
         {
-            maTabs.resize(nTab+1, NULL );
+            maTabs.resize(nTab+1, nullptr );
         }
         maTabs[nTab] = new ScTable(this, nTab,
                             OUString("baeh"));
@@ -609,9 +580,9 @@ void ScDocument::ResetClip( ScDocument* pSourceDoc, SCTAB nTab )
 
 void ScDocument::EnsureTable( SCTAB nTab )
 {
-    bool bExtras = !bIsUndo;        // Spaltenbreiten, Zeilenhoehen, Flags
+    bool bExtras = !bIsUndo;        // Column-Widths, Row-Heights, Flags
     if (static_cast<size_t>(nTab) >= maTabs.size())
-        maTabs.resize(nTab+1, NULL);
+        maTabs.resize(nTab+1, nullptr);
 
     if (!maTabs[nTab])
         maTabs[nTab] = new ScTable(this, nTab, "temp", bExtras, bExtras);
@@ -726,6 +697,20 @@ bool ScDocument::GetDataStart( SCTAB nTab, SCCOL& rStartCol, SCROW& rStartRow )
     return false;
 }
 
+bool ScDocument::GetTiledRenderingArea(SCTAB nTab, SCCOL& rEndCol, SCROW& rEndRow) const
+{
+    bool bHasPrintArea = GetPrintArea(nTab, rEndCol, rEndRow, false);
+
+    // we need some reasonable minimal document size
+    if (!bHasPrintArea || rEndCol < 20)
+        rEndCol = 20;
+
+    if (!bHasPrintArea || rEndRow < 50)
+        rEndRow = 50;
+
+    return true;
+}
+
 bool ScDocument::MoveTab( SCTAB nOldPos, SCTAB nNewPos, ScProgress* pProgress )
 {
     if (nOldPos == nNewPos)
@@ -746,10 +731,10 @@ bool ScDocument::MoveTab( SCTAB nOldPos, SCTAB nNewPos, ScProgress* pProgress )
             if (nNewPos == SC_TAB_APPEND || nNewPos >= nTabCount)
                 nNewPos = nTabCount-1;
 
-            //  Referenz-Updaterei
-            //! mit UpdateReference zusammenfassen!
+            // Update Reference
+            // TODO: combine with UpdateReference!
 
-            sc::RefUpdateMoveTabContext aCxt(nOldPos, nNewPos);
+            sc::RefUpdateMoveTabContext aCxt( *this, nOldPos, nNewPos);
 
             SCsTAB nDz = ((SCsTAB)nNewPos) - (SCsTAB)nOldPos;
             ScRange aSourceRange( 0,0,nOldPos, MAXCOL,MAXROW,nOldPos );
@@ -784,10 +769,8 @@ bool ScDocument::MoveTab( SCTAB nOldPos, SCTAB nNewPos, ScProgress* pProgress )
                 if (*it)
                     (*it)->UpdateCompile();
             SetNoListening( false );
-            it = maTabs.begin();
-            for (; it != maTabs.end(); ++it)
-                if (*it)
-                    (*it)->StartAllListeners();
+            StartAllListeners();
+
             // sheet names of references may not be valid until sheet is moved
             pChartListenerCollection->UpdateScheduledSeriesRanges();
 
@@ -810,8 +793,7 @@ bool ScDocument::CopyTab( SCTAB nOldPos, SCTAB nNewPos, const ScMarkData* pOnlyM
     OUString aName;
     GetName(nOldPos, aName);
 
-    //  vorneweg testen, ob der Prefix als gueltig erkannt wird
-    //  wenn nicht, nur doppelte vermeiden
+    //  check first if Prefix is valid; if not, then only avoid duplicates
     bool bPrefix = ValidTabName( aName );
     OSL_ENSURE(bPrefix, "invalid table name");
     SCTAB nDummy;
@@ -825,7 +807,8 @@ bool ScDocument::CopyTab( SCTAB nOldPos, SCTAB nNewPos, const ScMarkData* pOnlyM
         bValid = !GetTable( aName, nDummy );
 
     sc::AutoCalcSwitch aACSwitch(*this, false);
-    sc::RefUpdateInsertTabContext aCxt(nNewPos, 1);
+    sc::RefUpdateInsertTabContext aCxt( *this, nNewPos, 1);
+    sc::StartListeningContext aSLCxt(*this);
 
     if (bValid)
     {
@@ -861,7 +844,7 @@ bool ScDocument::CopyTab( SCTAB nOldPos, SCTAB nNewPos, const ScMarkData* pOnlyM
                 for (TableContainer::iterator it = maTabs.begin(); it != maTabs.end(); ++it)
                     if (*it && it != (maTabs.begin() + nOldPos))
                         (*it)->UpdateInsertTab(aCxt);
-                maTabs.push_back(NULL);
+                maTabs.push_back(nullptr);
                 for (i = static_cast<SCTAB>(maTabs.size())-1; i > nNewPos; i--)
                     maTabs[i] = maTabs[i - 1];
                 if (nNewPos <= nOldPos)
@@ -874,7 +857,7 @@ bool ScDocument::CopyTab( SCTAB nOldPos, SCTAB nNewPos, const ScMarkData* pOnlyM
                 SetNoListening( false );
                 for (TableContainer::iterator it = maTabs.begin(); it != maTabs.end(); ++it)
                     if (*it && it != maTabs.begin()+nOldPos && it != maTabs.begin()+nNewPos)
-                        (*it)->StartAllListeners();
+                        (*it)->StartListeners(aSLCxt, true);
 
                 if (pValidationList)
                     pValidationList->UpdateInsertTab(aCxt);
@@ -891,7 +874,7 @@ bool ScDocument::CopyTab( SCTAB nOldPos, SCTAB nNewPos, const ScMarkData* pOnlyM
     {
         SetNoListening( true );     // noch nicht bei CopyToTable/Insert
         sc::CopyToDocContext aCopyDocCxt(*this);
-        maTabs[nOldPos]->CopyToTable(aCopyDocCxt, 0, 0, MAXCOL, MAXROW, IDF_ALL, (pOnlyMarked != NULL),
+        maTabs[nOldPos]->CopyToTable(aCopyDocCxt, 0, 0, MAXCOL, MAXROW, InsertDeleteFlags::ALL, (pOnlyMarked != nullptr),
                                         maTabs[nNewPos], pOnlyMarked );
         maTabs[nNewPos]->SetTabBgColor(maTabs[nOldPos]->GetTabBgColor());
 
@@ -900,27 +883,22 @@ bool ScDocument::CopyTab( SCTAB nOldPos, SCTAB nNewPos, const ScMarkData* pOnlyM
         aRefCxt.meMode = URM_COPY;
         aRefCxt.maRange = ScRange(0, 0, nNewPos, MAXCOL, MAXROW, nNewPos);
         aRefCxt.mnTabDelta = nDz;
-        maTabs[nNewPos]->UpdateReference(aRefCxt, NULL);
+        maTabs[nNewPos]->UpdateReference(aRefCxt);
 
-        sc::RefUpdateInsertTabContext aInsTabCxt(nNewPos, 1);
-        maTabs[nNewPos]->UpdateInsertTabAbs(nNewPos); // alle abs. um eins hoch!!
-        maTabs[nOldPos]->UpdateInsertTab(aInsTabCxt);
+        maTabs[nNewPos]->UpdateInsertTabAbs(nNewPos); // move all paragraphs up by one!!
+        maTabs[nOldPos]->UpdateInsertTab(aCxt);
 
         maTabs[nOldPos]->UpdateCompile();
         maTabs[nNewPos]->UpdateCompile( true ); //  maybe already compiled in Clone, but used names need recompilation
         SetNoListening( false );
-        maTabs[nOldPos]->StartAllListeners();
-        maTabs[nNewPos]->StartAllListeners();
-
-        ScConditionalFormatList* pNewList = new ScConditionalFormatList(*maTabs[nOldPos]->GetCondFormList());
-        pNewList->UpdateReference(aRefCxt);
-        maTabs[nNewPos]->SetCondFormList( pNewList );
+        maTabs[nOldPos]->StartListeners(aSLCxt, true);
+        maTabs[nNewPos]->StartListeners(aSLCxt, true);
 
         sc::SetFormulaDirtyContext aFormulaDirtyCxt;
         SetAllFormulasDirty(aFormulaDirtyCxt);
 
-        if (pDrawLayer)
-            DrawCopyPage( static_cast<sal_uInt16>(nOldPos), static_cast<sal_uInt16>(nNewPos) );
+        if (pDrawLayer) //  Skip cloning Note caption object
+            DrawCopyPage( static_cast<sal_uInt16>(nOldPos), static_cast<sal_uInt16>(nNewPos), true );
 
         if (pDPCollection)
             pDPCollection->CopyToTab(nOldPos, nNewPos);
@@ -939,15 +917,13 @@ bool ScDocument::CopyTab( SCTAB nOldPos, SCTAB nNewPos, const ScMarkData* pOnlyM
     return bValid;
 }
 
-void VBA_InsertModule( ScDocument& rDoc, SCTAB nTab, const OUString& sModuleName, const OUString& sModuleSource );
-
 sal_uLong ScDocument::TransferTab( ScDocument* pSrcDoc, SCTAB nSrcPos,
                                 SCTAB nDestPos, bool bInsertNew,
                                 bool bResultsOnly )
 {
-    sal_uLong nRetVal = 1;                      // 0 => Fehler 1 = ok
+    sal_uLong nRetVal = 1;                  // 0 => error 1 = ok
                                             // 3 => NameBox
-                                            // 4 => beides
+                                            // 4 => both
 
     if (pSrcDoc->pShell->GetMedium())
     {
@@ -962,7 +938,7 @@ sal_uLong ScDocument::TransferTab( ScDocument* pSrcDoc, SCTAB nSrcPos,
     }
 
     bool bValid = true;
-    if (bInsertNew)             // neu einfuegen
+    if (bInsertNew)             // re-insert
     {
         OUString aName;
         pSrcDoc->GetName(nSrcPos, aName);
@@ -973,11 +949,11 @@ sal_uLong ScDocument::TransferTab( ScDocument* pSrcDoc, SCTAB nSrcPos,
         maTabs[nDestPos]->SetLayoutRTL(pSrcDoc->maTabs[nSrcPos]->IsLayoutRTL());
         maTabs[nDestPos]->SetLoadingRTL(pSrcDoc->maTabs[nSrcPos]->IsLoadingRTL());
     }
-    else                        // bestehende Tabelle ersetzen
+    else                        // replace existing tables
     {
         if (ValidTab(nDestPos) && nDestPos < static_cast<SCTAB>(maTabs.size()) && maTabs[nDestPos])
         {
-            maTabs[nDestPos]->DeleteArea( 0,0, MAXCOL,MAXROW, IDF_ALL );
+            maTabs[nDestPos]->DeleteArea( 0,0, MAXCOL,MAXROW, InsertDeleteFlags::ALL );
         }
         else
             bValid = false;
@@ -987,12 +963,12 @@ sal_uLong ScDocument::TransferTab( ScDocument* pSrcDoc, SCTAB nSrcPos,
     {
         bool bOldAutoCalcSrc = false;
         bool bOldAutoCalc = GetAutoCalc();
-        SetAutoCalc( false );   // Mehrfachberechnungen vermeiden
+        SetAutoCalc( false );   // avoid repeated calculations
         SetNoListening( true );
         if ( bResultsOnly )
         {
             bOldAutoCalcSrc = pSrcDoc->GetAutoCalc();
-            pSrcDoc->SetAutoCalc( true );   // falls was berechnet werden muss
+            pSrcDoc->SetAutoCalc( true );   // in case something needs calculation
         }
 
         {
@@ -1003,10 +979,8 @@ sal_uLong ScDocument::TransferTab( ScDocument* pSrcDoc, SCTAB nSrcPos,
             {   // scope for bulk broadcast
                 ScBulkBroadcast aBulkBroadcast( pBASM);
                 pSrcDoc->maTabs[nSrcPos]->CopyToTable(aCxt, 0, 0, MAXCOL, MAXROW,
-                        ( bResultsOnly ? IDF_ALL & ~IDF_FORMULA : IDF_ALL),
+                        ( bResultsOnly ? InsertDeleteFlags::ALL & ~InsertDeleteFlags::FORMULA : InsertDeleteFlags::ALL),
                         false, maTabs[nDestPos] );
-                maTabs[nDestPos]->CopyConditionalFormat(0, 0, MAXCOL, MAXROW,
-                            0, 0, pSrcDoc->maTabs[nSrcPos]);
             }
         }
         maTabs[nDestPos]->SetTabNo(nDestPos);
@@ -1018,7 +992,7 @@ sal_uLong ScDocument::TransferTab( ScDocument* pSrcDoc, SCTAB nSrcPos,
             aRefCxt.meMode = URM_COPY;
             aRefCxt.maRange = ScRange(0, 0, nDestPos, MAXCOL, MAXROW, nDestPos);
             aRefCxt.mnTabDelta = nDestPos - nSrcPos;
-            maTabs[nDestPos]->UpdateReference(aRefCxt, NULL);
+            maTabs[nDestPos]->UpdateReference(aRefCxt);
 
             // Readjust self-contained absolute references to this sheet
             maTabs[nDestPos]->TestTabRefAbs(nSrcPos);
@@ -1028,14 +1002,17 @@ sal_uLong ScDocument::TransferTab( ScDocument* pSrcDoc, SCTAB nSrcPos,
 
         SetNoListening( false );
         if ( !bResultsOnly )
-            maTabs[nDestPos]->StartAllListeners();
-        SetDirty( ScRange( 0, 0, nDestPos, MAXCOL, MAXROW, nDestPos));
+        {
+            sc::StartListeningContext aSLCxt(*this);
+            maTabs[nDestPos]->StartListeners(aSLCxt, true);
+        }
+        SetDirty( ScRange( 0, 0, nDestPos, MAXCOL, MAXROW, nDestPos), false);
 
         if ( bResultsOnly )
             pSrcDoc->SetAutoCalc( bOldAutoCalcSrc );
         SetAutoCalc( bOldAutoCalc );
 
-        //  Drawing kopieren
+        //  copy Drawing
 
         if (bInsertNew)
             TransferDrawPage( pSrcDoc, nSrcPos, nDestPos );
@@ -1048,7 +1025,7 @@ sal_uLong ScDocument::TransferTab( ScDocument* pSrcDoc, SCTAB nSrcPos,
 
     if ( bVbaEnabled  )
     {
-        SfxObjectShell* pSrcShell = pSrcDoc ? pSrcDoc->GetDocumentShell() : NULL;
+        SfxObjectShell* pSrcShell = pSrcDoc->GetDocumentShell();
         if ( pSrcShell )
         {
             OUString aLibName("Standard");
@@ -1112,7 +1089,7 @@ ScFormulaCell* ScDocument::SetFormulaCell( const ScAddress& rPos, ScFormulaCell*
     if (!TableExists(rPos.Tab()))
     {
         delete pCell;
-        return NULL;
+        return nullptr;
     }
 
     return maTabs[rPos.Tab()]->SetFormulaCell(rPos.Col(), rPos.Row(), pCell);
@@ -1137,12 +1114,12 @@ void ScDocument::SetConsolidateDlgData( const ScConsolidateParam* pData )
     if ( pData )
         pConsolidateDlgData = new ScConsolidateParam( *pData );
     else
-        pConsolidateDlgData = NULL;
+        pConsolidateDlgData = nullptr;
 }
 
 void ScDocument::SetChangeViewSettings(const ScChangeViewSettings& rNew)
 {
-    if (pChangeViewSettings==NULL)
+    if (pChangeViewSettings==nullptr)
         pChangeViewSettings = new ScChangeViewSettings;
 
     OSL_ENSURE( pChangeViewSettings, "Oops. No ChangeViewSettings :-( by!" );
@@ -1150,11 +1127,9 @@ void ScDocument::SetChangeViewSettings(const ScChangeViewSettings& rNew)
     *pChangeViewSettings=rNew;
 }
 
-//  ----------------------------------------------------------------------------
-
 ScFieldEditEngine* ScDocument::CreateFieldEditEngine()
 {
-    ScFieldEditEngine* pNewEditEngine = NULL;
+    ScFieldEditEngine* pNewEditEngine = nullptr;
     if (!pCacheFieldEditEngine)
     {
         pNewEditEngine = new ScFieldEditEngine(
@@ -1171,7 +1146,7 @@ ScFieldEditEngine* ScDocument::CreateFieldEditEngine()
         }
 
         pNewEditEngine = pCacheFieldEditEngine;
-        pCacheFieldEditEngine = NULL;
+        pCacheFieldEditEngine = nullptr;
     }
     return pNewEditEngine;
 }
@@ -1185,21 +1160,17 @@ void ScDocument::DisposeFieldEditEngine(ScFieldEditEngine*& rpEditEngine)
     }
     else
         delete rpEditEngine;
-    rpEditEngine = NULL;
+    rpEditEngine = nullptr;
 }
 
-//  ----------------------------------------------------------------------------
-
 ScRecursionHelper* ScDocument::CreateRecursionHelperInstance()
 {
     return new ScRecursionHelper;
 }
 
-//  ----------------------------------------------------------------------------
-
 ScLookupCache & ScDocument::GetLookupCache( const ScRange & rRange )
 {
-    ScLookupCache* pCache = 0;
+    ScLookupCache* pCache = nullptr;
     if (!pLookupCacheMapImpl)
         pLookupCacheMapImpl = new ScLookupCacheMapImpl;
     ScLookupCacheMap::iterator it( pLookupCacheMapImpl->aCacheMap.find( rRange));
@@ -1221,7 +1192,7 @@ void ScDocument::AddLookupCache( ScLookupCache & rCache )
         OSL_FAIL( "ScDocument::AddLookupCache: couldn't add to hash map");
     }
     else
-        StartListeningArea( rCache.getRange(), &rCache);
+        StartListeningArea( rCache.getRange(), false, &rCache);
 }
 
 void ScDocument::RemoveLookupCache( ScLookupCache & rCache )
@@ -1236,7 +1207,7 @@ void ScDocument::RemoveLookupCache( ScLookupCache & rCache )
     {
         ScLookupCache* pCache = (*it).second;
         pLookupCacheMapImpl->aCacheMap.erase( it);
-        EndListeningArea( pCache->getRange(), &rCache);
+        EndListeningArea( pCache->getRange(), false, &rCache);
     }
 }
 
@@ -1246,17 +1217,167 @@ void ScDocument::ClearLookupCaches()
         pLookupCacheMapImpl->clear();
 }
 
+bool ScDocument::IsCellInChangeTrack(const ScAddress &cell,Color *pColCellBoder)
+{
+    ScChangeTrack* pTrack = GetChangeTrack();
+    ScChangeViewSettings* pSettings = GetChangeViewSettings();
+    if ( !pTrack || !pTrack->GetFirst() || !pSettings || !pSettings->ShowChanges() )
+        return false;           // missing or turned-off
+    ScActionColorChanger aColorChanger(*pTrack);
+    //  Clipping happens from outside
+    //! TODO: without Clipping; only paint affected cells ??!??!?
+    const ScChangeAction* pAction = pTrack->GetFirst();
+    while (pAction)
+    {
+        ScChangeActionType eType;
+        if ( pAction->IsVisible() )
+        {
+            eType = pAction->GetType();
+            const ScBigRange& rBig = pAction->GetBigRange();
+            if ( rBig.aStart.Tab() == cell.Tab())
+            {
+                ScRange aRange = rBig.MakeRange();
+                if ( eType == SC_CAT_DELETE_ROWS )
+                    aRange.aEnd.SetRow( aRange.aStart.Row() );
+                else if ( eType == SC_CAT_DELETE_COLS )
+                    aRange.aEnd.SetCol( aRange.aStart.Col() );
+                if (ScViewUtil::IsActionShown( *pAction, *pSettings, *this ) )
+                {
+                    if (aRange.In(cell))
+                    {
+                        if (pColCellBoder != nullptr)
+                        {
+                            aColorChanger.Update( *pAction );
+                            Color aColor( aColorChanger.GetColor() );
+                            *pColCellBoder = aColor;
+                        }
+                        return true;
+                    }
+                }
+            }
+            if ( eType == SC_CAT_MOVE &&
+                static_cast<const ScChangeActionMove*>(pAction)->
+                GetFromRange().aStart.Tab() == cell.Col() )
+            {
+                ScRange aRange = static_cast<const ScChangeActionMove*>(pAction)->
+                    GetFromRange().MakeRange();
+                if (ScViewUtil::IsActionShown( *pAction, *pSettings, *this ) )
+                {
+                    if (aRange.In(cell))
+                    {
+                        if (pColCellBoder != nullptr)
+                        {
+                            aColorChanger.Update( *pAction );
+                            Color aColor( aColorChanger.GetColor() );
+                            *pColCellBoder = aColor;
+                        }
+                        return true;
+                    }
+                }
+            }
+        }
+        pAction = pAction->GetNext();
+    }
+    return false;
+}
+
+void ScDocument::GetCellChangeTrackNote( const ScAddress &aCellPos, OUString &aTrackText,bool &bLeftEdge)
+{
+    aTrackText.clear();
+    //  Change-Tracking
+    ScChangeTrack* pTrack = GetChangeTrack();
+    ScChangeViewSettings* pSettings = GetChangeViewSettings();
+    if ( pTrack && pTrack->GetFirst() && pSettings && pSettings->ShowChanges())
+    {
+        const ScChangeAction* pFound = nullptr;
+        const ScChangeAction* pFoundContent = nullptr;
+        const ScChangeAction* pFoundMove = nullptr;
+        long nModified = 0;
+        const ScChangeAction* pAction = pTrack->GetFirst();
+        while (pAction)
+        {
+            if ( pAction->IsVisible() &&
+                 ScViewUtil::IsActionShown( *pAction, *pSettings, *this ) )
+            {
+                ScChangeActionType eType = pAction->GetType();
+                const ScBigRange& rBig = pAction->GetBigRange();
+                if ( rBig.aStart.Tab() == aCellPos.Tab())
+                {
+                    ScRange aRange = rBig.MakeRange();
+                    if ( eType == SC_CAT_DELETE_ROWS )
+                        aRange.aEnd.SetRow( aRange.aStart.Row() );
+                    else if ( eType == SC_CAT_DELETE_COLS )
+                        aRange.aEnd.SetCol( aRange.aStart.Col() );
+                    if ( aRange.In( aCellPos ) )
+                    {
+                        pFound = pAction;       // the last wins
+                        switch ( eType )
+                        {
+                            case SC_CAT_CONTENT :
+                                pFoundContent = pAction;
+                            break;
+                            case SC_CAT_MOVE :
+                                pFoundMove = pAction;
+                            break;
+                            default:
+                                break;
+                        }
+                        ++nModified;
+                    }
+                }
+                if ( eType == SC_CAT_MOVE )
+                {
+                    ScRange aRange =
+                        static_cast<const ScChangeActionMove*>(pAction)->
+                        GetFromRange().MakeRange();
+                    if ( aRange.In( aCellPos ) )
+                    {
+                        pFound = pAction;
+                        ++nModified;
+                    }
+                }
+            }
+            pAction = pAction->GetNext();
+        }
+        if ( pFound )
+        {
+            if ( pFoundContent && pFound->GetType() != SC_CAT_CONTENT )
+                pFound = pFoundContent;     // Content wins
+            if ( pFoundMove && pFound->GetType() != SC_CAT_MOVE &&
+                    pFoundMove->GetActionNumber() >
+                    pFound->GetActionNumber() )
+                pFound = pFoundMove;        // Move wins
+            //  for deleted columns: arrow on left side of row
+            if ( pFound->GetType() == SC_CAT_DELETE_COLS )
+                bLeftEdge = true;
+            DateTime aDT = pFound->GetDateTime();
+            aTrackText  = pFound->GetUser();
+            aTrackText += ", ";
+            aTrackText += ScGlobal::pLocaleData->getDate(aDT);
+            aTrackText += " ";
+            aTrackText += ScGlobal::pLocaleData->getTime(aDT);
+            aTrackText += ":\n";
+            OUString aComStr = pFound->GetComment();
+            if(!aComStr.isEmpty())
+            {
+                aTrackText += aComStr;
+                aTrackText += "\n( ";
+            }
+            pFound->GetDescription( aTrackText, this );
+            if (!aComStr.isEmpty())
+            {
+                aTrackText += ")";
+            }
+        }
+    }
+}
+
 void ScDocument::SetPreviewFont( SfxItemSet* pFont )
 {
     delete pPreviewFont;
     pPreviewFont = pFont;
 }
 
-const ScMarkData ScDocument::GetPreviewSelection()
-{
-    return maPreviewSelection;
-}
-
 void  ScDocument::SetPreviewSelection( ScMarkData& rSel )
 {
     maPreviewSelection = rSel;
@@ -1264,7 +1385,7 @@ void  ScDocument::SetPreviewSelection( ScMarkData& rSel )
 
 SfxItemSet* ScDocument::GetPreviewFont( SCCOL nCol, SCROW nRow, SCTAB nTab )
 {
-    SfxItemSet* pRet = NULL;
+    SfxItemSet* pRet = nullptr;
     if ( pPreviewFont )
     {
         ScMarkData aSel = GetPreviewSelection();
@@ -1276,10 +1397,20 @@ SfxItemSet* ScDocument::GetPreviewFont( SCCOL nCol, SCROW nRow, SCTAB nTab )
 
 ScStyleSheet* ScDocument::GetPreviewCellStyle( SCCOL nCol, SCROW nRow, SCTAB nTab )
 {
-    ScStyleSheet* pRet = NULL;
+    ScStyleSheet* pRet = nullptr;
     ScMarkData aSel = GetPreviewSelection();
     if ( pPreviewCellStyle && aSel.IsCellMarked( nCol, nRow ) && aSel.GetFirstSelected() == nTab  )
         pRet = pPreviewCellStyle;
     return pRet;
 }
+
+sc::IconSetBitmapMap& ScDocument::GetIconSetBitmapMap()
+{
+    if (!m_pIconSetBitmapMap)
+    {
+        m_pIconSetBitmapMap.reset(new sc::IconSetBitmapMap);
+    }
+    return *m_pIconSetBitmapMap;
+}
+
 /* vim:set shiftwidth=4 softtabstop=4 expandtab: */
