@@ -26,6 +26,8 @@
 #include "mtvcellfunc.hxx"
 #include "scmatrix.hxx"
 
+#include "arraysumfunctor.hxx"
+
 #include <formula/token.hxx>
 
 using namespace formula;
@@ -201,46 +203,83 @@ double ScInterpreter::GetGammaDist( double fX, double fAlpha, double fLambda )
         return GetLowRegIGamma( fAlpha, fX / fLambda);
 }
 
-namespace {
-
 class NumericCellAccumulator
 {
-    double mfSum;
+    double mfFirst;
+    double mfRest;
     sal_uInt16 mnError;
 
 public:
-    NumericCellAccumulator() : mfSum(0.0), mnError(0) {}
+    NumericCellAccumulator() : mfFirst(0.0), mfRest(0.0), mnError(0) {}
 
-    void operator() (size_t, double fVal)
+    void operator() (const sc::CellStoreType::value_type& rNode, size_t nOffset, size_t nDataSize)
     {
-        mfSum += fVal;
-    }
-
-    void operator() (size_t, const ScFormulaCell* pCell)
-    {
-        if (mnError)
-            // Skip all the rest if we have an error.
-            return;
-
-        double fVal = 0.0;
-        sal_uInt16 nErr = 0;
-        ScFormulaCell& rCell = const_cast<ScFormulaCell&>(*pCell);
-        if (!rCell.GetErrorOrValue(nErr, fVal))
-            // The cell has neither error nor value.  Perhaps string result.
-            return;
-
-        if (nErr)
+        switch (rNode.type)
         {
-            // Cell has error.
-            mnError = nErr;
-            return;
-        }
+            case sc::element_type_numeric:
+            {
+                const double *p = &sc::numeric_block::at(*rNode.data, nOffset);
+                size_t i = 0;
 
-        mfSum += fVal;
+                // Store the first non-zero value in mfFirst (for some reason).
+                if (!mfFirst)
+                {
+                    for (i = 0; i < nDataSize; ++i)
+                    {
+                        if (!mfFirst)
+                            mfFirst = p[i];
+                        else
+                            break;
+                    }
+                }
+                p += i;
+                nDataSize -= i;
+                if (nDataSize == 0)
+                    return;
+
+                sc::ArraySumFunctor functor(p, nDataSize);
+
+                mfRest += functor();
+                break;
+            }
+
+            case sc::element_type_formula:
+            {
+                sc::formula_block::const_iterator it = sc::formula_block::begin(*rNode.data);
+                std::advance(it, nOffset);
+                sc::formula_block::const_iterator itEnd = it;
+                std::advance(itEnd, nDataSize);
+                for (; it != itEnd; ++it)
+                {
+                    double fVal = 0.0;
+                    sal_uInt16 nErr = 0;
+                    ScFormulaCell& rCell = const_cast<ScFormulaCell&>(*(*it));
+                    if (!rCell.GetErrorOrValue(nErr, fVal))
+                        // The cell has neither error nor value.  Perhaps string result.
+                        continue;
+
+                    if (nErr)
+                    {
+                        // Cell has error - skip all the rest
+                        mnError = nErr;
+                        return;
+                    }
+
+                    if ( !mfFirst )
+                        mfFirst = fVal;
+                    else
+                        mfRest += fVal;
+                }
+            }
+            break;
+            default:
+                ;
+        }
     }
 
     sal_uInt16 getError() const { return mnError; }
-    double getSum() const { return mfSum; }
+    double getFirst() const { return mfFirst; }
+    double getRest() const { return mfRest; }
 };
 
 class NumericCellCounter
@@ -286,15 +325,15 @@ class FuncCount : public sc::ColumnSpanSet::ColumnAction
     sal_uInt32 mnNumFmt;
 
 public:
-    FuncCount() : mpCol(0), mnCount(0), mnNumFmt(0) {}
+    FuncCount() : mpCol(nullptr), mnCount(0), mnNumFmt(0) {}
 
-    virtual void startColumn(ScColumn* pCol) SAL_OVERRIDE
+    virtual void startColumn(ScColumn* pCol) override
     {
         mpCol = pCol;
         mpCol->InitBlockPosition(maPos);
     }
 
-    virtual void execute(SCROW nRow1, SCROW nRow2, bool bVal) SAL_OVERRIDE
+    virtual void execute(SCROW nRow1, SCROW nRow2, bool bVal) override
     {
         if (!bVal)
             return;
@@ -318,15 +357,17 @@ class FuncSum : public sc::ColumnSpanSet::ColumnAction
     sal_uInt32 mnNumFmt;
 
 public:
-    FuncSum() : mpCol(0), mfSum(0.0), mnError(0), mnNumFmt(0) {}
+    FuncSum() : mpCol(nullptr), mfSum(0.0), mnError(0), mnNumFmt(0) {}
 
-    virtual void startColumn(ScColumn* pCol) SAL_OVERRIDE
+    virtual void startColumn(ScColumn* pCol) override
     {
         mpCol = pCol;
         mpCol->InitBlockPosition(maPos);
     }
 
-    virtual void execute(SCROW nRow1, SCROW nRow2, bool bVal) SAL_OVERRIDE
+    virtual void execute(SCROW, SCROW, bool) override { return; };
+
+    virtual void executeSum(SCROW nRow1, SCROW nRow2, bool bVal, double& fMem ) override
     {
         if (!bVal)
             return;
@@ -335,12 +376,19 @@ public:
             return;
 
         NumericCellAccumulator aFunc;
-        maPos.miCellPos = sc::ParseFormulaNumeric(maPos.miCellPos, mpCol->GetCellStore(), nRow1, nRow2, aFunc);
+        maPos.miCellPos = sc::ParseBlock(maPos.miCellPos, mpCol->GetCellStore(), aFunc, nRow1, nRow2);
         mnError = aFunc.getError();
         if (mnError)
             return;
 
-        mfSum += aFunc.getSum();
+        if ( fMem )
+            mfSum += aFunc.getFirst() + aFunc.getRest();
+        else
+        {
+            fMem = aFunc.getFirst();
+            mfSum += aFunc.getRest();
+        }
+
         mnNumFmt = mpCol->GetNumberFormat(nRow2);
     };
 
@@ -351,7 +399,7 @@ public:
 
 void IterateMatrix(
     const ScMatrixRef& pMat, ScIterFunc eFunc, bool bTextAsZero,
-    sal_uLong& rCount, short& rFuncFmtType, double& fRes, double& fMem, bool& bNull)
+    sal_uLong& rCount, short& rFuncFmtType, double& fRes, double& fMem )
 {
     if (!pMat)
         return;
@@ -364,14 +412,23 @@ void IterateMatrix(
         case ifSUM:
         {
             ScMatrix::IterateResult aRes = pMat->Sum(bTextAsZero);
-            if (bNull)
+            // If the first value is a NaN, it probably means it was an empty cell,
+            // and should be treated as zero.
+            if ( !rtl::math::isFinite(aRes.mfFirst) )
+            {
+                sal_uInt32 nErr = reinterpret_cast< sal_math_Double * >(&aRes.mfFirst)->nan_parts.fraction_lo;
+                if (nErr & 0xffff0000)
+                {
+                    aRes.mfFirst = 0;
+                }
+            }
+            if ( fMem )
+                fRes += aRes.mfFirst + aRes.mfRest;
+            else
             {
-                bNull = false;
                 fMem = aRes.mfFirst;
                 fRes += aRes.mfRest;
             }
-            else
-                fRes += aRes.mfFirst + aRes.mfRest;
             rCount += aRes.mnCount;
         }
         break;
@@ -402,15 +459,12 @@ void IterateMatrix(
     }
 }
 
-}
-
 double ScInterpreter::IterateParameters( ScIterFunc eFunc, bool bTextAsZero )
 {
     short nParamCount = GetByte();
     double fRes = ( eFunc == ifPRODUCT ) ? 1.0 : 0.0;
     double fVal = 0.0;
-    double fMem = 0.0; // first numeric value.
-    bool bNull = true;
+    double fMem = 0.0;  // first numeric value != 0.0
     sal_uLong nCount = 0;
     ScAddress aAdr;
     ScRange aRange;
@@ -479,13 +533,10 @@ double ScInterpreter::IterateParameters( ScIterFunc eFunc, bool bTextAsZero )
                 {
                     case ifAVERAGE:
                     case ifSUM:
-                        if ( bNull && fVal != 0.0 )
-                        {
-                            bNull = false;
-                            fMem = fVal;
-                        }
-                        else
+                        if ( fMem )
                             fRes += fVal;
+                        else
+                            fMem = fVal;
                         break;
                     case ifSUMSQ:   fRes += fVal * fVal; break;
                     case ifPRODUCT: fRes *= fVal; break;
@@ -534,13 +585,10 @@ double ScInterpreter::IterateParameters( ScIterFunc eFunc, bool bTextAsZero )
                     {
                         case ifAVERAGE:
                         case ifSUM:
-                            if ( bNull && fVal != 0.0 )
-                            {
-                                bNull = false;
-                                fMem = fVal;
-                            }
-                            else
+                            if ( fMem )
                                 fRes += fVal;
+                            else
+                                fMem = fVal;
                             break;
                         case ifSUMSQ:   fRes += fVal * fVal; break;
                         case ifPRODUCT: fRes *= fVal; break;
@@ -578,8 +626,7 @@ double ScInterpreter::IterateParameters( ScIterFunc eFunc, bool bTextAsZero )
                 {
                     break;
                 }
-                ScRefCellValue aCell;
-                aCell.assign(*pDok, aAdr);
+                ScRefCellValue aCell(*pDok, aAdr);
                 if (!aCell.isEmpty())
                 {
                     if( eFunc == ifCOUNT2 )
@@ -599,13 +646,10 @@ double ScInterpreter::IterateParameters( ScIterFunc eFunc, bool bTextAsZero )
                         {
                             case ifAVERAGE:
                             case ifSUM:
-                                if ( bNull && fVal != 0.0 )
-                                {
-                                    bNull = false;
-                                    fMem = fVal;
-                                }
-                                else
+                                if ( fMem )
                                     fRes += fVal;
+                                else
+                                    fMem = fVal;
                                 break;
                             case ifSUMSQ:   fRes += fVal * fVal; break;
                             case ifPRODUCT: fRes *= fVal; break;
@@ -655,6 +699,38 @@ double ScInterpreter::IterateParameters( ScIterFunc eFunc, bool bTextAsZero )
                     if ( nGlobalError )
                         nGlobalError = 0;
                 }
+                else if ( ( eFunc == ifSUM || eFunc == ifCOUNT ) && !mnSubTotalFlags )
+                {
+                    sc::ColumnSpanSet aSet( false );
+                    aSet.set( aRange, true );
+
+                    if ( eFunc == ifSUM )
+                    {
+                        FuncSum aAction;
+                        aSet.executeColumnAction( *pDok, aAction, fMem );
+                        sal_uInt16 nErr = aAction.getError();
+                        if ( nErr )
+                        {
+                            SetError( nErr );
+                            return fRes;
+                        }
+                        fRes += aAction.getSum();
+
+                        // Get the number format of the last iterated cell.
+                        nFuncFmtIndex = aAction.getNumberFormat();
+                    }
+                    else
+                    {
+                        FuncCount aAction;
+                        aSet.executeColumnAction(*pDok, aAction);
+                        nCount += aAction.getCount();
+
+                        // Get the number format of the last iterated cell.
+                        nFuncFmtIndex = aAction.getNumberFormat();
+                    }
+
+                    nFuncFmtType = pDok->GetFormatTable()->GetType( nFuncFmtIndex );
+                }
                 else
                 {
                     ScValueIterator aValIter( pDok, aRange, mnSubTotalFlags, bTextAsZero );
@@ -674,13 +750,10 @@ double ScInterpreter::IterateParameters( ScIterFunc eFunc, bool bTextAsZero )
                                             if ( !nErr )
                                             {
                                                 SetError(nErr);
-                                                if ( bNull && fVal != 0.0 )
-                                                {
-                                                    bNull = false;
-                                                    fMem = fVal;
-                                                }
-                                                else
+                                                if ( fMem )
                                                     fRes += fVal;
+                                                else
+                                                    fMem = fVal;
                                                 nCount++;
                                             }
                                         }
@@ -691,13 +764,10 @@ double ScInterpreter::IterateParameters( ScIterFunc eFunc, bool bTextAsZero )
                                         do
                                         {
                                             SetError(nErr);
-                                            if ( bNull && fVal != 0.0 )
-                                            {
-                                                bNull = false;
-                                                fMem = fVal;
-                                            }
-                                            else
+                                            if ( fMem )
                                                 fRes += fVal;
+                                            else
+                                                fMem = fVal;
                                             nCount++;
                                         }
                                         while (aValIter.GetNext(fVal, nErr));
@@ -762,13 +832,14 @@ double ScInterpreter::IterateParameters( ScIterFunc eFunc, bool bTextAsZero )
                 if ( nGlobalError && !( mnSubTotalFlags & SUBTOTAL_IGN_ERR_VAL ) )
                     break;
 
-                IterateMatrix(pMat, eFunc, bTextAsZero, nCount, nFuncFmtType, fRes, fMem, bNull);
+                IterateMatrix( pMat, eFunc, bTextAsZero, nCount, nFuncFmtType, fRes, fMem );
             }
             break;
             case svMatrix :
             {
                 ScMatrixRef pMat = PopMatrix();
-                IterateMatrix(pMat, eFunc, bTextAsZero, nCount, nFuncFmtType, fRes, fMem, bNull);
+
+                IterateMatrix( pMat, eFunc, bTextAsZero, nCount, nFuncFmtType, fRes, fMem );
             }
             break;
             case svError:
@@ -800,9 +871,9 @@ double ScInterpreter::IterateParameters( ScIterFunc eFunc, bool bTextAsZero )
         case ifPRODUCT: if ( !nCount ) fRes = 0.0; break;
         default: ; // nothing
     }
-    // Bei Summen etc. macht ein bool-Ergebnis keinen Sinn
-    // und Anzahl ist immer Number (#38345#)
-    if( eFunc == ifCOUNT || nFuncFmtType == css::util::NumberFormat::LOGICAL )
+    // A boolean return type makes no sense on sums et al.
+    // Counts are always numbers.
+    if( nFuncFmtType == css::util::NumberFormat::LOGICAL || eFunc == ifCOUNT || eFunc == ifCOUNT2 )
         nFuncFmtType = css::util::NumberFormat::NUMBER;
     return fRes;
 }
@@ -814,136 +885,7 @@ void ScInterpreter::ScSumSQ()
 
 void ScInterpreter::ScSum()
 {
-    if ( mnSubTotalFlags )
-        PushDouble( IterateParameters( ifSUM ) );
-    else
-    {
-        short nParamCount = GetByte();
-        double fRes = 0.0;
-        double fVal = 0.0;
-        ScAddress aAdr;
-        ScRange aRange;
-        size_t nRefInList = 0;
-        while (nParamCount-- > 0)
-        {
-            switch (GetStackType())
-            {
-                case svString:
-                {
-                    while (nParamCount-- > 0)
-                        Pop();
-                    SetError( errNoValue );
-                }
-                break;
-                case svDouble    :
-                    fVal = GetDouble();
-                    fRes += fVal;
-                    nFuncFmtType = css::util::NumberFormat::NUMBER;
-                    break;
-                case svExternalSingleRef:
-                {
-                    ScExternalRefCache::TokenRef pToken;
-                    ScExternalRefCache::CellFormat aFmt;
-                    PopExternalSingleRef(pToken, &aFmt);
-
-                    if (!pToken)
-                        break;
-
-                    StackVar eType = pToken->GetType();
-                    if (eType == formula::svDouble)
-                    {
-                        fVal = pToken->GetDouble();
-                        if (aFmt.mbIsSet)
-                        {
-                            nFuncFmtType = aFmt.mnType;
-                            nFuncFmtIndex = aFmt.mnIndex;
-                        }
-
-                        fRes += fVal;
-                    }
-                }
-                break;
-                case svSingleRef :
-                {
-                    PopSingleRef( aAdr );
-
-                    ScRefCellValue aCell;
-                    aCell.assign(*pDok, aAdr);
-                    if (!aCell.isEmpty())
-                    {
-                        if (aCell.hasNumeric())
-                        {
-                            fVal = GetCellValue(aAdr, aCell);
-                            CurFmtToFuncFmt();
-                            fRes += fVal;
-                        }
-                    }
-                }
-                break;
-                case svDoubleRef :
-                case svRefList :
-                {
-                    PopDoubleRef( aRange, nParamCount, nRefInList);
-
-                    sc::ColumnSpanSet aSet(false);
-                    aSet.set(aRange, true);
-
-                    FuncSum aAction;
-                    aSet.executeColumnAction(*pDok, aAction);
-                    sal_uInt16 nErr = aAction.getError();
-                    if (nErr)
-                    {
-                        SetError(nErr);
-                        return;
-                    }
-                    fRes += aAction.getSum();
-
-                    // Get the number format of the last iterated cell.
-                    nFuncFmtIndex = aAction.getNumberFormat();
-                    nFuncFmtType = pDok->GetFormatTable()->GetType(nFuncFmtIndex);
-                }
-                break;
-                case svExternalDoubleRef:
-                {
-                    ScMatrixRef pMat;
-                    PopExternalDoubleRef(pMat);
-                    if (nGlobalError)
-                        break;
-
-                    sal_uLong nCount = 0;
-                    double fMem = 0.0;
-                    bool bNull = true;
-                    IterateMatrix(pMat, ifSUM, false, nCount, nFuncFmtType, fRes, fMem, bNull);
-                    fRes += fMem;
-                }
-                break;
-                case svMatrix :
-                {
-                    ScMatrixRef pMat = PopMatrix();
-                    sal_uLong nCount = 0;
-                    double fMem = 0.0;
-                    bool bNull = true;
-                    IterateMatrix(pMat, ifSUM, false, nCount, nFuncFmtType, fRes, fMem, bNull);
-                    fRes += fMem;
-                }
-                break;
-                case svError:
-                {
-                    PopError();
-                }
-                break;
-                default :
-                    while (nParamCount-- > 0)
-                        PopError();
-                    SetError(errIllegalParameter);
-            }
-        }
-
-        if (nFuncFmtType == css::util::NumberFormat::LOGICAL)
-            nFuncFmtType = css::util::NumberFormat::NUMBER;
-
-        PushDouble(fRes);
-    }
+    PushDouble( IterateParameters( ifSUM ) );
 }
 
 void ScInterpreter::ScProduct()
@@ -958,156 +900,7 @@ void ScInterpreter::ScAverage( bool bTextAsZero )
 
 void ScInterpreter::ScCount()
 {
-    if ( mnSubTotalFlags )
-        PushDouble( IterateParameters( ifCOUNT ) );
-    else
-    {
-        short nParamCount = GetByte();
-        sal_uLong nCount = 0;
-        ScAddress aAdr;
-        ScRange aRange;
-        size_t nRefInList = 0;
-        if (nGlobalError)
-            nGlobalError = 0;
-
-        while (nParamCount-- > 0)
-        {
-            switch (GetRawStackType())
-            {
-                case svString:
-                {
-                    OUString aStr = PopString().getString();
-                    // Only check if string can be converted to number, no
-                    // error propagation.
-                    sal_uInt16 nErr = nGlobalError;
-                    nGlobalError = 0;
-                    ConvertStringToValue( aStr );
-                    if (!nGlobalError)
-                        ++nCount;
-                    nGlobalError = nErr;
-                }
-                break;
-                case svDouble    :
-                    GetDouble();
-                    nCount++;
-                    nFuncFmtType = css::util::NumberFormat::NUMBER;
-                    break;
-                case svExternalSingleRef:
-                {
-                    ScExternalRefCache::TokenRef pToken;
-                    ScExternalRefCache::CellFormat aFmt;
-                    PopExternalSingleRef(pToken, &aFmt);
-                    if (nGlobalError)
-                    {
-                        nGlobalError = 0;
-                        break;
-                    }
-
-                    if (!pToken)
-                        break;
-
-                    StackVar eType = pToken->GetType();
-                    if (eType == formula::svDouble)
-                    {
-                        nCount++;
-                        if (aFmt.mbIsSet)
-                        {
-                            nFuncFmtType = aFmt.mnType;
-                            nFuncFmtIndex = aFmt.mnIndex;
-                        }
-
-                        if (nGlobalError)
-                        {
-                            nGlobalError = 0;
-                            nCount--;
-                        }
-                    }
-                }
-                break;
-                case svSingleRef :
-                {
-                    PopSingleRef( aAdr );
-                    if (nGlobalError)
-                    {
-                        nGlobalError = 0;
-                        break;
-                    }
-                    ScRefCellValue aCell;
-                    aCell.assign(*pDok, aAdr);
-                    if (!aCell.isEmpty())
-                    {
-                        if (aCell.hasNumeric())
-                        {
-                            nCount++;
-                            CurFmtToFuncFmt();
-                            if (nGlobalError)
-                            {
-                                nGlobalError = 0;
-                                nCount--;
-                            }
-                        }
-                    }
-                }
-                break;
-                case svDoubleRef :
-                case svRefList :
-                {
-                    PopDoubleRef( aRange, nParamCount, nRefInList);
-                    if (nGlobalError)
-                    {
-                        nGlobalError = 0;
-                        break;
-                    }
-
-                    sc::ColumnSpanSet aSet(false);
-                    aSet.set(aRange, true);
-
-                    FuncCount aAction;
-                    aSet.executeColumnAction(*pDok, aAction);
-                    nCount += aAction.getCount();
-
-                    // Get the number format of the last iterated cell.
-                    nFuncFmtIndex = aAction.getNumberFormat();
-                    nFuncFmtType = pDok->GetFormatTable()->GetType(nFuncFmtIndex);
-                }
-                break;
-                case svExternalDoubleRef:
-                {
-                    ScMatrixRef pMat;
-                    PopExternalDoubleRef(pMat);
-                    if (nGlobalError)
-                        break;
-
-                    double fMem = 0.0, fRes = 0.0;
-                    bool bNull = true;
-                    IterateMatrix(pMat, ifCOUNT, false, nCount, nFuncFmtType, fRes, fMem, bNull);
-                }
-                break;
-                case svMatrix :
-                {
-                    ScMatrixRef pMat = PopMatrix();
-                    double fMem = 0.0, fRes = 0.0;
-                    bool bNull = true;
-                    IterateMatrix(pMat, ifCOUNT, false, nCount, nFuncFmtType, fRes, fMem, bNull);
-                }
-                break;
-                case svError:
-                {
-                    PopError();
-                    nGlobalError = 0;
-                }
-                break;
-                default :
-                    while (nParamCount-- > 0)
-                        PopError();
-                    SetError(errIllegalParameter);
-            }
-        }
-
-        nFuncFmtType = css::util::NumberFormat::NUMBER;
-
-        PushDouble(nCount);
-    }
+    PushDouble( IterateParameters( ifCOUNT ) );
 }
 
 void ScInterpreter::ScCount2()
