@@ -126,11 +126,7 @@ TokenPool::~TokenPool()
         delete ppP_Nlf[ n ];
     delete[] ppP_Nlf;
 
-    for( n = 0 ; n < nP_Matrix ; n++ )
-    {
-        if( ppP_Matrix[ n ] )
-            ppP_Matrix[ n ]->DecRef( );
-    }
+    ClearMatrix();
     delete[] ppP_Matrix;
 
     delete pScToken;
@@ -881,6 +877,7 @@ void TokenPool::Reset()
     maExtNames.clear();
     maExtCellRefs.clear();
     maExtAreaRefs.clear();
+    ClearMatrix();
 }
 
 bool TokenPool::IsSingleOp( const TokenId& rId, const DefTokenId eId ) const
@@ -936,4 +933,16 @@ ScMatrix* TokenPool::GetMatrix( unsigned int n ) const
     return nullptr;
 }
 
+void TokenPool::ClearMatrix()
+{
+    for(sal_uInt16 n = 0 ; n < nP_Matrix ; n++ )
+    {
+        if( ppP_Matrix[ n ] )
+        {
+            ppP_Matrix[ n ]->DecRef( );
+            ppP_Matrix[n] = nullptr;
+        }
+    }
+}
+
 /* vim:set shiftwidth=4 softtabstop=4 expandtab: */
