@@ -723,14 +723,22 @@ void XclExpLabelCell::Init( const XclExpRoot& rRoot,
     mxText = xText;
     mnSstIndex = 0;
 
-    // create the cell format
-    sal_uInt16 nXclFont = mxText->RemoveLeadingFont();
-    if( GetXFId() == EXC_XFID_NOTFOUND )
-    {
-        OSL_ENSURE( nXclFont != EXC_FONT_NOTFOUND, "XclExpLabelCell::Init - leading font not found" );
-        bool bForceLineBreak = mxText->IsWrapped();
-        SetXFId( rRoot.GetXFBuffer().InsertWithFont( pPattern, ApiScriptType::WEAK, nXclFont, bForceLineBreak ) );
-    }
+    const XclFormatRunVec& rFormats = mxText->GetFormats();
+    // remove formatting of the leading run if the entire string
+    // is equally formatted
+    sal_uInt16 nXclFont = EXC_FONT_NOTFOUND;
+    if( rFormats.size() == 1 )
+        nXclFont = mxText->RemoveLeadingFont();
+    else
+        nXclFont = mxText->GetLeadingFont();
+
+   // create cell format
+   if( GetXFId() == EXC_XFID_NOTFOUND )
+   {
+       OSL_ENSURE( nXclFont != EXC_FONT_NOTFOUND, "XclExpLabelCell::Init - leading font not found" );
+       bool bForceLineBreak = mxText->IsWrapped();
+       SetXFId( rRoot.GetXFBuffer().InsertWithFont( pPattern, ApiScriptType::WEAK, nXclFont, bForceLineBreak ) );
+   }
 
     // get auto-wrap attribute from cell format
     const XclExpXF* pXF = rRoot.GetXFBuffer().GetXFById( GetXFId() );
@@ -816,12 +824,12 @@ XclExpFormulaCell::XclExpFormulaCell(
         XclExpNumFmtBuffer& rNumFmtBfr = rRoot.GetNumFmtBuffer();
 
         // current cell number format
-        sal_uLong nScNumFmt = pPattern ?
+        sal_uInt32 nScNumFmt = pPattern ?
             GETITEMVALUE( pPattern->GetItemSet(), SfxUInt32Item, ATTR_VALUE_FORMAT, sal_uLong ) :
             rNumFmtBfr.GetStandardFormat();
 
         // alternative number format passed to XF buffer
-        sal_uLong nAltScNumFmt = NUMBERFORMAT_ENTRY_NOT_FOUND;
+        sal_uInt32 nAltScNumFmt = NUMBERFORMAT_ENTRY_NOT_FOUND;
         /*  Xcl doesn't know Boolean number formats, we write
             "TRUE";"FALSE" (language dependent). Don't do it for automatic
             formula formats, because Excel gets them right. */
@@ -921,7 +929,7 @@ void XclExpFormulaCell::Save( XclExpStream& rStrm )
 
 void XclExpFormulaCell::SaveXml( XclExpXmlStream& rStrm )
 {
-    const char* sType = NULL;
+    const char* sType = nullptr;
     OUString    sValue;
     XclXmlUtils::GetFormulaTypeAndValue( mrScFmlaCell, sType, sValue );
     sax_fastparser::FSHelperPtr& rWorksheet = rStrm.GetCurrentStream();
@@ -932,23 +940,81 @@ void XclExpFormulaCell::SaveXml( XclExpXmlStream& rStrm )
             // OOXTODO: XML_cm, XML_vm, XML_ph
             FSEND );
 
-    rWorksheet->startElement( XML_f,
-            // OOXTODO: XML_t,      ST_CellFormulaType
-            XML_aca,    XclXmlUtils::ToPsz( (mxTokArr && mxTokArr->IsVolatile()) || (mxAddRec && mxAddRec->IsVolatile()) ),
-            // OOXTODO: XML_ref,    ST_Ref
-            // OOXTODO: XML_dt2D,   bool
-            // OOXTODO: XML_dtr,    bool
-            // OOXTODO: XML_del1,   bool
-            // OOXTODO: XML_del2,   bool
-            // OOXTODO: XML_r1,     ST_CellRef
-            // OOXTODO: XML_r2,     ST_CellRef
-            // OOXTODO: XML_ca,     bool
-            // OOXTODO: XML_si,     uint
-            // OOXTODO: XML_bx      bool
-            FSEND );
-    rWorksheet->writeEscaped( XclXmlUtils::ToOUString(
-        rStrm.GetRoot().GetCompileFormulaContext(), mrScFmlaCell.aPos, mrScFmlaCell.GetCode()));
-    rWorksheet->endElement( XML_f );
+    bool bWriteFormula = true;
+    bool bTagStarted = false;
+    ScAddress aScPos( static_cast< SCCOL >( GetXclPos().mnCol ),
+            static_cast< SCROW >( GetXclPos().mnRow ), rStrm.GetRoot().GetCurrScTab() );
+
+    switch (mrScFmlaCell.GetMatrixFlag())
+    {
+        case MM_NONE:
+            break;
+        case MM_REFERENCE:
+            bWriteFormula = false;
+            break;
+        case MM_FORMULA:
+            {
+                // origin of the matrix - find the used matrix range
+                SCCOL nMatWidth;
+                SCROW nMatHeight;
+                mrScFmlaCell.GetMatColsRows( nMatWidth, nMatHeight );
+                OSL_ENSURE( nMatWidth && nMatHeight, "XclExpFormulaCell::XclExpFormulaCell - empty matrix" );
+                ScRange aMatScRange( aScPos );
+                ScAddress& rMatEnd = aMatScRange.aEnd;
+                rMatEnd.IncCol( static_cast< SCsCOL >( nMatWidth - 1 ) );
+                rMatEnd.IncRow( static_cast< SCsROW >( nMatHeight - 1 ) );
+                // reduce to valid range (range keeps valid, because start position IS valid
+                rStrm.GetRoot().GetAddressConverter().ValidateRange( aMatScRange, true );
+
+                OStringBuffer sFmlaCellRange;
+                if (ValidRange(aMatScRange))
+                {
+                    // calculate the cell range.
+                    sFmlaCellRange.append( XclXmlUtils::ToOString(
+                                rStrm.GetRoot().GetStringBuf(), aMatScRange.aStart ).getStr());
+                    sFmlaCellRange.append(":");
+                    sFmlaCellRange.append( XclXmlUtils::ToOString(
+                                rStrm.GetRoot().GetStringBuf(), aMatScRange.aEnd ).getStr());
+                }
+
+                if (    aMatScRange.aStart.Col() == GetXclPos().mnCol &&
+                        aMatScRange.aStart.Row() == static_cast<SCROW>(GetXclPos().mnRow))
+                {
+                    rWorksheet->startElement( XML_f,
+                            XML_aca, XclXmlUtils::ToPsz( (mxTokArr && mxTokArr->IsVolatile()) ||
+                                (mxAddRec && mxAddRec->IsVolatile())),
+                            XML_t, mxAddRec ? "array" : nullptr,
+                            XML_ref, !sFmlaCellRange.isEmpty()? sFmlaCellRange.getStr() : nullptr,
+                            // OOXTODO: XML_dt2D,   bool
+                            // OOXTODO: XML_dtr,    bool
+                            // OOXTODO: XML_del1,   bool
+                            // OOXTODO: XML_del2,   bool
+                            // OOXTODO: XML_r1,     ST_CellRef
+                            // OOXTODO: XML_r2,     ST_CellRef
+                            // OOXTODO: XML_ca,     bool
+                            // OOXTODO: XML_si,     uint
+                            // OOXTODO: XML_bx      bool
+                            FSEND );
+                    bTagStarted = true;
+                }
+            }
+            break;
+    }
+
+    if (bWriteFormula)
+    {
+        if (!bTagStarted)
+        {
+            rWorksheet->startElement( XML_f,
+                    XML_aca, XclXmlUtils::ToPsz( (mxTokArr && mxTokArr->IsVolatile()) ||
+                        (mxAddRec && mxAddRec->IsVolatile()) ),
+                    FSEND );
+        }
+        rWorksheet->writeEscaped( XclXmlUtils::ToOUString(
+                    rStrm.GetRoot().GetCompileFormulaContext(), mrScFmlaCell.aPos, mrScFmlaCell.GetCode()));
+        rWorksheet->endElement( XML_f );
+    }
+
     if( strcmp( sType, "inlineStr" ) == 0 )
     {
         rWorksheet->startElement( XML_is, FSEND );
@@ -1328,7 +1394,7 @@ void XclExpRkCell::WriteContents( XclExpStream& rStrm, sal_uInt16 nRelCol )
 // Rows and Columns
 
 XclExpOutlineBuffer::XclExpOutlineBuffer( const XclExpRoot& rRoot, bool bRows ) :
-        mpScOLArray( 0 ),
+        mpScOLArray( nullptr ),
         maLevelInfos( SC_OL_MAXDEPTH ),
         mnCurrLevel( 0 ),
         mbCurrCollapse( false )
@@ -1358,7 +1424,7 @@ void XclExpOutlineBuffer::UpdateColRow( SCCOLROW nScPos )
         if( nNewLevel >= mnCurrLevel )
         {
             // new level(s) opened, or no level closed - update all level infos
-            for( sal_uInt16 nScLevel = 0; nScLevel <= nNewOpenScLevel; ++nScLevel )
+            for( size_t nScLevel = 0; nScLevel <= nNewOpenScLevel; ++nScLevel )
             {
                 /*  In each level: check if a new group is started (there may be
                     neighbored groups without gap - therefore check ALL levels). */
@@ -2003,7 +2069,7 @@ void XclExpRow::SaveXml( XclExpXmlStream& rStrm )
         rWorksheet->startElement( XML_row,
                 XML_r,              OString::number(  (mnCurrentRow++) ).getStr(),
                 // OOXTODO: XML_spans,          optional
-                XML_s,              haveFormat ? lcl_GetStyleId( rStrm, mnXFIndex ).getStr() : NULL,
+                XML_s,              haveFormat ? lcl_GetStyleId( rStrm, mnXFIndex ).getStr() : nullptr,
                 XML_customFormat,   XclXmlUtils::ToPsz( haveFormat ),
                 XML_ht,             OString::number( (double) mnHeight / 20.0 ).getStr(),
                 XML_hidden,         XclXmlUtils::ToPsz( ::get_flag( mnFlags, EXC_ROW_HIDDEN ) ),
@@ -2051,7 +2117,7 @@ public:
                  mrColXFIndexes( rColXFIndexes ) {}
     virtual ~RowFinalizeTask() {}
     void     push_back( XclExpRow *pRow ) { maRows.push_back( pRow ); }
-    virtual void doWork() SAL_OVERRIDE
+    virtual void doWork() override
     {
         for (size_t i = 0; i < maRows.size(); i++ )
             maRows[ i ]->Finalize( mrColXFIndexes, mbProgress );
@@ -2081,7 +2147,7 @@ void XclExpRowBuffer::Finalize( XclExpDefaultRowData& rDefRowData, const ScfUInt
     else
     {
         comphelper::ThreadPool &rPool = comphelper::ThreadPool::getSharedOptimalPool();
-        std::vector<RowFinalizeTask*> pTasks(nThreads, NULL);
+        std::vector<RowFinalizeTask*> pTasks(nThreads, nullptr);
         for ( size_t i = 0; i < nThreads; i++ )
             pTasks[ i ] = new RowFinalizeTask( rColXFIndexes, i == 0 );
 
@@ -2107,7 +2173,7 @@ void XclExpRowBuffer::Finalize( XclExpDefaultRowData& rDefRowData, const ScfUInt
     XclExpDefaultRowData aMaxDefData;
     size_t nMaxDefCount = 0;
     // only look for default format in existing rows, if there are more than unused
-    XclExpRow* pPrev = NULL;
+    XclExpRow* pPrev = nullptr;
     typedef std::vector< XclExpRow* > XclRepeatedRows;
     XclRepeatedRows aRepeated;
     RowMap::iterator itr, itrBeg = maRowMap.begin(), itrEnd = maRowMap.end();
@@ -2453,7 +2519,7 @@ XclExpCellTable::XclExpCellTable( const XclExpRoot& rRoot ) :
             maRowBfr.AppendCell( xCell, bIsMergedBase );
 
         if ( !aAddNoteText.isEmpty()  )
-            mxNoteList->AppendNewRecord( new XclExpNote( GetRoot(), aScPos, NULL, aAddNoteText ) );
+            mxNoteList->AppendNewRecord( new XclExpNote( GetRoot(), aScPos, nullptr, aAddNoteText ) );
 
         // other sheet contents
         if( pPattern )
