@@ -20,12 +20,13 @@
 #include <comphelper/docpasswordhelper.hxx>
 #include <comphelper/sequenceashashmap.hxx>
 #include <osl/thread.h>
+#include <osl/diagnose.h>
 #include "xistream.hxx"
 #include "xlstring.hxx"
 #include "xiroot.hxx"
 
 #include <vector>
-#include <boost/scoped_array.hpp>
+#include <memory>
 
 using namespace ::com::sun::star;
 
@@ -93,7 +94,7 @@ sal_uInt16 XclImpDecrypter::Read( SvStream& rStrm, void* pData, sal_uInt16 nByte
         if( IsValid() )
         {
             Update( rStrm, mnRecSize );
-            nRet = OnRead( rStrm, reinterpret_cast< sal_uInt8* >( pData ), nBytes );
+            nRet = OnRead( rStrm, static_cast< sal_uInt8* >( pData ), nBytes );
             mnOldPos = rStrm.Tell();
         }
         else
@@ -134,7 +135,7 @@ uno::Sequence< beans::NamedValue > XclImpBiff5Decrypter::OnVerifyPassword( const
     if( (0 < nLen) && (nLen < 16) )
     {
         // init codec
-        maCodec.InitKey( (sal_uInt8*)aBytePassword.getStr() );
+        maCodec.InitKey( reinterpret_cast<sal_uInt8 const *>(aBytePassword.getStr()) );
 
         if ( maCodec.VerifyKey( mnKey, mnHash ) )
         {
@@ -150,7 +151,7 @@ uno::Sequence< beans::NamedValue > XclImpBiff5Decrypter::OnVerifyPassword( const
             OSL_ENSURE( aDocId.getLength() == 16, "Unexpected length of the senquence!" );
 
             ::msfilter::MSCodec_Std97 aCodec97;
-            aCodec97.InitKey( &aPassVect.front(), (sal_uInt8*)aDocId.getConstArray() );
+            aCodec97.InitKey( &aPassVect.front(), reinterpret_cast<sal_uInt8 const *>(aDocId.getConstArray()) );
 
             // merge the EncryptionData, there should be no conflicts
             ::comphelper::SequenceAsHashMap aEncryptionHash( maEncryptionData );
@@ -303,12 +304,12 @@ sal_uInt16 XclImpBiff8Decrypter::OnRead( SvStream& rStrm, sal_uInt8* pnData, sal
     return nRet;
 }
 
-sal_uInt32 XclImpBiff8Decrypter::GetBlock( sal_Size nStrmPos ) const
+sal_uInt32 XclImpBiff8Decrypter::GetBlock( sal_Size nStrmPos )
 {
     return static_cast< sal_uInt32 >( nStrmPos / EXC_ENCR_BLOCKSIZE );
 }
 
-sal_uInt16 XclImpBiff8Decrypter::GetOffset( sal_Size nStrmPos ) const
+sal_uInt16 XclImpBiff8Decrypter::GetOffset( sal_Size nStrmPos )
 {
     return static_cast< sal_uInt16 >( nStrmPos % EXC_ENCR_BLOCKSIZE );
 }
@@ -589,183 +590,116 @@ sal_uInt16 XclImpStream::PeekRecId( sal_Size nPos )
     return nRecId;
 }
 
-XclImpStream& XclImpStream::operator>>( sal_Int8& rnValue )
+sal_uInt8 XclImpStream::ReaduInt8()
 {
+    sal_uInt8 nValue = 0;
     if( EnsureRawReadSize( 1 ) )
     {
         if( mbUseDecr )
-            mxDecrypter->Read( mrStrm, &rnValue, 1 );
+            mxDecrypter->Read( mrStrm, &nValue, 1 );
         else
-            mrStrm.ReadSChar( rnValue );
+            mrStrm.ReadUChar( nValue );
         --mnRawRecLeft;
     }
-    return *this;
+    return nValue;
 }
 
-XclImpStream& XclImpStream::operator>>( sal_uInt8& rnValue )
-{
-    if( EnsureRawReadSize( 1 ) )
-    {
-        if( mbUseDecr )
-            mxDecrypter->Read( mrStrm, &rnValue, 1 );
-        else
-            mrStrm.ReadUChar( rnValue );
-        --mnRawRecLeft;
-    }
-    return *this;
-}
-
-XclImpStream& XclImpStream::operator>>( sal_Int16& rnValue )
+sal_Int16 XclImpStream::ReadInt16()
 {
+    sal_Int16 nValue = 0;
     if( EnsureRawReadSize( 2 ) )
     {
         if( mbUseDecr )
         {
             SVBT16 pnBuffer;
             mxDecrypter->Read( mrStrm, pnBuffer, 2 );
-            rnValue = static_cast< sal_Int16 >( SVBT16ToShort( pnBuffer ) );
+            nValue = static_cast< sal_Int16 >( SVBT16ToShort( pnBuffer ) );
         }
         else
-            mrStrm.ReadInt16( rnValue );
+            mrStrm.ReadInt16( nValue );
         mnRawRecLeft -= 2;
     }
-    return *this;
+    return nValue;
 }
 
-XclImpStream& XclImpStream::operator>>( sal_uInt16& rnValue )
+sal_uInt16 XclImpStream::ReaduInt16()
 {
+    sal_uInt16 nValue = 0;
     if( EnsureRawReadSize( 2 ) )
     {
         if( mbUseDecr )
         {
             SVBT16 pnBuffer;
             mxDecrypter->Read( mrStrm, pnBuffer, 2 );
-            rnValue = SVBT16ToShort( pnBuffer );
+            nValue = SVBT16ToShort( pnBuffer );
         }
         else
-            mrStrm.ReadUInt16( rnValue );
+            mrStrm.ReadUInt16( nValue );
         mnRawRecLeft -= 2;
     }
-    return *this;
+    return nValue;
 }
 
-XclImpStream& XclImpStream::operator>>( sal_Int32& rnValue )
+sal_Int32 XclImpStream::ReadInt32()
 {
+    sal_Int32 nValue = 0;
     if( EnsureRawReadSize( 4 ) )
     {
         if( mbUseDecr )
         {
             SVBT32 pnBuffer;
             mxDecrypter->Read( mrStrm, pnBuffer, 4 );
-            rnValue = static_cast< sal_Int32 >( SVBT32ToUInt32( pnBuffer ) );
+            nValue = static_cast< sal_Int32 >( SVBT32ToUInt32( pnBuffer ) );
         }
         else
-            mrStrm.ReadInt32( rnValue );
+            mrStrm.ReadInt32( nValue );
         mnRawRecLeft -= 4;
     }
-    return *this;
+    return nValue;
 }
 
-XclImpStream& XclImpStream::operator>>( sal_uInt32& rnValue )
+sal_uInt32 XclImpStream::ReaduInt32()
 {
+    sal_uInt32 nValue = 0;
     if( EnsureRawReadSize( 4 ) )
     {
         if( mbUseDecr )
         {
             SVBT32 pnBuffer;
             mxDecrypter->Read( mrStrm, pnBuffer, 4 );
-            rnValue = SVBT32ToUInt32( pnBuffer );
+            nValue = SVBT32ToUInt32( pnBuffer );
         }
         else
-            mrStrm.ReadUInt32( rnValue );
+            mrStrm.ReadUInt32( nValue );
         mnRawRecLeft -= 4;
     }
-    return *this;
+    return nValue;
 }
 
-XclImpStream& XclImpStream::operator>>( float& rfValue )
-{
-    if( EnsureRawReadSize( 4 ) )
-    {
-        if( mbUseDecr )
-        {
-            SVBT32 pnBuffer;
-            mxDecrypter->Read( mrStrm, pnBuffer, 4 );
-            sal_uInt32 nValue = SVBT32ToUInt32( pnBuffer );
-            memcpy( &rfValue, &nValue, 4 );
-        }
-        else
-            mrStrm.ReadFloat( rfValue );
-        mnRawRecLeft -= 4;
-    }
-    return *this;
-}
-
-XclImpStream& XclImpStream::operator>>( double& rfValue )
+double XclImpStream::ReadDouble()
 {
+    double nValue = 0;
     if( EnsureRawReadSize( 8 ) )
     {
         if( mbUseDecr )
         {
             SVBT64 pnBuffer;
             mxDecrypter->Read( mrStrm, pnBuffer, 8 );
-            rfValue = SVBT64ToDouble( pnBuffer );
+            nValue = SVBT64ToDouble( pnBuffer );
         }
         else
-            mrStrm.ReadDouble( rfValue );
+            mrStrm.ReadDouble( nValue );
         mnRawRecLeft -= 8;
     }
-    return *this;
-}
-
-sal_uInt8 XclImpStream::ReaduInt8()
-{
-    sal_uInt8 nValue(0);
-    operator>>( nValue );
     return nValue;
 }
 
-sal_Int16 XclImpStream::ReadInt16()
-{
-    sal_Int16 nValue(0);
-    operator>>( nValue );
-    return nValue;
-}
-
-sal_uInt16 XclImpStream::ReaduInt16()
-{
-    sal_uInt16 nValue(0);
-    operator>>( nValue );
-    return nValue;
-}
-
-sal_Int32 XclImpStream::ReadInt32()
-{
-    sal_Int32 nValue(0);
-    operator>>( nValue );
-    return nValue;
-}
-
-sal_uInt32 XclImpStream::ReaduInt32()
-{
-    sal_uInt32 nValue(0);
-    operator>>( nValue );
-    return nValue;
-}
-
-double XclImpStream::ReadDouble()
-{
-    double fValue(0.0);
-    operator>>( fValue );
-    return fValue;
-}
-
 sal_Size XclImpStream::Read( void* pData, sal_Size nBytes )
 {
     sal_Size nRet = 0;
     if( mbValid && pData && (nBytes > 0) )
     {
-        sal_uInt8* pnBuffer = reinterpret_cast< sal_uInt8* >( pData );
+        sal_uInt8* pnBuffer = static_cast< sal_uInt8* >( pData );
         sal_Size nBytesLeft = nBytes;
 
         while( mbValid && (nBytesLeft > 0) )
@@ -791,7 +725,7 @@ sal_Size XclImpStream::CopyToStream( SvStream& rOutStrm, sal_Size nBytes )
     if( mbValid && (nBytes > 0) )
     {
         const sal_Size nMaxBuffer = 4096;
-        boost::scoped_array<sal_uInt8> pnBuffer(new sal_uInt8[ ::std::min( nBytes, nMaxBuffer ) ]);
+        std::unique_ptr<sal_uInt8[]> pnBuffer(new sal_uInt8[ ::std::min( nBytes, nMaxBuffer ) ]);
         sal_Size nBytesLeft = nBytes;
 
         while( mbValid && (nBytesLeft > 0) )
@@ -880,7 +814,7 @@ OUString XclImpStream::ReadRawUniString( sal_uInt16 nChars, bool b16Bit )
     sal_uInt16 nCharsLeft = nChars;
     sal_uInt16 nReadSize;
 
-    boost::scoped_array<sal_Unicode> pcBuffer(new sal_Unicode[ nCharsLeft + 1 ]);
+    std::unique_ptr<sal_Unicode[]> pcBuffer(new sal_Unicode[ nCharsLeft + 1 ]);
 
     while( IsValid() && (nCharsLeft > 0) )
     {
@@ -901,7 +835,7 @@ OUString XclImpStream::ReadRawUniString( sal_uInt16 nChars, bool b16Bit )
             sal_uInt16 nReadChar;
             for( ; IsValid() && (pcUniChar < pcEndChar); ++pcUniChar )
             {
-                operator>>( nReadChar );
+                nReadChar = ReaduInt16();
                 (*pcUniChar) = (nReadChar == EXC_NUL) ? mcNulSubst : static_cast< sal_Unicode >( nReadChar );
             }
         }
@@ -910,7 +844,7 @@ OUString XclImpStream::ReadRawUniString( sal_uInt16 nChars, bool b16Bit )
             sal_uInt8 nReadChar;
             for( ; IsValid() && (pcUniChar < pcEndChar); ++pcUniChar )
             {
-                operator>>( nReadChar );
+                nReadChar = ReaduInt8();
                 (*pcUniChar) = (nReadChar == EXC_NUL_C) ? mcNulSubst : static_cast< sal_Unicode >( nReadChar );
             }
         }
@@ -986,7 +920,8 @@ void XclImpStream::IgnoreUniString( sal_uInt16 nChars )
 
 OUString XclImpStream::ReadRawByteString( sal_uInt16 nChars )
 {
-    boost::scoped_array<sal_Char> pcBuffer(new sal_Char[ nChars + 1 ]);
+    nChars = GetMaxRawReadSize(nChars);
+    std::unique_ptr<sal_Char[]> pcBuffer(new sal_Char[ nChars + 1 ]);
     sal_uInt16 nCharsRead = ReadRawData( pcBuffer.get(), nChars );
     pcBuffer[ nCharsRead ] = '\0';
     OUString aRet( pcBuffer.get(), strlen(pcBuffer.get()), mrRoot.GetTextEncoding() );
