@@ -26,10 +26,10 @@
 #include <com/sun/star/sheet/SingleReference.hpp>
 #include <com/sun/star/sheet/XFormulaTokens.hpp>
 #include <com/sun/star/sheet/XPrintAreas.hpp>
+#include <osl/diagnose.h>
 #include <rtl/ustrbuf.hxx>
-#include "oox/helper/attributelist.hxx"
-#include "oox/helper/containerhelper.hxx"
-#include "oox/helper/propertyset.hxx"
+#include <oox/helper/attributelist.hxx>
+#include <oox/helper/propertyset.hxx>
 #include "addressconverter.hxx"
 #include "biffinputstream.hxx"
 #include "externallinkbuffer.hxx"
@@ -37,19 +37,15 @@
 #include "worksheetbuffer.hxx"
 #include "tokenarray.hxx"
 #include "tokenuno.hxx"
+#include "compiler.hxx"
 
 namespace oox {
 namespace xls {
 
-// ============================================================================
-
 using namespace ::com::sun::star::sheet;
 using namespace ::com::sun::star::table;
 using namespace ::com::sun::star::uno;
 
-
-// ============================================================================
-
 namespace {
 
 const sal_uInt32 BIFF12_DEFNAME_HIDDEN      = 0x00000001;
@@ -63,8 +59,6 @@ const sal_uInt16 BIFF_REFFLAG_ROW1REL       = 0x0002;
 const sal_uInt16 BIFF_REFFLAG_COL2REL       = 0x0004;
 const sal_uInt16 BIFF_REFFLAG_ROW2REL       = 0x0008;
 
-// ----------------------------------------------------------------------------
-
 const sal_Char* const spcOoxPrefix = "_xlnm.";
 
 const sal_Char* const sppcBaseNames[] =
@@ -87,9 +81,9 @@ const sal_Char* const sppcBaseNames[] =
 
 OUString lclGetBaseName( sal_Unicode cBuiltinId )
 {
-    OSL_ENSURE( cBuiltinId < STATIC_ARRAY_SIZE( sppcBaseNames ), "lclGetBaseName - unsupported built-in identifier" );
+    OSL_ENSURE( cBuiltinId < SAL_N_ELEMENTS( sppcBaseNames ), "lclGetBaseName - unsupported built-in identifier" );
     OUStringBuffer aBuffer;
-    if( cBuiltinId < STATIC_ARRAY_SIZE( sppcBaseNames ) )
+    if( cBuiltinId < SAL_N_ELEMENTS( sppcBaseNames ) )
         aBuffer.appendAscii( sppcBaseNames[ cBuiltinId ] );
     else
         aBuffer.append( static_cast< sal_Int32 >( cBuiltinId ) );
@@ -101,14 +95,14 @@ OUString lclGetPrefixedName( sal_Unicode cBuiltinId )
     return OUStringBuffer().appendAscii( spcOoxPrefix ).append( lclGetBaseName( cBuiltinId ) ).makeStringAndClear();
 }
 
-/** returns the built-in name identifier from a perfixed built-in name, e.g. '_xlnm.Print_Area'. */
+/** returns the built-in name identifier from a prefixed built-in name, e.g. '_xlnm.Print_Area'. */
 sal_Unicode lclGetBuiltinIdFromPrefixedName( const OUString& rModelName )
 {
     OUString aPrefix = OUString::createFromAscii( spcOoxPrefix );
     sal_Int32 nPrefixLen = aPrefix.getLength();
     if( rModelName.matchIgnoreAsciiCase( aPrefix ) )
     {
-        for( sal_Unicode cBuiltinId = 0; cBuiltinId < STATIC_ARRAY_SIZE( sppcBaseNames ); ++cBuiltinId )
+        for( sal_Unicode cBuiltinId = 0; cBuiltinId < SAL_N_ELEMENTS( sppcBaseNames ); ++cBuiltinId )
         {
             OUString aBaseName = lclGetBaseName( cBuiltinId );
             sal_Int32 nBaseNameLen = aBaseName.getLength();
@@ -122,7 +116,7 @@ sal_Unicode lclGetBuiltinIdFromPrefixedName( const OUString& rModelName )
 /** returns the built-in name identifier from a built-in base name, e.g. 'Print_Area'. */
 sal_Unicode lclGetBuiltinIdFromBaseName( const OUString& rModelName )
 {
-    for( sal_Unicode cBuiltinId = 0; cBuiltinId < STATIC_ARRAY_SIZE( sppcBaseNames ); ++cBuiltinId )
+    for( sal_Unicode cBuiltinId = 0; cBuiltinId < SAL_N_ELEMENTS( sppcBaseNames ); ++cBuiltinId )
         if( rModelName.equalsIgnoreAsciiCaseAscii( sppcBaseNames[ cBuiltinId ] ) )
             return cBuiltinId;
     return BIFF_DEFNAME_UNKNOWN;
@@ -183,8 +177,6 @@ Any lclConvertReference( const Any& rRefAny, const CellAddress& rBaseAddr, sal_u
 
 } // namespace
 
-// ============================================================================
-
 DefinedNameModel::DefinedNameModel() :
     mnSheet( -1 ),
     mnFuncGroupId( -1 ),
@@ -195,8 +187,6 @@ DefinedNameModel::DefinedNameModel() :
 {
 }
 
-// ============================================================================
-
 DefinedNameBase::DefinedNameBase( const WorkbookHelper& rHelper ) :
     WorkbookHelper( rHelper )
 {
@@ -237,33 +227,12 @@ Any DefinedNameBase::getReference( const CellAddress& rBaseAddr ) const
     return Any();
 }
 
-ApiTokenSequence DefinedNameBase::importOoxFormula( sal_Int16 nBaseSheet )
-{
-    return (!maModel.maFormula.isEmpty()) ?
-        getFormulaParser().importFormula( CellAddress( nBaseSheet, 0, 0 ), maModel.maFormula ) :
-        getFormulaParser().convertErrorToFormula( BIFF_ERR_NAME );
-}
-
-ApiTokenSequence DefinedNameBase::importBiff12Formula( sal_Int16 nBaseSheet, SequenceInputStream& rStrm )
-{
-    return getFormulaParser().importFormula( CellAddress( nBaseSheet, 0, 0 ), FORMULATYPE_DEFINEDNAME, rStrm );
-}
-
-ApiTokenSequence DefinedNameBase::importBiffFormula( sal_Int16 nBaseSheet, BiffInputStream& rStrm, const sal_uInt16* pnFmlaSize )
-{
-    return (!pnFmlaSize || (*pnFmlaSize > 0)) ?
-        getFormulaParser().importFormula( CellAddress( nBaseSheet, 0, 0 ), FORMULATYPE_DEFINEDNAME, rStrm, pnFmlaSize ) :
-        getFormulaParser().convertErrorToFormula( BIFF_ERR_NAME );
-}
-
-// ============================================================================
-
 DefinedName::DefinedName( const WorkbookHelper& rHelper ) :
     DefinedNameBase( rHelper ),
-    mpScRangeData(NULL),
+    mpScRangeData(nullptr),
     mnTokenIndex( -1 ),
-    mcBuiltinId( BIFF_DEFNAME_UNKNOWN ),
-    mnFmlaSize( 0 )
+    mnCalcSheet( 0 ),
+    mcBuiltinId( BIFF_DEFNAME_UNKNOWN )
 {
 }
 
@@ -279,7 +248,7 @@ void DefinedName::importDefinedName( const AttributeList& rAttribs )
     mnCalcSheet = (maModel.mnSheet >= 0) ? getWorksheets().getCalcSheetIndex( maModel.mnSheet ) : -1;
 
     /*  Detect built-in state from name itself, there is no built-in flag.
-        Built-in names are prexixed with '_xlnm.' instead. */
+        Built-in names are prefixed with '_xlnm.' instead. */
     mcBuiltinId = lclGetBuiltinIdFromPrefixedName( maModel.maName );
 }
 
@@ -291,9 +260,10 @@ void DefinedName::setFormula( const OUString& rFormula )
 void DefinedName::importDefinedName( SequenceInputStream& rStrm )
 {
     sal_uInt32 nFlags;
-    rStrm >> nFlags;
+    nFlags = rStrm.readuInt32();
     rStrm.skip( 1 );    // keyboard shortcut
-    rStrm >> maModel.mnSheet >> maModel.maName;
+    maModel.mnSheet = rStrm.readInt32();
+    rStrm >> maModel.maName;
     mnCalcSheet = (maModel.mnSheet >= 0) ? getWorksheets().getCalcSheetIndex( maModel.mnSheet ) : -1;
 
     // macro function/command, hidden flag
@@ -355,40 +325,21 @@ void DefinedName::createNameObject( sal_Int32 nIndex )
     mnTokenIndex = nIndex;
 }
 
-ApiTokenSequence
-DefinedName::getTokens()
+std::unique_ptr<ScTokenArray> DefinedName::getScTokens()
 {
-    // convert and set formula of the defined name
-    ApiTokenSequence aTokens;
-    switch( getFilterType() )
-    {
-        case FILTER_OOXML:
-        {
-            if( mxFormula.get() )
-            {
-                SequenceInputStream aStrm( *mxFormula );
-                aTokens = importBiff12Formula( mnCalcSheet, aStrm );
-            }
-            else
-                aTokens = importOoxFormula( mnCalcSheet );
-        }
-        break;
-        case FILTER_BIFF:
-        {
-            OSL_ENSURE( mxBiffStrm.get(), "DefinedName::convertFormula - missing BIFF stream" );
-            if( mxBiffStrm.get() )
-            {
-                BiffInputStream& rStrm = mxBiffStrm->getStream();
-                BiffInputStreamPosGuard aStrmGuard( rStrm );
-                if( mxBiffStrm->restorePosition() )
-                    aTokens = importBiffFormula( mnCalcSheet, rStrm, &mnFmlaSize );
-            }
-        }
-        break;
-        case FILTER_UNKNOWN:
-        break;
-    }
-    return aTokens;
+    ScTokenArray aTokenArray;
+    ScCompiler aCompiler(&getScDocument(), ScAddress(0, 0, mnCalcSheet));
+    aCompiler.SetGrammar(formula::FormulaGrammar::GRAM_OOXML);
+    std::unique_ptr<ScTokenArray> pArray(aCompiler.CompileString(maModel.maFormula));
+    // Compile the tokens into RPN once to populate information into tokens
+    // where necessary, e.g. for TableRef inner reference. RPN can be discarded
+    // after, a resulting error must be reset.
+    sal_uInt16 nErr = pArray->GetCodeError();
+    aCompiler.CompileTokenArray();
+    pArray->DelRPN();
+    pArray->SetCodeError(nErr);
+
+    return pArray;
 }
 
 void DefinedName::convertFormula()
@@ -400,10 +351,8 @@ void DefinedName::convertFormula()
     // convert and set formula of the defined name
     if ( getFilterType() == FILTER_OOXML )
     {
-        ApiTokenSequence aTokens = getTokens();
-        ScTokenArray aTokenArray;
-        (void)ScTokenConversion::ConvertToTokenArray( this->getScDocument(), aTokenArray, aTokens );
-        mpScRangeData->SetCode( aTokenArray );
+        std::unique_ptr<ScTokenArray> pTokenArray = getScTokens();
+        mpScRangeData->SetCode( *pTokenArray );
     }
 
     ScTokenArray* pTokenArray = mpScRangeData->GetCode();
@@ -418,7 +367,7 @@ void DefinedName::convertFormula()
             ApiCellRangeList aPrintRanges;
             getFormulaParser().extractCellRangeList( aPrintRanges, aFTokenSeq, false, mnCalcSheet );
             if( xPrintAreas.is() && !aPrintRanges.empty() )
-                xPrintAreas->setPrintAreas( ContainerHelper::vectorToSequence( aPrintRanges ) );
+                xPrintAreas->setPrintAreas( aPrintRanges.toSequence() );
         }
         break;
         case BIFF_DEFNAME_PRINTTITLES:
@@ -431,7 +380,7 @@ void DefinedName::convertFormula()
                 bool bHasRowTitles = false;
                 bool bHasColTitles = false;
                 const CellAddress& rMaxPos = getAddressConverter().getMaxAddress();
-                for( ApiCellRangeList::const_iterator aIt = aTitleRanges.begin(), aEnd = aTitleRanges.end(); (aIt != aEnd) && (!bHasRowTitles || !bHasColTitles); ++aIt )
+                for( ::std::vector< CellRangeAddress >::const_iterator aIt = aTitleRanges.begin(), aEnd = aTitleRanges.end(); (aIt != aEnd) && (!bHasRowTitles || !bHasColTitles); ++aIt )
                 {
                     bool bFullRow = (aIt->StartColumn == 0) && (aIt->EndColumn >= rMaxPos.Column);
                     bool bFullCol = (aIt->StartRow == 0) && (aIt->EndRow >= rMaxPos.Row);
@@ -462,8 +411,6 @@ bool DefinedName::getAbsoluteRange( CellRangeAddress& orRange ) const
     return getFormulaParser().extractCellRange( orRange, aFTokenSeq, false );
 }
 
-// ============================================================================
-
 DefinedNamesBuffer::DefinedNamesBuffer( const WorkbookHelper& rHelper ) :
     WorkbookHelper( rHelper )
 {
@@ -537,8 +484,6 @@ DefinedNameRef DefinedNamesBuffer::createDefinedName()
     return xDefName;
 }
 
-// ============================================================================
-
 } // namespace xls
 } // namespace oox
 
