@@ -66,7 +66,6 @@ const sal_uInt16 BIFF12_EXTNAME_ICONIFIED   = 0x0020;
 } // namespace
 
 ExternalNameModel::ExternalNameModel() :
-    mbBuiltIn( false ),
     mbNotify( false ),
     mbPreferPic( false ),
     mbStdDocName( false ),
@@ -125,7 +124,8 @@ void ExternalName::importExternalNameFlags( SequenceInputStream& rStrm )
 {
     sal_uInt16 nFlags;
     sal_Int32 nSheetId;
-    rStrm >> nFlags >> nSheetId;
+    nFlags = rStrm.readuInt16();
+    nSheetId = rStrm.readInt32();
     // index into sheet list of EXTSHEETNAMES (one-based in BIFF12)
     maModel.mnSheet = nSheetId - 1;
     // no flag for built-in names, as in OOXML...
@@ -141,7 +141,8 @@ void ExternalName::importExternalNameFlags( SequenceInputStream& rStrm )
 void ExternalName::importDdeItemValues( SequenceInputStream& rStrm )
 {
     sal_Int32 nRows, nCols;
-    rStrm >> nRows >> nCols;
+    nRows = rStrm.readInt32();
+    nCols = rStrm.readInt32();
     setResultSize( nCols, nRows );
 }
 
@@ -225,7 +226,7 @@ bool ExternalName::getDdeLinkData( OUString& orDdeServer, OUString& orDdeTopic,
         {
             PropertySet aDocProps( getDocument() );
             Reference< XDDELinks > xDdeLinks( aDocProps.getAnyProperty( PROP_DDELinks ), UNO_QUERY_THROW );
-            mxDdeLink = xDdeLinks->addDDELink( mrParentLink.getClassName(), mrParentLink.getTargetUrl(), maModel.maName, ::com::sun::star::sheet::DDELinkMode_DEFAULT );
+            mxDdeLink = xDdeLinks->addDDELink( mrParentLink.getClassName(), mrParentLink.getTargetUrl(), maModel.maName, css::sheet::DDELinkMode_DEFAULT );
             mbDdeLinkCreated = true;    // ignore if setting results fails
             if( !maResults.empty() )
             {
@@ -426,19 +427,19 @@ ExternalLinkInfo ExternalLink::getLinkInfo() const
         case LINKTYPE_SELF:
         case LINKTYPE_SAME:
         case LINKTYPE_INTERNAL:
-            aLinkInfo.Type = ::com::sun::star::sheet::ExternalLinkType::SELF;
+            aLinkInfo.Type = css::sheet::ExternalLinkType::SELF;
         break;
         case LINKTYPE_EXTERNAL:
-            aLinkInfo.Type = ::com::sun::star::sheet::ExternalLinkType::DOCUMENT;
+            aLinkInfo.Type = css::sheet::ExternalLinkType::DOCUMENT;
             aLinkInfo.Data <<= maTargetUrl;
         break;
         case LINKTYPE_LIBRARY:
             // parser will return library function names in OPCODE_BAD string tokens
-            aLinkInfo.Type = ::com::sun::star::sheet::ExternalLinkType::SPECIAL;
+            aLinkInfo.Type = css::sheet::ExternalLinkType::SPECIAL;
         break;
         case LINKTYPE_DDE:
         {
-            aLinkInfo.Type = ::com::sun::star::sheet::ExternalLinkType::DDE;
+            aLinkInfo.Type = css::sheet::ExternalLinkType::DDE;
             DDELinkInfo aDdeLinkInfo;
             aDdeLinkInfo.Service = maClassName;
             aDdeLinkInfo.Topic = maTargetUrl;
@@ -452,7 +453,7 @@ ExternalLinkInfo ExternalLink::getLinkInfo() const
         }
         break;
         default:
-            aLinkInfo.Type = ::com::sun::star::sheet::ExternalLinkType::UNKNOWN;
+            aLinkInfo.Type = css::sheet::ExternalLinkType::UNKNOWN;
     }
     return aLinkInfo;
 }
@@ -488,7 +489,7 @@ Reference< XExternalSheetCache > ExternalLink::getSheetCache( sal_Int32 nTabId )
     catch( Exception& )
     {
     }
-    return 0;
+    return nullptr;
 }
 
 void ExternalLink::getSheetRange( LinkSheetRange& orSheetRange, sal_Int32 nTabId1, sal_Int32 nTabId2 ) const
@@ -565,7 +566,7 @@ void ExternalLink::setExternalTargetUrl( const OUString& rTargetUrl, const OUStr
     else if( rTargetType == CREATE_MSOFFICE_RELATION_TYPE( "xlExternalLinkPath/xlLibrary" ) )
     {
         meLinkType = LINKTYPE_LIBRARY;
-        meFuncLibType = getFormulaParser().getFuncLibTypeFromLibraryName( rTargetUrl );
+        meFuncLibType = FunctionProvider::getFuncLibTypeFromLibraryName( rTargetUrl );
     }
     OSL_ENSURE( meLinkType != LINKTYPE_UNKNOWN, "ExternalLink::setExternalTargetUrl - empty target URL or unknown target type" );
 
@@ -622,7 +623,9 @@ RefSheetsModel::RefSheetsModel() :
 
 void RefSheetsModel::readBiff12Data( SequenceInputStream& rStrm )
 {
-    rStrm >> mnExtRefId >> mnTabId1 >> mnTabId2;
+    mnExtRefId = rStrm.readInt32();
+    mnTabId1 = rStrm.readInt32();
+    mnTabId2 = rStrm.readInt32();
 }
 
 ExternalLinkBuffer::ExternalLinkBuffer( const WorkbookHelper& rHelper ) :
@@ -675,7 +678,7 @@ void ExternalLinkBuffer::importExternalSheets( SequenceInputStream& rStrm )
     OSL_ENSURE( maRefSheets.empty(), "ExternalLinkBuffer::importExternalSheets - multiple EXTERNALSHEETS records" );
     maRefSheets.clear();
     sal_Int32 nRefCount;
-    rStrm >> nRefCount;
+    nRefCount = rStrm.readInt32();
     size_t nMaxCount = getLimitedValue< size_t, sal_Int64 >( nRefCount, 0, rStrm.getRemaining() / 12 );
     maRefSheets.reserve( nMaxCount );
     for( size_t nRefId = 0; !rStrm.isEof() && (nRefId < nMaxCount); ++nRefId )
@@ -778,7 +781,7 @@ ExternalLinkRef ExternalLinkBuffer::createExternalLink()
 const RefSheetsModel* ExternalLinkBuffer::getRefSheets( sal_Int32 nRefId ) const
 {
     return ((0 <= nRefId) && (static_cast< size_t >( nRefId ) < maRefSheets.size())) ?
-        &maRefSheets[ static_cast< size_t >( nRefId ) ] : 0;
+        &maRefSheets[ static_cast< size_t >( nRefId ) ] : nullptr;
 }
 
 } // namespace xls
