@@ -38,10 +38,10 @@
 #include <com/sun/star/sheet/XDataPilotField.hpp>
 #include <com/sun/star/sheet/XDataPilotTablesSupplier.hpp>
 #include <com/sun/star/sheet/XSheetOperation.hpp>
-#include "oox/helper/attributelist.hxx"
-#include "oox/helper/containerhelper.hxx"
-#include "oox/helper/propertyset.hxx"
-#include "oox/token/properties.hxx"
+#include <oox/helper/attributelist.hxx>
+#include <oox/helper/containerhelper.hxx>
+#include <oox/helper/propertyset.hxx>
+#include <oox/token/properties.hxx>
 #include "addressconverter.hxx"
 #include "biffinputstream.hxx"
 
@@ -52,17 +52,12 @@
 namespace oox {
 namespace xls {
 
-// ============================================================================
-
 using namespace ::com::sun::star::container;
 using namespace ::com::sun::star::sheet;
 using namespace ::com::sun::star::table;
 using namespace ::com::sun::star::uno;
 using namespace com::sun::star;
 
-
-// ============================================================================
-
 namespace {
 
 const sal_Int32 OOX_PT_DATALAYOUTFIELD              = -2;           /// Placeholder index of data layout field.
@@ -70,8 +65,6 @@ const sal_Int32 OOX_PT_DATALAYOUTFIELD              = -2;           /// Placehol
 const sal_Int32 OOX_PT_PREVIOUS_ITEM                = 0x001000FC;   /// Calculation of data item result is based on previous item.
 const sal_Int32 OOX_PT_NEXT_ITEM                    = 0x001000FD;   /// Calculation of data item result is based on next item.
 
-// ----------------------------------------------------------------------------
-
 const sal_uInt32 BIFF12_PTFIELD_DATAFIELD           = 0x00000008;
 const sal_uInt32 BIFF12_PTFIELD_DEFAULT             = 0x00000100;
 const sal_uInt32 BIFF12_PTFIELD_SUM                 = 0x00000200;
@@ -158,8 +151,6 @@ const sal_uInt8 BIFF12_PTDEF_COLAXIS                = 2;
 
 } // namespace
 
-// ============================================================================
-
 PTFieldItemModel::PTFieldItemModel() :
     mnCacheItem( -1 ),
     mnType( XML_data ),
@@ -176,8 +167,6 @@ void PTFieldItemModel::setBiffType( sal_uInt16 nType )
     mnType = STATIC_ARRAY_SELECT( spnTypes, nType, XML_data );
 }
 
-// ----------------------------------------------------------------------------
-
 PTFieldModel::PTFieldModel() :
     mnAxis( XML_TOKEN_INVALID ),
     mnNumFmtId( 0 ),
@@ -224,16 +213,12 @@ void PTFieldModel::setBiffAxis( sal_uInt8 nAxis )
     mnAxis = STATIC_ARRAY_SELECT( spnAxisIds, nAxis, XML_TOKEN_INVALID );
 }
 
-// ----------------------------------------------------------------------------
-
 PTPageFieldModel::PTPageFieldModel() :
     mnField( -1 ),
     mnItem( BIFF12_PTPAGEFIELD_MULTIITEMS )
 {
 }
 
-// ----------------------------------------------------------------------------
-
 PTDataFieldModel::PTDataFieldModel() :
     mnField( -1 ),
     mnSubtotal( XML_sum ),
@@ -256,8 +241,6 @@ void PTDataFieldModel::setBiffShowDataAs( sal_Int32 nShowDataAs )
     mnShowDataAs = STATIC_ARRAY_SELECT( spnShowDataAs, nShowDataAs, XML_TOKEN_INVALID );
 }
 
-// ----------------------------------------------------------------------------
-
 PivotTableField::PivotTableField( PivotTable& rPivotTable, sal_Int32 nFieldIndex ) :
     WorkbookHelper( rPivotTable ),
     mrPivotTable( rPivotTable ),
@@ -325,7 +308,11 @@ void PivotTableField::importReferenceItem( const AttributeList& rAttribs )
 void PivotTableField::importPTField( SequenceInputStream& rStrm )
 {
     sal_uInt32 nFlags1, nFlags2;
-    rStrm >> nFlags1 >> maModel.mnNumFmtId >> nFlags2 >> maModel.mnAutoShowItems >> maModel.mnAutoShowRankBy;
+    nFlags1 = rStrm.readuInt32();
+    maModel.mnNumFmtId = rStrm.readInt32();
+    nFlags2 = rStrm.readuInt32();
+    maModel.mnAutoShowItems = rStrm.readInt32();
+    maModel.mnAutoShowRankBy = rStrm.readInt32();
 
     maModel.setBiffAxis( extractValue< sal_uInt8 >( nFlags1, 0, 3 ) );
     maModel.mbDataField       = getFlag( nFlags1, BIFF12_PTFIELD_DATAFIELD );
@@ -361,7 +348,9 @@ void PivotTableField::importPTFItem( SequenceInputStream& rStrm )
     PTFieldItemModel aModel;
     sal_uInt8 nType;
     sal_uInt16 nFlags;
-    rStrm >> nType >> nFlags >> aModel.mnCacheItem;
+    nType = rStrm.readuChar();
+    nFlags = rStrm.readuInt16();
+    aModel.mnCacheItem = rStrm.readInt32();
 
     aModel.setBiffType( nType );
     aModel.mbShowDetails = !getFlag( nFlags, BIFF12_PTFITEM_HIDEDETAILS );
@@ -372,12 +361,12 @@ void PivotTableField::importPTFItem( SequenceInputStream& rStrm )
 
 void PivotTableField::importPTReference( SequenceInputStream& rStrm )
 {
-    rStrm >> maModel.mnSortRefField;
+    maModel.mnSortRefField = rStrm.readInt32();
 }
 
 void PivotTableField::importPTReferenceItem( SequenceInputStream& rStrm )
 {
-    rStrm >> maModel.mnSortRefItem;
+    maModel.mnSortRefItem = rStrm.readInt32();
 }
 
 void PivotTableField::finalizeImport( const Reference< XDataPilotDescriptor >& rxDPDesc )
@@ -698,7 +687,7 @@ Reference< XDataPilotField > PivotTableField::convertRowColPageField( sal_Int32
             else
             {
                 const PivotCacheField* pCacheField = (maModel.mnSortRefField == OOX_PT_DATALAYOUTFIELD) ?
-                    mrPivotTable.getCacheFieldOfDataField( maModel.mnSortRefItem ) : 0;
+                    mrPivotTable.getCacheFieldOfDataField( maModel.mnSortRefItem ) : nullptr;
                 if( pCacheField )
                 {
                     aSortInfo.Mode = DataPilotFieldSortMode::DATA;
@@ -747,8 +736,6 @@ Reference< XDataPilotField > PivotTableField::convertRowColPageField( sal_Int32
     return xDPField;
 }
 
-// ============================================================================
-
 PTFilterModel::PTFilterModel() :
     mfValue( 0.0 ),
     mnField( -1 ),
@@ -762,8 +749,6 @@ PTFilterModel::PTFilterModel() :
 {
 }
 
-// ----------------------------------------------------------------------------
-
 PivotTableFilter::PivotTableFilter( const PivotTable& rPivotTable ) :
     WorkbookHelper( rPivotTable ),
     mrPivotTable( rPivotTable )
@@ -797,9 +782,14 @@ void PivotTableFilter::importPTFilter( SequenceInputStream& rStrm )
 {
     sal_Int32 nType;
     sal_uInt16 nFlags;
-    rStrm >> maModel.mnField >> maModel.mnMemPropField >> nType;
+    maModel.mnField = rStrm.readInt32();
+    maModel.mnMemPropField = rStrm.readInt32();
+    nType = rStrm.readInt32();
     rStrm.skip( 4 );    // unused
-    rStrm >> maModel.mnId >> maModel.mnMeasureField >> maModel.mnMeasureHier >> nFlags;
+    maModel.mnId = rStrm.readInt32();
+    maModel.mnMeasureField = rStrm.readInt32();
+    maModel.mnMeasureHier = rStrm.readInt32();
+    nFlags = rStrm.readuInt16();
     if( getFlag( nFlags, BIFF12_PTFILTER_HASNAME ) )
         rStrm >> maModel.maName;
     if( getFlag( nFlags, BIFF12_PTFILTER_HASDESCRIPTION ) )
@@ -836,7 +826,8 @@ void PivotTableFilter::importPTFilter( SequenceInputStream& rStrm )
 void PivotTableFilter::importTop10Filter( SequenceInputStream& rStrm )
 {
     sal_uInt8 nFlags;
-    rStrm >> nFlags >> maModel.mfValue;
+    nFlags = rStrm.readuChar();
+    maModel.mfValue = rStrm.readDouble();
 
     SAL_WARN_IF(
         getFlag(nFlags, BIFF12_TOP10FILTER_PERCENT) != (maModel.mnType == XML_percent),
@@ -865,16 +856,12 @@ void PivotTableFilter::finalizeImport()
     }
 }
 
-// ============================================================================
-
 PTDefinitionModel::PTDefinitionModel() :
     mnCacheId( -1 ),
     mnDataPosition( 0 ),
     mnPageWrap( 0 ),
     mnIndent( 1 ),
     mnChartFormat( 0 ),
-    mnRowFields( 0 ),
-    mnColFields( 0 ),
     mbDataOnRows( false ),
     mbShowError( false ),
     mbShowMissing( true ),
@@ -902,8 +889,6 @@ PTDefinitionModel::PTDefinitionModel() :
 {
 }
 
-// ----------------------------------------------------------------------------
-
 PTLocationModel::PTLocationModel() :
     mnFirstHeaderRow( 0 ),
     mnFirstDataRow( 0 ),
@@ -913,13 +898,11 @@ PTLocationModel::PTLocationModel() :
 {
 }
 
-// ----------------------------------------------------------------------------
-
 PivotTable::PivotTable( const WorkbookHelper& rHelper ) :
     WorkbookHelper( rHelper ),
-    mpDPObject(NULL),
+    mpDPObject(nullptr),
     maDataField( *this, OOX_PT_DATALAYOUTFIELD ),
-    mpPivotCache( 0 )
+    mpPivotCache( nullptr )
 {
 }
 
@@ -977,7 +960,7 @@ void PivotTable::importPivotTableDefinition( const AttributeList& rAttribs )
 
 void PivotTable::importLocation( const AttributeList& rAttribs, sal_Int16 nSheet )
 {
-    getAddressConverter().convertToCellRangeUnchecked( maLocationModel.maRange, rAttribs.getString( XML_ref, OUString() ), nSheet );
+    AddressConverter::convertToCellRangeUnchecked( maLocationModel.maRange, rAttribs.getString( XML_ref, OUString() ), nSheet );
     maLocationModel.mnFirstHeaderRow = rAttribs.getInteger( XML_firstHeaderRow, 0 );
     maLocationModel.mnFirstDataRow   = rAttribs.getInteger( XML_firstDataRow, 0 );
     maLocationModel.mnFirstDataCol   = rAttribs.getInteger( XML_firstDataCol, 0 );
@@ -1022,13 +1005,18 @@ void PivotTable::importPTDefinition( SequenceInputStream& rStrm )
 {
     sal_uInt32 nFlags1, nFlags2, nFlags3;
     sal_uInt8 nDataAxis;
-    rStrm >> nFlags1 >> nFlags2 >> nFlags3 >> nDataAxis;
+    nFlags1 = rStrm.readuInt32();
+    nFlags2 = rStrm.readuInt32();
+    nFlags3 = rStrm.readuInt32();
+    nDataAxis = rStrm.readuChar();
     maDefModel.mnPageWrap = rStrm.readuInt8();
     rStrm.skip( 2 );    // refresh versions
-    rStrm >> maDefModel.mnDataPosition;
+    maDefModel.mnDataPosition = rStrm.readInt32();
     maDefModel.mnAutoFormatId = rStrm.readuInt16();
     rStrm.skip( 2 );    // unused
-    rStrm >> maDefModel.mnChartFormat >> maDefModel.mnCacheId >> maDefModel.maName;
+    maDefModel.mnChartFormat = rStrm.readInt32();
+    maDefModel.mnCacheId = rStrm.readInt32();
+    rStrm >> maDefModel.maName;
     if( getFlag( nFlags2, BIFF12_PTDEF_HASDATACAPTION ) )
         rStrm >> maDefModel.maDataCaption;
     if( getFlag( nFlags2, BIFF12_PTDEF_HASGRANDTOTALCAPTION ) )
@@ -1091,10 +1079,13 @@ void PivotTable::importPTDefinition( SequenceInputStream& rStrm )
 void PivotTable::importPTLocation( SequenceInputStream& rStrm, sal_Int16 nSheet )
 {
     BinRange aBinRange;
-    rStrm   >> aBinRange >> maLocationModel.mnFirstHeaderRow
-            >> maLocationModel.mnFirstDataRow >> maLocationModel.mnFirstDataCol
-            >> maLocationModel.mnRowPageCount >> maLocationModel.mnColPageCount;
-    getAddressConverter().convertToCellRangeUnchecked( maLocationModel.maRange, aBinRange, nSheet );
+    rStrm >> aBinRange;
+    maLocationModel.mnFirstHeaderRow = rStrm.readInt32();
+    maLocationModel.mnFirstDataRow = rStrm.readInt32();
+    maLocationModel.mnFirstDataCol = rStrm.readInt32();
+    maLocationModel.mnRowPageCount = rStrm.readInt32();
+    maLocationModel.mnColPageCount = rStrm.readInt32();
+    AddressConverter::convertToCellRangeUnchecked( maLocationModel.maRange, aBinRange, nSheet );
 }
 
 void PivotTable::importPTRowFields( SequenceInputStream& rStrm )
@@ -1111,9 +1102,10 @@ void PivotTable::importPTPageField( SequenceInputStream& rStrm )
 {
     PTPageFieldModel aModel;
     sal_uInt8 nFlags;
-    rStrm >> aModel.mnField >> aModel.mnItem;
+    aModel.mnField = rStrm.readInt32();
+    aModel.mnItem = rStrm.readInt32();
     rStrm.skip( 4 );    // hierarchy
-    rStrm >> nFlags;
+    nFlags = rStrm.readuChar();
     if( getFlag( nFlags, BIFF12_PTPAGEFIELD_HASNAME ) )
         rStrm >> aModel.maName;
     maPageFields.push_back( aModel );
@@ -1124,7 +1116,13 @@ void PivotTable::importPTDataField( SequenceInputStream& rStrm )
     PTDataFieldModel aModel;
     sal_Int32 nSubtotal, nShowDataAs;
     sal_uInt8 nHasName;
-    rStrm >> aModel.mnField >> nSubtotal >> nShowDataAs >> aModel.mnBaseField >> aModel.mnBaseItem >> aModel.mnNumFmtId >> nHasName;
+    aModel.mnField = rStrm.readInt32(  );
+    nSubtotal = rStrm.readInt32();
+    nShowDataAs = rStrm.readInt32();
+    aModel.mnBaseField = rStrm.readInt32();
+    aModel.mnBaseItem = rStrm.readInt32();
+    aModel.mnNumFmtId = rStrm.readInt32();
+    nHasName = rStrm.readuChar();
     if( nHasName == 1 )
         rStrm >> aModel.maName;
     aModel.setBiffSubtotal( nSubtotal );
@@ -1303,13 +1301,13 @@ Reference< XDataPilotField > PivotTable::getDataLayoutField() const
 
 const PivotCacheField* PivotTable::getCacheField( sal_Int32 nFieldIdx ) const
 {
-    return mpPivotCache ? mpPivotCache->getCacheField( nFieldIdx ) : 0;
+    return mpPivotCache ? mpPivotCache->getCacheField( nFieldIdx ) : nullptr;
 }
 
 const PivotCacheField* PivotTable::getCacheFieldOfDataField( sal_Int32 nDataItemIdx ) const
 {
     const PTDataFieldModel* pDataField = ContainerHelper::getVectorElement( maDataFields, nDataItemIdx );
-    return pDataField ? getCacheField( pDataField->mnField ) : 0;
+    return pDataField ? getCacheField( pDataField->mnField ) : nullptr;
 }
 
 sal_Int32 PivotTable::getCacheDatabaseIndex( sal_Int32 nFieldIdx ) const
@@ -1317,11 +1315,6 @@ sal_Int32 PivotTable::getCacheDatabaseIndex( sal_Int32 nFieldIdx ) const
     return mpPivotCache ? mpPivotCache->getCacheDatabaseIndex( nFieldIdx ) : -1;
 }
 
-ScDPObject* PivotTable::getDPObject()
-{
-    return mpDPObject;
-}
-
 // private --------------------------------------------------------------------
 
 PivotTableField* PivotTable::getTableField( sal_Int32 nFieldIdx )
@@ -1345,8 +1338,6 @@ void PivotTable::importFields( IndexVector& orFields, SequenceInputStream& rStrm
         orFields.push_back( rStrm.readInt32() );
 }
 
-// ============================================================================
-
 PivotTableBuffer::PivotTableBuffer( const WorkbookHelper& rHelper ) :
     WorkbookHelper( rHelper )
 {
@@ -1364,8 +1355,6 @@ void PivotTableBuffer::finalizeImport()
     maTables.forEachMem( &PivotTable::finalizeImport );
 }
 
-// ============================================================================
-
 } // namespace xls
 } // namespace oox
 
