@@ -37,7 +37,7 @@
 #include "queryentry.hxx"
 #include <sortparam.hxx>
 
-#include "svx/dataaccessdescriptor.hxx"
+#include <svx/dataaccessdescriptor.hxx>
 
 #include <com/sun/star/sheet/DataImportMode.hpp>
 #include <com/sun/star/table/TableSortField.hpp>
@@ -58,7 +58,7 @@ using namespace xmloff::token;
 
 ScXMLExportDatabaseRanges::ScXMLExportDatabaseRanges(ScXMLExport& rTempExport)
     : rExport(rTempExport),
-    pDoc( NULL )
+    pDoc( nullptr )
 {
 }
 
@@ -74,7 +74,7 @@ ScMyEmptyDatabaseRangesContainer ScXMLExportDatabaseRanges::GetEmptyDatabaseRang
         uno::Reference <beans::XPropertySet> xPropertySet (rExport.GetModel(), uno::UNO_QUERY);
         if (xPropertySet.is())
         {
-            uno::Reference <sheet::XDatabaseRanges> xDatabaseRanges(xPropertySet->getPropertyValue(OUString(SC_UNO_DATABASERNG)), uno::UNO_QUERY);
+            uno::Reference <sheet::XDatabaseRanges> xDatabaseRanges(xPropertySet->getPropertyValue(SC_UNO_DATABASERNG), uno::UNO_QUERY);
             rExport.CheckAttrList();
             if (xDatabaseRanges.is())
             {
@@ -88,7 +88,7 @@ ScMyEmptyDatabaseRangesContainer ScXMLExportDatabaseRanges::GetEmptyDatabaseRang
                     {
                         uno::Reference <beans::XPropertySet> xDatabaseRangePropertySet (xDatabaseRange, uno::UNO_QUERY);
                         if (xDatabaseRangePropertySet.is() &&
-                            ::cppu::any2bool(xDatabaseRangePropertySet->getPropertyValue(OUString(SC_UNONAME_STRIPDAT))))
+                            ::cppu::any2bool(xDatabaseRangePropertySet->getPropertyValue(SC_UNONAME_STRIPDAT)))
                         {
                             uno::Sequence <beans::PropertyValue> aImportProperties(xDatabaseRange->getImportDescriptor());
                             sal_Int32 nLength = aImportProperties.getLength();
@@ -139,7 +139,7 @@ public:
 
         // name
         OUStringBuffer aBuf;
-        aBuf.appendAscii(STR_DB_LOCAL_NONAME);
+        aBuf.append(STR_DB_LOCAL_NONAME);
         aBuf.append(static_cast<sal_Int32>(r.first)); // appended number equals sheet index on import.
 
         write(aBuf.makeStringAndClear(), *r.second);
@@ -151,7 +151,7 @@ public:
         {
             // name
             OUStringBuffer aBuf;
-            aBuf.appendAscii(STR_DB_GLOBAL_NONAME);
+            aBuf.append(STR_DB_GLOBAL_NONAME);
             aBuf.append(++mnCounter); // 1-based, for entirely arbitrary reasons.  The numbers are ignored on import.
 
             write(aBuf.makeStringAndClear(), rData);
@@ -160,6 +160,11 @@ public:
             write(rData.GetName(), rData);
     }
 
+    void operator() (std::unique_ptr<ScDBData> const& p)
+    {
+        return operator()(*p);
+    }
+
 private:
     void write(const OUString& rName, const ScDBData& rData)
     {
@@ -220,13 +225,13 @@ private:
         OUString sDatabaseName;
         OUString sConRes;
 
-        ::svx::ODataAccessDescriptor aDescriptor;
+        svx::ODataAccessDescriptor aDescriptor;
         aDescriptor.setDataSource(aParam.aDBName);
-        if (aDescriptor.has(::svx::daDataSource))
+        if (aDescriptor.has(svx::daDataSource))
         {
             sDatabaseName = aParam.aDBName;
         }
-        else if (aDescriptor.has(::svx::daConnectionResource))
+        else if (aDescriptor.has(svx::daConnectionResource))
         {
             sConRes = aParam.aDBName;
         }
@@ -262,7 +267,7 @@ private:
             {
                 if (!sDatabaseName.isEmpty())
                     mrExport.AddAttribute(XML_NAMESPACE_TABLE, XML_DATABASE_NAME, sDatabaseName);
-                mrExport.AddAttribute(XML_NAMESPACE_TABLE, XML_TABLE_NAME, aParam.aStatement);
+                mrExport.AddAttribute(XML_NAMESPACE_TABLE, XML_DATABASE_TABLE_NAME, aParam.aStatement);
                 SvXMLElementExport aElemID(mrExport, XML_NAMESPACE_TABLE, XML_DATABASE_SOURCE_TABLE, true, true);
                 if (!sConRes.isEmpty())
                 {
@@ -348,8 +353,8 @@ private:
             if (aParam.bUserDef)
             {
                 OUStringBuffer aBuf;
-                aBuf.appendAscii(SC_USERLIST);
-                aBuf.append(aParam.nUserIndex);
+                aBuf.append(SC_USERLIST);
+                aBuf.append(static_cast<sal_Int32>(aParam.nUserIndex));
                 mrExport.AddAttribute(XML_NAMESPACE_TABLE, XML_DATA_TYPE, aBuf.makeStringAndClear());
             }
             else
@@ -363,7 +368,7 @@ private:
         }
     }
 
-    OUString getOperatorXML(const ScQueryEntry& rEntry, bool bRegExp) const
+    static OUString getOperatorXML(const ScQueryEntry& rEntry, bool bRegExp)
     {
         switch (rEntry.eOp)
         {
@@ -422,7 +427,7 @@ private:
     {
         ScXMLExport& mrExport;
     public:
-        WriteSetItem(ScXMLExport& r) : mrExport(r) {}
+        explicit WriteSetItem(ScXMLExport& r) : mrExport(r) {}
         void operator() (const ScQueryEntry::Item& rItem) const
         {
             mrExport.AddAttribute(XML_NAMESPACE_TABLE, XML_VALUE, rItem.maString.getString());
@@ -504,7 +509,8 @@ private:
             OUString aAddrStr;
             ScRangeStringConverter::GetStringFromRange(
                 aAddrStr, aAdvSource, mpDoc, ::formula::FormulaGrammar::CONV_OOO);
-            mrExport.AddAttribute(XML_NAMESPACE_TABLE, XML_CONDITION_SOURCE_RANGE_ADDRESS, aAddrStr);
+            if (!aAddrStr.isEmpty())
+                mrExport.AddAttribute(XML_NAMESPACE_TABLE, XML_CONDITION_SOURCE_RANGE_ADDRESS, aAddrStr);
         }
 
         if (!aParam.bDuplicate)
@@ -640,7 +646,7 @@ private:
             if (aParam.bUserDef)
             {
                 OUStringBuffer aBuf;
-                aBuf.appendAscii(SC_USERLIST);
+                aBuf.append(SC_USERLIST);
                 aBuf.append(static_cast<sal_Int32>(aParam.nUserIndex));
                 mrExport.AddAttribute(XML_NAMESPACE_TABLE, XML_DATA_TYPE, aBuf.makeStringAndClear());
             }
