@@ -15,20 +15,17 @@
 
 #include "CorrelationDialog.hxx"
 
-namespace
-{
-    static const OUString strCorrelationTemplate("=CORREL(%VAR1%; %VAR2%)");
-}
+static const char strCorrelationTemplate[] = "=CORREL(%VAR1%; %VAR2%)";
 
 ScCorrelationDialog::ScCorrelationDialog(
                         SfxBindings* pSfxBindings, SfxChildWindow* pChildWindow,
-                        Window* pParent, ScViewData* pViewData ) :
+                        vcl::Window* pParent, ScViewData* pViewData ) :
     ScMatrixComparisonGenerator(
             pSfxBindings, pChildWindow, pParent, pViewData,
             "CorrelationDialog", "modules/scalc/ui/correlationdialog.ui" )
 {}
 
-sal_Bool ScCorrelationDialog::Close()
+bool ScCorrelationDialog::Close()
 {
     return DoClose( ScCorrelationDialogWrapper::GetChildWindowId() );
 }
@@ -40,7 +37,7 @@ const OUString ScCorrelationDialog::getLabel()
 
 const OUString ScCorrelationDialog::getTemplate()
 {
-    return strCorrelationTemplate;
+    return OUString(strCorrelationTemplate);
 }
 
 /* vim:set shiftwidth=4 softtabstop=4 expandtab: */
