@@ -57,50 +57,39 @@
 #include "scmod.hxx"
 #include "chartlis.hxx"
 #include "rangeutl.hxx"
-#include "formula/grammar.hxx"
+#include <formula/grammar.hxx>
 #include "dragdata.hxx"
 #include "clipdata.hxx"
 
-// #108584#
 #include "scitems.hxx"
 
-// #108584#
 #include <editeng/eeitem.hxx>
 
-// #108584#
 #include <editeng/fhgtitem.hxx>
 #include <vcl/svapp.hxx>
 
-
 using namespace com::sun::star;
 
-// -----------------------------------------------------------------------
-
-#define SCDRAWTRANS_TYPE_EMBOBJ         1
-#define SCDRAWTRANS_TYPE_DRAWMODEL      2
-#define SCDRAWTRANS_TYPE_DOCUMENT       3
-
-// -----------------------------------------------------------------------
-
-// -----------------------------------------------------------------------
+#define SCDRAWTRANS_TYPE_EMBOBJ         SotClipboardFormatId::STRING
+#define SCDRAWTRANS_TYPE_DRAWMODEL      SotClipboardFormatId::BITMAP
+#define SCDRAWTRANS_TYPE_DOCUMENT       SotClipboardFormatId::GDIMETAFILE
 
 ScDrawTransferObj::ScDrawTransferObj( SdrModel* pClipModel, ScDocShell* pContainerShell,
                                         const TransferableObjectDescriptor& rDesc ) :
     pModel( pClipModel ),
     aObjDesc( rDesc ),
-    pBookmark( NULL ),
+    pBookmark( nullptr ),
     bGraphic( false ),
     bGrIsBit( false ),
     bOleObj( false ),
-    pDragSourceView( NULL ),
+    pDragSourceView( nullptr ),
     nDragSourceFlags( 0 ),
     bDragWasInternal( false ),
     nSourceDocID( 0 ),
     maShellID(SfxObjectShell::CreateShellID(pContainerShell))
 {
-    //
+
     //  check what kind of objects are contained
-    //
 
     SdrPage* pPage = pModel->GetPage(0);
     if (pPage)
@@ -109,9 +98,8 @@ ScDrawTransferObj::ScDrawTransferObj( SdrModel* pClipModel, ScDocShell* pContain
         SdrObject* pObject = aIter.Next();
         if (pObject && !aIter.Next())               // exactly one object?
         {
-            //
+
             //  OLE object
-            //
 
             sal_uInt16 nSdrObjKind = pObject->GetObjIdentifier();
             if (nSdrObjKind == OBJ_OLE2)
@@ -119,31 +107,27 @@ ScDrawTransferObj::ScDrawTransferObj( SdrModel* pClipModel, ScDocShell* pContain
                 // if object has no persistence it must be copied as a part of document
                 try
                 {
-                    uno::Reference< embed::XEmbedPersist > xPersObj( ((SdrOle2Obj*)pObject)->GetObjRef(), uno::UNO_QUERY );
+                    uno::Reference< embed::XEmbedPersist > xPersObj( static_cast<SdrOle2Obj*>(pObject)->GetObjRef(), uno::UNO_QUERY );
                     if ( xPersObj.is() && xPersObj->hasEntry() )
-                        bOleObj = sal_True;
+                        bOleObj = true;
                 }
                 catch( uno::Exception& )
                 {}
                 // aOleData is initialized later
             }
 
-            //
             //  Graphic object
-            //
 
             if (nSdrObjKind == OBJ_GRAF)
             {
-                bGraphic = sal_True;
-                if ( ((SdrGrafObj*)pObject)->GetGraphic().GetType() == GRAPHIC_BITMAP )
-                    bGrIsBit = sal_True;
+                bGraphic = true;
+                if ( static_cast<SdrGrafObj*>(pObject)->GetGraphic().GetType() == GRAPHIC_BITMAP )
+                    bGrIsBit = true;
             }
 
-            //
             //  URL button
-            //
 
-            SdrUnoObj* pUnoCtrl = PTR_CAST(SdrUnoObj, pObject);
+            SdrUnoObj* pUnoCtrl = dynamic_cast<SdrUnoObj*>( pObject );
             if (pUnoCtrl && FmFormInventor == pUnoCtrl->GetObjInventor())
             {
                 uno::Reference<awt::XControlModel> xControlModel = pUnoCtrl->GetUnoControlModel();
@@ -173,7 +157,7 @@ ScDrawTransferObj::ScDrawTransferObj( SdrModel* pClipModel, ScDocShell* pContain
                                     OUString aUrl = sTmp;
                                     OUString aAbs;
                                     const SfxMedium* pMedium;
-                                    if (pContainerShell && (pMedium = pContainerShell->GetMedium()) != NULL)
+                                    if (pContainerShell && (pMedium = pContainerShell->GetMedium()) != nullptr)
                                     {
                                         bool bWasAbs = true;
                                         aAbs = pMedium->GetURLObject().smartRel2Abs( aUrl, bWasAbs ).
@@ -203,9 +187,7 @@ ScDrawTransferObj::ScDrawTransferObj( SdrModel* pClipModel, ScDocShell* pContain
         }
     }
 
-    //
     //  get size for object descriptor
-    //
 
     // #i71538# use complete SdrViews
     // SdrExchangeView aView(pModel);
@@ -224,19 +206,15 @@ ScDrawTransferObj::ScDrawTransferObj( SdrModel* pClipModel, ScDocShell* pContain
     aObjDesc.maSize = aSrcSize;
     PrepareOLE( aObjDesc );
 
-    //
     // remember a unique ID of the source document
-    //
+
     if ( pContainerShell )
     {
-        ScDocument* pDoc = pContainerShell->GetDocument();
-        if ( pDoc )
+        ScDocument& rDoc = pContainerShell->GetDocument();
+        nSourceDocID = rDoc.GetDocumentID();
+        if ( pPage )
         {
-            nSourceDocID = pDoc->GetDocumentID();
-            if ( pPage )
-            {
-                ScChartHelper::FillProtectedChartRangesVector( m_aProtectedChartRangesVector, pDoc, pPage );
-            }
+            ScChartHelper::FillProtectedChartRangesVector( m_aProtectedChartRangesVector, &rDoc, pPage );
         }
     }
 }
@@ -249,7 +227,7 @@ ScDrawTransferObj::~ScDrawTransferObj()
     if ( pScMod->GetClipData().pDrawClipboard == this )
     {
         OSL_FAIL("ScDrawTransferObj wasn't released");
-        pScMod->SetClipObject( NULL, NULL );
+        pScMod->SetClipObject( nullptr, nullptr );
     }
     if ( pScMod->GetDragData().pDrawTransfer == this )
     {
@@ -267,15 +245,15 @@ ScDrawTransferObj::~ScDrawTransferObj()
     delete pDragSourceView;
 }
 
-ScDrawTransferObj* ScDrawTransferObj::GetOwnClipboard( Window* )
+ScDrawTransferObj* ScDrawTransferObj::GetOwnClipboard( vcl::Window* )
 {
     ScDrawTransferObj* pObj = SC_MOD()->GetClipData().pDrawClipboard;
     return pObj;
 }
 
-static sal_Bool lcl_HasOnlyControls( SdrModel* pModel )
+static bool lcl_HasOnlyControls( SdrModel* pModel )
 {
-    sal_Bool bOnlyControls = false;         // default if there are no objects
+    bool bOnlyControls = false;         // default if there are no objects
 
     if ( pModel )
     {
@@ -286,10 +264,10 @@ static sal_Bool lcl_HasOnlyControls( SdrModel* pModel )
             SdrObject* pObj = aIter.Next();
             if ( pObj )
             {
-                bOnlyControls = sal_True;   // only set if there are any objects at all
+                bOnlyControls = true;   // only set if there are any objects at all
                 while ( pObj )
                 {
-                    if (!pObj->ISA(SdrUnoObj))
+                    if (dynamic_cast<const SdrUnoObj*>( pObj) ==  nullptr)
                     {
                         bOnlyControls = false;
                         break;
@@ -307,38 +285,38 @@ void ScDrawTransferObj::AddSupportedFormats()
 {
     if ( bGrIsBit )             // single bitmap graphic
     {
-        AddFormat( SOT_FORMATSTR_ID_OBJECTDESCRIPTOR );
-        AddFormat( SOT_FORMATSTR_ID_SVXB );
-        AddFormat( SOT_FORMATSTR_ID_PNG );
-        AddFormat( SOT_FORMAT_BITMAP );
-        AddFormat( SOT_FORMAT_GDIMETAFILE );
+        AddFormat( SotClipboardFormatId::OBJECTDESCRIPTOR );
+        AddFormat( SotClipboardFormatId::SVXB );
+        AddFormat( SotClipboardFormatId::PNG );
+        AddFormat( SotClipboardFormatId::BITMAP );
+        AddFormat( SotClipboardFormatId::GDIMETAFILE );
     }
     else if ( bGraphic )        // other graphic
     {
         // #i25616#
-        AddFormat( SOT_FORMATSTR_ID_DRAWING );
+        AddFormat( SotClipboardFormatId::DRAWING );
 
-        AddFormat( SOT_FORMATSTR_ID_OBJECTDESCRIPTOR );
-        AddFormat( SOT_FORMATSTR_ID_SVXB );
-        AddFormat( SOT_FORMAT_GDIMETAFILE );
-        AddFormat( SOT_FORMATSTR_ID_PNG );
-        AddFormat( SOT_FORMAT_BITMAP );
+        AddFormat( SotClipboardFormatId::OBJECTDESCRIPTOR );
+        AddFormat( SotClipboardFormatId::SVXB );
+        AddFormat( SotClipboardFormatId::GDIMETAFILE );
+        AddFormat( SotClipboardFormatId::PNG );
+        AddFormat( SotClipboardFormatId::BITMAP );
     }
     else if ( pBookmark )       // url button
     {
-//      AddFormat( SOT_FORMATSTR_ID_EMBED_SOURCE );
-        AddFormat( SOT_FORMATSTR_ID_OBJECTDESCRIPTOR );
-        AddFormat( SOT_FORMATSTR_ID_SOLK );
-        AddFormat( SOT_FORMAT_STRING );
-        AddFormat( SOT_FORMATSTR_ID_UNIFORMRESOURCELOCATOR );
-        AddFormat( SOT_FORMATSTR_ID_NETSCAPE_BOOKMARK );
-        AddFormat( SOT_FORMATSTR_ID_DRAWING );
+//      AddFormat( SotClipboardFormatId::EMBED_SOURCE );
+        AddFormat( SotClipboardFormatId::OBJECTDESCRIPTOR );
+        AddFormat( SotClipboardFormatId::SOLK );
+        AddFormat( SotClipboardFormatId::STRING );
+        AddFormat( SotClipboardFormatId::UNIFORMRESOURCELOCATOR );
+        AddFormat( SotClipboardFormatId::NETSCAPE_BOOKMARK );
+        AddFormat( SotClipboardFormatId::DRAWING );
     }
     else if ( bOleObj )         // single OLE object
     {
-        AddFormat( SOT_FORMATSTR_ID_EMBED_SOURCE );
-        AddFormat( SOT_FORMATSTR_ID_OBJECTDESCRIPTOR );
-        AddFormat( SOT_FORMAT_GDIMETAFILE );
+        AddFormat( SotClipboardFormatId::EMBED_SOURCE );
+        AddFormat( SotClipboardFormatId::OBJECTDESCRIPTOR );
+        AddFormat( SotClipboardFormatId::GDIMETAFILE );
 
         CreateOLEData();
 
@@ -356,41 +334,40 @@ void ScDrawTransferObj::AddSupportedFormats()
     }
     else                        // any drawing objects
     {
-        AddFormat( SOT_FORMATSTR_ID_EMBED_SOURCE );
-        AddFormat( SOT_FORMATSTR_ID_OBJECTDESCRIPTOR );
-        AddFormat( SOT_FORMATSTR_ID_DRAWING );
+        AddFormat( SotClipboardFormatId::EMBED_SOURCE );
+        AddFormat( SotClipboardFormatId::OBJECTDESCRIPTOR );
+        AddFormat( SotClipboardFormatId::DRAWING );
 
         // leave out bitmap and metafile if there are only controls
         if ( !lcl_HasOnlyControls( pModel ) )
         {
-            AddFormat( SOT_FORMATSTR_ID_PNG );
-            AddFormat( SOT_FORMAT_BITMAP );
-            AddFormat( SOT_FORMAT_GDIMETAFILE );
+            AddFormat( SotClipboardFormatId::PNG );
+            AddFormat( SotClipboardFormatId::BITMAP );
+            AddFormat( SotClipboardFormatId::GDIMETAFILE );
         }
     }
 
 //  if( pImageMap )
-//      AddFormat( SOT_FORMATSTR_ID_SVIM );
+//      AddFormat( SotClipboardFormatId::SVIM );
 }
 
-sal_Bool ScDrawTransferObj::GetData(
-    const ::com::sun::star::datatransfer::DataFlavor& rFlavor, const OUString& rDestDoc )
+bool ScDrawTransferObj::GetData( const css::datatransfer::DataFlavor& rFlavor, const OUString& rDestDoc )
 {
-    sal_Bool bOK = false;
-    sal_uInt32 nFormat = SotExchange::GetFormat( rFlavor );
+    bool bOK = false;
+    SotClipboardFormatId nFormat = SotExchange::GetFormat( rFlavor );
 
-    if ( bOleObj && nFormat != SOT_FORMAT_GDIMETAFILE )
+    if ( bOleObj && nFormat != SotClipboardFormatId::GDIMETAFILE )
     {
         CreateOLEData();
 
         if( aOleData.GetTransferable().is() && aOleData.HasFormat( rFlavor ) )
         {
-            sal_uLong nOldSwapMode = 0;
+            SdrSwapGraphicsMode nOldSwapMode(SdrSwapGraphicsMode::DEFAULT);
 
             if( pModel )
             {
                 nOldSwapMode = pModel->GetSwapGraphicsMode();
-                pModel->SetSwapGraphicsMode( SDR_SWAPGRAPHICSMODE_PURGE );
+                pModel->SetSwapGraphicsMode( SdrSwapGraphicsMode::PURGE );
             }
 
             bOK = SetAny( aOleData.GetAny(rFlavor, rDestDoc), rFlavor );
@@ -404,17 +381,17 @@ sal_Bool ScDrawTransferObj::GetData(
 
     if( HasFormat( nFormat ) )
     {
-        if ( nFormat == SOT_FORMATSTR_ID_LINKSRCDESCRIPTOR || nFormat == SOT_FORMATSTR_ID_OBJECTDESCRIPTOR )
+        if ( nFormat == SotClipboardFormatId::LINKSRCDESCRIPTOR || nFormat == SotClipboardFormatId::OBJECTDESCRIPTOR )
         {
             bOK = SetTransferableObjectDescriptor( aObjDesc, rFlavor );
         }
-        else if ( nFormat == SOT_FORMATSTR_ID_DRAWING )
+        else if ( nFormat == SotClipboardFormatId::DRAWING )
         {
             bOK = SetObject( pModel, SCDRAWTRANS_TYPE_DRAWMODEL, rFlavor );
         }
-        else if ( nFormat == SOT_FORMAT_BITMAP
-            || nFormat == SOT_FORMATSTR_ID_PNG
-            || nFormat == SOT_FORMAT_GDIMETAFILE )
+        else if ( nFormat == SotClipboardFormatId::BITMAP
+            || nFormat == SotClipboardFormatId::PNG
+            || nFormat == SotClipboardFormatId::GDIMETAFILE )
         {
             // #i71538# use complete SdrViews
             // SdrExchangeView aView( pModel );
@@ -422,12 +399,12 @@ sal_Bool ScDrawTransferObj::GetData(
             SdrPageView* pPv = aView.ShowSdrPage(aView.GetModel()->GetPage(0));
             OSL_ENSURE( pPv, "pPv not there..." );
             aView.MarkAllObj( pPv );
-            if ( nFormat == SOT_FORMAT_GDIMETAFILE )
+            if ( nFormat == SotClipboardFormatId::GDIMETAFILE )
                 bOK = SetGDIMetaFile( aView.GetMarkedObjMetaFile(true), rFlavor );
             else
                 bOK = SetBitmapEx( aView.GetMarkedObjBitmapEx(true), rFlavor );
         }
-        else if ( nFormat == SOT_FORMATSTR_ID_SVXB )
+        else if ( nFormat == SotClipboardFormatId::SVXB )
         {
             // only enabled for single graphics object
 
@@ -438,12 +415,12 @@ sal_Bool ScDrawTransferObj::GetData(
                 SdrObject* pObject = aIter.Next();
                 if (pObject && pObject->GetObjIdentifier() == OBJ_GRAF)
                 {
-                    SdrGrafObj* pGraphObj = (SdrGrafObj*) pObject;
+                    SdrGrafObj* pGraphObj = static_cast<SdrGrafObj*>(pObject);
                     bOK = SetGraphic( pGraphObj->GetGraphic(), rFlavor );
                 }
             }
         }
-        else if ( nFormat == SOT_FORMATSTR_ID_EMBED_SOURCE )
+        else if ( nFormat == SotClipboardFormatId::EMBED_SOURCE )
         {
             if ( bOleObj )              // single OLE object
             {
@@ -470,24 +447,23 @@ sal_Bool ScDrawTransferObj::GetData(
     return bOK;
 }
 
-sal_Bool ScDrawTransferObj::WriteObject( SotStorageStreamRef& rxOStm, void* pUserObject, sal_uInt32 nUserObjectId,
-                                        const ::com::sun::star::datatransfer::DataFlavor& /* rFlavor */ )
+bool ScDrawTransferObj::WriteObject( tools::SvRef<SotStorageStream>& rxOStm, void* pUserObject, SotClipboardFormatId nUserObjectId,
+                                        const css::datatransfer::DataFlavor& /* rFlavor */ )
 {
     // called from SetObject, put data into stream
 
-    sal_Bool bRet = false;
+    bool bRet = false;
     switch (nUserObjectId)
     {
         case SCDRAWTRANS_TYPE_DRAWMODEL:
             {
-                SdrModel* pDrawModel = (SdrModel*)pUserObject;
+                SdrModel* pDrawModel = static_cast<SdrModel*>(pUserObject);
                 rxOStm->SetBufferSize( 0xff00 );
 
-                // #108584#
                 // for the changed pool defaults from drawing layer pool set those
                 // attributes as hard attributes to preserve them for saving
                 const SfxItemPool& rItemPool = pModel->GetItemPool();
-                const SvxFontHeightItem& rDefaultFontHeight = (const SvxFontHeightItem&)rItemPool.GetDefaultItem(EE_CHAR_FONTHEIGHT);
+                const SvxFontHeightItem& rDefaultFontHeight = static_cast<const SvxFontHeightItem&>(rItemPool.GetDefaultItem(EE_CHAR_FONTHEIGHT));
 
                 // SW should have no MasterPages
                 OSL_ENSURE(0L == pModel->GetMasterPageCount(), "SW with MasterPages (!)");
@@ -500,7 +476,7 @@ sal_Bool ScDrawTransferObj::WriteObject( SotStorageStreamRef& rxOStm, void* pUse
                     while(aIter.IsMore())
                     {
                         SdrObject* pObj = aIter.Next();
-                        const SvxFontHeightItem& rItem = (const SvxFontHeightItem&)pObj->GetMergedItem(EE_CHAR_FONTHEIGHT);
+                        const SvxFontHeightItem& rItem = static_cast<const SvxFontHeightItem&>(pObj->GetMergedItem(EE_CHAR_FONTHEIGHT));
 
                         if(rItem.GetHeight() == rDefaultFontHeight.GetHeight())
                         {
@@ -510,7 +486,7 @@ sal_Bool ScDrawTransferObj::WriteObject( SotStorageStreamRef& rxOStm, void* pUse
                 }
 
                 {
-                    com::sun::star::uno::Reference<com::sun::star::io::XOutputStream> xDocOut( new utl::OOutputStreamWrapper( *rxOStm ) );
+                    css::uno::Reference<css::io::XOutputStream> xDocOut( new utl::OOutputStreamWrapper( *rxOStm ) );
                     if( SvxDrawingLayerExport( pDrawModel, xDocOut ) )
                         rxOStm->Commit();
                 }
@@ -522,14 +498,14 @@ sal_Bool ScDrawTransferObj::WriteObject( SotStorageStreamRef& rxOStm, void* pUse
         case SCDRAWTRANS_TYPE_EMBOBJ:
             {
                 // impl. for "single OLE"
-                embed::XEmbeddedObject* pEmbObj = (embed::XEmbeddedObject*) pUserObject;
+                embed::XEmbeddedObject* pEmbObj = static_cast<embed::XEmbeddedObject*>(pUserObject);
 
                 ::utl::TempFile     aTempFile;
                 aTempFile.EnableKillingFile();
                 uno::Reference< embed::XStorage > xWorkStore =
                     ::comphelper::OStorageHelper::GetStorageFromURL( aTempFile.GetURL(), embed::ElementModes::READWRITE );
 
-                uno::Reference < embed::XEmbedPersist > xPers( (embed::XVisualObject*)pEmbObj, uno::UNO_QUERY );
+                uno::Reference < embed::XEmbedPersist > xPers( static_cast<embed::XVisualObject*>(pEmbObj), uno::UNO_QUERY );
                 if ( xPers.is() )
                 {
                     try
@@ -566,7 +542,7 @@ sal_Bool ScDrawTransferObj::WriteObject( SotStorageStreamRef& rxOStm, void* pUse
         case SCDRAWTRANS_TYPE_DOCUMENT:
             {
                 // impl. for "DocShell"
-                SfxObjectShell*   pEmbObj = (SfxObjectShell*) pUserObject;
+                SfxObjectShell*   pEmbObj = static_cast<SfxObjectShell*>(pUserObject);
 
                 try
                 {
@@ -576,9 +552,9 @@ sal_Bool ScDrawTransferObj::WriteObject( SotStorageStreamRef& rxOStm, void* pUse
                         ::comphelper::OStorageHelper::GetStorageFromURL( aTempFile.GetURL(), embed::ElementModes::READWRITE );
 
                     // write document storage
-                    pEmbObj->SetupStorage( xWorkStore, SOFFICE_FILEFORMAT_CURRENT, false, false );
+                    pEmbObj->SetupStorage( xWorkStore, SOFFICE_FILEFORMAT_CURRENT, false );
 
-                    // mba: no relative ULRs for clipboard!
+                    // mba: no relative URLs for clipboard!
                     SfxMedium aMedium( xWorkStore, OUString() );
                     bRet = pEmbObj->DoSaveObjectAs( aMedium, false );
                     pEmbObj->DoSaveCompleted();
@@ -587,18 +563,18 @@ sal_Bool ScDrawTransferObj::WriteObject( SotStorageStreamRef& rxOStm, void* pUse
                     if ( xTransact.is() )
                         xTransact->commit();
 
-                    SvStream* pSrcStm = ::utl::UcbStreamHelper::CreateStream( aTempFile.GetURL(), STREAM_READ );
+                    SvStream* pSrcStm = ::utl::UcbStreamHelper::CreateStream( aTempFile.GetURL(), StreamMode::READ );
                     if( pSrcStm )
                     {
                         rxOStm->SetBufferSize( 0xff00 );
-                        *rxOStm << *pSrcStm;
+                        rxOStm->WriteStream( *pSrcStm );
                         delete pSrcStm;
                     }
 
-                    bRet = sal_True;
+                    bRet = true;
 
                     xWorkStore->dispose();
-                    xWorkStore = uno::Reference < embed::XStorage >();
+                    xWorkStore.clear();
                     rxOStm->Commit();
                 }
                 catch ( uno::Exception& )
@@ -618,7 +594,7 @@ void ScDrawTransferObj::ObjectReleased()
 {
     ScModule* pScMod = SC_MOD();
     if ( pScMod->GetClipData().pDrawClipboard == this )
-        pScMod->SetClipObject( NULL, NULL );
+        pScMod->SetClipObject( nullptr, nullptr );
 
     TransferableHelper::ObjectReleased();
 }
@@ -654,8 +630,8 @@ static void lcl_InitMarks( SdrMarkView& rDest, const SdrMarkView& rSource, SCTAB
     OSL_ENSURE(pDestPV,"PageView ?");
 
     const SdrMarkList& rMarkList = rSource.GetMarkedObjectList();
-    sal_uLong nCount = rMarkList.GetMarkCount();
-    for (sal_uLong i=0; i<nCount; i++)
+    const size_t nCount = rMarkList.GetMarkCount();
+    for (size_t i=0; i<nCount; ++i)
     {
         SdrMark* pMark = rMarkList.GetMark(i);
         SdrObject* pObj = pMark->GetMarkedSdrObj();
@@ -691,7 +667,7 @@ void ScDrawTransferObj::SetDragSourceFlags( sal_uInt16 nFlags )
 
 void ScDrawTransferObj::SetDragWasInternal()
 {
-    bDragWasInternal = sal_True;
+    bDragWasInternal = true;
 }
 
 OUString ScDrawTransferObj::GetShellID() const
@@ -710,11 +686,11 @@ SdrOle2Obj* ScDrawTransferObj::GetSingleObject()
         SdrObject* pObject = aIter.Next();
         if (pObject && pObject->GetObjIdentifier() == OBJ_OLE2)
         {
-            return (SdrOle2Obj*) pObject;
+            return static_cast<SdrOle2Obj*>(pObject);
         }
     }
 
-    return NULL;
+    return nullptr;
 }
 
 void ScDrawTransferObj::CreateOLEData()
@@ -738,7 +714,6 @@ void ScDrawTransferObj::CreateOLEData()
 }
 
 //  initialize aDocShellRef with a live document from the ClipDoc
-//
 
 void ScDrawTransferObj::InitDocShell()
 {
@@ -747,12 +722,12 @@ void ScDrawTransferObj::InitDocShell()
         ScDocShell* pDocSh = new ScDocShell;
         aDocShellRef = pDocSh;      // ref must be there before InitNew
 
-        pDocSh->DoInitNew(NULL);
+        pDocSh->DoInitNew();
 
-        ScDocument* pDestDoc = pDocSh->GetDocument();
-        pDestDoc->InitDrawLayer( pDocSh );
+        ScDocument& rDestDoc = pDocSh->GetDocument();
+        rDestDoc.InitDrawLayer( pDocSh );
 
-        SdrModel* pDestModel = pDestDoc->GetDrawLayer();
+        SdrModel* pDestModel = rDestDoc.GetDrawLayer();
         // #i71538# use complete SdrViews
         // SdrExchangeView aDestView( pDestModel );
         SdrView aDestView( pDestModel );
@@ -760,9 +735,9 @@ void ScDrawTransferObj::InitDocShell()
         aDestView.Paste(
             *pModel,
             Point(aSrcSize.Width()/2, aSrcSize.Height()/2),
-            NULL, 0, OUString(), OUString());
+            nullptr, SdrInsertFlags::NONE, OUString(), OUString());
 
-        // put objects to right layer (see ScViewFunc::PasteDataFormat for SOT_FORMATSTR_ID_DRAWING)
+        // put objects to right layer (see ScViewFunc::PasteDataFormat for SotClipboardFormatId::DRAWING)
 
         SdrPage* pPage = pDestModel->GetPage(0);
         if (pPage)
@@ -771,7 +746,7 @@ void ScDrawTransferObj::InitDocShell()
             SdrObject* pObject = aIter.Next();
             while (pObject)
             {
-                if ( pObject->ISA(SdrUnoObj) )
+                if ( dynamic_cast<const SdrUnoObj*>( pObject) !=  nullptr )
                     pObject->NbcSetLayer(SC_LAYER_CONTROLS);
                 else
                     pObject->NbcSetLayer(SC_LAYER_FRONT);
@@ -783,16 +758,16 @@ void ScDrawTransferObj::InitDocShell()
         Rectangle aDestArea( aTmpPoint, aSrcSize );
         pDocSh->SetVisArea( aDestArea );
 
-        ScViewOptions aViewOpt( pDestDoc->GetViewOptions() );
+        ScViewOptions aViewOpt( rDestDoc.GetViewOptions() );
         aViewOpt.SetOption( VOPT_GRID, false );
-        pDestDoc->SetViewOptions( aViewOpt );
+        rDestDoc.SetViewOptions( aViewOpt );
 
-        ScViewData aViewData( pDocSh, NULL );
+        ScViewData aViewData( pDocSh, nullptr );
         aViewData.SetTabNo( 0 );
         aViewData.SetScreen( aDestArea );
         aViewData.SetCurX( 0 );
         aViewData.SetCurY( 0 );
-        pDocSh->UpdateOle(&aViewData, sal_True);
+        pDocSh->UpdateOle(&aViewData, true);
     }
 }
 
@@ -801,12 +776,12 @@ namespace
     class theScDrawTransferObjUnoTunnelId : public rtl::Static< UnoTunnelIdInit, theScDrawTransferObjUnoTunnelId > {};
 }
 
-const com::sun::star::uno::Sequence< sal_Int8 >& ScDrawTransferObj::getUnoTunnelId()
+const css::uno::Sequence< sal_Int8 >& ScDrawTransferObj::getUnoTunnelId()
 {
     return theScDrawTransferObjUnoTunnelId::get().getSeq();
 }
 
-sal_Int64 SAL_CALL ScDrawTransferObj::getSomething( const com::sun::star::uno::Sequence< sal_Int8 >& rId ) throw( com::sun::star::uno::RuntimeException )
+sal_Int64 SAL_CALL ScDrawTransferObj::getSomething( const css::uno::Sequence< sal_Int8 >& rId ) throw( css::uno::RuntimeException, std::exception )
 {
     sal_Int64 nRet;
     if( ( rId.getLength() == 16 ) &&
@@ -819,5 +794,4 @@ sal_Int64 SAL_CALL ScDrawTransferObj::getSomething( const com::sun::star::uno::S
     return nRet;
 }
 
-
 /* vim:set shiftwidth=4 softtabstop=4 expandtab: */
