@@ -21,7 +21,6 @@
 #include <editeng/eeitem.hxx>
 #include <editeng/justifyitem.hxx>
 
-
 #include <com/sun/star/uno/Sequence.hxx>
 #include <com/sun/star/embed/XTransactedObject.hpp>
 
@@ -49,7 +48,6 @@
 #include "clipdata.hxx"
 #include "clipparam.hxx"
 
-// for InitDocShell
 #include <editeng/paperinf.hxx>
 #include <editeng/sizeitem.hxx>
 #include <svx/algitem.hxx>
@@ -63,17 +61,14 @@
 #include "cellsuno.hxx"
 #include "stringutil.hxx"
 #include "formulaiter.hxx"
+#include <gridwin.hxx>
 
 using namespace com::sun::star;
 
-// -----------------------------------------------------------------------
-
-#define SCTRANS_TYPE_IMPEX          1
-#define SCTRANS_TYPE_EDIT_RTF       2
-#define SCTRANS_TYPE_EDIT_BIN       3
-#define SCTRANS_TYPE_EMBOBJ         4
-
-// -----------------------------------------------------------------------
+#define SCTRANS_TYPE_IMPEX          SotClipboardFormatId::STRING
+#define SCTRANS_TYPE_EDIT_RTF       SotClipboardFormatId::BITMAP
+#define SCTRANS_TYPE_EDIT_BIN       SotClipboardFormatId::GDIMETAFILE
+#define SCTRANS_TYPE_EMBOBJ         SotClipboardFormatId::PRIVATE
 
 void ScTransferObj::GetAreaSize( ScDocument* pDoc, SCTAB nTab1, SCTAB nTab2, SCROW& nRow, SCCOL& nCol )
 {
@@ -97,7 +92,7 @@ void ScTransferObj::GetAreaSize( ScDocument* pDoc, SCTAB nTab1, SCTAB nTab2, SCR
 }
 
 void ScTransferObj::PaintToDev( OutputDevice* pDev, ScDocument* pDoc, double nPrintFactor,
-                                const ScRange& rBlock, sal_Bool bMetaFile )
+                                const ScRange& rBlock, bool bMetaFile )
 {
     if (!pDoc)
         return;
@@ -105,7 +100,7 @@ void ScTransferObj::PaintToDev( OutputDevice* pDev, ScDocument* pDoc, double nPr
     Point aPoint;
     Rectangle aBound( aPoint, pDev->GetOutputSize() );      //! use size from clip area?
 
-    ScViewData aViewData(NULL,NULL);
+    ScViewData aViewData(nullptr,nullptr);
     aViewData.InitData( pDoc );
 
     aViewData.SetTabNo( rBlock.aEnd.Tab() );
@@ -115,10 +110,9 @@ void ScTransferObj::PaintToDev( OutputDevice* pDev, ScDocument* pDoc, double nPr
     ScPrintFunc::DrawToDev( pDoc, pDev, nPrintFactor, aBound, &aViewData, bMetaFile );
 }
 
-// -----------------------------------------------------------------------
-
 ScTransferObj::ScTransferObj( ScDocument* pClipDoc, const TransferableObjectDescriptor& rDesc ) :
     pDoc( pClipDoc ),
+    nNonFiltered(0),
     aObjDesc( rDesc ),
     nDragHandleX( 0 ),
     nDragHandleY( 0 ),
@@ -129,9 +123,7 @@ ScTransferObj::ScTransferObj( ScDocument* pClipDoc, const TransferableObjectDesc
 {
     OSL_ENSURE(pDoc->IsClipboard(), "wrong document");
 
-    //
     // get aBlock from clipboard doc
-    //
 
     SCCOL nCol1;
     SCROW nRow1;
@@ -189,7 +181,7 @@ ScTransferObj::~ScTransferObj()
     if ( pScMod->GetClipData().pCellClipboard == this )
     {
         OSL_FAIL("ScTransferObj wasn't released");
-        pScMod->SetClipObject( NULL, NULL );
+        pScMod->SetClipObject( nullptr, nullptr );
     }
     if ( pScMod->GetDragData().pCellTransfer == this )
     {
@@ -205,7 +197,7 @@ ScTransferObj::~ScTransferObj()
 
 }
 
-ScTransferObj* ScTransferObj::GetOwnClipboard( Window* pUIWin )
+ScTransferObj* ScTransferObj::GetOwnClipboard( vcl::Window* pUIWin )
 {
     ScTransferObj* pObj = SC_MOD()->GetClipData().pCellClipboard;
     if ( pObj && pUIWin )
@@ -217,10 +209,10 @@ ScTransferObj* ScTransferObj::GetOwnClipboard( Window* pUIWin )
         //  may be from other clipboard operations (like flushing, #86059#)
 
         TransferableDataHelper aDataHelper( TransferableDataHelper::CreateFromSystemClipboard( pUIWin ) );
-        if ( !aDataHelper.HasFormat( SOT_FORMATSTR_ID_DIF ) )
+        if ( !aDataHelper.HasFormat( SotClipboardFormatId::DIF ) )
         {
 //          OSL_FAIL("ScTransferObj wasn't released");
-            pObj = NULL;
+            pObj = nullptr;
         }
     }
     return pObj;
@@ -228,36 +220,36 @@ ScTransferObj* ScTransferObj::GetOwnClipboard( Window* pUIWin )
 
 void ScTransferObj::AddSupportedFormats()
 {
-    AddFormat( SOT_FORMATSTR_ID_EMBED_SOURCE );
-    AddFormat( SOT_FORMATSTR_ID_OBJECTDESCRIPTOR );
-    AddFormat( SOT_FORMAT_GDIMETAFILE );
-    AddFormat( SOT_FORMATSTR_ID_PNG );
-    AddFormat( SOT_FORMAT_BITMAP );
+    AddFormat( SotClipboardFormatId::EMBED_SOURCE );
+    AddFormat( SotClipboardFormatId::OBJECTDESCRIPTOR );
+    AddFormat( SotClipboardFormatId::GDIMETAFILE );
+    AddFormat( SotClipboardFormatId::PNG );
+    AddFormat( SotClipboardFormatId::BITMAP );
 
     // ScImportExport formats
-    AddFormat( SOT_FORMATSTR_ID_HTML );
-    AddFormat( SOT_FORMATSTR_ID_SYLK );
-    AddFormat( SOT_FORMATSTR_ID_LINK );
-    AddFormat( SOT_FORMATSTR_ID_DIF );
-    AddFormat( SOT_FORMAT_STRING );
+    AddFormat( SotClipboardFormatId::HTML );
+    AddFormat( SotClipboardFormatId::SYLK );
+    AddFormat( SotClipboardFormatId::LINK );
+    AddFormat( SotClipboardFormatId::DIF );
+    AddFormat( SotClipboardFormatId::STRING );
 
-    AddFormat( SOT_FORMAT_RTF );
+    AddFormat( SotClipboardFormatId::RTF );
     if ( aBlock.aStart == aBlock.aEnd )
-        AddFormat( SOT_FORMATSTR_ID_EDITENGINE );
+        AddFormat( SotClipboardFormatId::EDITENGINE );
 }
 
-sal_Bool ScTransferObj::GetData( const datatransfer::DataFlavor& rFlavor, const OUString& /*rDestDoc*/ )
+bool ScTransferObj::GetData( const datatransfer::DataFlavor& rFlavor, const OUString& /*rDestDoc*/ )
 {
-    sal_uInt32  nFormat = SotExchange::GetFormat( rFlavor );
-    bool    bOK = false;
+    SotClipboardFormatId nFormat = SotExchange::GetFormat( rFlavor );
+    bool        bOK = false;
 
     if( HasFormat( nFormat ) )
     {
-        if ( nFormat == SOT_FORMATSTR_ID_LINKSRCDESCRIPTOR || nFormat == SOT_FORMATSTR_ID_OBJECTDESCRIPTOR )
+        if ( nFormat == SotClipboardFormatId::LINKSRCDESCRIPTOR || nFormat == SotClipboardFormatId::OBJECTDESCRIPTOR )
         {
             bOK = SetTransferableObjectDescriptor( aObjDesc, rFlavor );
         }
-        else if ( ( nFormat == SOT_FORMAT_RTF || nFormat == SOT_FORMATSTR_ID_EDITENGINE ) &&
+        else if ( ( nFormat == SotClipboardFormatId::RTF || nFormat == SotClipboardFormatId::EDITENGINE ) &&
                         aBlock.aStart == aBlock.aEnd )
         {
             //  RTF from a single cell is handled by EditEngine
@@ -283,20 +275,21 @@ sal_Bool ScTransferObj::GetData( const datatransfer::DataFlavor& rFlavor, const
             }
 
             bOK = SetObject( &aEngine,
-                            (nFormat == FORMAT_RTF) ? SCTRANS_TYPE_EDIT_RTF : SCTRANS_TYPE_EDIT_BIN,
+                            (nFormat == SotClipboardFormatId::RTF) ? SCTRANS_TYPE_EDIT_RTF : SCTRANS_TYPE_EDIT_BIN,
                             rFlavor );
         }
-        else if ( ScImportExport::IsFormatSupported( nFormat ) || nFormat == SOT_FORMAT_RTF )
+        else if ( ScImportExport::IsFormatSupported( nFormat ) || nFormat == SotClipboardFormatId::RTF )
         {
             //  if this transfer object was used to create a DDE link, filtered rows
             //  have to be included for subsequent calls (to be consistent with link data)
-            if ( nFormat == SOT_FORMATSTR_ID_LINK )
+            if ( nFormat == SotClipboardFormatId::LINK )
                 bUsedForLink = true;
 
             bool bIncludeFiltered = pDoc->IsCutMode() || bUsedForLink;
 
+            bool bReduceBlockFormat = nFormat == SotClipboardFormatId::HTML || nFormat == SotClipboardFormatId::RTF;
             ScRange aReducedBlock = aBlock;
-            if ( nFormat == SOT_FORMATSTR_ID_HTML && (aBlock.aEnd.Col() == MAXCOL || aBlock.aEnd.Row() == MAXROW) && aBlock.aStart.Tab() == aBlock.aEnd.Tab() )
+            if (bReduceBlockFormat && (aBlock.aEnd.Col() == MAXCOL || aBlock.aEnd.Row() == MAXROW) && aBlock.aStart.Tab() == aBlock.aEnd.Tab())
             {
                 bool bShrunk = false;
                 //shrink the area to allow pasting to external applications
@@ -323,13 +316,13 @@ sal_Bool ScTransferObj::GetData( const datatransfer::DataFlavor& rFlavor, const
 
             //  DataType depends on format type:
 
-            if ( rFlavor.DataType.equals( ::getCppuType( (const OUString*) 0 ) ) )
+            if ( rFlavor.DataType.equals( ::cppu::UnoType<OUString>::get() ) )
             {
                 OUString aString;
                 if ( aObj.ExportString( aString, nFormat ) )
                     bOK = SetString( aString, rFlavor );
             }
-            else if ( rFlavor.DataType.equals( ::getCppuType( (const uno::Sequence< sal_Int8 >*) 0 ) ) )
+            else if ( rFlavor.DataType.equals( cppu::UnoType<uno::Sequence< sal_Int8 >>::get() ) )
             {
                 //  SetObject converts a stream into a Int8-Sequence
                 bOK = SetObject( &aObj, SCTRANS_TYPE_IMPEX, rFlavor );
@@ -339,21 +332,21 @@ sal_Bool ScTransferObj::GetData( const datatransfer::DataFlavor& rFlavor, const
                 OSL_FAIL("unknown DataType");
             }
         }
-        else if ( nFormat == SOT_FORMAT_BITMAP || nFormat == SOT_FORMATSTR_ID_PNG )
+        else if ( nFormat == SotClipboardFormatId::BITMAP || nFormat == SotClipboardFormatId::PNG )
         {
             Rectangle aMMRect = pDoc->GetMMRect( aBlock.aStart.Col(), aBlock.aStart.Row(),
                                                  aBlock.aEnd.Col(), aBlock.aEnd.Row(),
                                                  aBlock.aStart.Tab() );
-            VirtualDevice aVirtDev;
-            aVirtDev.SetOutputSizePixel( aVirtDev.LogicToPixel( aMMRect.GetSize(), MAP_100TH_MM ) );
+            ScopedVclPtrInstance< VirtualDevice > pVirtDev;
+            pVirtDev->SetOutputSizePixel( pVirtDev->LogicToPixel( aMMRect.GetSize(), MAP_100TH_MM ) );
 
-            PaintToDev( &aVirtDev, pDoc, 1.0, aBlock, false );
+            PaintToDev( pVirtDev, pDoc, 1.0, aBlock, false );
 
-            aVirtDev.SetMapMode( MapMode( MAP_PIXEL ) );
-            Bitmap aBmp = aVirtDev.GetBitmap( Point(), aVirtDev.GetOutputSize() );
+            pVirtDev->SetMapMode( MapMode( MAP_PIXEL ) );
+            Bitmap aBmp = pVirtDev->GetBitmap( Point(), pVirtDev->GetOutputSize() );
             bOK = SetBitmapEx( aBmp, rFlavor );
         }
-        else if ( nFormat == SOT_FORMAT_GDIMETAFILE )
+        else if ( nFormat == SotClipboardFormatId::GDIMETAFILE )
         {
             // #i123405# Do not limit visual size calculation for metafile creation.
             // It seems unlikely that removing the limitation causes problems since
@@ -365,24 +358,24 @@ sal_Bool ScTransferObj::GetData( const datatransfer::DataFlavor& rFlavor, const
 
             // like SvEmbeddedTransfer::GetData:
             GDIMetaFile     aMtf;
-            VirtualDevice   aVDev;
+            ScopedVclPtrInstance< VirtualDevice > pVDev;
             MapMode         aMapMode( pEmbObj->GetMapUnit() );
             Rectangle       aVisArea( pEmbObj->GetVisArea( ASPECT_CONTENT ) );
 
-            aVDev.EnableOutput( false );
-            aVDev.SetMapMode( aMapMode );
+            pVDev->EnableOutput( false );
+            pVDev->SetMapMode( aMapMode );
             aMtf.SetPrefSize( aVisArea.GetSize() );
             aMtf.SetPrefMapMode( aMapMode );
-            aMtf.Record( &aVDev );
+            aMtf.Record( pVDev );
 
-            pEmbObj->DoDraw( &aVDev, Point(), aVisArea.GetSize(), JobSetup(), ASPECT_CONTENT );
+            pEmbObj->DoDraw( pVDev, Point(), aVisArea.GetSize(), JobSetup() );
 
             aMtf.Stop();
             aMtf.WindStart();
 
             bOK = SetGDIMetaFile( aMtf, rFlavor );
         }
-        else if ( nFormat == SOT_FORMATSTR_ID_EMBED_SOURCE )
+        else if ( nFormat == SotClipboardFormatId::EMBED_SOURCE )
         {
             //TODO/LATER: differentiate between formats?!
             // #i123405# Do limit visual size calculation to PageSize
@@ -395,7 +388,7 @@ sal_Bool ScTransferObj::GetData( const datatransfer::DataFlavor& rFlavor, const
     return bOK;
 }
 
-sal_Bool ScTransferObj::WriteObject( SotStorageStreamRef& rxOStm, void* pUserObject, sal_uInt32 nUserObjectId,
+bool ScTransferObj::WriteObject( tools::SvRef<SotStorageStream>& rxOStm, void* pUserObject, SotClipboardFormatId nUserObjectId,
                                         const datatransfer::DataFlavor& rFlavor )
 {
     // called from SetObject, put data into stream
@@ -405,9 +398,9 @@ sal_Bool ScTransferObj::WriteObject( SotStorageStreamRef& rxOStm, void* pUserObj
     {
         case SCTRANS_TYPE_IMPEX:
             {
-                ScImportExport* pImpEx = (ScImportExport*)pUserObject;
+                ScImportExport* pImpEx = static_cast<ScImportExport*>(pUserObject);
 
-                sal_uInt32 nFormat = SotExchange::GetFormat( rFlavor );
+                SotClipboardFormatId nFormat = SotExchange::GetFormat( rFlavor );
                 // mba: no BaseURL for data exchange
                 if ( pImpEx->ExportStream( *rxOStm, OUString(), nFormat ) )
                     bRet = ( rxOStm->GetError() == ERRCODE_NONE );
@@ -417,7 +410,7 @@ sal_Bool ScTransferObj::WriteObject( SotStorageStreamRef& rxOStm, void* pUserObj
         case SCTRANS_TYPE_EDIT_RTF:
         case SCTRANS_TYPE_EDIT_BIN:
             {
-                ScTabEditEngine* pEngine = (ScTabEditEngine*)pUserObject;
+                ScTabEditEngine* pEngine = static_cast<ScTabEditEngine*>(pUserObject);
                 if ( nUserObjectId == SCTRANS_TYPE_EDIT_RTF )
                 {
                     pEngine->Write( *rxOStm, EE_FORMAT_RTF );
@@ -445,16 +438,16 @@ sal_Bool ScTransferObj::WriteObject( SotStorageStreamRef& rxOStm, void* pUserObj
         case SCTRANS_TYPE_EMBOBJ:
             {
                 // TODO/MBA: testing
-                SfxObjectShell*   pEmbObj = (SfxObjectShell*) pUserObject;
+                SfxObjectShell*   pEmbObj = static_cast<SfxObjectShell*>(pUserObject);
                 ::utl::TempFile     aTempFile;
                 aTempFile.EnableKillingFile();
                 uno::Reference< embed::XStorage > xWorkStore =
                     ::comphelper::OStorageHelper::GetStorageFromURL( aTempFile.GetURL(), embed::ElementModes::READWRITE );
 
                 // write document storage
-                pEmbObj->SetupStorage( xWorkStore, SOFFICE_FILEFORMAT_CURRENT, false, false );
+                pEmbObj->SetupStorage( xWorkStore, SOFFICE_FILEFORMAT_CURRENT, false );
 
-                // mba: no relative ULRs for clipboard!
+                // mba: no relative URLs for clipboard!
                 SfxMedium aMedium( xWorkStore, OUString() );
                 bRet = pEmbObj->DoSaveObjectAs( aMedium, false );
                 pEmbObj->DoSaveCompleted();
@@ -463,18 +456,18 @@ sal_Bool ScTransferObj::WriteObject( SotStorageStreamRef& rxOStm, void* pUserObj
                 if ( xTransact.is() )
                     xTransact->commit();
 
-                SvStream* pSrcStm = ::utl::UcbStreamHelper::CreateStream( aTempFile.GetURL(), STREAM_READ );
+                SvStream* pSrcStm = ::utl::UcbStreamHelper::CreateStream( aTempFile.GetURL(), StreamMode::READ );
                 if( pSrcStm )
                 {
                     rxOStm->SetBufferSize( 0xff00 );
-                    *rxOStm << *pSrcStm;
+                    rxOStm->WriteStream( *pSrcStm );
                     delete pSrcStm;
                 }
 
                 bRet = true;
 
                 xWorkStore->dispose();
-                xWorkStore = uno::Reference < embed::XStorage >();
+                xWorkStore.clear();
                 rxOStm->Commit();
             }
             break;
@@ -489,7 +482,7 @@ void ScTransferObj::ObjectReleased()
 {
     ScModule* pScMod = SC_MOD();
     if ( pScMod->GetClipData().pCellClipboard == this )
-        pScMod->SetClipObject( NULL, NULL );
+        pScMod->SetClipObject( nullptr, nullptr );
 
     TransferableHelper::ObjectReleased();
 }
@@ -505,7 +498,7 @@ void ScTransferObj::DragFinished( sal_Int8 nDropAction )
             ScMarkData aMarkData = GetSourceMarkData();
             //  external drag&drop doesn't copy objects, so they also aren't deleted:
             //  bApi=TRUE, don't show error messages from drag&drop
-            pSourceSh->GetDocFunc().DeleteContents( aMarkData, IDF_ALL & ~IDF_OBJECTS, true, true );
+            pSourceSh->GetDocFunc().DeleteContents( aMarkData, InsertDeleteFlags::ALL & ~InsertDeleteFlags::OBJECTS, true, true );
         }
     }
 
@@ -513,7 +506,7 @@ void ScTransferObj::DragFinished( sal_Int8 nDropAction )
     if ( pScMod->GetDragData().pCellTransfer == this )
         pScMod->ResetDragObject();
 
-    xDragSourceRanges = NULL;       // don't keep source after dropping
+    xDragSourceRanges = nullptr;       // don't keep source after dropping
 
     TransferableHelper::DragFinished( nDropAction );
 }
@@ -560,8 +553,8 @@ ScDocument* ScTransferObj::GetSourceDocument()
 {
     ScDocShell* pSourceDocSh = GetSourceDocShell();
     if (pSourceDocSh)
-        return pSourceDocSh->GetDocument();
-    return NULL;
+        return &pSourceDocSh->GetDocument();
+    return nullptr;
 }
 
 ScDocShell* ScTransferObj::GetSourceDocShell()
@@ -570,7 +563,7 @@ ScDocShell* ScTransferObj::GetSourceDocShell()
     if (pRangesObj)
         return pRangesObj->GetDocShell();
 
-    return NULL;    // none set
+    return nullptr;    // none set
 }
 
 ScMarkData ScTransferObj::GetSourceMarkData()
@@ -585,9 +578,8 @@ ScMarkData ScTransferObj::GetSourceMarkData()
     return aMarkData;
 }
 
-//
 //  initialize aDocShellRef with a live document from the ClipDoc
-//
+
 // #i123405# added parameter to allow size calculation without limitation
 // to PageSize, e.g. used for Metafile creation for clipboard.
 
@@ -598,19 +590,19 @@ void ScTransferObj::InitDocShell(bool bLimitToPageSize)
         ScDocShell* pDocSh = new ScDocShell;
         aDocShellRef = pDocSh;      // ref must be there before InitNew
 
-        pDocSh->DoInitNew(NULL);
+        pDocSh->DoInitNew();
 
-        ScDocument* pDestDoc = pDocSh->GetDocument();
+        ScDocument& rDestDoc = pDocSh->GetDocument();
         ScMarkData aDestMark;
         aDestMark.SelectTable( 0, true );
 
-        pDestDoc->SetDocOptions( pDoc->GetDocOptions() );   // #i42666#
+        rDestDoc.SetDocOptions( pDoc->GetDocOptions() );   // #i42666#
 
         OUString aTabName;
         pDoc->GetName( aBlock.aStart.Tab(), aTabName );
-        pDestDoc->RenameTab( 0, aTabName, false );          // no UpdateRef (empty)
+        rDestDoc.RenameTab( 0, aTabName, false );          // no UpdateRef (empty)
 
-        pDestDoc->CopyStdStylesFrom( pDoc );
+        rDestDoc.CopyStdStylesFrom( pDoc );
 
         SCCOL nStartX = aBlock.aStart.Col();
         SCROW nStartY = aBlock.aStart.Row();
@@ -622,24 +614,24 @@ void ScTransferObj::InitDocShell(bool bLimitToPageSize)
 
         SCCOL nCol;
         SCTAB nSrcTab = aBlock.aStart.Tab();
-        pDestDoc->SetLayoutRTL(0, pDoc->IsLayoutRTL(nSrcTab));
+        rDestDoc.SetLayoutRTL(0, pDoc->IsLayoutRTL(nSrcTab));
         for (nCol=nStartX; nCol<=nEndX; nCol++)
             if ( pDoc->ColHidden(nCol, nSrcTab) )
-                pDestDoc->ShowCol( nCol, 0, false );
+                rDestDoc.ShowCol( nCol, 0, false );
             else
-                pDestDoc->SetColWidth( nCol, 0, pDoc->GetColWidth( nCol, nSrcTab ) );
+                rDestDoc.SetColWidth( nCol, 0, pDoc->GetColWidth( nCol, nSrcTab ) );
 
         for (SCROW nRow = nStartY; nRow <= nEndY; ++nRow)
         {
             if ( pDoc->RowHidden(nRow, nSrcTab) )
-                pDestDoc->ShowRow( nRow, 0, false );
+                rDestDoc.ShowRow( nRow, 0, false );
             else
             {
-                pDestDoc->SetRowHeight( nRow, 0, pDoc->GetOriginalHeight( nRow, nSrcTab ) );
+                rDestDoc.SetRowHeight( nRow, 0, pDoc->GetOriginalHeight( nRow, nSrcTab ) );
 
                 //  if height was set manually, that flag has to be copied, too
                 bool bManual = pDoc->IsManualRowHeight(nRow, nSrcTab);
-                pDestDoc->SetManualHeight(nRow, nRow, 0, bManual);
+                rDestDoc.SetManualHeight(nRow, nRow, 0, bManual);
             }
         }
 
@@ -654,15 +646,15 @@ void ScTransferObj::InitDocShell(bool bLimitToPageSize)
         bool bWasCut = pDoc->IsCutMode();
         if (!bWasCut)
             pDoc->SetClipArea( aDestRange, true );          // Cut
-        pDestDoc->CopyFromClip( aDestRange, aDestMark, IDF_ALL, NULL, pDoc, false );
+        rDestDoc.CopyFromClip( aDestRange, aDestMark, InsertDeleteFlags::ALL, nullptr, pDoc, false );
         pDoc->SetClipArea( aDestRange, bWasCut );
 
-        StripRefs( pDoc, nStartX,nStartY, nEndX,nEndY, pDestDoc, 0,0 );
+        StripRefs( pDoc, nStartX,nStartY, nEndX,nEndY, &rDestDoc );
 
         ScRange aMergeRange = aDestRange;
-        pDestDoc->ExtendMerge( aMergeRange, true );
+        rDestDoc.ExtendMerge( aMergeRange, true );
 
-        pDoc->CopyDdeLinks( pDestDoc );         // copy values of DDE Links
+        pDoc->CopyDdeLinks( &rDestDoc );         // copy values of DDE Links
 
         //  page format (grid etc) and page size (maximum size for ole object)
 
@@ -673,19 +665,19 @@ void ScTransferObj::InitDocShell(bool bLimitToPageSize)
         if (pStyleSheet)
         {
             const SfxItemSet& rSourceSet = pStyleSheet->GetItemSet();
-            aPaperSize = ((const SvxSizeItem&) rSourceSet.Get(ATTR_PAGE_SIZE)).GetSize();
+            aPaperSize = static_cast<const SvxSizeItem&>( rSourceSet.Get(ATTR_PAGE_SIZE)).GetSize();
 
             //  CopyStyleFrom kopiert SetItems mit richtigem Pool
-            ScStyleSheetPool* pDestPool = pDestDoc->GetStyleSheetPool();
+            ScStyleSheetPool* pDestPool = rDestDoc.GetStyleSheetPool();
             pDestPool->CopyStyleFrom( pStylePool, aStyleName, SFX_STYLE_FAMILY_PAGE );
         }
 
-        ScViewData aViewData( pDocSh, NULL );
+        ScViewData aViewData( pDocSh, nullptr );
         aViewData.SetScreen( nStartX,nStartY, nEndX,nEndY );
         aViewData.SetCurX( nStartX );
         aViewData.SetCurY( nStartY );
 
-        pDestDoc->SetViewOptions( pDoc->GetViewOptions() );
+        rDestDoc.SetViewOptions( pDoc->GetViewOptions() );
 
         //      Size
         //! get while copying sizes
@@ -694,12 +686,11 @@ void ScTransferObj::InitDocShell(bool bLimitToPageSize)
         long nPosY = 0;
 
         for (nCol=0; nCol<nStartX; nCol++)
-            nPosX += pDestDoc->GetColWidth( nCol, 0 );
-        nPosY += pDestDoc->GetRowHeight( 0, nStartY-1, 0 );
+            nPosX += rDestDoc.GetColWidth( nCol, 0 );
+        nPosY += rDestDoc.GetRowHeight( 0, nStartY-1, 0 );
         nPosX = (long) ( nPosX * HMM_PER_TWIPS );
         nPosY = (long) ( nPosY * HMM_PER_TWIPS );
 
-
         aPaperSize.Width()  *= 2;       // limit OLE object to double of page size
         aPaperSize.Height() *= 2;
 
@@ -707,14 +698,14 @@ void ScTransferObj::InitDocShell(bool bLimitToPageSize)
         long nSizeY = 0;
         for (nCol=nStartX; nCol<=nEndX; nCol++)
         {
-            long nAdd = pDestDoc->GetColWidth( nCol, 0 );
+            long nAdd = rDestDoc.GetColWidth( nCol, 0 );
             if ( bLimitToPageSize && nSizeX+nAdd > aPaperSize.Width() && nSizeX )   // above limit?
                 break;
             nSizeX += nAdd;
         }
         for (SCROW nRow=nStartY; nRow<=nEndY; nRow++)
         {
-            long nAdd = pDestDoc->GetRowHeight( nRow, 0 );
+            long nAdd = rDestDoc.GetRowHeight( nRow, 0 );
             if ( bLimitToPageSize && nSizeY+nAdd > aPaperSize.Height() && nSizeY )  // above limit?
                 break;
             nSizeY += nAdd;
@@ -732,27 +723,26 @@ void ScTransferObj::InitDocShell(bool bLimitToPageSize)
         pDocSh->UpdateOle(&aViewData, true);
 
         //! SetDocumentModified?
-        if ( pDestDoc->IsChartListenerCollectionNeedsUpdate() )
-            pDestDoc->UpdateChartListenerCollection();
+        if ( rDestDoc.IsChartListenerCollectionNeedsUpdate() )
+            rDestDoc.UpdateChartListenerCollection();
     }
 }
 
-SfxObjectShell* ScTransferObj::SetDrawClipDoc( sal_Bool bAnyOle )
+SfxObjectShell* ScTransferObj::SetDrawClipDoc( bool bAnyOle )
 {
-    // update ScGlobal::pDrawClipDocShellRef
+    // update ScGlobal::xDrawClipDocShellRef
 
-    delete ScGlobal::pDrawClipDocShellRef;
+    ScGlobal::xDrawClipDocShellRef.Clear();
     if (bAnyOle)
     {
-        ScGlobal::pDrawClipDocShellRef =
-                        new ScDocShellRef(new ScDocShell(SFX_CREATE_MODE_INTERNAL));      // there must be a ref
-        (*ScGlobal::pDrawClipDocShellRef)->DoInitNew(NULL);
-        return *ScGlobal::pDrawClipDocShellRef;
+        ScGlobal::xDrawClipDocShellRef = new ScDocShell(SfxModelFlags::EMBEDDED_OBJECT | SfxModelFlags::DISABLE_EMBEDDED_SCRIPTS); // there must be a ref
+        ScGlobal::xDrawClipDocShellRef->DoInitNew();
+        return ScGlobal::xDrawClipDocShellRef.get();
     }
     else
     {
-        ScGlobal::pDrawClipDocShellRef = NULL;
-        return NULL;
+        ScGlobal::xDrawClipDocShellRef.Clear();
+        return nullptr;
     }
 }
 
@@ -808,7 +798,7 @@ void ScTransferObj::StripRefs( ScDocument* pDoc,
             ScAddress aPos(nCol, nRow, nDestTab);
             if (nErrCode)
             {
-                if ( ((const SvxHorJustifyItem*) pDestDoc->GetAttr(
+                if ( static_cast<const SvxHorJustifyItem*>(pDestDoc->GetAttr(
                         nCol,nRow,nDestTab, ATTR_HOR_JUSTIFY))->GetValue() ==
                         SVX_HOR_JUSTIFY_STANDARD )
                     pDestDoc->ApplyAttr( nCol,nRow,nDestTab,
@@ -847,12 +837,12 @@ namespace
     class theScTransferUnoTunnelId : public rtl::Static< UnoTunnelIdInit, theScTransferUnoTunnelId> {};
 }
 
-const com::sun::star::uno::Sequence< sal_Int8 >& ScTransferObj::getUnoTunnelId()
+const css::uno::Sequence< sal_Int8 >& ScTransferObj::getUnoTunnelId()
 {
     return theScTransferUnoTunnelId::get().getSeq();
 }
 
-sal_Int64 SAL_CALL ScTransferObj::getSomething( const com::sun::star::uno::Sequence< sal_Int8 >& rId ) throw( com::sun::star::uno::RuntimeException )
+sal_Int64 SAL_CALL ScTransferObj::getSomething( const css::uno::Sequence< sal_Int8 >& rId ) throw( css::uno::RuntimeException, std::exception )
 {
     sal_Int64 nRet;
     if( ( rId.getLength() == 16 ) &&
@@ -865,5 +855,4 @@ sal_Int64 SAL_CALL ScTransferObj::getSomething( const com::sun::star::uno::Seque
     return nRet;
 }
 
-
 /* vim:set shiftwidth=4 softtabstop=4 expandtab: */
