@@ -61,13 +61,9 @@
 #include "conflictsdlg.hxx"
 #include "globstr.hrc"
 #include "markdata.hxx"
+#include <memory>
 
-//------------------------------------------------------------------
-
-//
 //          Redraw - Benachrichtigungen
-//
-
 
 void ScDocShell::PostEditView( ScEditEngineDefaulter* pEditEngine, const ScAddress& rCursorPos )
 {
@@ -76,7 +72,7 @@ void ScDocShell::PostEditView( ScEditEngineDefaulter* pEditEngine, const ScAddre
         //  Test: nur aktive ViewShell
 
     ScTabViewShell* pViewSh = ScTabViewShell::GetActiveViewShell();
-    if (pViewSh && pViewSh->GetViewData()->GetDocShell() == this)
+    if (pViewSh && pViewSh->GetViewData().GetDocShell() == this)
     {
         ScEditViewHint aHint( pEditEngine, rCursorPos );
         pViewSh->Notify( *this, aHint );
@@ -86,7 +82,7 @@ void ScDocShell::PostEditView( ScEditEngineDefaulter* pEditEngine, const ScAddre
 void ScDocShell::PostDataChanged()
 {
     Broadcast( SfxSimpleHint( FID_DATACHANGED ) );
-    SFX_APP()->Broadcast(SfxSimpleHint( FID_ANYDATACHANGED ));      // Navigator
+    SfxGetpApp()->Broadcast(SfxSimpleHint( FID_ANYDATACHANGED ));      // Navigator
     aDocument.ClearFormulaContext();
     //! Navigator direkt benachrichtigen!
 }
@@ -131,7 +127,6 @@ void ScDocShell::PostPaint( const ScRangeList& rRanges, sal_uInt16 nPart, sal_uI
                 continue;
         }
 
-
         if (nExtFlags & SC_PF_LINES)            // Platz fuer Linien beruecksichtigen
         {
                                                 //! Abfrage auf versteckte Spalten/Zeilen!
@@ -216,16 +211,14 @@ void ScDocShell::UpdatePaintExt( sal_uInt16& rExtFlags, SCCOL nStartCol, SCROW n
     UpdatePaintExt( rExtFlags, ScRange( nStartCol, nStartRow, nStartTab, nEndCol, nEndRow, nEndTab ) );
 }
 
-//------------------------------------------------------------------
-
-void ScDocShell::LockPaint_Impl(sal_Bool bDoc)
+void ScDocShell::LockPaint_Impl(bool bDoc)
 {
     if ( !pPaintLockData )
         pPaintLockData = new ScPaintLockData;
     pPaintLockData->IncLevel(bDoc);
 }
 
-void ScDocShell::UnlockPaint_Impl(sal_Bool bDoc)
+void ScDocShell::UnlockPaint_Impl(bool bDoc)
 {
     if ( pPaintLockData )
     {
@@ -236,7 +229,7 @@ void ScDocShell::UnlockPaint_Impl(sal_Bool bDoc)
             //      Paint jetzt ausfuehren
 
             ScPaintLockData* pPaint = pPaintLockData;
-            pPaintLockData = NULL;                      // nicht weitersammeln
+            pPaintLockData = nullptr;                      // nicht weitersammeln
 
             ScRangeListRef xRangeList = pPaint->GetRangeList();
             if (xRangeList)
@@ -286,24 +279,19 @@ void ScDocShell::UnlockDocument_Impl(sal_uInt16 nNew)
     }
 }
 
-sal_uInt16 ScDocShell::GetLockCount() const
-{
-    return nDocumentLock;
-}
-
 void ScDocShell::SetLockCount(sal_uInt16 nNew)
 {
     if (nNew)                   // setzen
     {
         if ( !pPaintLockData )
             pPaintLockData = new ScPaintLockData;
-        pPaintLockData->SetLevel(nNew-1, sal_True);
+        pPaintLockData->SetLevel(nNew-1, true);
         LockDocument_Impl(nNew);
     }
     else if (pPaintLockData)    // loeschen
     {
-        pPaintLockData->SetLevel(0, sal_True);  // bei Unlock sofort ausfuehren
-        UnlockPaint_Impl(sal_True);                 // jetzt
+        pPaintLockData->SetLevel(0, true);  // bei Unlock sofort ausfuehren
+        UnlockPaint_Impl(true);                 // jetzt
         UnlockDocument_Impl(0);
     }
 }
@@ -320,7 +308,7 @@ void ScDocShell::UnlockPaint()
 
 void ScDocShell::LockDocument()
 {
-    LockPaint_Impl(sal_True);
+    LockPaint_Impl(true);
     LockDocument_Impl(nDocumentLock + 1);
 }
 
@@ -328,7 +316,7 @@ void ScDocShell::UnlockDocument()
 {
     if (nDocumentLock)
     {
-        UnlockPaint_Impl(sal_True);
+        UnlockPaint_Impl(true);
         UnlockDocument_Impl(nDocumentLock - 1);
     }
     else
@@ -337,8 +325,6 @@ void ScDocShell::UnlockDocument()
     }
 }
 
-//------------------------------------------------------------------
-
 void ScDocShell::SetInplace( bool bInplace )
 {
     if (bIsInplace != bInplace)
@@ -356,7 +342,7 @@ void ScDocShell::CalcOutputFactor()
         return;
     }
 
-    sal_Bool bTextWysiwyg = SC_MOD()->GetInputOptions().GetTextWysiwyg();
+    bool bTextWysiwyg = SC_MOD()->GetInputOptions().GetTextWysiwyg();
     if (bTextWysiwyg)
     {
         nPrtToScreenFactor = 1.0;
@@ -367,13 +353,13 @@ void ScDocShell::CalcOutputFactor()
             "ABCDEFGHIJKLMNOPQRSTUVWXYZabcdefghijklmnopqrstuvwxyz01234567890123456789");
     long nPrinterWidth = 0;
     long nWindowWidth = 0;
-    const ScPatternAttr* pPattern = (const ScPatternAttr*)&aDocument.GetPool()->
-                                            GetDefaultItem(ATTR_PATTERN);
+    const ScPatternAttr* pPattern = static_cast<const ScPatternAttr*>(&aDocument.GetPool()->
+                                            GetDefaultItem(ATTR_PATTERN));
 
-    Font aDefFont;
+    vcl::Font aDefFont;
     OutputDevice* pRefDev = GetRefDevice();
     MapMode aOldMode = pRefDev->GetMapMode();
-    Font    aOldFont = pRefDev->GetFont();
+    vcl::Font aOldFont = pRefDev->GetFont();
 
     pRefDev->SetMapMode(MAP_PIXEL);
     pPattern->GetFont(aDefFont, SC_AUTOCOL_BLACK, pRefDev); // font color doesn't matter here
@@ -382,11 +368,11 @@ void ScDocShell::CalcOutputFactor()
     pRefDev->SetFont(aOldFont);
     pRefDev->SetMapMode(aOldMode);
 
-    VirtualDevice aVirtWindow( *Application::GetDefaultDevice() );
-    aVirtWindow.SetMapMode(MAP_PIXEL);
-    pPattern->GetFont(aDefFont, SC_AUTOCOL_BLACK, &aVirtWindow);    // font color doesn't matter here
-    aVirtWindow.SetFont(aDefFont);
-    nWindowWidth = aVirtWindow.GetTextWidth(aTestString);
+    ScopedVclPtrInstance< VirtualDevice > pVirtWindow( *Application::GetDefaultDevice() );
+    pVirtWindow->SetMapMode(MAP_PIXEL);
+    pPattern->GetFont(aDefFont, SC_AUTOCOL_BLACK, pVirtWindow);    // font color doesn't matter here
+    pVirtWindow->SetFont(aDefFont);
+    nWindowWidth = pVirtWindow->GetTextWidth(aTestString);
     nWindowWidth = (long) ( nWindowWidth / ScGlobal::nScreenPPTX * HMM_PER_TWIPS );
 
     if (nPrinterWidth && nWindowWidth)
@@ -398,19 +384,12 @@ void ScDocShell::CalcOutputFactor()
     }
 }
 
-double ScDocShell::GetOutputFactor() const
-{
-    return nPrtToScreenFactor;
-}
-
-//---------------------------------------------------------------------
-
 void ScDocShell::InitOptions(bool bForLoading)      // called from InitNew and Load
 {
     //  Einstellungen aus dem SpellCheckCfg kommen in Doc- und ViewOptions
 
     sal_uInt16 nDefLang, nCjkLang, nCtlLang;
-    sal_Bool bAutoSpell;
+    bool bAutoSpell;
     ScModule::GetSpellSettings( nDefLang, nCjkLang, nCtlLang, bAutoSpell );
     ScModule* pScMod = SC_MOD();
 
@@ -445,14 +424,12 @@ void ScDocShell::InitOptions(bool bForLoading)      // called from InitNew and L
     aDocument.SetLanguage( (LanguageType) nDefLang, (LanguageType) nCjkLang, (LanguageType) nCtlLang );
 }
 
-//---------------------------------------------------------------------
-
 Printer* ScDocShell::GetDocumentPrinter()       // fuer OLE
 {
     return aDocument.GetPrinter();
 }
 
-SfxPrinter* ScDocShell::GetPrinter(sal_Bool bCreateIfNotExist)
+SfxPrinter* ScDocShell::GetPrinter(bool bCreateIfNotExist)
 {
     return aDocument.GetPrinter(bCreateIfNotExist);
 }
@@ -461,7 +438,7 @@ void ScDocShell::UpdateFontList()
 {
     delete pImpl->pFontList;
     // pImpl->pFontList = new FontList( GetPrinter(), Application::GetDefaultDevice() );
-    pImpl->pFontList = new FontList( GetRefDevice(), NULL, false ); // sal_False or sal_True???
+    pImpl->pFontList = new FontList( GetRefDevice(), nullptr, false ); // sal_False or sal_True???
     SvxFontListItem aFontListItem( pImpl->pFontList, SID_ATTR_CHAR_FONTLIST );
     PutItem( aFontListItem );
 
@@ -473,13 +450,13 @@ OutputDevice* ScDocShell::GetRefDevice()
     return aDocument.GetRefDevice();
 }
 
-sal_uInt16 ScDocShell::SetPrinter( SfxPrinter* pNewPrinter, sal_uInt16 nDiffFlags )
+sal_uInt16 ScDocShell::SetPrinter( SfxPrinter* pNewPrinter, SfxPrinterChangeFlags nDiffFlags )
 {
     SfxPrinter *pOld = aDocument.GetPrinter( false );
     if ( pOld && pOld->IsPrinting() )
         return SFX_PRINTERROR_BUSY;
 
-    if (nDiffFlags & SFX_PRINTER_PRINTER)
+    if (nDiffFlags & SfxPrinterChangeFlags::PRINTER)
     {
         if ( aDocument.GetPrinter() != pNewPrinter )
         {
@@ -503,9 +480,8 @@ sal_uInt16 ScDocShell::SetPrinter( SfxPrinter* pNewPrinter, sal_uInt16 nDiffFlag
             while (pFrame)
             {
                 SfxViewShell* pSh = pFrame->GetViewShell();
-                if (pSh && pSh->ISA(ScTabViewShell))
+                if (ScTabViewShell* pViewSh = dynamic_cast<ScTabViewShell*>(pSh))
                 {
-                    ScTabViewShell* pViewSh = (ScTabViewShell*)pSh;
                     ScInputHandler* pInputHdl = pScMod->GetInputHdl(pViewSh);
                     if (pInputHdl)
                         pInputHdl->UpdateRefDevice();
@@ -514,7 +490,7 @@ sal_uInt16 ScDocShell::SetPrinter( SfxPrinter* pNewPrinter, sal_uInt16 nDiffFlag
             }
         }
     }
-    else if (nDiffFlags & SFX_PRINTER_JOBSETUP)
+    else if (nDiffFlags & SfxPrinterChangeFlags::JOBSETUP)
     {
         SfxPrinter* pOldPrinter = aDocument.GetPrinter();
         if (pOldPrinter)
@@ -529,25 +505,25 @@ sal_uInt16 ScDocShell::SetPrinter( SfxPrinter* pNewPrinter, sal_uInt16 nDiffFlag
         }
     }
 
-    if (nDiffFlags & SFX_PRINTER_OPTIONS)
+    if (nDiffFlags & SfxPrinterChangeFlags::OPTIONS)
     {
         aDocument.SetPrintOptions();        //! aus neuem Printer ???
     }
 
-    if (nDiffFlags & (SFX_PRINTER_CHG_ORIENTATION | SFX_PRINTER_CHG_SIZE))
+    if (nDiffFlags & (SfxPrinterChangeFlags::CHG_ORIENTATION | SfxPrinterChangeFlags::CHG_SIZE))
     {
         OUString aStyle = aDocument.GetPageStyle( GetCurTab() );
         ScStyleSheetPool* pStPl = aDocument.GetStyleSheetPool();
-        SfxStyleSheet* pStyleSheet = (SfxStyleSheet*)pStPl->Find(aStyle, SFX_STYLE_FAMILY_PAGE);
+        SfxStyleSheet* pStyleSheet = static_cast<SfxStyleSheet*>(pStPl->Find(aStyle, SFX_STYLE_FAMILY_PAGE));
         if (pStyleSheet)
         {
             SfxItemSet& rSet = pStyleSheet->GetItemSet();
 
-            if (nDiffFlags & SFX_PRINTER_CHG_ORIENTATION)
+            if (nDiffFlags & SfxPrinterChangeFlags::CHG_ORIENTATION)
             {
-                const SvxPageItem& rOldItem = (const SvxPageItem&)rSet.Get(ATTR_PAGE);
-                sal_Bool bWasLand = rOldItem.IsLandscape();
-                sal_Bool bNewLand = ( pNewPrinter->GetOrientation() == ORIENTATION_LANDSCAPE );
+                const SvxPageItem& rOldItem = static_cast<const SvxPageItem&>(rSet.Get(ATTR_PAGE));
+                bool bWasLand = rOldItem.IsLandscape();
+                bool bNewLand = ( pNewPrinter->GetOrientation() == ORIENTATION_LANDSCAPE );
                 if (bNewLand != bWasLand)
                 {
                     SvxPageItem aNewItem( rOldItem );
@@ -555,13 +531,13 @@ sal_uInt16 ScDocShell::SetPrinter( SfxPrinter* pNewPrinter, sal_uInt16 nDiffFlag
                     rSet.Put( aNewItem );
 
                     //  Groesse umdrehen
-                    Size aOldSize = ((const SvxSizeItem&)rSet.Get(ATTR_PAGE_SIZE)).GetSize();
+                    Size aOldSize = static_cast<const SvxSizeItem&>(rSet.Get(ATTR_PAGE_SIZE)).GetSize();
                     Size aNewSize(aOldSize.Height(),aOldSize.Width());
                     SvxSizeItem aNewSItem(ATTR_PAGE_SIZE,aNewSize);
                     rSet.Put( aNewSItem );
                 }
             }
-            if (nDiffFlags & SFX_PRINTER_CHG_SIZE)
+            if (nDiffFlags & SfxPrinterChangeFlags::CHG_SIZE)
             {
                 SvxSizeItem aPaperSizeItem( ATTR_PAGE_SIZE, SvxPaperInfo::GetPaperSize(pNewPrinter) );
                 rSet.Put( aPaperSizeItem );
@@ -574,17 +550,15 @@ sal_uInt16 ScDocShell::SetPrinter( SfxPrinter* pNewPrinter, sal_uInt16 nDiffFlag
     return 0;
 }
 
-//---------------------------------------------------------------------
-
 ScChangeAction* ScDocShell::GetChangeAction( const ScAddress& rPos )
 {
-    ScChangeTrack* pTrack = GetDocument()->GetChangeTrack();
+    ScChangeTrack* pTrack = GetDocument().GetChangeTrack();
     if (!pTrack)
-        return NULL;
+        return nullptr;
 
     SCTAB nTab = rPos.Tab();
 
-    const ScChangeAction* pFound = NULL;
+    const ScChangeAction* pFound = nullptr;
     long nModified = 0;
     const ScChangeAction* pAction = pTrack->GetFirst();
     while (pAction)
@@ -612,7 +586,7 @@ ScChangeAction* ScDocShell::GetChangeAction( const ScAddress& rPos )
             if ( pAction->GetType() == SC_CAT_MOVE )
             {
                 ScRange aRange =
-                    ((const ScChangeActionMove*)pAction)->
+                    static_cast<const ScChangeActionMove*>(pAction)->
                     GetFromRange().MakeRange();
                 if ( aRange.In( rPos ) )
                 {
@@ -624,7 +598,7 @@ ScChangeAction* ScDocShell::GetChangeAction( const ScAddress& rPos )
         pAction = pAction->GetNext();
     }
 
-    return (ScChangeAction*)pFound;
+    return const_cast<ScChangeAction*>(pFound);
 }
 
 void ScDocShell::SetChangeComment( ScChangeAction* pAction, const OUString& rComment )
@@ -636,7 +610,7 @@ void ScDocShell::SetChangeComment( ScChangeAction* pAction, const OUString& rCom
         SetDocumentModified();
 
         //  Dialog-Notify
-        ScChangeTrack* pTrack = GetDocument()->GetChangeTrack();
+        ScChangeTrack* pTrack = GetDocument().GetChangeTrack();
         if (pTrack)
         {
             sal_uLong nNumber = pAction->GetActionNumber();
@@ -645,7 +619,7 @@ void ScDocShell::SetChangeComment( ScChangeAction* pAction, const OUString& rCom
     }
 }
 
-void ScDocShell::ExecuteChangeCommentDialog( ScChangeAction* pAction, Window* pParent,sal_Bool bPrevNext)
+void ScDocShell::ExecuteChangeCommentDialog( ScChangeAction* pAction, vcl::Window* pParent, bool bPrevNext)
 {
     if (!pAction) return;           // ohne Aktion ist nichts..
 
@@ -655,7 +629,7 @@ void ScDocShell::ExecuteChangeCommentDialog( ScChangeAction* pAction, Window* pP
     DateTime aDT = pAction->GetDateTime();
     OUString aDate = ScGlobal::pLocaleData->getDate( aDT );
     aDate += " ";
-    aDate += ScGlobal::pLocaleData->getTime( aDT, false, false );
+    aDate += ScGlobal::pLocaleData->getTime( aDT, false );
 
     SfxItemSet aSet( GetPool(),
                       SID_ATTR_POSTIT_AUTHOR, SID_ATTR_POSTIT_AUTHOR,
@@ -667,15 +641,11 @@ void ScDocShell::ExecuteChangeCommentDialog( ScChangeAction* pAction, Window* pP
     aSet.Put( SvxPostItAuthorItem( aAuthor,  SID_ATTR_POSTIT_AUTHOR ) );
     aSet.Put( SvxPostItDateItem  ( aDate,    SID_ATTR_POSTIT_DATE ) );
 
-    ScRedComDialog* pDlg = new ScRedComDialog( pParent, aSet,this,pAction,bPrevNext);
+    std::unique_ptr<ScRedComDialog> pDlg(new ScRedComDialog( pParent, aSet,this,pAction,bPrevNext));
 
     pDlg->Execute();
-
-    delete pDlg;
 }
 
-//---------------------------------------------------------------------
-
 void ScDocShell::CompareDocument( ScDocument& rOtherDoc )
 {
     ScChangeTrack* pTrack = aDocument.GetChangeTrack();
@@ -707,7 +677,7 @@ void ScDocShell::CompareDocument( ScDocument& rOtherDoc )
             if (pOtherMed)
                 aOtherFile = pOtherMed->GetName();
         }
-        sal_Bool bSameDoc = ( aThisFile == aOtherFile && !aThisFile.isEmpty() );
+        bool bSameDoc = ( aThisFile == aOtherFile && !aThisFile.isEmpty() );
         if ( !bSameDoc )
         {
             //  create change actions from comparing with the name of the user
@@ -737,13 +707,9 @@ void ScDocShell::CompareDocument( ScDocument& rOtherDoc )
     SetDocumentModified();
 }
 
-//---------------------------------------------------------------------
-//
 //              Merge (Aenderungen zusammenfuehren)
-//
-//---------------------------------------------------------------------
 
-static inline sal_Bool lcl_Equal( const ScChangeAction* pA, const ScChangeAction* pB, sal_Bool bIgnore100Sec )
+static inline bool lcl_Equal( const ScChangeAction* pA, const ScChangeAction* pB, bool bIgnore100Sec )
 {
     return pA && pB &&
         pA->GetActionNumber() == pB->GetActionNumber() &&
@@ -755,7 +721,7 @@ static inline sal_Bool lcl_Equal( const ScChangeAction* pA, const ScChangeAction
     //  State nicht vergleichen, falls eine alte Aenderung akzeptiert wurde
 }
 
-static bool lcl_FindAction( ScDocument* pDoc, const ScChangeAction* pAction, ScDocument* pSearchDoc, const ScChangeAction* pFirstSearchAction, const ScChangeAction* pLastSearchAction, sal_Bool bIgnore100Sec )
+static bool lcl_FindAction( ScDocument* pDoc, const ScChangeAction* pAction, ScDocument* pSearchDoc, const ScChangeAction* pFirstSearchAction, const ScChangeAction* pLastSearchAction, bool bIgnore100Sec )
 {
     if ( !pDoc || !pAction || !pSearchDoc || !pFirstSearchAction || !pLastSearchAction )
     {
@@ -809,13 +775,13 @@ void ScDocShell::MergeDocument( ScDocument& rOtherDoc, bool bShared, bool bCheck
         {
             // visuelles RedLining einschalten
             ScChangeViewSettings aChangeViewSet;
-            aChangeViewSet.SetShowChanges(sal_True);
+            aChangeViewSet.SetShowChanges(true);
             aDocument.SetChangeViewSettings(aChangeViewSet);
         }
     }
 
     // include Nano seconds in compare?
-    sal_Bool bIgnore100Sec = !pSourceTrack->IsTimeNanoSeconds() ||
+    bool bIgnore100Sec = !pSourceTrack->IsTimeNanoSeconds() ||
             !pThisTrack->IsTimeNanoSeconds();
 
     //  gemeinsame Ausgangsposition suchen
@@ -834,7 +800,6 @@ void ScDocShell::MergeDocument( ScDocument& rOtherDoc, bool bShared, bool bCheck
 
     //! Abfrage, ob die Dokumente vor dem Change-Tracking gleich waren !!!
 
-
     const ScChangeAction* pFirstMergeAction = pSourceAction;
     const ScChangeAction* pFirstSearchAction = pThisAction;
 
@@ -859,7 +824,7 @@ void ScDocShell::MergeDocument( ScDocument& rOtherDoc, bool bShared, bool bCheck
 
     sal_uLong nLastMergeAction = pSourceTrack->GetLast()->GetActionNumber();
     // UpdateReference-Undo, gueltige Referenzen fuer den letzten gemeinsamen Zustand
-    pSourceTrack->MergePrepare( (ScChangeAction*) pFirstMergeAction, bShared );
+    pSourceTrack->MergePrepare( const_cast<ScChangeAction*>(pFirstMergeAction), bShared );
 
     //  MergeChangeData an alle noch folgenden Aktionen in diesem Dokument anpassen
     //  -> Referenzen gueltig fuer dieses Dokument
@@ -880,20 +845,20 @@ void ScDocShell::MergeDocument( ScDocument& rOtherDoc, bool bShared, bool bCheck
                 case SC_CAT_DELETE_ROWS :
                 case SC_CAT_DELETE_TABS :
                 {
-                    const ScChangeActionDel* pDel = (const ScChangeActionDel*) pThisAction;
+                    const ScChangeActionDel* pDel = static_cast<const ScChangeActionDel*>(pThisAction);
                     if ( pDel->IsTopDelete() && !pDel->IsTabDeleteCol() )
                     {   // deleted Table enthaelt deleted Cols, die nicht
                         sal_uLong nStart, nEnd;
                         pSourceTrack->AppendDeleteRange(
-                            pDel->GetOverAllRange().MakeRange(), NULL, nStart, nEnd );
+                            pDel->GetOverAllRange().MakeRange(), nullptr, nStart, nEnd );
                     }
                 }
                 break;
                 case SC_CAT_MOVE :
                 {
-                    const ScChangeActionMove* pMove = (const ScChangeActionMove*) pThisAction;
+                    const ScChangeActionMove* pMove = static_cast<const ScChangeActionMove*>(pThisAction);
                     pSourceTrack->AppendMove( pMove->GetFromRange().MakeRange(),
-                        pMove->GetBigRange().MakeRange(), NULL );
+                        pMove->GetBigRange().MakeRange(), nullptr );
                 }
                 break;
                 default:
@@ -908,10 +873,10 @@ void ScDocShell::MergeDocument( ScDocument& rOtherDoc, bool bShared, bool bCheck
     LockPaint();    // #i73877# no repainting after each action
 
     //  MergeChangeData in das aktuelle Dokument uebernehmen
-    sal_Bool bHasRejected = false;
+    bool bHasRejected = false;
     OUString aOldUser = pThisTrack->GetUser();
-    pThisTrack->SetUseFixDateTime( sal_True );
-    ScMarkData& rMarkData = pViewSh->GetViewData()->GetMarkData();
+    pThisTrack->SetUseFixDateTime( true );
+    ScMarkData& rMarkData = pViewSh->GetViewData().GetMarkData();
     ScMarkData aOldMarkData( rMarkData );
     pSourceAction = pFirstMergeAction;
     while ( pSourceAction && pSourceAction->GetActionNumber() <= nLastMergeAction )
@@ -947,7 +912,7 @@ void ScDocShell::MergeDocument( ScDocument& rOtherDoc, bool bShared, bool bCheck
 #if OSL_DEBUG_LEVEL > 0
                 OUString aValue;
                 if ( eSourceType == SC_CAT_CONTENT )
-                    ((const ScChangeActionContent*)pSourceAction)->GetNewString( aValue, &aDocument );
+                    static_cast<const ScChangeActionContent*>(pSourceAction)->GetNewString( aValue, &aDocument );
                 OStringBuffer aError(OUStringToOString(aValue,
                     osl_getThreadTextEncoding()));
                 aError.append(" weggelassen");
@@ -976,7 +941,7 @@ void ScDocShell::MergeDocument( ScDocument& rOtherDoc, bool bShared, bool bCheck
                         if ( pOldAction && pOldAction->IsVirgin() )
                         {
                             pThisTrack->Reject( pOldAction );
-                            bHasRejected = sal_True;
+                            bHasRejected = true;
                             bExecute = false;
                         }
                     }
@@ -991,7 +956,7 @@ void ScDocShell::MergeDocument( ScDocument& rOtherDoc, bool bShared, bool bCheck
                             //! oder Reject-Aenderung normal ausfuehren
 
                             pThisTrack->Reject(pOldAction);
-                            bHasRejected = sal_True;                // fuer Paint
+                            bHasRejected = true;                // fuer Paint
                         }
                         bExecute = false;
                     }
@@ -1012,9 +977,9 @@ void ScDocShell::MergeDocument( ScDocument& rOtherDoc, bool bShared, bool bCheck
                             OSL_ENSURE( aSourceRange.aStart == aSourceRange.aEnd, "huch?" );
                             ScAddress aPos = aSourceRange.aStart;
                             OUString aValue;
-                            ((const ScChangeActionContent*)pSourceAction)->GetNewString( aValue, &aDocument );
+                            static_cast<const ScChangeActionContent*>(pSourceAction)->GetNewString( aValue, &aDocument );
                             sal_uInt8 eMatrix = MM_NONE;
-                            const ScCellValue& rCell = ((const ScChangeActionContent*)pSourceAction)->GetNewCell();
+                            const ScCellValue& rCell = static_cast<const ScChangeActionContent*>(pSourceAction)->GetNewCell();
                             if (rCell.meType == CELLTYPE_FORMULA)
                                 eMatrix = rCell.mpFormula->GetMatrixFlag();
                             switch ( eMatrix )
@@ -1031,18 +996,12 @@ void ScDocShell::MergeDocument( ScDocument& rOtherDoc, bool bShared, bool bCheck
                                     aSourceRange.aEnd.SetRow( aPos.Row() + nRows - 1 );
                                     aValue = aValue.copy(1, aValue.getLength()-2); // remove the 1st and last characters.
                                     GetDocFunc().EnterMatrix( aSourceRange,
-                                        NULL, NULL, aValue, false, false,
+                                        nullptr, nullptr, aValue, false, false,
                                         EMPTY_OUSTRING, formula::FormulaGrammar::GRAM_DEFAULT );
                                 }
                                 break;
                                 case MM_REFERENCE :     // do nothing
                                 break;
-                                case MM_FAKE :
-                                    OSL_FAIL( "MergeDocument: MatrixFlag MM_FAKE" );
-                                    pViewSh->EnterData( aPos.Col(), aPos.Row(), aPos.Tab(), aValue );
-                                break;
-                                default:
-                                    OSL_FAIL( "MergeDocument: unknown MatrixFlag" );
                             }
                         }
                         break;
@@ -1050,25 +1009,25 @@ void ScDocShell::MergeDocument( ScDocument& rOtherDoc, bool bShared, bool bCheck
                         {
                             OUString aName;
                             aDocument.CreateValidTabName( aName );
-                            GetDocFunc().InsertTable( aSourceRange.aStart.Tab(), aName, sal_True, false );
+                            GetDocFunc().InsertTable( aSourceRange.aStart.Tab(), aName, true, false );
                         }
                         break;
                         case SC_CAT_INSERT_ROWS:
-                            GetDocFunc().InsertCells( aSourceRange, NULL, INS_INSROWS, sal_True, false );
+                            GetDocFunc().InsertCells( aSourceRange, nullptr, INS_INSROWS_BEFORE, true, false );
                         break;
                         case SC_CAT_INSERT_COLS:
-                            GetDocFunc().InsertCells( aSourceRange, NULL, INS_INSCOLS, sal_True, false );
+                            GetDocFunc().InsertCells( aSourceRange, nullptr, INS_INSCOLS_BEFORE, true, false );
                         break;
                         case SC_CAT_DELETE_TABS :
-                            GetDocFunc().DeleteTable( aSourceRange.aStart.Tab(), sal_True, false );
+                            GetDocFunc().DeleteTable( aSourceRange.aStart.Tab(), true, false );
                         break;
                         case SC_CAT_DELETE_ROWS:
                         {
-                            const ScChangeActionDel* pDel = (const ScChangeActionDel*) pSourceAction;
+                            const ScChangeActionDel* pDel = static_cast<const ScChangeActionDel*>(pSourceAction);
                             if ( pDel->IsTopDelete() )
                             {
                                 aSourceRange = pDel->GetOverAllRange().MakeRange();
-                                GetDocFunc().DeleteCells( aSourceRange, NULL, DEL_DELROWS, sal_True, false );
+                                GetDocFunc().DeleteCells( aSourceRange, nullptr, DEL_DELROWS, true, false );
 
                                 // #i101099# [Collaboration] Changes are not correctly shown
                                 if ( bShared )
@@ -1084,20 +1043,20 @@ void ScDocShell::MergeDocument( ScDocument& rOtherDoc, bool bShared, bool bCheck
                         break;
                         case SC_CAT_DELETE_COLS:
                         {
-                            const ScChangeActionDel* pDel = (const ScChangeActionDel*) pSourceAction;
+                            const ScChangeActionDel* pDel = static_cast<const ScChangeActionDel*>(pSourceAction);
                             if ( pDel->IsTopDelete() && !pDel->IsTabDeleteCol() )
                             {   // deleted Table enthaelt deleted Cols, die nicht
                                 aSourceRange = pDel->GetOverAllRange().MakeRange();
-                                GetDocFunc().DeleteCells( aSourceRange, NULL, DEL_DELCOLS, sal_True, false );
+                                GetDocFunc().DeleteCells( aSourceRange, nullptr, DEL_DELCOLS, true, false );
                             }
                         }
                         break;
                         case SC_CAT_MOVE :
                         {
-                            const ScChangeActionMove* pMove = (const ScChangeActionMove*) pSourceAction;
+                            const ScChangeActionMove* pMove = static_cast<const ScChangeActionMove*>(pSourceAction);
                             ScRange aFromRange( pMove->GetFromRange().MakeRange() );
                             GetDocFunc().MoveBlock( aFromRange,
-                                aSourceRange.aStart, sal_True, sal_True, false, false );
+                                aSourceRange.aStart, true, true, false, false );
                         }
                         break;
                         default:
@@ -1117,7 +1076,7 @@ void ScDocShell::MergeDocument( ScDocument& rOtherDoc, bool bShared, bool bCheck
                 }
 
                 // Referenzen anpassen
-                pSourceTrack->MergeOwn( (ScChangeAction*) pSourceAction, nFirstNewNumber, bShared );
+                pSourceTrack->MergeOwn( const_cast<ScChangeAction*>(pSourceAction), nFirstNewNumber, bShared );
 
                 // merge action state
                 if ( bShared && !pSourceAction->IsRejected() )
@@ -1125,7 +1084,7 @@ void ScDocShell::MergeDocument( ScDocument& rOtherDoc, bool bShared, bool bCheck
                     ScChangeAction* pAct = pThisTrack->GetLast();
                     if ( pAct && pAct->GetActionNumber() > nOldActionMax )
                     {
-                        pThisTrack->MergeActionState( pAct, pSourceAction );
+                        ScChangeTrack::MergeActionState( pAct, pSourceAction );
                     }
                 }
 
@@ -1183,7 +1142,7 @@ bool ScDocShell::MergeSharedDocument( ScDocShell* pSharedDocShell )
         return false;
     }
 
-    ScDocument& rSharedDoc = *( pSharedDocShell->GetDocument() );
+    ScDocument& rSharedDoc = pSharedDocShell->GetDocument();
     ScChangeTrack* pSharedTrack = rSharedDoc.GetChangeTrack();
     if ( !pSharedTrack )
     {
@@ -1196,7 +1155,7 @@ bool ScDocShell::MergeSharedDocument( ScDocShell* pSharedDocShell )
     aDocument.SetChangeViewSettings( aChangeViewSet );
 
     // find first merge action in this document
-    sal_Bool bIgnore100Sec = !pThisTrack->IsTimeNanoSeconds() || !pSharedTrack->IsTimeNanoSeconds();
+    bool bIgnore100Sec = !pThisTrack->IsTimeNanoSeconds() || !pSharedTrack->IsTimeNanoSeconds();
     ScChangeAction* pThisAction = pThisTrack->GetFirst();
     ScChangeAction* pSharedAction = pSharedTrack->GetFirst();
     while ( lcl_Equal( pThisAction, pSharedAction, bIgnore100Sec ) )
@@ -1231,17 +1190,17 @@ bool ScDocShell::MergeSharedDocument( ScDocShell* pSharedDocShell )
             ScConflictsFinder aFinder( pSharedTrack, nActStartShared, nActEndShared, nActStartOwn, nActEndOwn, aConflictsList );
             if ( aFinder.Find() )
             {
-                ScConflictsListHelper::TransformConflictsList( aConflictsList, NULL, &aOwnInverseMergeMap );
+                ScConflictsListHelper::TransformConflictsList( aConflictsList, nullptr, &aOwnInverseMergeMap );
                 bool bLoop = true;
                 while ( bLoop )
                 {
                     bLoop = false;
-                    ScConflictsDlg aDlg( GetActiveDialogParent(), GetViewData(), &rSharedDoc, aConflictsList );
-                    if ( aDlg.Execute() == RET_CANCEL )
+                    ScopedVclPtrInstance< ScConflictsDlg > aDlg( GetActiveDialogParent(), GetViewData(), &rSharedDoc, aConflictsList );
+                    if ( aDlg->Execute() == RET_CANCEL )
                     {
-                        QueryBox aBox( GetActiveDialogParent(), WinBits( WB_YES_NO | WB_DEF_YES ),
+                        ScopedVclPtrInstance<QueryBox> aBox( GetActiveDialogParent(), WinBits( WB_YES_NO | WB_DEF_YES ),
                             ScGlobal::GetRscString( STR_DOC_WILLNOTBESAVED ) );
-                        if ( aBox.Execute() == RET_YES )
+                        if ( aBox->Execute() == RET_YES )
                         {
                             return false;
                         }
@@ -1286,7 +1245,7 @@ bool ScDocShell::MergeSharedDocument( ScDocShell* pSharedDocShell )
             // resolve conflicts for shared non-content actions
             if ( !aConflictsList.empty() )
             {
-                ScConflictsListHelper::TransformConflictsList( aConflictsList, &aSharedMergeMap, NULL );
+                ScConflictsListHelper::TransformConflictsList( aConflictsList, &aSharedMergeMap, nullptr );
                 ScConflictsResolver aResolver( pThisTrack, aConflictsList );
                 pAction = pThisTrack->GetAction( nEndShared );
                 while ( pAction && pAction->GetActionNumber() >= nStartShared )
@@ -1299,9 +1258,9 @@ bool ScDocShell::MergeSharedDocument( ScDocShell* pSharedDocShell )
             nEndShared = pThisTrack->GetActionMax();
 
             // only show changes from shared document
-            aChangeViewSet.SetShowChanges( sal_True );
-            aChangeViewSet.SetShowAccepted( sal_True );
-            aChangeViewSet.SetHasActionRange( true );
+            aChangeViewSet.SetShowChanges( true );
+            aChangeViewSet.SetShowAccepted( true );
+            aChangeViewSet.SetHasActionRange();
             aChangeViewSet.SetTheActionRange( nStartShared, nEndShared );
             aDocument.SetChangeViewSettings( aChangeViewSet );
 
@@ -1315,7 +1274,7 @@ bool ScDocShell::MergeSharedDocument( ScDocShell* pSharedDocShell )
             // resolve conflicts for shared content actions and own actions
             if ( !aConflictsList.empty() )
             {
-                ScConflictsListHelper::TransformConflictsList( aConflictsList, NULL, &aOwnMergeMap );
+                ScConflictsListHelper::TransformConflictsList( aConflictsList, nullptr, &aOwnMergeMap );
                 ScConflictsResolver aResolver( pThisTrack, aConflictsList );
                 pAction = pThisTrack->GetAction( nEndShared );
                 while ( pAction && pAction->GetActionNumber() >= nStartShared )
@@ -1343,9 +1302,9 @@ bool ScDocShell::MergeSharedDocument( ScDocShell* pSharedDocShell )
             sal_uLong nEndShared = pThisTrack->GetActionMax();
 
             // only show changes from shared document
-            aChangeViewSet.SetShowChanges( sal_True );
-            aChangeViewSet.SetShowAccepted( sal_True );
-            aChangeViewSet.SetHasActionRange( true );
+            aChangeViewSet.SetShowChanges( true );
+            aChangeViewSet.SetShowAccepted( true );
+            aChangeViewSet.SetHasActionRange();
             aChangeViewSet.SetTheActionRange( nStartShared, nEndShared );
             aDocument.SetChangeViewSettings( aChangeViewSet );
         }
@@ -1354,11 +1313,11 @@ bool ScDocShell::MergeSharedDocument( ScDocShell* pSharedDocShell )
         PostPaintExtras();
         PostPaintGridAll();
 
-        InfoBox aInfoBox( GetActiveDialogParent(), ScGlobal::GetRscString( STR_DOC_UPDATED ) );
-        aInfoBox.Execute();
+        ScopedVclPtrInstance< InfoBox > aInfoBox( GetActiveDialogParent(), ScGlobal::GetRscString( STR_DOC_UPDATED ) );
+        aInfoBox->Execute();
     }
 
-    return ( pThisAction != NULL );
+    return ( pThisAction != nullptr );
 }
 
 /* vim:set shiftwidth=4 softtabstop=4 expandtab: */
