@@ -43,21 +43,21 @@
 
 /*************************************************************************
 |*
-|* Basisklasse fuer alle Drawmodul-spezifischen Funktionen
+|* base class for draw module specific functions
 |*
 \************************************************************************/
 
-FuDraw::FuDraw(ScTabViewShell* pViewSh, Window* pWin, ScDrawView* pViewP,
+FuDraw::FuDraw(ScTabViewShell* pViewSh, vcl::Window* pWin, ScDrawView* pViewP,
                SdrModel* pDoc, SfxRequest& rReq) :
     FuPoor      (pViewSh, pWin, pViewP, pDoc, rReq),
-    aNewPointer ( POINTER_ARROW ),
-    aOldPointer ( POINTER_ARROW )
+    aNewPointer ( PointerStyle::Arrow ),
+    aOldPointer ( PointerStyle::Arrow )
 {
 }
 
 /*************************************************************************
 |*
-|* Destruktor
+|* destructor
 |*
 \************************************************************************/
 
@@ -67,22 +67,22 @@ FuDraw::~FuDraw()
 
 /*************************************************************************
 |*
-|* Modifier-Tasten auswerten
+|* evaluate modifier keys
 |*
 \************************************************************************/
 
 void FuDraw::DoModifiers(const MouseEvent& rMEvt)
 {
-    //  Shift   = Ortho und AngleSnap
+    //  Shift   = Ortho and AngleSnap
     //  Control = Snap (Toggle)
-    //  Alt     = zentrisch
+    //  Alt     = centric
 
-    sal_Bool bShift = rMEvt.IsShift();
-    sal_Bool bAlt   = rMEvt.IsMod2();
+    bool bShift = rMEvt.IsShift();
+    bool bAlt   = rMEvt.IsMod2();
 
     bool bOrtho     = bShift;
-    sal_Bool bAngleSnap = bShift;
-    sal_Bool bCenter    = bAlt;
+    bool bAngleSnap = bShift;
+    bool bCenter    = bAlt;
 
     // #i33136#
     if(doConstructOrthogonal())
@@ -104,10 +104,13 @@ void FuDraw::DoModifiers(const MouseEvent& rMEvt)
 
 void FuDraw::ResetModifiers()
 {
-    ScViewData* pViewData = pViewShell->GetViewData();
-    const ScViewOptions& rOpt = pViewData->GetOptions();
+    if (!pView)
+        return;
+
+    ScViewData& rViewData = pViewShell->GetViewData();
+    const ScViewOptions& rOpt = rViewData.GetOptions();
     const ScGridOptions& rGrid = rOpt.GetGridOptions();
-    sal_Bool bGridOpt = rGrid.GetUseGridSnap();
+    bool bGridOpt = rGrid.GetUseGridSnap();
 
     if (pView->IsOrtho())
         pView->SetOrtho(false);
@@ -131,7 +134,7 @@ void FuDraw::ResetModifiers()
 |*
 \************************************************************************/
 
-sal_Bool FuDraw::MouseButtonDown(const MouseEvent& rMEvt)
+bool FuDraw::MouseButtonDown(const MouseEvent& rMEvt)
 {
     // remember button state for creation of own MouseEvents
     SetMouseButtonCode(rMEvt.GetButtons());
@@ -146,7 +149,7 @@ sal_Bool FuDraw::MouseButtonDown(const MouseEvent& rMEvt)
 |*
 \************************************************************************/
 
-sal_Bool FuDraw::MouseMove(const MouseEvent& rMEvt)
+bool FuDraw::MouseMove(const MouseEvent& rMEvt)
 {
     //  evaluate modifiers only if in a drawing layer action
     //  (don't interfere with keyboard shortcut handling)
@@ -162,7 +165,7 @@ sal_Bool FuDraw::MouseMove(const MouseEvent& rMEvt)
 |*
 \************************************************************************/
 
-sal_Bool FuDraw::MouseButtonUp(const MouseEvent& rMEvt)
+bool FuDraw::MouseButtonUp(const MouseEvent& rMEvt)
 {
     // remember button state for creation of own MouseEvents
     SetMouseButtonCode(rMEvt.GetButtons());
@@ -173,65 +176,65 @@ sal_Bool FuDraw::MouseButtonUp(const MouseEvent& rMEvt)
 
 /*************************************************************************
 |*
-|* Tastaturereignisse bearbeiten
+|* process keyboard events
 |*
-|* Wird ein KeyEvent bearbeitet, so ist der Return-Wert sal_True, andernfalls
-|* FALSE.
+|* if a keyevent is processed -> returns sal_True
+|*                            -> else  FALSE
 |*
 \************************************************************************/
 
-static sal_Bool lcl_KeyEditMode( SdrObject* pObj, ScTabViewShell* pViewShell, const KeyEvent* pInitialKey )
+static bool lcl_KeyEditMode( SdrObject* pObj, ScTabViewShell* pViewShell, const KeyEvent* pInitialKey )
 {
-    sal_Bool bReturn = false;
-    if ( pObj && pObj->ISA(SdrTextObj) && !pObj->ISA(SdrUnoObj) )
+    bool bReturn = false;
+    if ( pObj && dynamic_cast<const SdrTextObj*>( pObj) != nullptr && dynamic_cast<const SdrUnoObj*>( pObj) ==  nullptr )
     {
         // start text edit - like FuSelection::MouseButtonUp,
         // but with bCursorToEnd instead of mouse position
 
         OutlinerParaObject* pOPO = pObj->GetOutlinerParaObject();
-        sal_Bool bVertical = ( pOPO && pOPO->IsVertical() );
+        bool bVertical = ( pOPO && pOPO->IsVertical() );
         sal_uInt16 nTextSlotId = bVertical ? SID_DRAW_TEXT_VERTICAL : SID_DRAW_TEXT;
 
         // don't switch shells if text shell is already active
-        FuPoor* pPoor = pViewShell->GetViewData()->GetView()->GetDrawFuncPtr();
+        FuPoor* pPoor = pViewShell->GetViewData().GetView()->GetDrawFuncPtr();
         if ( !pPoor || pPoor->GetSlotID() != nTextSlotId )
         {
-            pViewShell->GetViewData()->GetDispatcher().
-                Execute(nTextSlotId, SFX_CALLMODE_SYNCHRON | SFX_CALLMODE_RECORD);
+            pViewShell->GetViewData().GetDispatcher().
+                Execute(nTextSlotId, SfxCallMode::SYNCHRON | SfxCallMode::RECORD);
         }
 
         // get the resulting FuText and set in edit mode
-        pPoor = pViewShell->GetViewData()->GetView()->GetDrawFuncPtr();
+        pPoor = pViewShell->GetViewData().GetView()->GetDrawFuncPtr();
         if ( pPoor && pPoor->GetSlotID() == nTextSlotId )    // no RTTI
         {
-            FuText* pText = (FuText*)pPoor;
-            pText->SetInEditMode( pObj, NULL, sal_True, pInitialKey );
+            FuText* pText = static_cast<FuText*>(pPoor);
+            pText->SetInEditMode( pObj, nullptr, true, pInitialKey );
             //! set cursor to end of text
         }
-        bReturn = sal_True;
+        bReturn = true;
     }
     return bReturn;
 }
 
-sal_Bool FuDraw::KeyInput(const KeyEvent& rKEvt)
+bool FuDraw::KeyInput(const KeyEvent& rKEvt)
 {
-    sal_Bool bReturn = false;
-    ScViewData& rViewData = *pViewShell->GetViewData();
+    bool bReturn = false;
+    ScViewData& rViewData = pViewShell->GetViewData();
 
     switch ( rKEvt.GetKeyCode().GetCode() )
     {
         case KEY_ESCAPE:
             if ( pViewShell->IsDrawTextShell() || aSfxRequest.GetSlot() == SID_DRAW_NOTEEDIT )
             {
-                // in normale Draw-Shell, wenn Objekt selektiert, sonst Zeichnen aus
-                rViewData.GetDispatcher().Execute(aSfxRequest.GetSlot(), SFX_CALLMODE_SLOT | SFX_CALLMODE_RECORD);
-                bReturn = sal_True;
+                // if object selected -> normal draw-shell, else turn off drawing
+                rViewData.GetDispatcher().Execute(aSfxRequest.GetSlot(), SfxCallMode::SLOT | SfxCallMode::RECORD);
+                bReturn = true;
             }
             else if ( pViewShell->IsDrawSelMode() )
             {
                 pView->UnmarkAll();
-                rViewData.GetDispatcher().Execute(SID_OBJECT_SELECT, SFX_CALLMODE_SLOT | SFX_CALLMODE_RECORD);
-                bReturn = sal_True;
+                rViewData.GetDispatcher().Execute(SID_OBJECT_SELECT, SfxCallMode::SLOT | SfxCallMode::RECORD);
+                bReturn = true;
             }
             else if ( pView->AreObjectsMarked() )
             {
@@ -242,17 +245,17 @@ sal_Bool FuDraw::KeyInput(const KeyEvent& rKEvt)
                 else
                     pView->UnmarkAll();
 
-                //  Beim Bezier-Editieren ist jetzt wieder das Objekt selektiert
+                //  while bezier editing, object is selected
                 if (!pView->AreObjectsMarked())
                     pViewShell->SetDrawShell( false );
 
-                bReturn = sal_True;
+                bReturn = true;
             }
             break;
 
-        case KEY_DELETE:                    //! ueber Accelerator
+        case KEY_DELETE:                    //! via accelerator
             pView->DeleteMarked();
-            bReturn = sal_True;
+            bReturn = true;
         break;
 
         case KEY_RETURN:
@@ -264,17 +267,17 @@ sal_Bool FuDraw::KeyInput(const KeyEvent& rKEvt)
                 const SdrMarkList& rMarkList = pView->GetMarkedObjectList();
                 if( !pView->IsTextEdit() && 1 == rMarkList.GetMarkCount() )
                 {
-                    sal_Bool bOle = pViewShell->GetViewFrame()->GetFrame().IsInPlace();
+                    bool bOle = pViewShell->GetViewFrame()->GetFrame().IsInPlace();
                     SdrObject* pObj = rMarkList.GetMark( 0 )->GetMarkedSdrObj();
-                    if( pObj && pObj->ISA( SdrOle2Obj ) && !bOle )
+                    if( pObj && dynamic_cast<const SdrOle2Obj*>( pObj) !=  nullptr && !bOle )
                     {
                         pViewShell->ActivateObject( static_cast< SdrOle2Obj* >( pObj ), 0 );
 
                         // consumed
-                        bReturn = sal_True;
+                        bReturn = true;
                     }
-                    else if ( lcl_KeyEditMode( pObj, pViewShell, NULL ) )       // start text edit for suitable object
-                        bReturn = sal_True;
+                    else if ( lcl_KeyEditMode( pObj, pViewShell, nullptr ) )       // start text edit for suitable object
+                        bReturn = true;
                 }
             }
         }
@@ -290,38 +293,41 @@ sal_Bool FuDraw::KeyInput(const KeyEvent& rKEvt)
                 if( !pView->IsTextEdit() && 1 == rMarkList.GetMarkCount() )
                 {
                     SdrObject* pObj = rMarkList.GetMark( 0 )->GetMarkedSdrObj();
-                    if ( lcl_KeyEditMode( pObj, pViewShell, NULL ) )            // start text edit for suitable object
-                        bReturn = sal_True;
+                    if ( lcl_KeyEditMode( pObj, pViewShell, nullptr ) )            // start text edit for suitable object
+                        bReturn = true;
                 }
             }
         }
         break;
 
-        // #97016#
         case KEY_TAB:
         {
             // in calc do NOT start draw object selection using TAB/SHIFT-TAB when
             // there is not yet a object selected
             if(pView->AreObjectsMarked())
             {
-                KeyCode aCode = rKEvt.GetKeyCode();
+                vcl::KeyCode aCode = rKEvt.GetKeyCode();
 
                 if ( !aCode.IsMod1() && !aCode.IsMod2() )
                 {
                     // changeover to the next object
                     if(!pView->MarkNextObj( !aCode.IsShift() ))
                     {
-                        // No next object: go over open end and
-                        // get first from the other side
-                        pView->UnmarkAllObj();
-                        pView->MarkNextObj(!aCode.IsShift());
+                        //If there is only one object, don't do the UnmarkAllObj() & MarkNextObj().
+                        if ( pView->GetMarkableObjCount() > 1 && pView->HasMarkableObj() )
+                        {
+                            // No next object: go over open end and
+                            // get first from the other side
+                            pView->UnmarkAllObj();
+                            pView->MarkNextObj(!aCode.IsShift());
+                        }
                     }
 
                     // II
                     if(pView->AreObjectsMarked())
                         pView->MakeVisible(pView->GetAllMarkedRect(), *pWindow);
 
-                    bReturn = sal_True;
+                    bReturn = true;
                 }
 
                 // handle Mod1 and Mod2 to get travelling running on different systems
@@ -329,7 +335,7 @@ sal_Bool FuDraw::KeyInput(const KeyEvent& rKEvt)
                 {
                     // II do something with a selected handle?
                     const SdrHdlList& rHdlList = pView->GetHdlList();
-                    sal_Bool bForward(!rKEvt.GetKeyCode().IsShift());
+                    bool bForward(!rKEvt.GetKeyCode().IsShift());
 
                     ((SdrHdlList&)rHdlList).TravelFocusHdl(bForward);
 
@@ -344,63 +350,60 @@ sal_Bool FuDraw::KeyInput(const KeyEvent& rKEvt)
                     }
 
                     // consumed
-                    bReturn = sal_True;
+                    bReturn = true;
                 }
             }
         }
         break;
 
-        // #97016#
         case KEY_END:
         {
             // in calc do NOT select the last draw object when
             // there is not yet a object selected
             if(pView->AreObjectsMarked())
             {
-                KeyCode aCode = rKEvt.GetKeyCode();
+                vcl::KeyCode aCode = rKEvt.GetKeyCode();
 
                 if ( aCode.IsMod1() )
                 {
                     // mark last object
                     pView->UnmarkAllObj();
-                    pView->MarkNextObj(false);
+                    pView->MarkNextObj();
 
                     // II
                     if(pView->AreObjectsMarked())
                         pView->MakeVisible(pView->GetAllMarkedRect(), *pWindow);
 
-                    bReturn = sal_True;
+                    bReturn = true;
                 }
             }
         }
         break;
 
-        // #97016#
         case KEY_HOME:
         {
             // in calc do NOT select the first draw object when
             // there is not yet a object selected
             if(pView->AreObjectsMarked())
             {
-                KeyCode aCode = rKEvt.GetKeyCode();
+                vcl::KeyCode aCode = rKEvt.GetKeyCode();
 
                 if ( aCode.IsMod1() )
                 {
                     // mark first object
                     pView->UnmarkAllObj();
-                    pView->MarkNextObj(sal_True);
+                    pView->MarkNextObj(true);
 
                     // II
                     if(pView->AreObjectsMarked())
                         pView->MakeVisible(pView->GetAllMarkedRect(), *pWindow);
 
-                    bReturn = sal_True;
+                    bReturn = true;
                 }
             }
         }
         break;
 
-        // #97016#
         case KEY_UP:
         case KEY_DOWN:
         case KEY_LEFT:
@@ -427,30 +430,30 @@ sal_Bool FuDraw::KeyInput(const KeyEvent& rKEvt)
 
                 if (nCode == KEY_UP)
                 {
-                    // Scroll nach oben
+                    // scroll up
                     nX = 0;
                     nY =-1;
                 }
                 else if (nCode == KEY_DOWN)
                 {
-                    // Scroll nach unten
+                    // scroll down
                     nX = 0;
                     nY = 1;
                 }
                 else if (nCode == KEY_LEFT)
                 {
-                    // Scroll nach links
+                    // scroll left
                     nX =-1;
                     nY = 0;
                 }
                 else if (nCode == KEY_RIGHT)
                 {
-                    // Scroll nach rechts
+                    // scroll right
                     nX = 1;
                     nY = 0;
                 }
 
-                sal_Bool bReadOnly = rViewData.GetDocShell()->IsReadOnly();
+                bool bReadOnly = rViewData.GetDocShell()->IsReadOnly();
 
                 if(!rKEvt.GetKeyCode().IsMod1() && !bReadOnly)
                 {
@@ -480,7 +483,7 @@ sal_Bool FuDraw::KeyInput(const KeyEvent& rKEvt)
                         const SdrHdlList& rHdlList = pView->GetHdlList();
                         SdrHdl* pHdl = rHdlList.GetFocusHdl();
 
-                        if(0L == pHdl)
+                        if(nullptr == pHdl)
                         {
                             // only take action when move is allowed
                             if(pView->IsMoveAllowed())
@@ -523,7 +526,7 @@ sal_Bool FuDraw::KeyInput(const KeyEvent& rKEvt)
                                 // II
                                 pView->MakeVisible(pView->GetAllMarkedRect(), *pWindow);
 
-                                bReturn = sal_True;
+                                bReturn = true;
                             }
                         }
                         else
@@ -537,16 +540,16 @@ sal_Bool FuDraw::KeyInput(const KeyEvent& rKEvt)
                                 const SdrDragStat& rDragStat = pView->GetDragStat();
 
                                 // start dragging
-                                pView->BegDragObj(aStartPoint, 0, pHdl, 0);
+                                pView->BegDragObj(aStartPoint, nullptr, pHdl, 0);
 
                                 if(pView->IsDragObj())
                                 {
                                     bool bWasNoSnap = rDragStat.IsNoSnap();
-                                    sal_Bool bWasSnapEnabled = pView->IsSnapEnabled();
+                                    bool bWasSnapEnabled = pView->IsSnapEnabled();
 
                                     // switch snapping off
                                     if(!bWasNoSnap)
-                                        ((SdrDragStat&)rDragStat).SetNoSnap(sal_True);
+                                        ((SdrDragStat&)rDragStat).SetNoSnap();
                                     if(bWasSnapEnabled)
                                         pView->SetSnapEnabled(false);
 
@@ -564,7 +567,7 @@ sal_Bool FuDraw::KeyInput(const KeyEvent& rKEvt)
                                 Rectangle aVisRect(aEndPoint - Point(100, 100), Size(200, 200));
                                 pView->MakeVisible(aVisRect, *pWindow);
 
-                                bReturn = sal_True;
+                                bReturn = true;
                             }
                         }
                     }
@@ -573,7 +576,6 @@ sal_Bool FuDraw::KeyInput(const KeyEvent& rKEvt)
         }
         break;
 
-        // #97016#
         case KEY_SPACE:
         {
             // in calc do only something when draw objects are selected
@@ -607,12 +609,12 @@ sal_Bool FuDraw::KeyInput(const KeyEvent& rKEvt)
                             pView->MarkPoint(*pHdl);
                         }
 
-                        if(0L == rHdlList.GetFocusHdl())
+                        if(nullptr == rHdlList.GetFocusHdl())
                         {
                             // restore point with focus
-                            SdrHdl* pNewOne = 0L;
+                            SdrHdl* pNewOne = nullptr;
 
-                            for(sal_uInt32 a(0); !pNewOne && a < rHdlList.GetHdlCount(); a++)
+                            for(size_t a = 0; !pNewOne && a < rHdlList.GetHdlCount(); ++a)
                             {
                                 SdrHdl* pAct = rHdlList.GetHdl(a);
 
@@ -631,7 +633,7 @@ sal_Bool FuDraw::KeyInput(const KeyEvent& rKEvt)
                             }
                         }
 
-                        bReturn = sal_True;
+                        bReturn = true;
                     }
                 }
             }
@@ -655,23 +657,16 @@ sal_Bool FuDraw::KeyInput(const KeyEvent& rKEvt)
 
             // start text edit for suitable object, pass key event to OutlinerView
             if ( lcl_KeyEditMode( pObj, pViewShell, &rKEvt ) )
-                bReturn = sal_True;
+                bReturn = true;
         }
     }
 
-    return (bReturn);
-}
-
-// II
-void FuDraw::SelectionHasChanged()
-{
-    const SdrHdlList& rHdlList = pView->GetHdlList();
-    ((SdrHdlList&)rHdlList).ResetFocusHdl();
+    return bReturn;
 }
 
 /*************************************************************************
 |*
-|* Function aktivieren
+|* enable function
 |*
 \************************************************************************/
 
@@ -682,7 +677,7 @@ void FuDraw::Activate()
 
 /*************************************************************************
 |*
-|* Function deaktivieren
+|* disable function
 |*
 \************************************************************************/
 
@@ -693,24 +688,24 @@ void FuDraw::Deactivate()
 
 /*************************************************************************
 |*
-|* Maus-Pointer umschalten
+|* toggle mouse-pointer
 |*
 \************************************************************************/
 
-static sal_Bool lcl_UrlHit( SdrView* pView, const Point& rPosPixel, Window* pWindow )
+static bool lcl_UrlHit( SdrView* pView, const Point& rPosPixel, vcl::Window* pWindow )
 {
     SdrViewEvent aVEvt;
-    MouseEvent aMEvt( rPosPixel, 1, 0, MOUSE_LEFT );
-    SdrHitKind eHit = pView->PickAnything( aMEvt, SDRMOUSEBUTTONDOWN, aVEvt );
+    MouseEvent aMEvt( rPosPixel, 1, MouseEventModifiers::NONE, MOUSE_LEFT );
+    SdrHitKind eHit = pView->PickAnything( aMEvt, SdrMouseEventKind::BUTTONDOWN, aVEvt );
 
-    if ( eHit != SDRHIT_NONE && aVEvt.pObj != NULL )
+    if ( eHit != SDRHIT_NONE && aVEvt.pObj != nullptr )
     {
         if ( ScDrawLayer::GetIMapInfo( aVEvt.pObj ) && ScDrawLayer::GetHitIMapObject(
                                 aVEvt.pObj, pWindow->PixelToLogic(rPosPixel), *pWindow ) )
-            return sal_True;
+            return true;
 
         if ( aVEvt.eEvent == SDREVENT_EXECUTEURL )
-            return sal_True;
+            return true;
     }
 
     return false;
@@ -721,19 +716,19 @@ void FuDraw::ForcePointer(const MouseEvent* pMEvt)
     if ( !pView->IsAction() )
     {
         Point aPosPixel = pWindow->GetPointerPosPixel();
-        sal_Bool bAlt       = pMEvt && pMEvt->IsMod2();
+        bool bAlt       = pMEvt && pMEvt->IsMod2();
         Point aPnt      = pWindow->PixelToLogic( aPosPixel );
         SdrHdl* pHdl    = pView->PickHandle(aPnt);
         SdrObject* pObj;
         SdrPageView* pPV;
 
-        ScMacroInfo* pInfo = 0;
-        if ( pView->PickObj(aPnt, pView->getHitTolLog(), pObj, pPV, SDRSEARCH_ALSOONMASTER) )
+        ScMacroInfo* pInfo = nullptr;
+        if ( pView->PickObj(aPnt, pView->getHitTolLog(), pObj, pPV, SdrSearchOptions::ALSOONMASTER) )
         {
             if ( pObj->IsGroupObject() )
             {
-                SdrObject* pHit = 0;
-                if ( pView->PickObj(aMDPos, pView->getHitTolLog(), pHit, pPV, SDRSEARCH_DEEP ) )
+                SdrObject* pHit = nullptr;
+                if ( pView->PickObj(aMDPos, pView->getHitTolLog(), pHit, pPV, SdrSearchOptions::DEEP ) )
                     pObj = pHit;
             }
             pInfo = ScDrawLayer::GetMacroInfo( pObj );
@@ -741,43 +736,43 @@ void FuDraw::ForcePointer(const MouseEvent* pMEvt)
 
         if ( pView->IsTextEdit() )
         {
-            pViewShell->SetActivePointer(Pointer(POINTER_TEXT));        // kann nicht sein ?
+            pViewShell->SetActivePointer(Pointer(PointerStyle::Text));        // can't be ?
         }
         else if ( pHdl )
         {
             pViewShell->SetActivePointer(
-                pView->GetPreferedPointer( aPnt, pWindow ) );
+                pView->GetPreferredPointer( aPnt, pWindow ) );
         }
         else if ( pView->IsMarkedHit(aPnt) )
         {
-            pViewShell->SetActivePointer( Pointer(POINTER_MOVE) );
+            pViewShell->SetActivePointer( Pointer(PointerStyle::Move) );
         }
         else if ( !bAlt && ( !pMEvt || !pMEvt->GetButtons() )
                         && lcl_UrlHit( pView, aPosPixel, pWindow ) )
         {
-            //  kann mit ALT unterdrueckt werden
-            pWindow->SetPointer( Pointer( POINTER_REFHAND ) );          // Text-URL / ImageMap
+            //  could be suppressed with ALT
+            pWindow->SetPointer( Pointer( PointerStyle::RefHand ) );          // Text-URL / ImageMap
         }
-        else if ( !bAlt && pView->PickObj(aPnt, pView->getHitTolLog(), pObj, pPV, SDRSEARCH_PICKMACRO) )
+        else if ( !bAlt && pView->PickObj(aPnt, pView->getHitTolLog(), pObj, pPV, SdrSearchOptions::PICKMACRO) )
         {
-            //  kann mit ALT unterdrueckt werden
-            SdrObjMacroHitRec aHitRec;  //! muss da noch irgendwas gesetzt werden ????
+            //  could be suppressed with ALT
+            SdrObjMacroHitRec aHitRec;  //! something missing ????
             pViewShell->SetActivePointer( pObj->GetMacroPointer(aHitRec) );
         }
         else if ( !bAlt && pInfo && (!pInfo->GetMacro().isEmpty() || !pInfo->GetHlink().isEmpty()) )
-            pWindow->SetPointer( Pointer( POINTER_REFHAND ) );
+            pWindow->SetPointer( Pointer( PointerStyle::RefHand ) );
         else if ( IsDetectiveHit( aPnt ) )
-            pViewShell->SetActivePointer( Pointer( POINTER_DETECTIVE ) );
+            pViewShell->SetActivePointer( Pointer( PointerStyle::Detective ) );
         else
             pViewShell->SetActivePointer( aNewPointer );            //! in Gridwin?
     }
 }
 
-sal_Bool FuDraw::IsEditingANote() const
+bool FuDraw::IsEditingANote() const
 {
     const SdrMarkList& rMarkList = pView->GetMarkedObjectList();
-    sal_Int32 backval=rMarkList.GetMarkCount();
-    for (sal_Int32 nlv1=0;nlv1<backval;nlv1++)
+    const size_t backval=rMarkList.GetMarkCount();
+    for (size_t nlv1=0; nlv1<backval; ++nlv1)
     {
         SdrObject* pObj = rMarkList.GetMark( nlv1 )->GetMarkedSdrObj();
         if ( ScDrawLayer::IsNoteCaption( pObj ) )
@@ -788,9 +783,9 @@ sal_Bool FuDraw::IsEditingANote() const
     return false;
 }
 
-sal_Bool FuDraw::IsSizingOrMovingNote( const MouseEvent& rMEvt ) const
+bool FuDraw::IsSizingOrMovingNote( const MouseEvent& rMEvt ) const
 {
-    sal_Bool bIsSizingOrMoving = false;
+    bool bIsSizingOrMoving = false;
     if ( rMEvt.IsLeft() )
     {
         const SdrMarkList& rNoteMarkList = pView->GetMarkedObjectList();
