@@ -65,9 +65,9 @@ ScFunctionChildWindow::ScFunctionChildWindow( vcl::Window* pParentP,
 {
     VclPtr<ScFunctionDockWin> pWin = VclPtr<ScFunctionDockWin>::Create( pBindings, this,
                                         pParentP, ScResId( FID_FUNCTION_BOX ) );
-    pWindow = pWin;
+    SetWindow(pWin);
 
-    eChildAlignment = SfxChildAlignment::RIGHT;
+    SetAlignment(SfxChildAlignment::RIGHT);
 
     pWin->Initialize( pInfo );
 }
@@ -90,14 +90,14 @@ ScFunctionDockWin::ScFunctionDockWin( SfxBindings* pBindingsP,
                 SfxChildWindow *pCW, vcl::Window* pParent, const ResId& rResId ) :
 
     SfxDockingWindow( pBindingsP, pCW, pParent, rResId ),
-    aPrivatSplit    ( VclPtr<ScPrivatSplit>::Create( this, ResId( FT_SPLIT, *rResId.GetResMgr()  ),SC_SPLIT_VERT) ),
+    aPrivatSplit    ( VclPtr<ScPrivatSplit>::Create( this, ResId( FT_SPLIT, *rResId.GetResMgr() ) ) ),
     aCatBox         ( VclPtr<ListBox>::Create( this, ResId( CB_CAT, *rResId.GetResMgr() ) ) ),
     aFuncList       ( VclPtr<ListBox>::Create( this, ResId( LB_FUNC, *rResId.GetResMgr() ) ) ),
     aDDFuncList     ( VclPtr<ListBox>::Create( this, ResId( DDLB_FUNC, *rResId.GetResMgr() ) ) ),
     aInsertButton   ( VclPtr<ImageButton>::Create( this, ResId( IMB_INSERT, *rResId.GetResMgr() ) ) ),
     aFiFuncDesc     ( VclPtr<FixedText>::Create( this, ResId( FI_FUNCDESC, *rResId.GetResMgr() ) ) ),
     aOldSize        (0,0),
-    pFuncDesc       (NULL)
+    pFuncDesc       (nullptr)
 {
     FreeResource();
     InitLRUList();
@@ -106,13 +106,13 @@ ScFunctionDockWin::ScFunctionDockWin( SfxBindings* pBindingsP,
     aIdle.SetPriority(SchedulerPriority::LOWER);
     aIdle.SetIdleHdl(LINK( this, ScFunctionDockWin, TimerHdl));
 
-    if (pCW != NULL)
+    if (pCW != nullptr)
         eSfxNewAlignment=GetAlignment();
     else
         eSfxNewAlignment=SfxChildAlignment::RIGHT;
     eSfxOldAlignment=eSfxNewAlignment;
     aFiFuncDesc->SetUpdateMode(true);
-    pAllFuncList=aFuncList.get();
+    pAllFuncList=aFuncList;
     aDDFuncList->Disable();
     aDDFuncList->Hide();
     nArgs=0;
@@ -124,17 +124,16 @@ ScFunctionDockWin::ScFunctionDockWin( SfxBindings* pBindingsP,
     aFiFuncDesc->SetFont(aFont);
     aFiFuncDesc->SetBackground( GetBackground() );       //! never transparent?
 
-    Link<> aLink=LINK( this, ScFunctionDockWin, SelHdl);
+    Link<ListBox&,void> aLink=LINK( this, ScFunctionDockWin, SelHdl);
     aCatBox->SetSelectHdl(aLink);
     aFuncList->SetSelectHdl(aLink);
     aDDFuncList->SetSelectHdl(aLink);
 
-    Link<> a2Link=LINK( this, ScFunctionDockWin, SetSelectionHdl);
-    aFuncList->SetDoubleClickHdl(a2Link);
+    aFuncList->SetDoubleClickHdl(LINK( this, ScFunctionDockWin, SetSelectionHdl));
     aDDFuncList->SetSelectHdl(aLink);
-    aInsertButton->SetClickHdl(a2Link);
+    aInsertButton->SetClickHdl(LINK( this, ScFunctionDockWin, SetSelectionClickHdl));
 
-    Link<> a3Link=LINK( this, ScFunctionDockWin, SetSplitHdl);
+    Link<ScPrivatSplit&,void> a3Link=LINK( this, ScFunctionDockWin, SetSplitHdl);
     aPrivatSplit->SetCtrModifiedHdl(a3Link);
     StartListening( *pBindingsP, true );
 
@@ -149,7 +148,7 @@ ScFunctionDockWin::ScFunctionDockWin( SfxBindings* pBindingsP,
     Range aYRange(3*aTxtSize.Height()+aFuncList->GetPosPixel().Y(),
                 GetOutputSizePixel().Height()-2*aTxtSize.Height());
     aPrivatSplit->SetYRange(aYRange);
-    SelHdl(aCatBox.get());
+    SelHdl(*aCatBox.get());
     bInit = true;
 }
 
@@ -276,8 +275,8 @@ void ScFunctionDockWin::SetSize()
                             aPrivatSplit->Hide();
                             aFuncList->Disable();
                             aFuncList->Hide();
-                            pAllFuncList=aDDFuncList.get();
-                            SelHdl(aCatBox.get());
+                            pAllFuncList=aDDFuncList;
+                            SelHdl(*aCatBox.get());
                             aDDFuncList->SelectEntryPos(nSelEntry);
                         }
                         break;
@@ -294,8 +293,8 @@ void ScFunctionDockWin::SetSize()
                             aPrivatSplit->Show();
                             aFuncList->Enable();
                             aFuncList->Show();
-                            pAllFuncList=aFuncList.get();
-                            SelHdl(aCatBox.get());
+                            pAllFuncList=aFuncList;
+                            SelHdl(*aCatBox.get());
                             aFuncList->SelectEntryPos(nSelEntry);
                         }
                         break;
@@ -573,22 +572,22 @@ void ScFunctionDockWin::SetDescription()
         OUStringBuffer aBuf(pAllFuncList->GetSelectEntry());
         if(nDockMode==0)
         {
-            aBuf.appendAscii(":\n\n");
+            aBuf.append(":\n\n");
         }
         else
         {
-            aBuf.appendAscii(":   ");
+            aBuf.append(":   ");
         }
 
         aBuf.append(pDesc->GetParamList());
 
         if(nDockMode==0)
         {
-            aBuf.appendAscii("\n\n");
+            aBuf.append("\n\n");
         }
         else
         {
-            aBuf.appendAscii("\n");
+            aBuf.append("\n");
         }
 
         aBuf.append(*pDesc->pFuncDesc);
@@ -762,7 +761,7 @@ void ScFunctionDockWin::UpdateFunctionList()
         {
             pAllFuncList->SetEntryData(
                 pAllFuncList->InsertEntry( *(pDesc->pFuncName) ),
-                (void*)pDesc );
+                const_cast<ScFuncDesc *>(pDesc) );
             pDesc = pFuncMgr->Next();
         }
     }
@@ -773,7 +772,7 @@ void ScFunctionDockWin::UpdateFunctionList()
         {
             const formula::IFunctionDescription* pDesc = *iter;
             if (pDesc)
-                pAllFuncList->SetEntryData( pAllFuncList->InsertEntry( pDesc->getFunctionName()), (void*)pDesc);
+                pAllFuncList->SetEntryData( pAllFuncList->InsertEntry( pDesc->getFunctionName()), const_cast<formula::IFunctionDescription *>(pDesc));
         }
     }
 
@@ -818,11 +817,14 @@ void ScFunctionDockWin::DoEnter()
     {
 
         ScModule* pScMod = SC_MOD();
-        ScTabViewShell* pViewSh = PTR_CAST( ScTabViewShell, pCurSh);
+        ScTabViewShell* pViewSh = dynamic_cast<ScTabViewShell*>( pCurSh );
         ScInputHandler* pHdl = pScMod->GetInputHdl( pViewSh );
         if(!pScMod->IsEditMode())
         {
             pScMod->SetInputMode(SC_INPUT_TABLE);
+            // the above call can result in us being disposed
+            if (OutputDevice::isDisposed())
+                return;
             aString = "=";
             aString += pAllFuncList->GetSelectEntry();
             if (pHdl)
@@ -877,7 +879,7 @@ void ScFunctionDockWin::DoEnter()
                 aString += pAllFuncList->GetSelectEntry();
             }
             EditView *pEdView=pHdl->GetActiveView();
-            if(pEdView!=NULL) // @ Wegen Absturz bei Namen festlegen
+            if(pEdView!=nullptr) // @ Wegen Absturz bei Namen festlegen
             {
                 if(nArgs>0)
                 {
@@ -891,7 +893,7 @@ void ScFunctionDockWin::DoEnter()
                 else
                 {
                     aString += "()";
-                    pEdView->InsertText(aString,false);
+                    pEdView->InsertText(aString);
                     pHdl->DataChanged();
                 }
             }
@@ -923,21 +925,18 @@ void ScFunctionDockWin::DoEnter()
 #*
 #************************************************************************/
 
-IMPL_LINK( ScFunctionDockWin, SelHdl, ListBox*, pLb )
+IMPL_LINK_TYPED( ScFunctionDockWin, SelHdl, ListBox&, rLb, void )
 {
-    if ( pLb == aCatBox.get() )
+    if ( &rLb == aCatBox.get() )
     {
         UpdateFunctionList();
         SetDescription();
     }
 
-    if ( pLb == aFuncList.get() || pLb == aDDFuncList.get() )
+    if ( &rLb == aFuncList.get() || &rLb == aDDFuncList.get() )
     {
         SetDescription();
     }
-
-    //SetSize();
-    return 0;
 }
 
 /*************************************************************************
@@ -955,15 +954,13 @@ IMPL_LINK( ScFunctionDockWin, SelHdl, ListBox*, pLb )
 #*
 #************************************************************************/
 
-IMPL_LINK( ScFunctionDockWin, SetSelectionHdl, void*, pCtrl )
+IMPL_LINK_NOARG_TYPED( ScFunctionDockWin, SetSelectionClickHdl, Button*, void )
 {
-    if (static_cast<ImageButton *>(pCtrl) == aInsertButton.get() ||
-        static_cast<ListBox *>(pCtrl) == aFuncList.get())
-    {
-        DoEnter();          // Uebernimmt die Eingabe
-    }
-
-    return 0;
+    DoEnter();          // Uebernimmt die Eingabe
+}
+IMPL_LINK_NOARG_TYPED( ScFunctionDockWin, SetSelectionHdl, ListBox&, void )
+{
+    DoEnter();          // Uebernimmt die Eingabe
 }
 
 /*************************************************************************
@@ -981,9 +978,9 @@ IMPL_LINK( ScFunctionDockWin, SetSelectionHdl, void*, pCtrl )
 #*
 #************************************************************************/
 
-IMPL_LINK( ScFunctionDockWin, SetSplitHdl, ScPrivatSplit*, pCtrl )
+IMPL_LINK_TYPED( ScFunctionDockWin, SetSplitHdl, ScPrivatSplit&, rCtrl, void )
 {
-    if (pCtrl == aPrivatSplit.get())
+    if (&rCtrl == aPrivatSplit.get())
     {
         short nDeltaY=aPrivatSplit->GetDeltaY();
         Size aFLSize=aFuncList->GetSizePixel();
@@ -997,8 +994,6 @@ IMPL_LINK( ScFunctionDockWin, SetSplitHdl, ScPrivatSplit*, pCtrl )
         aFiFuncDesc->SetPosPixel(aFDTopLeft);
         aFiFuncDesc->SetSizePixel(aFDSize);
     }
-
-    return 0;
 }
 
 void ScFunctionDockWin::ToggleFloatingMode()
@@ -1023,7 +1018,7 @@ IMPL_LINK_NOARG_TYPED(ScFunctionDockWin, TimerHdl, Idle *, void)
 void ScFunctionDockWin::Initialize(SfxChildWinInfo *pInfo)
 {
     OUString aStr;
-    if(pInfo!=NULL)
+    if(pInfo!=nullptr)
     {
         if ( !pInfo->aExtraString.isEmpty() )
         {
@@ -1058,7 +1053,7 @@ void ScFunctionDockWin::Initialize(SfxChildWinInfo *pInfo)
         aStr = aStr.copy( n1+1 );
         sal_Int32 nSelPos = aStr.toInt32();
         aCatBox->SelectEntryPos(nSelPos);
-        SelHdl(aCatBox.get());
+        SelHdl(*aCatBox.get());
 
         //  if the window has already been shown (from SfxDockingWindow::Initialize if docked),
         //  set the splitter position now, otherwise it is set in StateChanged with type INITSHOW
