@@ -38,8 +38,7 @@
 #include "funcdesc.hxx"
 #include <com/sun/star/document/LinkUpdateModes.hpp>
 #include <com/sun/star/sheet/FunctionArgument.hpp>
-#include "ScPanelFactory.hxx"
-#include <boost/scoped_array.hpp>
+#include <memory>
 
 using namespace com::sun::star;
 
@@ -99,7 +98,7 @@ SAL_DLLPUBLIC_EXPORT void * SAL_CALL sc_component_getFactory(
     const sal_Char * pImplName, void * pServiceManager, void * /* pRegistryKey */ )
 {
     if (!pServiceManager)
-        return NULL;
+        return nullptr;
 
     uno::Reference<lang::XSingleServiceFactory> xFactory;
     OUString aImpl(OUString::createFromAscii(pImplName));
@@ -161,7 +160,7 @@ SAL_DLLPUBLIC_EXPORT void * SAL_CALL sc_component_getFactory(
                 ScDocument_getSupportedServiceNames() ));
     }
 
-    void* pRet = NULL;
+    void* pRet = nullptr;
     if (xFactory.is())
     {
         xFactory->acquire();
@@ -186,7 +185,7 @@ uno::Reference<uno::XInterface> SAL_CALL ScSpreadsheetSettings_CreateInstance(
 {
     SolarMutexGuard aGuard;
     ScDLL::Init();
-    return (cppu::OWeakObject*)new ScSpreadsheetSettings();
+    return static_cast<cppu::OWeakObject*>(new ScSpreadsheetSettings());
 }
 
 OUString ScSpreadsheetSettings::getImplementationName_Static()
@@ -196,9 +195,7 @@ OUString ScSpreadsheetSettings::getImplementationName_Static()
 
 uno::Sequence<OUString> ScSpreadsheetSettings::getSupportedServiceNames_Static()
 {
-    uno::Sequence<OUString> aRet(1);
-    OUString* pArray = aRet.getArray();
-    pArray[0] = SCSPREADSHEETSETTINGS_SERVICE;
+    uno::Sequence<OUString> aRet { SCSPREADSHEETSETTINGS_SERVICE };
     return aRet;
 }
 
@@ -442,7 +439,7 @@ uno::Any SAL_CALL ScSpreadsheetSettings::getPropertyValue( const OUString& aProp
             OUString* pAry = aSeq.getArray();
             for (size_t i=0; i<nCount; ++i)
             {
-                OUString aEntry((*pUserList)[i]->GetString());
+                OUString aEntry((*pUserList)[i].GetString());
                 pAry[i] = aEntry;
             }
             aRet <<= aSeq;
@@ -502,7 +499,7 @@ void SAL_CALL ScRecentFunctionsObj::setRecentFunctionIds(
     sal_uInt16 nCount = (sal_uInt16) std::min( aRecentFunctionIds.getLength(), (sal_Int32) LRU_MAX );
     const sal_Int32* pAry = aRecentFunctionIds.getConstArray();
 
-    boost::scoped_array<sal_uInt16> pFuncs(nCount ? new sal_uInt16[nCount] : NULL);
+    std::unique_ptr<sal_uInt16[]> pFuncs(nCount ? new sal_uInt16[nCount] : nullptr);
     for (sal_uInt16 i=0; i<nCount; i++)
         pFuncs[i] = (sal_uInt16)pAry[i];        //! auf gueltige Werte testen?
 
