@@ -34,6 +34,7 @@
 #include <comphelper/classids.hxx>
 #include <toolkit/helper/vclunohelper.hxx>
 #include <svx/charthelper.hxx>
+#include <svtools/embedhlp.hxx>
 
 #include "chartuno.hxx"
 #include "miscuno.hxx"
@@ -49,19 +50,15 @@ using namespace com::sun::star;
 
 #define PROP_HANDLE_RELATED_CELLRANGES  1
 
-//------------------------------------------------------------------------
-
 SC_SIMPLE_SERVICE_INFO( ScChartObj, "ScChartObj", "com.sun.star.table.TableChart" )
 SC_SIMPLE_SERVICE_INFO( ScChartsObj, "ScChartsObj", "com.sun.star.table.TableCharts" )
 
-//------------------------------------------------------------------------
-
 static SdrOle2Obj* lcl_FindChartObj( ScDocShell* pDocShell, SCTAB nTab, const OUString& rName )
 {
     if (pDocShell)
     {
-        ScDocument* pDoc = pDocShell->GetDocument();
-        ScDrawLayer* pDrawLayer = pDoc->GetDrawLayer();
+        ScDocument& rDoc = pDocShell->GetDocument();
+        ScDrawLayer* pDrawLayer = rDoc.GetDrawLayer();
         if (pDrawLayer)
         {
             SdrPage* pPage = pDrawLayer->GetPage(static_cast<sal_uInt16>(nTab));
@@ -72,14 +69,14 @@ static SdrOle2Obj* lcl_FindChartObj( ScDocShell* pDocShell, SCTAB nTab, const OU
                 SdrObject* pObject = aIter.Next();
                 while (pObject)
                 {
-                    if ( pObject->GetObjIdentifier() == OBJ_OLE2 && pDoc->IsChart(pObject) )
+                    if ( pObject->GetObjIdentifier() == OBJ_OLE2 && ScDocument::IsChart(pObject) )
                     {
-                        uno::Reference < embed::XEmbeddedObject > xObj = ((SdrOle2Obj*)pObject)->GetObjRef();
+                        uno::Reference < embed::XEmbeddedObject > xObj = static_cast<SdrOle2Obj*>(pObject)->GetObjRef();
                         if ( xObj.is() )
                         {
                             OUString aObjName = pDocShell->GetEmbeddedObjectContainer().GetEmbeddedObjectName( xObj );
                             if ( aObjName == rName )
-                                return (SdrOle2Obj*)pObject;
+                                return static_cast<SdrOle2Obj*>(pObject);
                         }
                     }
                     pObject = aIter.Next();
@@ -87,32 +84,32 @@ static SdrOle2Obj* lcl_FindChartObj( ScDocShell* pDocShell, SCTAB nTab, const OU
             }
         }
     }
-    return NULL;
+    return nullptr;
 }
 
-//------------------------------------------------------------------------
-
 ScChartsObj::ScChartsObj(ScDocShell* pDocSh, SCTAB nT) :
     pDocShell( pDocSh ),
     nTab( nT )
 {
-    pDocShell->GetDocument()->AddUnoObject(*this);
+    pDocShell->GetDocument().AddUnoObject(*this);
 }
 
 ScChartsObj::~ScChartsObj()
 {
+    SolarMutexGuard g;
+
     if (pDocShell)
-        pDocShell->GetDocument()->RemoveUnoObject(*this);
+        pDocShell->GetDocument().RemoveUnoObject(*this);
 }
 
 void ScChartsObj::Notify( SfxBroadcaster&, const SfxHint& rHint )
 {
     //! Referenz-Update
 
-    if ( rHint.ISA( SfxSimpleHint ) &&
-            ((const SfxSimpleHint&)rHint).GetId() == SFX_HINT_DYING )
+    const SfxSimpleHint* pSimpleHint = dynamic_cast<const SfxSimpleHint*>(&rHint);
+    if ( pSimpleHint && pSimpleHint->GetId() == SFX_HINT_DYING )
     {
-        pDocShell = NULL;       // ungueltig geworden
+        pDocShell = nullptr;       // ungueltig geworden
     }
 }
 
@@ -121,8 +118,8 @@ ScChartObj* ScChartsObj::GetObjectByIndex_Impl(long nIndex) const
     OUString aName;
     if ( pDocShell )
     {
-        ScDocument* pDoc = pDocShell->GetDocument();
-        ScDrawLayer* pDrawLayer = pDoc->GetDrawLayer();
+        ScDocument& rDoc = pDocShell->GetDocument();
+        ScDrawLayer* pDrawLayer = rDoc.GetDrawLayer();
         if (pDrawLayer)
         {
             SdrPage* pPage = pDrawLayer->GetPage(static_cast<sal_uInt16>(nTab));
@@ -134,11 +131,11 @@ ScChartObj* ScChartsObj::GetObjectByIndex_Impl(long nIndex) const
                 SdrObject* pObject = aIter.Next();
                 while (pObject)
                 {
-                    if ( pObject->GetObjIdentifier() == OBJ_OLE2 && pDoc->IsChart(pObject) )
+                    if ( pObject->GetObjIdentifier() == OBJ_OLE2 && ScDocument::IsChart(pObject) )
                     {
                         if ( nPos == nIndex )
                         {
-                            uno::Reference < embed::XEmbeddedObject > xObj = ((SdrOle2Obj*)pObject)->GetObjRef();
+                            uno::Reference < embed::XEmbeddedObject > xObj = static_cast<SdrOle2Obj*>(pObject)->GetObjRef();
                             if ( xObj.is() )
                                 aName = pDocShell->GetEmbeddedObjectContainer().GetEmbeddedObjectName( xObj );
                             break;  // nicht weitersuchen
@@ -153,14 +150,14 @@ ScChartObj* ScChartsObj::GetObjectByIndex_Impl(long nIndex) const
 
     if (!aName.isEmpty())
         return new ScChartObj( pDocShell, nTab, aName );
-    return NULL;
+    return nullptr;
 }
 
 ScChartObj* ScChartsObj::GetObjectByName_Impl(const OUString& aName) const
 {
     if ( lcl_FindChartObj( pDocShell, nTab, aName ) )
         return new ScChartObj( pDocShell, nTab, aName );
-    return NULL;
+    return nullptr;
 }
 
 // XTableCharts
@@ -169,17 +166,18 @@ void SAL_CALL ScChartsObj::addNewByName( const OUString& rName,
                                         const awt::Rectangle& aRect,
                                         const uno::Sequence<table::CellRangeAddress>& aRanges,
                                         sal_Bool bColumnHeaders, sal_Bool bRowHeaders )
-                                    throw(::com::sun::star::uno::RuntimeException)
+                                    throw(css::uno::RuntimeException,
+                                          std::exception)
 {
     SolarMutexGuard aGuard;
     if (!pDocShell)
         return;
 
-    ScDocument* pDoc = pDocShell->GetDocument();
+    ScDocument& rDoc = pDocShell->GetDocument();
     ScDrawLayer* pModel = pDocShell->MakeDrawLayer();
     SdrPage* pPage = pModel->GetPage(static_cast<sal_uInt16>(nTab));
     OSL_ENSURE(pPage,"addChart: keine Page");
-    if (!pPage || !pDoc)
+    if (!pPage)
         return;
 
     //  chart can't be inserted if any ole object with that name exists on any table
@@ -215,7 +213,7 @@ void SAL_CALL ScChartsObj::addNewByName( const OUString& rName,
             //  Rechteck anpassen
             //! Fehler/Exception, wenn leer/ungueltig ???
             Point aRectPos( aRect.X, aRect.Y );
-            bool bLayoutRTL = pDoc->IsLayoutRTL( nTab );
+            bool bLayoutRTL = rDoc.IsLayoutRTL( nTab );
             if ( ( aRectPos.X() < 0 && !bLayoutRTL ) || ( aRectPos.X() > 0 && bLayoutRTL ) )
                 aRectPos.X() = 0;
 
@@ -233,14 +231,14 @@ void SAL_CALL ScChartsObj::addNewByName( const OUString& rName,
             sal_Int64 nAspect(embed::Aspects::MSOLE_CONTENT);
             MapUnit aMapUnit(VCLUnoHelper::UnoEmbed2VCLMapUnit( xObj->getMapUnit( nAspect ) ));
             Size aSize(aInsRect.GetSize());
-            aSize = Window::LogicToLogic( aSize, MapMode( MAP_100TH_MM ), MapMode( aMapUnit ) );
+            aSize = vcl::Window::LogicToLogic( aSize, MapMode( MAP_100TH_MM ), MapMode( aMapUnit ) );
             awt::Size aSz;
             aSz.Width = aSize.Width();
             aSz.Height = aSize.Height();
 
             // Calc -> DataProvider
             uno::Reference< chart2::data::XDataProvider > xDataProvider = new
-                ScChart2DataProvider( pDoc );
+                ScChart2DataProvider( &rDoc );
             // Chart -> DataReceiver
             uno::Reference< chart2::data::XDataReceiver > xReceiver;
             uno::Reference< embed::XComponentSupplier > xCompSupp( xObj, uno::UNO_QUERY );
@@ -249,7 +247,7 @@ void SAL_CALL ScChartsObj::addNewByName( const OUString& rName,
             if( xReceiver.is())
             {
                 OUString sRangeStr;
-                xNewRanges->Format(sRangeStr, SCR_ABS_3D, pDoc);
+                xNewRanges->Format(sRangeStr, SCR_ABS_3D, &rDoc);
 
                 // connect
                 if( !sRangeStr.isEmpty() )
@@ -278,8 +276,8 @@ void SAL_CALL ScChartsObj::addNewByName( const OUString& rName,
             }
 
             ScChartListener* pChartListener =
-                new ScChartListener( aName, pDoc, xNewRanges );
-            pDoc->GetChartListenerCollection()->insert( pChartListener );
+                new ScChartListener( aName, &rDoc, xNewRanges );
+            rDoc.GetChartListenerCollection()->insert( pChartListener );
             pChartListener->StartListeningTo();
 
             SdrOle2Obj* pObj = new SdrOle2Obj( ::svt::EmbeddedObjectRef( xObj, embed::Aspects::MSOLE_CONTENT ), aName, aInsRect );
@@ -298,15 +296,15 @@ void SAL_CALL ScChartsObj::addNewByName( const OUString& rName,
 }
 
 void SAL_CALL ScChartsObj::removeByName( const OUString& aName )
-                                            throw(uno::RuntimeException)
+                                            throw(uno::RuntimeException, std::exception)
 {
     SolarMutexGuard aGuard;
     SdrOle2Obj* pObj = lcl_FindChartObj( pDocShell, nTab, aName );
     if (pObj)
     {
-        ScDocument* pDoc = pDocShell->GetDocument();
-        pDoc->GetChartListenerCollection()->removeByName(aName);
-        ScDrawLayer* pModel = pDoc->GetDrawLayer();     // ist nicht 0
+        ScDocument& rDoc = pDocShell->GetDocument();
+        rDoc.GetChartListenerCollection()->removeByName(aName);
+        ScDrawLayer* pModel = rDoc.GetDrawLayer();     // ist nicht 0
         SdrPage* pPage = pModel->GetPage(static_cast<sal_uInt16>(nTab));    // ist nicht 0
 
         pModel->AddUndo( new SdrUndoDelObj( *pObj ) );
@@ -319,7 +317,7 @@ void SAL_CALL ScChartsObj::removeByName( const OUString& aName )
 // XEnumerationAccess
 
 uno::Reference<container::XEnumeration> SAL_CALL ScChartsObj::createEnumeration()
-                                                    throw(uno::RuntimeException)
+                                                    throw(uno::RuntimeException, std::exception)
 {
     SolarMutexGuard aGuard;
     return new ScIndexEnumeration(this, OUString("com.sun.star.table.TableChartsEnumeration"));
@@ -327,14 +325,14 @@ uno::Reference<container::XEnumeration> SAL_CALL ScChartsObj::createEnumeration(
 
 // XIndexAccess
 
-sal_Int32 SAL_CALL ScChartsObj::getCount() throw(uno::RuntimeException)
+sal_Int32 SAL_CALL ScChartsObj::getCount() throw(uno::RuntimeException, std::exception)
 {
     SolarMutexGuard aGuard;
     sal_Int32 nCount = 0;
     if ( pDocShell )
     {
-        ScDocument* pDoc = pDocShell->GetDocument();
-        ScDrawLayer* pDrawLayer = pDoc->GetDrawLayer();
+        ScDocument& rDoc = pDocShell->GetDocument();
+        ScDrawLayer* pDrawLayer = rDoc.GetDrawLayer();
         if (pDrawLayer)
         {
             SdrPage* pPage = pDrawLayer->GetPage(static_cast<sal_uInt16>(nTab));
@@ -345,7 +343,7 @@ sal_Int32 SAL_CALL ScChartsObj::getCount() throw(uno::RuntimeException)
                 SdrObject* pObject = aIter.Next();
                 while (pObject)
                 {
-                    if ( pObject->GetObjIdentifier() == OBJ_OLE2 && pDoc->IsChart(pObject) )
+                    if ( pObject->GetObjIdentifier() == OBJ_OLE2 && ScDocument::IsChart(pObject) )
                         ++nCount;
                     pObject = aIter.Next();
                 }
@@ -357,7 +355,7 @@ sal_Int32 SAL_CALL ScChartsObj::getCount() throw(uno::RuntimeException)
 
 uno::Any SAL_CALL ScChartsObj::getByIndex( sal_Int32 nIndex )
                             throw(lang::IndexOutOfBoundsException,
-                                    lang::WrappedTargetException, uno::RuntimeException)
+                                    lang::WrappedTargetException, uno::RuntimeException, std::exception)
 {
     SolarMutexGuard aGuard;
     uno::Reference<table::XTableChart> xChart(GetObjectByIndex_Impl(nIndex));
@@ -367,13 +365,13 @@ uno::Any SAL_CALL ScChartsObj::getByIndex( sal_Int32 nIndex )
         throw lang::IndexOutOfBoundsException();
 }
 
-uno::Type SAL_CALL ScChartsObj::getElementType() throw(uno::RuntimeException)
+uno::Type SAL_CALL ScChartsObj::getElementType() throw(uno::RuntimeException, std::exception)
 {
     SolarMutexGuard aGuard;
-    return getCppuType((uno::Reference<table::XTableChart>*)0);
+    return cppu::UnoType<table::XTableChart>::get();
 }
 
-sal_Bool SAL_CALL ScChartsObj::hasElements() throw(uno::RuntimeException)
+sal_Bool SAL_CALL ScChartsObj::hasElements() throw(uno::RuntimeException, std::exception)
 {
     SolarMutexGuard aGuard;
     return getCount() != 0;
@@ -381,7 +379,7 @@ sal_Bool SAL_CALL ScChartsObj::hasElements() throw(uno::RuntimeException)
 
 uno::Any SAL_CALL ScChartsObj::getByName( const OUString& aName )
             throw(container::NoSuchElementException,
-                    lang::WrappedTargetException, uno::RuntimeException)
+                    lang::WrappedTargetException, uno::RuntimeException, std::exception)
 {
     SolarMutexGuard aGuard;
     uno::Reference<table::XTableChart> xChart(GetObjectByName_Impl(aName));
@@ -391,19 +389,19 @@ uno::Any SAL_CALL ScChartsObj::getByName( const OUString& aName )
         throw container::NoSuchElementException();
 }
 
-uno::Sequence<OUString> SAL_CALL ScChartsObj::getElementNames() throw(uno::RuntimeException)
+uno::Sequence<OUString> SAL_CALL ScChartsObj::getElementNames() throw(uno::RuntimeException, std::exception)
 {
     SolarMutexGuard aGuard;
     if (pDocShell)
     {
-        ScDocument* pDoc = pDocShell->GetDocument();
+        ScDocument& rDoc = pDocShell->GetDocument();
 
         long nCount = getCount();
         uno::Sequence<OUString> aSeq(nCount);
         OUString* pAry = aSeq.getArray();
 
         long nPos = 0;
-        ScDrawLayer* pDrawLayer = pDoc->GetDrawLayer();
+        ScDrawLayer* pDrawLayer = rDoc.GetDrawLayer();
         if (pDrawLayer)
         {
             SdrPage* pPage = pDrawLayer->GetPage(static_cast<sal_uInt16>(nTab));
@@ -414,10 +412,10 @@ uno::Sequence<OUString> SAL_CALL ScChartsObj::getElementNames() throw(uno::Runti
                 SdrObject* pObject = aIter.Next();
                 while (pObject)
                 {
-                    if ( pObject->GetObjIdentifier() == OBJ_OLE2 && pDoc->IsChart(pObject) )
+                    if ( pObject->GetObjIdentifier() == OBJ_OLE2 && ScDocument::IsChart(pObject) )
                     {
                         OUString aName;
-                        uno::Reference < embed::XEmbeddedObject > xObj = ((SdrOle2Obj*)pObject)->GetObjRef();
+                        uno::Reference < embed::XEmbeddedObject > xObj = static_cast<SdrOle2Obj*>(pObject)->GetObjRef();
                         if ( xObj.is() )
                             aName = pDocShell->GetEmbeddedObjectContainer().GetEmbeddedObjectName( xObj );
 
@@ -436,14 +434,12 @@ uno::Sequence<OUString> SAL_CALL ScChartsObj::getElementNames() throw(uno::Runti
 }
 
 sal_Bool SAL_CALL ScChartsObj::hasByName( const OUString& aName )
-                                        throw(uno::RuntimeException)
+                                        throw(uno::RuntimeException, std::exception)
 {
     SolarMutexGuard aGuard;
-    return ( lcl_FindChartObj( pDocShell, nTab, aName ) != NULL );
+    return ( lcl_FindChartObj( pDocShell, nTab, aName ) != nullptr );
 }
 
-//------------------------------------------------------------------------
-
 ScChartObj::ScChartObj(ScDocShell* pDocSh, SCTAB nT, const OUString& rN)
     :ScChartObj_Base( m_aMutex )
     ,ScChartObj_PBase( ScChartObj_Base::rBHelper )
@@ -451,39 +447,41 @@ ScChartObj::ScChartObj(ScDocShell* pDocSh, SCTAB nT, const OUString& rN)
     ,nTab( nT )
     ,aChartName( rN )
 {
-    pDocShell->GetDocument()->AddUnoObject(*this);
+    pDocShell->GetDocument().AddUnoObject(*this);
 
     uno::Sequence< table::CellRangeAddress > aInitialPropValue;
-    registerPropertyNoMember( OUString( "RelatedCellRanges" ),
+    registerPropertyNoMember( "RelatedCellRanges",
         PROP_HANDLE_RELATED_CELLRANGES, beans::PropertyAttribute::MAYBEVOID,
-        ::getCppuType( &aInitialPropValue ), &aInitialPropValue );
+        cppu::UnoType<decltype(aInitialPropValue)>::get(), &aInitialPropValue );
 }
 
 ScChartObj::~ScChartObj()
 {
+    SolarMutexGuard g;
+
     if (pDocShell)
-        pDocShell->GetDocument()->RemoveUnoObject(*this);
+        pDocShell->GetDocument().RemoveUnoObject(*this);
 }
 
 void ScChartObj::Notify( SfxBroadcaster&, const SfxHint& rHint )
 {
     //! Referenz-Update
 
-    if ( rHint.ISA( SfxSimpleHint ) &&
-            ((const SfxSimpleHint&)rHint).GetId() == SFX_HINT_DYING )
+    const SfxSimpleHint* pSimpleHint = dynamic_cast<const SfxSimpleHint*>(&rHint);
+    if ( pSimpleHint && pSimpleHint->GetId() == SFX_HINT_DYING )
     {
-        pDocShell = NULL;       // ungueltig geworden
+        pDocShell = nullptr;       // ungueltig geworden
     }
 }
 
 void ScChartObj::GetData_Impl( ScRangeListRef& rRanges, bool& rColHeaders, bool& rRowHeaders ) const
 {
     bool bFound = false;
-    ScDocument* pDoc = (pDocShell? pDocShell->GetDocument(): 0);
 
-    if( pDoc )
+    if( pDocShell )
     {
-        uno::Reference< chart2::XChartDocument > xChartDoc( pDoc->GetChartByName( aChartName ) );
+        ScDocument& rDoc = pDocShell->GetDocument();
+        uno::Reference< chart2::XChartDocument > xChartDoc( rDoc.GetChartByName( aChartName ) );
         if( xChartDoc.is() )
         {
             uno::Reference< chart2::data::XDataReceiver > xReceiver( xChartDoc, uno::UNO_QUERY );
@@ -503,13 +501,13 @@ void ScChartObj::GetData_Impl( ScRangeListRef& rRanges, bool& rColHeaders, bool&
                     const beans::PropertyValue& rProp = pPropArray[i];
                     OUString aPropName(rProp.Name);
 
-                    if (aPropName.equalsAscii( "CellRangeRepresentation" ))
+                    if (aPropName == "CellRangeRepresentation")
                         rProp.Value >>= aRanges;
-                    else if (aPropName.equalsAscii( "DataRowSource" ))
+                    else if (aPropName == "DataRowSource")
                         eDataRowSource = (chart::ChartDataRowSource)ScUnoHelpFunctions::GetEnumFromAny( rProp.Value );
-                    else if (aPropName.equalsAscii( "HasCategories" ))
+                    else if (aPropName == "HasCategories")
                         bHasCategories = ScUnoHelpFunctions::GetBoolFromAny( rProp.Value );
-                    else if (aPropName.equalsAscii( "FirstCellAsLabel" ))
+                    else if (aPropName == "FirstCellAsLabel")
                         bFirstCellAsLabel = ScUnoHelpFunctions::GetBoolFromAny( rProp.Value );
                 }
 
@@ -523,14 +521,14 @@ void ScChartObj::GetData_Impl( ScRangeListRef& rRanges, bool& rColHeaders, bool&
                     rColHeaders=bHasCategories;
                     rRowHeaders=bFirstCellAsLabel;
                 }
-                rRanges->Parse( aRanges, pDoc);
+                rRanges->Parse( aRanges, &rDoc);
             }
             bFound = true;
         }
      }
     if( !bFound )
     {
-        rRanges = 0;
+        rRanges = nullptr;
         rColHeaders = false;
         rRowHeaders = false;
     }
@@ -540,15 +538,15 @@ void ScChartObj::Update_Impl( const ScRangeListRef& rRanges, bool bColHeaders, b
 {
     if (pDocShell)
     {
-        ScDocument* pDoc = pDocShell->GetDocument();
-        sal_Bool bUndo(pDoc->IsUndoEnabled());
+        ScDocument& rDoc = pDocShell->GetDocument();
+        bool bUndo(rDoc.IsUndoEnabled());
 
         if (bUndo)
         {
             pDocShell->GetUndoManager()->AddUndoAction(
                 new ScUndoChartData( pDocShell, aChartName, rRanges, bColHeaders, bRowHeaders, false ) );
         }
-        pDoc->UpdateChartArea( aChartName, rRanges, bColHeaders, bRowHeaders, false );
+        rDoc.UpdateChartArea( aChartName, rRanges, bColHeaders, bRowHeaders, false );
     }
 }
 
@@ -559,7 +557,8 @@ void ScChartObj::Update_Impl( const ScRangeListRef& rRanges, bool bColHeaders, b
     return *ScChartObj_PABase::getArrayHelper();
 }
 
-void ScChartObj::setFastPropertyValue_NoBroadcast( sal_Int32 nHandle, const uno::Any& rValue ) throw (uno::Exception)
+void ScChartObj::setFastPropertyValue_NoBroadcast( sal_Int32 nHandle, const uno::Any& rValue )
+    throw (uno::Exception, std::exception)
 {
     switch ( nHandle )
     {
@@ -578,11 +577,13 @@ void ScChartObj::setFastPropertyValue_NoBroadcast( sal_Int32 nHandle, const uno:
                         ScUnoConversion::FillScRange( aRange, aCellRange );
                         rRangeList->Append( aRange );
                     }
-                    ScDocument* pDoc = ( pDocShell ? pDocShell->GetDocument() : NULL );
-                    ScChartListenerCollection* pCollection = ( pDoc ? pDoc->GetChartListenerCollection() : NULL );
-                    if ( pCollection )
+                    if ( pDocShell )
                     {
-                        pCollection->ChangeListening( aChartName, rRangeList );
+                        ScChartListenerCollection* pCollection = pDocShell->GetDocument().GetChartListenerCollection();
+                        if ( pCollection )
+                        {
+                            pCollection->ChangeListening( aChartName, rRangeList );
+                        }
                     }
                 }
             }
@@ -598,11 +599,11 @@ void ScChartObj::getFastPropertyValue( uno::Any& rValue, sal_Int32 nHandle ) con
     {
         case PROP_HANDLE_RELATED_CELLRANGES:
         {
-            ScDocument* pDoc = ( pDocShell ? pDocShell->GetDocument() : NULL );
-            if (!pDoc)
+            if (!pDocShell)
                 break;
+            ScDocument& rDoc = pDocShell->GetDocument();
 
-            ScChartListenerCollection* pCollection = pDoc->GetChartListenerCollection();
+            ScChartListenerCollection* pCollection = rDoc.GetChartListenerCollection();
             if (!pCollection)
                 break;
 
@@ -658,7 +659,7 @@ void ScChartObj::disposing()
 
 // XTableChart
 
-sal_Bool SAL_CALL ScChartObj::getHasColumnHeaders() throw(uno::RuntimeException)
+sal_Bool SAL_CALL ScChartObj::getHasColumnHeaders() throw(uno::RuntimeException, std::exception)
 {
     SolarMutexGuard aGuard;
     ScRangeListRef xRanges = new ScRangeList;
@@ -668,17 +669,18 @@ sal_Bool SAL_CALL ScChartObj::getHasColumnHeaders() throw(uno::RuntimeException)
 }
 
 void SAL_CALL ScChartObj::setHasColumnHeaders( sal_Bool bHasColumnHeaders )
-                                                throw(uno::RuntimeException)
+    throw(uno::RuntimeException,
+          std::exception)
 {
     SolarMutexGuard aGuard;
     ScRangeListRef xRanges = new ScRangeList;
     bool bOldColHeaders, bOldRowHeaders;
     GetData_Impl( xRanges, bOldColHeaders, bOldRowHeaders );
-    if ( bOldColHeaders != (bHasColumnHeaders != false) )
+    if ( bOldColHeaders != bool(bHasColumnHeaders) )
         Update_Impl( xRanges, bHasColumnHeaders, bOldRowHeaders );
 }
 
-sal_Bool SAL_CALL ScChartObj::getHasRowHeaders() throw(uno::RuntimeException)
+sal_Bool SAL_CALL ScChartObj::getHasRowHeaders() throw(uno::RuntimeException, std::exception)
 {
     SolarMutexGuard aGuard;
     ScRangeListRef xRanges = new ScRangeList;
@@ -688,17 +690,17 @@ sal_Bool SAL_CALL ScChartObj::getHasRowHeaders() throw(uno::RuntimeException)
 }
 
 void SAL_CALL ScChartObj::setHasRowHeaders( sal_Bool bHasRowHeaders )
-                                                throw(uno::RuntimeException)
+    throw(uno::RuntimeException, std::exception)
 {
     SolarMutexGuard aGuard;
     ScRangeListRef xRanges = new ScRangeList;
     bool bOldColHeaders, bOldRowHeaders;
     GetData_Impl( xRanges, bOldColHeaders, bOldRowHeaders );
-    if ( bOldRowHeaders != (bHasRowHeaders != false) )
+    if ( bOldRowHeaders != bool(bHasRowHeaders) )
         Update_Impl( xRanges, bOldColHeaders, bHasRowHeaders );
 }
 
-uno::Sequence<table::CellRangeAddress> SAL_CALL ScChartObj::getRanges() throw(uno::RuntimeException)
+uno::Sequence<table::CellRangeAddress> SAL_CALL ScChartObj::getRanges() throw(uno::RuntimeException, std::exception)
 {
     SolarMutexGuard aGuard;
     ScRangeListRef xRanges = new ScRangeList;
@@ -731,7 +733,7 @@ uno::Sequence<table::CellRangeAddress> SAL_CALL ScChartObj::getRanges() throw(un
 }
 
 void SAL_CALL ScChartObj::setRanges( const uno::Sequence<table::CellRangeAddress>& aRanges )
-                                                throw(uno::RuntimeException)
+    throw(uno::RuntimeException, std::exception)
 {
     SolarMutexGuard aGuard;
     ScRangeListRef xOldRanges = new ScRangeList;
@@ -758,7 +760,7 @@ void SAL_CALL ScChartObj::setRanges( const uno::Sequence<table::CellRangeAddress
 
 // XEmbeddedObjectSupplier
 
-uno::Reference<lang::XComponent> SAL_CALL ScChartObj::getEmbeddedObject() throw(uno::RuntimeException)
+uno::Reference<lang::XComponent> SAL_CALL ScChartObj::getEmbeddedObject() throw(uno::RuntimeException, std::exception)
 {
     SolarMutexGuard aGuard;
     SdrOle2Obj* pObject = lcl_FindChartObj( pDocShell, nTab, aChartName );
@@ -768,18 +770,18 @@ uno::Reference<lang::XComponent> SAL_CALL ScChartObj::getEmbeddedObject() throw(
         return uno::Reference < lang::XComponent > ( pObject->GetObjRef()->getComponent(), uno::UNO_QUERY );
     }
 
-    return NULL;
+    return nullptr;
 }
 
 // XNamed
 
-OUString SAL_CALL ScChartObj::getName() throw(uno::RuntimeException)
+OUString SAL_CALL ScChartObj::getName() throw(uno::RuntimeException, std::exception)
 {
     SolarMutexGuard aGuard;
     return aChartName;
 }
 
-void SAL_CALL ScChartObj::setName( const OUString& /* aName */ ) throw(uno::RuntimeException)
+void SAL_CALL ScChartObj::setName( const OUString& /* aName */ ) throw(uno::RuntimeException, std::exception)
 {
     SolarMutexGuard aGuard;
     throw uno::RuntimeException();      // name cannot be changed
@@ -787,13 +789,9 @@ void SAL_CALL ScChartObj::setName( const OUString& /* aName */ ) throw(uno::Runt
 
 // XPropertySet
 
-uno::Reference< beans::XPropertySetInfo > ScChartObj::getPropertySetInfo() throw (uno::RuntimeException)
+uno::Reference< beans::XPropertySetInfo > ScChartObj::getPropertySetInfo() throw (uno::RuntimeException, std::exception)
 {
     return createPropertySetInfo( getInfoHelper() ) ;
 }
 
-//------------------------------------------------------------------------
-
-
-
 /* vim:set shiftwidth=4 softtabstop=4 expandtab: */
