@@ -17,7 +17,6 @@
  *   the License at http://www.apache.org/licenses/LICENSE-2.0 .
  */
 
-
 #include "tokenuno.hxx"
 
 #include <sal/macros.h>
@@ -45,26 +44,22 @@
 using namespace ::formula;
 using namespace ::com::sun::star;
 
-// ============================================================================
-
 static const SfxItemPropertyMapEntry* lcl_GetFormulaParserMap()
 {
     static const SfxItemPropertyMapEntry aFormulaParserMap_Impl[] =
     {
-        {MAP_CHAR_LEN(SC_UNO_COMPILEFAP),           0,  &getBooleanCppuType(),                   0, 0 },
-        {MAP_CHAR_LEN(SC_UNO_COMPILEENGLISH),       0,  &getBooleanCppuType(),                   0, 0 },
-        {MAP_CHAR_LEN(SC_UNO_IGNORELEADING),        0,  &getBooleanCppuType(),                   0, 0 },
-        {MAP_CHAR_LEN(SC_UNO_FORMULACONVENTION),    0,  &getCppuType(&sheet::AddressConvention::UNSPECIFIED), 0, 0 },
-        {MAP_CHAR_LEN(SC_UNO_OPCODEMAP),            0,  &getCppuType((uno::Sequence< sheet::FormulaOpCodeMapEntry >*)0), 0, 0 },
-        {0,0,0,0,0,0}
+        {OUString(SC_UNO_COMPILEFAP),           0,  cppu::UnoType<bool>::get(),                   0, 0 },
+        {OUString(SC_UNO_COMPILEENGLISH),       0,  cppu::UnoType<bool>::get(),                   0, 0 },
+        {OUString(SC_UNO_IGNORELEADING),        0,  cppu::UnoType<bool>::get(),                   0, 0 },
+        {OUString(SC_UNO_FORMULACONVENTION),    0,  cppu::UnoType<decltype(sheet::AddressConvention::UNSPECIFIED)>::get(), 0, 0 },
+        {OUString(SC_UNO_OPCODEMAP),            0,  cppu::UnoType<uno::Sequence< sheet::FormulaOpCodeMapEntry >>::get(), 0, 0 },
+        { OUString(), 0, css::uno::Type(), 0, 0 }
     };
     return aFormulaParserMap_Impl;
 }
 
 SC_SIMPLE_SERVICE_INFO( ScFormulaParserObj, "ScFormulaParserObj", SC_SERVICENAME_FORMULAPARS )
 
-// ============================================================================
-
 ScFormulaParserObj::ScFormulaParserObj(ScDocShell* pDocSh) :
     mpDocShell( pDocSh ),
     mnConv( sheet::AddressConvention::UNSPECIFIED ),
@@ -72,19 +67,22 @@ ScFormulaParserObj::ScFormulaParserObj(ScDocShell* pDocSh) :
     mbIgnoreSpaces( true ),
     mbCompileFAP( false )
 {
-    mpDocShell->GetDocument()->AddUnoObject(*this);
+    mpDocShell->GetDocument().AddUnoObject(*this);
 }
 
 ScFormulaParserObj::~ScFormulaParserObj()
 {
+    SolarMutexGuard g;
+
     if (mpDocShell)
-        mpDocShell->GetDocument()->RemoveUnoObject(*this);
+        mpDocShell->GetDocument().RemoveUnoObject(*this);
 }
 
 void ScFormulaParserObj::Notify( SfxBroadcaster&, const SfxHint& rHint )
 {
-    if ( rHint.ISA( SfxSimpleHint ) && ((const SfxSimpleHint&)rHint).GetId() == SFX_HINT_DYING )
-        mpDocShell = NULL;
+    const SfxSimpleHint* pSimpleHint = dynamic_cast<const SfxSimpleHint*>(&rHint);
+    if ( pSimpleHint && pSimpleHint->GetId() == SFX_HINT_DYING )
+        mpDocShell = nullptr;
 }
 
 // XFormulaParser
@@ -118,32 +116,32 @@ void ScFormulaParserObj::SetCompilerFlags( ScCompiler& rCompiler ) const
         eConv = aConvMap[mnConv];
 
     rCompiler.SetRefConvention( eConv );
-
-    rCompiler.SetCompileForFAP(mbCompileFAP);
+    rCompiler.EnableJumpCommandReorder(!mbCompileFAP);
+    rCompiler.EnableStopOnError(!mbCompileFAP);
 
     rCompiler.SetExternalLinks( maExternalLinks);
 }
 
 uno::Sequence<sheet::FormulaToken> SAL_CALL ScFormulaParserObj::parseFormula(
-        const OUString& aFormula, const table::CellAddress& rReferencePos )
-                                throw (uno::RuntimeException)
+    const OUString& aFormula, const table::CellAddress& rReferencePos )
+        throw (uno::RuntimeException, std::exception)
 {
     SolarMutexGuard aGuard;
     uno::Sequence<sheet::FormulaToken> aRet;
 
     if (mpDocShell)
     {
-        ScDocument* pDoc = mpDocShell->GetDocument();
-        ScExternalRefManager::ApiGuard aExtRefGuard(pDoc);
+        ScDocument& rDoc = mpDocShell->GetDocument();
+        ScExternalRefManager::ApiGuard aExtRefGuard(&rDoc);
 
         ScAddress aRefPos( ScAddress::UNINITIALIZED );
         ScUnoConversion::FillScAddress( aRefPos, rReferencePos );
-        ScCompiler aCompiler( pDoc, aRefPos);
-        aCompiler.SetGrammar(pDoc->GetGrammar());
+        ScCompiler aCompiler( &rDoc, aRefPos);
+        aCompiler.SetGrammar(rDoc.GetGrammar());
         SetCompilerFlags( aCompiler );
 
         ScTokenArray* pCode = aCompiler.CompileString( aFormula );
-        (void)ScTokenConversion::ConvertToTokenSequence( *pDoc, aRet, *pCode );
+        (void)ScTokenConversion::ConvertToTokenSequence( rDoc, aRet, *pCode );
         delete pCode;
     }
 
@@ -152,20 +150,20 @@ uno::Sequence<sheet::FormulaToken> SAL_CALL ScFormulaParserObj::parseFormula(
 
 OUString SAL_CALL ScFormulaParserObj::printFormula(
         const uno::Sequence<sheet::FormulaToken>& aTokens, const table::CellAddress& rReferencePos )
-                                throw (uno::RuntimeException)
+                                throw (uno::RuntimeException, std::exception)
 {
     SolarMutexGuard aGuard;
     OUString aRet;
 
     if (mpDocShell)
     {
-        ScDocument* pDoc = mpDocShell->GetDocument();
+        ScDocument& rDoc = mpDocShell->GetDocument();
         ScTokenArray aCode;
-        (void)ScTokenConversion::ConvertToTokenArray( *pDoc, aCode, aTokens );
+        (void)ScTokenConversion::ConvertToTokenArray( rDoc, aCode, aTokens );
         ScAddress aRefPos( ScAddress::UNINITIALIZED );
         ScUnoConversion::FillScAddress( aRefPos, rReferencePos );
-        ScCompiler aCompiler( pDoc, aRefPos, aCode);
-        aCompiler.SetGrammar(pDoc->GetGrammar());
+        ScCompiler aCompiler( &rDoc, aRefPos, aCode);
+        aCompiler.SetGrammar(rDoc.GetGrammar());
         SetCompilerFlags( aCompiler );
 
         OUStringBuffer aBuffer;
@@ -179,7 +177,7 @@ OUString SAL_CALL ScFormulaParserObj::printFormula(
 // XPropertySet
 
 uno::Reference<beans::XPropertySetInfo> SAL_CALL ScFormulaParserObj::getPropertySetInfo()
-                                                        throw(uno::RuntimeException)
+                                                        throw(uno::RuntimeException, std::exception)
 {
     SolarMutexGuard aGuard;
     static uno::Reference< beans::XPropertySetInfo > aRef(new SfxItemPropertySetInfo( lcl_GetFormulaParserMap() ));
@@ -190,15 +188,15 @@ void SAL_CALL ScFormulaParserObj::setPropertyValue(
                         const OUString& aPropertyName, const uno::Any& aValue )
                 throw(beans::UnknownPropertyException, beans::PropertyVetoException,
                         lang::IllegalArgumentException, lang::WrappedTargetException,
-                        uno::RuntimeException)
+                        uno::RuntimeException, std::exception)
 {
     SolarMutexGuard aGuard;
     OUString aString(aPropertyName);
-    if ( aString.equalsAscii( SC_UNO_COMPILEFAP ) )
+    if ( aString == SC_UNO_COMPILEFAP )
     {
         aValue >>= mbCompileFAP;
     }
-    else if ( aString.equalsAscii( SC_UNO_COMPILEENGLISH ) )
+    else if ( aString == SC_UNO_COMPILEENGLISH )
     {
         bool bOldEnglish = mbEnglish;
         if (aValue >>= mbEnglish)
@@ -208,36 +206,36 @@ void SAL_CALL ScFormulaParserObj::setPropertyValue(
             // CompileEnglish _before_ OpCodeMap!
             if (mxOpCodeMap.get() && mbEnglish != bOldEnglish)
             {
-                ScDocument* pDoc = mpDocShell->GetDocument();
-                ScCompiler aCompiler( pDoc, ScAddress());
-                aCompiler.SetGrammar(pDoc->GetGrammar());
-                mxOpCodeMap = aCompiler.CreateOpCodeMap( maOpCodeMapping, mbEnglish);
+                ScDocument& rDoc = mpDocShell->GetDocument();
+                ScCompiler aCompiler( &rDoc, ScAddress());
+                aCompiler.SetGrammar(rDoc.GetGrammar());
+                mxOpCodeMap = formula::FormulaCompiler::CreateOpCodeMap( maOpCodeMapping, mbEnglish);
             }
         }
         else
             throw lang::IllegalArgumentException();
     }
-    else if ( aString.equalsAscii( SC_UNO_FORMULACONVENTION ) )
+    else if ( aString == SC_UNO_FORMULACONVENTION )
     {
         aValue >>= mnConv;
     }
-    else if ( aString.equalsAscii( SC_UNO_IGNORELEADING ) )
+    else if ( aString == SC_UNO_IGNORELEADING )
     {
         aValue >>= mbIgnoreSpaces;
     }
-    else if ( aString.equalsAscii( SC_UNO_OPCODEMAP ) )
+    else if ( aString == SC_UNO_OPCODEMAP )
     {
         if (aValue >>= maOpCodeMapping)
         {
-            ScDocument* pDoc = mpDocShell->GetDocument();
-            ScCompiler aCompiler( pDoc, ScAddress());
-            aCompiler.SetGrammar(pDoc->GetGrammar());
-            mxOpCodeMap = aCompiler.CreateOpCodeMap( maOpCodeMapping, mbEnglish);
+            ScDocument& rDoc = mpDocShell->GetDocument();
+            ScCompiler aCompiler( &rDoc, ScAddress());
+            aCompiler.SetGrammar(rDoc.GetGrammar());
+            mxOpCodeMap = formula::FormulaCompiler::CreateOpCodeMap( maOpCodeMapping, mbEnglish);
         }
         else
             throw lang::IllegalArgumentException();
     }
-    else if ( aString.equalsAscii( SC_UNO_EXTERNALLINKS ) )
+    else if ( aString == SC_UNO_EXTERNALLINKS )
     {
         if (!(aValue >>= maExternalLinks))
             throw lang::IllegalArgumentException();
@@ -248,32 +246,32 @@ void SAL_CALL ScFormulaParserObj::setPropertyValue(
 
 uno::Any SAL_CALL ScFormulaParserObj::getPropertyValue( const OUString& aPropertyName )
                 throw(beans::UnknownPropertyException, lang::WrappedTargetException,
-                        uno::RuntimeException)
+                        uno::RuntimeException, std::exception)
 {
     SolarMutexGuard aGuard;
     uno::Any aRet;
     OUString aString(aPropertyName);
-    if ( aString.equalsAscii( SC_UNO_COMPILEFAP ) )
+    if ( aString == SC_UNO_COMPILEFAP )
     {
         aRet <<= mbCompileFAP;
     }
-    else if ( aString.equalsAscii( SC_UNO_COMPILEENGLISH ) )
+    else if ( aString == SC_UNO_COMPILEENGLISH )
     {
         aRet <<= mbEnglish;
     }
-    else if ( aString.equalsAscii( SC_UNO_FORMULACONVENTION ) )
+    else if ( aString == SC_UNO_FORMULACONVENTION )
     {
         aRet <<= mnConv;
     }
-    else if ( aString.equalsAscii( SC_UNO_IGNORELEADING ) )
+    else if ( aString == SC_UNO_IGNORELEADING )
     {
         aRet <<= mbIgnoreSpaces;
     }
-    else if ( aString.equalsAscii( SC_UNO_OPCODEMAP ) )
+    else if ( aString == SC_UNO_OPCODEMAP )
     {
         aRet <<= maOpCodeMapping;
     }
-    else if ( aString.equalsAscii( SC_UNO_EXTERNALLINKS ) )
+    else if ( aString == SC_UNO_EXTERNALLINKS )
     {
         aRet <<= maExternalLinks;
     }
@@ -284,8 +282,6 @@ uno::Any SAL_CALL ScFormulaParserObj::getPropertyValue( const OUString& aPropert
 
 SC_IMPL_DUMMY_PROPERTY_LISTENER( ScFormulaParserObj )
 
-// ============================================================================
-
 static void lcl_ExternalRefToApi( sheet::SingleReference& rAPI, const ScSingleRefData& rRef )
 {
     rAPI.Column         = 0;
@@ -412,15 +408,15 @@ bool ScTokenConversion::ConvertToTokenSequence( const ScDocument& rDoc,
                 case svSingleRef:
                     {
                         sheet::SingleReference aSingleRef;
-                        lcl_SingleRefToApi( aSingleRef, static_cast<const ScToken&>(rToken).GetSingleRef() );
+                        lcl_SingleRefToApi( aSingleRef, *rToken.GetSingleRef() );
                         rAPI.Data <<= aSingleRef;
                     }
                     break;
                 case formula::svDoubleRef:
                     {
                         sheet::ComplexReference aCompRef;
-                        lcl_SingleRefToApi( aCompRef.Reference1, static_cast<const ScToken&>(rToken).GetSingleRef() );
-                        lcl_SingleRefToApi( aCompRef.Reference2, static_cast<const ScToken&>(rToken).GetSingleRef2() );
+                        lcl_SingleRefToApi( aCompRef.Reference1, *rToken.GetSingleRef() );
+                        lcl_SingleRefToApi( aCompRef.Reference2, *rToken.GetSingleRef2() );
                         rAPI.Data <<= aCompRef;
                     }
                     break;
@@ -428,18 +424,18 @@ bool ScTokenConversion::ConvertToTokenSequence( const ScDocument& rDoc,
                     {
                         sheet::NameToken aNameToken;
                         aNameToken.Index = static_cast<sal_Int32>( rToken.GetIndex() );
-                        aNameToken.Global = static_cast<sal_Bool>( rToken.IsGlobal() );
+                        aNameToken.Global = rToken.IsGlobal();
                         rAPI.Data <<= aNameToken;
                     }
                     break;
                 case svMatrix:
-                    if (!ScRangeToSequence::FillMixedArray( rAPI.Data, static_cast<const ScToken&>(rToken).GetMatrix(), true))
+                    if (!ScRangeToSequence::FillMixedArray( rAPI.Data, rToken.GetMatrix(), true))
                         rAPI.Data.clear();
                     break;
                 case svExternalSingleRef:
                     {
                         sheet::SingleReference aSingleRef;
-                        lcl_ExternalRefToApi( aSingleRef, static_cast<const ScToken&>(rToken).GetSingleRef() );
+                        lcl_ExternalRefToApi( aSingleRef, *rToken.GetSingleRef() );
                         size_t nCacheId;
                         rDoc.GetExternalRefManager()->getCacheTable(
                             rToken.GetIndex(), rToken.GetString().getString(), false, &nCacheId);
@@ -454,8 +450,8 @@ bool ScTokenConversion::ConvertToTokenSequence( const ScDocument& rDoc,
                 case svExternalDoubleRef:
                     {
                         sheet::ComplexReference aComplRef;
-                        lcl_ExternalRefToApi( aComplRef.Reference1, static_cast<const ScToken&>(rToken).GetSingleRef() );
-                        lcl_ExternalRefToApi( aComplRef.Reference2, static_cast<const ScToken&>(rToken).GetSingleRef2() );
+                        lcl_ExternalRefToApi( aComplRef.Reference1, *rToken.GetSingleRef() );
+                        lcl_ExternalRefToApi( aComplRef.Reference2, *rToken.GetSingleRef2() );
                         size_t nCacheId;
                         rDoc.GetExternalRefManager()->getCacheTable(
                             rToken.GetIndex(), rToken.GetString().getString(), false, &nCacheId);
@@ -463,7 +459,7 @@ bool ScTokenConversion::ConvertToTokenSequence( const ScDocument& rDoc,
                         // NOTE: This assumes that cached sheets are in consecutive order!
                         aComplRef.Reference2.Sheet =
                             aComplRef.Reference1.Sheet +
-                            (static_cast<const ScToken&>(rToken).GetSingleRef2().Tab() - static_cast<const ScToken&>(rToken).GetSingleRef().Tab());
+                            (rToken.GetSingleRef2()->Tab() - rToken.GetSingleRef()->Tab());
                         sheet::ExternalReference aExtRef;
                         aExtRef.Index = rToken.GetIndex();
                         aExtRef.Reference <<= aComplRef;
@@ -482,8 +478,9 @@ bool ScTokenConversion::ConvertToTokenSequence( const ScDocument& rDoc,
                     break;
                 default:
                     OSL_TRACE( "ScTokenConversion::ConvertToTokenSequence: unhandled token type SvStackVar %d", rToken.GetType());
+                    //fall-through
                 case svSep:     // occurs with ocSep, ocOpen, ocClose, ocArray*
-                case svJump:    // occurs with ocIf, ocChose
+                case svJump:    // occurs with ocIf, ocChoose
                 case svMissing: // occurs with ocMissing
                     rAPI.Data.clear();      // no data
             }
@@ -496,15 +493,9 @@ bool ScTokenConversion::ConvertToTokenSequence( const ScDocument& rDoc,
     return !bError;
 }
 
-// ============================================================================
-
-SAL_WNODEPRECATED_DECLARATIONS_PUSH
-ScFormulaOpCodeMapperObj::ScFormulaOpCodeMapperObj(::std::auto_ptr<formula::FormulaCompiler> _pCompiler)
-: formula::FormulaOpCodeMapperObj(_pCompiler)
+ScFormulaOpCodeMapperObj::ScFormulaOpCodeMapperObj(::std::unique_ptr<formula::FormulaCompiler> && _pCompiler)
+: formula::FormulaOpCodeMapperObj(std::move(_pCompiler))
 {
 }
-SAL_WNODEPRECATED_DECLARATIONS_POP
-
-// ============================================================================
 
 /* vim:set shiftwidth=4 softtabstop=4 expandtab: */
