@@ -87,7 +87,7 @@ ScDocShell* GetDocShellFromRange( const uno::Reference< uno::XInterface >& xRang
 }
 
 uno::Reference< XHelperInterface >
-getUnoSheetModuleObj( const uno::Reference< table::XCellRange >& xRange ) throw ( uno::RuntimeException )
+getUnoSheetModuleObj( const uno::Reference< table::XCellRange >& xRange ) throw ( uno::RuntimeException, std::exception )
 {
     uno::Reference< sheet::XSheetCellRange > xSheetRange( xRange, uno::UNO_QUERY_THROW );
     uno::Reference< sheet::XSpreadsheet > xSheet( xSheetRange->getSpreadsheet(), uno::UNO_SET_THROW );
@@ -114,12 +114,12 @@ private:
         return xProps;
     }
 
-    bool getReplaceCellsWarning() throw ( uno::RuntimeException )
+    static bool getReplaceCellsWarning() throw ( uno::RuntimeException )
     {
         return getGlobalSheetSettings()->getReplaceCellsWarning();
     }
 
-    void setReplaceCellsWarning( bool bState ) throw ( uno::RuntimeException )
+    static void setReplaceCellsWarning( bool bState ) throw ( uno::RuntimeException )
     {
         getGlobalSheetSettings()->setReplaceCellsWarning( bState );
     }
@@ -162,10 +162,10 @@ implnCopy( const uno::Reference< frame::XModel>& xModel )
     ScTabViewShell* pViewShell = getBestViewShell( xModel );
     if ( pViewShell )
     {
-        pViewShell->CopyToClip(NULL,false,false,true);
+        pViewShell->CopyToClip(nullptr,false,false,true);
 
         // mark the copied transfer object so it is used in ScVbaRange::Insert
-        ScTransferObj* pClipObj = ScTransferObj::GetOwnClipboard( NULL );
+        ScTransferObj* pClipObj = ScTransferObj::GetOwnClipboard( nullptr );
         if (pClipObj)
             pClipObj->SetUseInApi( true );
     }
@@ -177,16 +177,16 @@ implnCut( const uno::Reference< frame::XModel>& xModel )
     ScTabViewShell* pViewShell =  getBestViewShell( xModel );
     if ( pViewShell )
     {
-        pViewShell->CutToClip( NULL, true );
+        pViewShell->CutToClip( nullptr, true );
 
         // mark the copied transfer object so it is used in ScVbaRange::Insert
-        ScTransferObj* pClipObj = ScTransferObj::GetOwnClipboard( NULL );
+        ScTransferObj* pClipObj = ScTransferObj::GetOwnClipboard( nullptr );
         if (pClipObj)
             pClipObj->SetUseInApi( true );
     }
 }
 
-void implnPasteSpecial( const uno::Reference< frame::XModel>& xModel, InsertDeleteFlags nFlags, sal_uInt16 nFunction, bool bSkipEmpty, bool bTranspose)
+void implnPasteSpecial( const uno::Reference< frame::XModel>& xModel, InsertDeleteFlags nFlags, ScPasteFunc nFunction, bool bSkipEmpty, bool bTranspose)
 {
     PasteCellsWarningReseter resetWarningBox;
     InsCellCmd eMoveMode = INS_NONE;
@@ -199,12 +199,12 @@ void implnPasteSpecial( const uno::Reference< frame::XModel>& xModel, InsertDele
         if (pWin)
         {
             ScTransferObj* pOwnClip = ScTransferObj::GetOwnClipboard( pWin );
-            ScDocument* pDoc = NULL;
+            ScDocument* pDoc = nullptr;
             if ( pOwnClip )
                 pDoc = pOwnClip->GetDocument();
             pTabViewShell->PasteFromClip( nFlags, pDoc,
                 nFunction, bSkipEmpty, bTranspose, false,
-                eMoveMode, IDF_NONE, true );
+                eMoveMode, InsertDeleteFlags::NONE, true );
             pTabViewShell->CellContentChanged();
         }
     }
@@ -216,7 +216,7 @@ getDocShell( const css::uno::Reference< css::frame::XModel>& xModel )
 {
     uno::Reference< uno::XInterface > xIf( xModel, uno::UNO_QUERY_THROW );
     ScModelObj* pModel = dynamic_cast< ScModelObj* >( xIf.get() );
-    ScDocShell* pDocShell = NULL;
+    ScDocShell* pDocShell = nullptr;
     if ( pModel )
         pDocShell = static_cast<ScDocShell*>(pModel->GetEmbeddedObject());
     return pDocShell;
@@ -229,7 +229,7 @@ getBestViewShell( const css::uno::Reference< css::frame::XModel>& xModel )
     ScDocShell* pDocShell = getDocShell( xModel );
     if ( pDocShell )
         return pDocShell->GetBestViewShell();
-    return NULL;
+    return nullptr;
 }
 
 ScTabViewShell*
@@ -245,11 +245,11 @@ getViewFrame( const uno::Reference< frame::XModel >& xModel )
     ScTabViewShell* pViewShell = getBestViewShell( xModel );
     if ( pViewShell )
         return pViewShell->GetViewFrame();
-    return NULL;
+    return nullptr;
 }
 
 uno::Reference< XHelperInterface >
-getUnoSheetModuleObj( const uno::Reference< sheet::XSpreadsheet >& xSheet ) throw ( uno::RuntimeException )
+getUnoSheetModuleObj( const uno::Reference< sheet::XSpreadsheet >& xSheet ) throw ( uno::RuntimeException, std::exception )
 {
     uno::Reference< beans::XPropertySet > xProps( xSheet, uno::UNO_QUERY_THROW );
     OUString sCodeName;
@@ -263,7 +263,7 @@ getUnoSheetModuleObj( const uno::Reference< sheet::XSpreadsheet >& xSheet ) thro
 }
 
 uno::Reference< XHelperInterface >
-getUnoSheetModuleObj( const uno::Reference< sheet::XSheetCellRangeContainer >& xRanges ) throw ( uno::RuntimeException )
+getUnoSheetModuleObj( const uno::Reference< sheet::XSheetCellRangeContainer >& xRanges ) throw ( uno::RuntimeException, std::exception )
 {
     uno::Reference< container::XEnumerationAccess > xEnumAccess( xRanges, uno::UNO_QUERY_THROW );
     uno::Reference< container::XEnumeration > xEnum = xEnumAccess->createEnumeration();
@@ -272,7 +272,7 @@ getUnoSheetModuleObj( const uno::Reference< sheet::XSheetCellRangeContainer >& x
 }
 
 uno::Reference< XHelperInterface >
-getUnoSheetModuleObj( const uno::Reference< table::XCell >& xCell ) throw ( uno::RuntimeException )
+getUnoSheetModuleObj( const uno::Reference< table::XCell >& xCell ) throw ( uno::RuntimeException, std::exception )
 {
     uno::Reference< sheet::XSheetCellRange > xSheetRange( xCell, uno::UNO_QUERY_THROW );
     uno::Reference< sheet::XSpreadsheet > xSheet( xSheetRange->getSpreadsheet(), uno::UNO_SET_THROW );
@@ -280,7 +280,7 @@ getUnoSheetModuleObj( const uno::Reference< table::XCell >& xCell ) throw ( uno:
 }
 
 uno::Reference< XHelperInterface >
-getUnoSheetModuleObj( const uno::Reference< frame::XModel >& xModel, SCTAB nTab ) throw ( uno::RuntimeException )
+getUnoSheetModuleObj( const uno::Reference< frame::XModel >& xModel, SCTAB nTab ) throw ( uno::RuntimeException, std::exception )
 {
     uno::Reference< sheet::XSpreadsheetDocument > xDoc( xModel, uno::UNO_QUERY_THROW );
     uno::Reference< container::XIndexAccess > xSheets( xDoc->getSheets(), uno::UNO_QUERY_THROW );
@@ -316,7 +316,7 @@ void setUpDocumentModules( const uno::Reference< sheet::XSpreadsheetDocument >&
                 uno::Reference< script::vba::XVBAModuleInfo > xVBAModuleInfo( xLib, uno::UNO_QUERY_THROW );
                 uno::Reference< lang::XMultiServiceFactory> xSF( pShell->GetModel(), uno::UNO_QUERY_THROW);
                 uno::Reference< container::XNameAccess > xVBACodeNamedObjectAccess( xSF->createInstance("ooo.vba.VBAObjectModuleObjectProvider"), uno::UNO_QUERY_THROW );
-                // set up the module info for the workbook and sheets in the nealy created
+                // set up the module info for the workbook and sheets in the newly created
                 // spreadsheet
                 ScDocument& rDoc = pShell->GetDocument();
                 OUString sCodeName = rDoc.GetCodeName();
@@ -371,7 +371,7 @@ void setUpDocumentModules( const uno::Reference< sheet::XSpreadsheetDocument >&
 SfxItemSet*
 ScVbaCellRangeAccess::GetDataSet( ScCellRangesBase* pRangeObj )
 {
-    return pRangeObj ? pRangeObj->GetCurrentDataSet( true ) : 0;
+    return pRangeObj ? pRangeObj->GetCurrentDataSet( true ) : nullptr;
 }
 
 } // namespace excel
