@@ -19,7 +19,7 @@
 #include "vbaborders.hxx"
 
 #include <sal/macros.h>
-#include <cppuhelper/implbase3.hxx>
+#include <cppuhelper/implbase.hxx>
 #include <ooo/vba/excel/XlBordersIndex.hpp>
 #include <ooo/vba/excel/XlBorderWeight.hpp>
 #include <ooo/vba/excel/XlLineStyle.hpp>
@@ -34,17 +34,16 @@ using namespace ::com::sun::star;
 using namespace ::ooo::vba;
 using namespace ::ooo::vba::excel;
 
-
-typedef ::cppu::WeakImplHelper1<container::XIndexAccess > RangeBorders_Base;
-typedef InheritedHelperInterfaceImpl1<excel::XBorder > ScVbaBorder_Base;
+typedef ::cppu::WeakImplHelper<container::XIndexAccess > RangeBorders_Base;
+typedef InheritedHelperInterfaceWeakImpl<excel::XBorder > ScVbaBorder_Base;
 
 // #TODO sort these indexes to match the order in which Excel iterates over the
 // borders, the enumeration will match the order in this list
 static const sal_Int16 supportedIndexTable[] = {  XlBordersIndex::xlEdgeLeft, XlBordersIndex::xlEdgeTop, XlBordersIndex::xlEdgeBottom, XlBordersIndex::xlEdgeRight, XlBordersIndex::xlDiagonalDown, XlBordersIndex::xlDiagonalUp, XlBordersIndex::xlInsideVertical, XlBordersIndex::xlInsideHorizontal };
 
-const static OUString sTableBorder("TableBorder");
+static const char sTableBorder[] = "TableBorder";
 
-//  Equiv widths in in 1/100 mm
+//  Equiv widths in 1/100 mm
 const static sal_Int32 OOLineThin = 35;
 const static sal_Int32 OOLineMedium = 88;
 const static sal_Int32 OOLineThick = 141;
@@ -142,13 +141,13 @@ private:
         }
         return true;
     }
-    ScVbaBorder(); // no impl
+
 protected:
-    virtual OUString getServiceImplName()
+    virtual OUString getServiceImplName() override
     {
         return OUString("ScVbaBorder");
     }
-    virtual css::uno::Sequence<OUString> getServiceNames()
+    virtual css::uno::Sequence<OUString> getServiceNames() override
     {
         static uno::Sequence< OUString > aServiceNames;
         if ( aServiceNames.getLength() == 0 )
@@ -162,14 +161,14 @@ public:
     ScVbaBorder( const uno::Reference< beans::XPropertySet > & xProps, const uno::Reference< uno::XComponentContext >& xContext, sal_Int32 lineType, ScVbaPalette& rPalette) : ScVbaBorder_Base( uno::Reference< XHelperInterface >( xProps, uno::UNO_QUERY ), xContext ), m_xProps( xProps ), m_LineType( lineType ), m_Palette( rPalette ) {}
 
     // XBorder
-    uno::Any SAL_CALL getColor() throw (uno::RuntimeException)
+    uno::Any SAL_CALL getColor() throw (uno::RuntimeException, std::exception) override
     {
         table::BorderLine aBorderLine;
         if ( getBorderLine( aBorderLine ) )
             return uno::makeAny( OORGBToXLRGB( aBorderLine.Color ) );
-        throw uno::RuntimeException("No Implementation available", uno::Reference< uno::XInterface >() );
+        throw uno::RuntimeException("No Implementation available" );
     }
-    void SAL_CALL setColor( const uno::Any& _color ) throw (uno::RuntimeException)
+    void SAL_CALL setColor( const uno::Any& _color ) throw (uno::RuntimeException, std::exception) override
     {
         sal_Int32 nColor = 0;
         _color >>= nColor;
@@ -180,10 +179,10 @@ public:
             setBorderLine( aBorderLine );
         }
         else
-            throw uno::RuntimeException("No Implementation available", uno::Reference< uno::XInterface >() );
+            throw uno::RuntimeException("No Implementation available" );
     }
 
-    uno::Any SAL_CALL getColorIndex() throw (uno::RuntimeException)
+    uno::Any SAL_CALL getColorIndex() throw (uno::RuntimeException, std::exception) override
     {
         sal_Int32 nColor = 0;
         XLRGBToOORGB( getColor() ) >>= nColor;
@@ -203,7 +202,7 @@ public:
         return uno::makeAny(nIndex);
     }
 
-    void SAL_CALL setColorIndex( const uno::Any& _colorindex ) throw (uno::RuntimeException)
+    void SAL_CALL setColorIndex( const uno::Any& _colorindex ) throw (uno::RuntimeException, std::exception) override
     {
         sal_Int32 nColor = 0;
         _colorindex >>= nColor;
@@ -211,7 +210,7 @@ public:
             nColor = 1;
         setColor( OORGBToXLRGB( m_Palette.getPalette()->getByIndex( --nColor )  ) );
     }
-    uno::Any SAL_CALL getWeight() throw (uno::RuntimeException)
+    uno::Any SAL_CALL getWeight() throw (uno::RuntimeException, std::exception) override
     {
         table::BorderLine aBorderLine;
         if ( getBorderLine( aBorderLine ) )
@@ -231,9 +230,9 @@ public:
                     break;
             }
         }
-        throw uno::RuntimeException("Method failed", uno::Reference< uno::XInterface >() );
+        throw uno::RuntimeException("Method failed" );
     }
-    void SAL_CALL setWeight( const uno::Any& _weight ) throw (uno::RuntimeException)
+    void SAL_CALL setWeight( const uno::Any& _weight ) throw (uno::RuntimeException, std::exception) override
     {
         sal_Int32 nWeight = 0;
         _weight >>= nWeight;
@@ -255,20 +254,20 @@ public:
                     aBorderLine.OuterLineWidth = OOLineHairline;
                     break;
                 default:
-                    throw uno::RuntimeException("Bad param", uno::Reference< uno::XInterface >() );
+                    throw uno::RuntimeException("Bad param" );
             }
             setBorderLine( aBorderLine );
         }
         else
-                    throw uno::RuntimeException("Method failed", uno::Reference< uno::XInterface >() );
+                    throw uno::RuntimeException("Method failed" );
     }
 
-    uno::Any SAL_CALL getLineStyle() throw (uno::RuntimeException)
+    uno::Any SAL_CALL getLineStyle() throw (uno::RuntimeException, std::exception) override
     {
         // always return xlContinuous;
         return uno::makeAny( XlLineStyle::xlContinuous );
     }
-    void SAL_CALL setLineStyle( const uno::Any& _linestyle ) throw (uno::RuntimeException)
+    void SAL_CALL setLineStyle( const uno::Any& _linestyle ) throw (uno::RuntimeException, std::exception) override
     {
         // Urk no choice but to silently ignore we don't support this attribute
         // #TODO would be nice to support the excel line styles
@@ -289,12 +288,12 @@ public:
                 case XlLineStyle::xlSlantDashDot:
                     break;
                 default:
-                    throw uno::RuntimeException("Bad param", uno::Reference< uno::XInterface >() );
+                    throw uno::RuntimeException("Bad param" );
             }
             setBorderLine( aBorderLine );
         }
         else
-            throw uno::RuntimeException("Method failed", uno::Reference< uno::XInterface >() );
+            throw uno::RuntimeException("Method failed" );
     }
 };
 
@@ -306,7 +305,7 @@ private:
     ScVbaPalette m_Palette;
     sal_Int32 getTableIndex( sal_Int32 nConst )
     {
-        // hokay return position of the index in the table
+        // okay return position of the index in the table
         sal_Int32 nIndexes = getCount();
         sal_Int32 realIndex = 0;
         const sal_Int16* pTableEntry = supportedIndexTable;
@@ -322,11 +321,11 @@ public:
     {
     }
     // XIndexAccess
-    virtual ::sal_Int32 SAL_CALL getCount(  ) throw (uno::RuntimeException)
+    virtual ::sal_Int32 SAL_CALL getCount(  ) throw (uno::RuntimeException, std::exception) override
     {
         return sizeof( supportedIndexTable ) / sizeof( supportedIndexTable[0] );
     }
-    virtual uno::Any SAL_CALL getByIndex( ::sal_Int32 Index ) throw (lang::IndexOutOfBoundsException, lang::WrappedTargetException, uno::RuntimeException)
+    virtual uno::Any SAL_CALL getByIndex( ::sal_Int32 Index ) throw (lang::IndexOutOfBoundsException, lang::WrappedTargetException, uno::RuntimeException, std::exception) override
     {
 
         sal_Int32 nIndex = getTableIndex( Index );
@@ -337,11 +336,11 @@ public:
         }
         throw lang::IndexOutOfBoundsException();
     }
-    virtual uno::Type SAL_CALL getElementType(  ) throw (uno::RuntimeException)
+    virtual uno::Type SAL_CALL getElementType(  ) throw (uno::RuntimeException, std::exception) override
     {
-        return  excel::XBorder::static_type(0);
+        return  cppu::UnoType<excel::XBorder>::get();
     }
-    virtual ::sal_Bool SAL_CALL hasElements(  ) throw (uno::RuntimeException)
+    virtual sal_Bool SAL_CALL hasElements(  ) throw (uno::RuntimeException, std::exception) override
     {
         return sal_True;
     }
@@ -358,13 +357,13 @@ class RangeBorderEnumWrapper : public EnumerationHelper_BASE
     uno::Reference<container::XIndexAccess > m_xIndexAccess;
     sal_Int32 nIndex;
 public:
-    RangeBorderEnumWrapper( const uno::Reference< container::XIndexAccess >& xIndexAccess ) : m_xIndexAccess( xIndexAccess ), nIndex( 0 ) {}
-    virtual ::sal_Bool SAL_CALL hasMoreElements(  ) throw (uno::RuntimeException)
+    explicit RangeBorderEnumWrapper( const uno::Reference< container::XIndexAccess >& xIndexAccess ) : m_xIndexAccess( xIndexAccess ), nIndex( 0 ) {}
+    virtual sal_Bool SAL_CALL hasMoreElements(  ) throw (uno::RuntimeException, std::exception) override
     {
         return ( nIndex < m_xIndexAccess->getCount() );
     }
 
-    virtual uno::Any SAL_CALL nextElement(  ) throw (container::NoSuchElementException, lang::WrappedTargetException, uno::RuntimeException)
+    virtual uno::Any SAL_CALL nextElement(  ) throw (container::NoSuchElementException, lang::WrappedTargetException, uno::RuntimeException, std::exception) override
     {
         if ( nIndex < m_xIndexAccess->getCount() )
             return m_xIndexAccess->getByIndex( nIndex++ );
@@ -395,7 +394,7 @@ ScVbaBorders::createCollectionObject( const css::uno::Any& aSource )
 uno::Type
 ScVbaBorders::getElementType() throw (uno::RuntimeException)
 {
-    return excel::XBorders::static_type(0);
+    return cppu::UnoType<excel::XBorders>::get();
 }
 
 uno::Any
@@ -404,8 +403,7 @@ ScVbaBorders::getItemByIntIndex( const sal_Int32 nIndex )  throw (uno::RuntimeEx
     return createCollectionObject( m_xIndexAccess->getByIndex( nIndex ) );
 }
 
-
-uno::Any SAL_CALL ScVbaBorders::getColor() throw (uno::RuntimeException)
+uno::Any SAL_CALL ScVbaBorders::getColor() throw (uno::RuntimeException, std::exception)
 {
     sal_Int32 count = getCount();
     uno::Any color;
@@ -425,7 +423,7 @@ uno::Any SAL_CALL ScVbaBorders::getColor() throw (uno::RuntimeException)
     }
     return  color;
 }
-void SAL_CALL ScVbaBorders::setColor( const uno::Any& _color ) throw (uno::RuntimeException)
+void SAL_CALL ScVbaBorders::setColor( const uno::Any& _color ) throw (uno::RuntimeException, std::exception)
 {
     sal_Int32 count = getCount();
     for( sal_Int32 i = 0; i < count ; i++ )
@@ -434,7 +432,7 @@ void SAL_CALL ScVbaBorders::setColor( const uno::Any& _color ) throw (uno::Runti
         xBorder->setColor( _color );
     }
 }
-uno::Any SAL_CALL ScVbaBorders::getColorIndex() throw (uno::RuntimeException)
+uno::Any SAL_CALL ScVbaBorders::getColorIndex() throw (uno::RuntimeException, std::exception)
 {
     sal_Int32 count = getCount();
     uno::Any nColorIndex;
@@ -454,7 +452,7 @@ uno::Any SAL_CALL ScVbaBorders::getColorIndex() throw (uno::RuntimeException)
     }
     return  nColorIndex;
 }
-void SAL_CALL ScVbaBorders::setColorIndex( const uno::Any& _colorindex ) throw (uno::RuntimeException)
+void SAL_CALL ScVbaBorders::setColorIndex( const uno::Any& _colorindex ) throw (uno::RuntimeException, std::exception)
 {
     sal_Int32 count = getCount();
     for( sal_Int32 i = 0; i < count ; i++ )
@@ -486,7 +484,7 @@ lcl_areAllLineWidthsSame( const table::TableBorder& maTableBorder, bool bIsCell
     return bRes;
 }
 
-uno::Any SAL_CALL ScVbaBorders::getLineStyle() throw (uno::RuntimeException)
+uno::Any SAL_CALL ScVbaBorders::getLineStyle() throw (uno::RuntimeException, std::exception)
 {
     table::TableBorder maTableBorder;
     m_xProps->getPropertyValue( sTableBorder ) >>= maTableBorder;
@@ -506,7 +504,7 @@ uno::Any SAL_CALL ScVbaBorders::getLineStyle() throw (uno::RuntimeException)
     }
     return uno::makeAny( aLinestyle );
 }
-void SAL_CALL ScVbaBorders::setLineStyle( const uno::Any& _linestyle ) throw (uno::RuntimeException)
+void SAL_CALL ScVbaBorders::setLineStyle( const uno::Any& _linestyle ) throw (uno::RuntimeException, std::exception)
 {
     sal_Int32 count = getCount();
     for( sal_Int32 i = 0; i < count ; i++ )
@@ -515,7 +513,7 @@ void SAL_CALL ScVbaBorders::setLineStyle( const uno::Any& _linestyle ) throw (un
         xBorder->setLineStyle( _linestyle );
     }
 }
-uno::Any SAL_CALL ScVbaBorders::getWeight() throw (uno::RuntimeException)
+uno::Any SAL_CALL ScVbaBorders::getWeight() throw (uno::RuntimeException, std::exception)
 {
     sal_Int32 count = getCount();
     uno::Any weight;
@@ -535,7 +533,7 @@ uno::Any SAL_CALL ScVbaBorders::getWeight() throw (uno::RuntimeException)
     }
     return  weight;
 }
-void SAL_CALL ScVbaBorders::setWeight( const uno::Any& _weight ) throw (uno::RuntimeException)
+void SAL_CALL ScVbaBorders::setWeight( const uno::Any& _weight ) throw (uno::RuntimeException, std::exception)
 {
     sal_Int32 count = getCount();
     for( sal_Int32 i = 0; i < count ; i++ )
@@ -545,7 +543,6 @@ void SAL_CALL ScVbaBorders::setWeight( const uno::Any& _weight ) throw (uno::Run
     }
 }
 
-
 OUString
 ScVbaBorders::getServiceImplName()
 {
