@@ -68,7 +68,7 @@ const OUString HASLEGEND("HasLegend");
 ScVbaChart::ScVbaChart( const css::uno::Reference< ov::XHelperInterface >& _xParent, const css::uno::Reference< css::uno::XComponentContext >& _xContext, const css::uno::Reference< css::lang::XComponent >& _xChartComponent, const css::uno::Reference< css::table::XTableChart >& _xTableChart ) : ChartImpl_BASE( _xParent, _xContext ), mxTableChart( _xTableChart )
 {
     mxChartDocument.set( _xChartComponent, uno::UNO_QUERY_THROW ) ;
-    // #TODO is is possible that the XPropertySet interface is not set
+    // #TODO is it possible that the XPropertySet interface is not set
     // code in setPlotBy seems to indicate that this is possible? but
     // additionally there is no check in most of the places where it is used
     // ( and therefore could possibly be NULL )
@@ -78,7 +78,7 @@ ScVbaChart::ScVbaChart( const css::uno::Reference< ov::XHelperInterface >& _xPar
 }
 
 OUString SAL_CALL
-ScVbaChart::getName() throw (css::uno::RuntimeException)
+ScVbaChart::getName() throw (css::uno::RuntimeException, std::exception)
 {
     OUString sName;
     uno::Reference< beans::XPropertySet > xProps( mxChartDocument, uno::UNO_QUERY_THROW );
@@ -93,13 +93,13 @@ ScVbaChart::getName() throw (css::uno::RuntimeException)
 }
 
 uno::Any  SAL_CALL
-ScVbaChart::SeriesCollection(const uno::Any&) throw (uno::RuntimeException)
+ScVbaChart::SeriesCollection(const uno::Any&) throw (uno::RuntimeException, std::exception)
 {
     return uno::Any();
 }
 
 ::sal_Int32 SAL_CALL
-ScVbaChart::getChartType() throw ( uno::RuntimeException, script::BasicErrorException)
+ScVbaChart::getChartType() throw ( uno::RuntimeException, script::BasicErrorException, std::exception)
 {
     sal_Int32 nChartType = -1;
     try
@@ -156,7 +156,7 @@ ScVbaChart::getChartType() throw ( uno::RuntimeException, script::BasicErrorExce
             }
         else if ( sDiagramType == "com.sun.star.chart.StockDiagram" )
         {
-            sal_Bool bVolume = false;
+            bool bVolume = false;
             mxDiagramPropertySet->getPropertyValue(VOLUME) >>= bVolume;
             if (bVolume)
             {
@@ -169,7 +169,7 @@ ScVbaChart::getChartType() throw ( uno::RuntimeException, script::BasicErrorExce
         }
         else if ( sDiagramType == "com.sun.star.chart.XYDiagram" )
         {
-            sal_Bool bHasLines = false;
+            bool bHasLines = false;
             mxDiagramPropertySet->getPropertyValue(LINES) >>= bHasLines;
             sal_Int32 nSplineType = 0;
             mxDiagramPropertySet->getPropertyValue(SPLINETYPE) >>= nSplineType;
@@ -212,13 +212,13 @@ ScVbaChart::getChartType() throw ( uno::RuntimeException, script::BasicErrorExce
     }
     catch ( const uno::Exception& )
     {
-        throw script::BasicErrorException( OUString(), uno::Reference< uno::XInterface >(), SbERR_METHOD_FAILED, OUString() );
+        throw script::BasicErrorException( OUString(), uno::Reference< uno::XInterface >(), ERRCODE_BASIC_METHOD_FAILED, OUString() );
     }
     return nChartType;
 }
 
 void SAL_CALL
-ScVbaChart::setChartType( ::sal_Int32 _nChartType ) throw ( uno::RuntimeException, script::BasicErrorException)
+ScVbaChart::setChartType( ::sal_Int32 _nChartType ) throw ( uno::RuntimeException, script::BasicErrorException, std::exception)
 {
 try
 {
@@ -262,7 +262,7 @@ try
         case xlSurfaceWireframe:
         case xlSurfaceTopView:
         case xlSurfaceTopViewWireframe:
-            setDiagram( OUString("com.sun.star.chart.BarDiagram"));
+            setDiagram( "com.sun.star.chart.BarDiagram");
             break;
         case xlLine:
         case xl3DLine:
@@ -271,7 +271,7 @@ try
         case xlLineMarkers:
         case xlLineMarkersStacked:
         case xlLineMarkersStacked100:
-            setDiagram( OUString("com.sun.star.chart.LineDiagram"));
+            setDiagram( "com.sun.star.chart.LineDiagram");
             break;
         case xl3DArea:
         case xlArea:
@@ -279,19 +279,19 @@ try
         case xlAreaStacked100:
         case xl3DAreaStacked:
         case xl3DAreaStacked100:
-            setDiagram( OUString("com.sun.star.chart.AreaDiagram") );
+            setDiagram( "com.sun.star.chart.AreaDiagram" );
             break;
         case xlDoughnut:
         case xlDoughnutExploded:
-            setDiagram( OUString("com.sun.star.chart.DonutDiagram") );
+            setDiagram( "com.sun.star.chart.DonutDiagram" );
             break;
         case xlStockHLC:
         case xlStockOHLC:
         case xlStockVHLC:
         case xlStockVOHLC:
-            setDiagram( OUString("com.sun.star.chart.StockDiagram"));
-            mxDiagramPropertySet->setPropertyValue( UPDOWN, uno::makeAny(sal_Bool((_nChartType == xlStockOHLC) || (_nChartType == xlStockVOHLC))));
-            mxDiagramPropertySet->setPropertyValue(VOLUME, uno::makeAny(sal_Bool((_nChartType == xlStockVHLC) || (_nChartType == xlStockVOHLC))));
+            setDiagram( "com.sun.star.chart.StockDiagram");
+            mxDiagramPropertySet->setPropertyValue( UPDOWN, uno::makeAny((_nChartType == xlStockOHLC) || (_nChartType == xlStockVOHLC)));
+            mxDiagramPropertySet->setPropertyValue( VOLUME, uno::makeAny((_nChartType == xlStockVHLC) || (_nChartType == xlStockVOHLC)));
             break;
 
         case xlPieOfPie:                            // not possible
@@ -300,13 +300,13 @@ try
         case xl3DPie:
         case xlPie:
         case xlBarOfPie:                            // not possible (Zoom pie)
-            setDiagram( OUString("com.sun.star.chart.PieDiagram"));
+            setDiagram( "com.sun.star.chart.PieDiagram");
             break;
 
         case xlRadar:
         case xlRadarMarkers:
         case xlRadarFilled:
-            setDiagram( OUString("com.sun.star.chart.NetDiagram"));
+            setDiagram( "com.sun.star.chart.NetDiagram");
             break;
         case xlXYScatter:
         case xlBubble:                      // not possible
@@ -315,7 +315,7 @@ try
         case xlXYScatterLinesNoMarkers:
         case xlXYScatterSmooth:
         case xlXYScatterSmoothNoMarkers:
-            setDiagram( OUString("com.sun.star.chart.XYDiagram"));
+            setDiagram( "com.sun.star.chart.XYDiagram");
             switch(_nChartType)
             {
                 case xlXYScatter:
@@ -336,7 +336,7 @@ try
             }
             break;
         default:
-            throw script::BasicErrorException( OUString(), uno::Reference< uno::XInterface >(), SbERR_CONVERSION, OUString() );
+            throw script::BasicErrorException( OUString(), uno::Reference< uno::XInterface >(), ERRCODE_BASIC_CONVERSION, OUString() );
     }
 
     switch (_nChartType)
@@ -380,7 +380,6 @@ try
                 break;
         }
 
-
         switch (_nChartType)
         {
                 case xlConeColClustered:
@@ -539,12 +538,12 @@ try
     }
     catch ( const uno::Exception& )
     {
-        throw script::BasicErrorException( OUString(), uno::Reference< uno::XInterface >(), SbERR_METHOD_FAILED, OUString() );
+        throw script::BasicErrorException( OUString(), uno::Reference< uno::XInterface >(), ERRCODE_BASIC_METHOD_FAILED, OUString() );
     }
 }
 
 void SAL_CALL
-ScVbaChart::Activate() throw (script::BasicErrorException, uno::RuntimeException)
+ScVbaChart::Activate() throw (script::BasicErrorException, uno::RuntimeException, std::exception)
 {
     // #TODO how are Chart sheets handled ( I know we don't even consider
     // them in the worksheets/sheets collections ), but.....???
@@ -555,11 +554,11 @@ ScVbaChart::Activate() throw (script::BasicErrorException, uno::RuntimeException
     if ( pChartObj )
         pChartObj->Activate();
     else
-        throw script::BasicErrorException( OUString(), uno::Reference< uno::XInterface >(), SbERR_METHOD_FAILED, OUString( "no ChartObject as parent" ) );
+        throw script::BasicErrorException( OUString(), uno::Reference< uno::XInterface >(), ERRCODE_BASIC_METHOD_FAILED, OUString( "no ChartObject as parent" ) );
 }
 
 void SAL_CALL
-ScVbaChart::setSourceData( const css::uno::Reference< ::ooo::vba::excel::XRange >& _xCalcRange, const css::uno::Any& _aPlotBy ) throw (css::script::BasicErrorException, css::uno::RuntimeException)
+ScVbaChart::setSourceData( const css::uno::Reference< ::ooo::vba::excel::XRange >& _xCalcRange, const css::uno::Any& _aPlotBy ) throw (css::script::BasicErrorException, css::uno::RuntimeException, std::exception)
 {
     try
     {
@@ -573,19 +572,15 @@ ScVbaChart::setSourceData( const css::uno::Reference< ::ooo::vba::excel::XRange
 
         mxTableChart->setRanges(mRangeAddresses);
 
-        sal_Bool bsetRowHeaders = false;
-        sal_Bool bsetColumnHeaders = false;
+        bool bsetRowHeaders = false;
+        bool bsetColumnHeaders = false;
 
         ScVbaRange* pRange = static_cast< ScVbaRange* >( _xCalcRange.get() );
         if ( pRange )
         {
-            ScDocument* pDoc = pRange->getScDocument();
-            if ( pDoc )
-            {
-                bsetRowHeaders = pDoc->HasRowHeader(  static_cast< SCCOL >( mSingleRangeAddress.StartColumn ), static_cast< SCROW >( mSingleRangeAddress.StartRow ), static_cast< SCCOL >( mSingleRangeAddress.EndColumn ), static_cast< SCROW >( mSingleRangeAddress.EndRow ), static_cast< SCTAB >( mSingleRangeAddress.Sheet ) );
-                bsetColumnHeaders =  pDoc->HasColHeader(  static_cast< SCCOL >( mSingleRangeAddress.StartColumn ), static_cast< SCROW >( mSingleRangeAddress.StartRow ), static_cast< SCCOL >( mSingleRangeAddress.EndColumn ), static_cast< SCROW >( mSingleRangeAddress.EndRow ), static_cast< SCTAB >( mSingleRangeAddress.Sheet ));
-;
-            }
+            ScDocument& rDoc = pRange->getScDocument();
+            bsetRowHeaders = rDoc.HasRowHeader(  static_cast< SCCOL >( mSingleRangeAddress.StartColumn ), static_cast< SCROW >( mSingleRangeAddress.StartRow ), static_cast< SCCOL >( mSingleRangeAddress.EndColumn ), static_cast< SCROW >( mSingleRangeAddress.EndRow ), static_cast< SCTAB >( mSingleRangeAddress.Sheet ) );
+            bsetColumnHeaders = rDoc.HasColHeader(  static_cast< SCCOL >( mSingleRangeAddress.StartColumn ), static_cast< SCROW >( mSingleRangeAddress.StartRow ), static_cast< SCCOL >( mSingleRangeAddress.EndColumn ), static_cast< SCROW >( mSingleRangeAddress.EndRow ), static_cast< SCTAB >( mSingleRangeAddress.Sheet ));
         }
         mxTableChart->setHasRowHeaders(bsetRowHeaders);
         mxTableChart->setHasColumnHeaders(bsetColumnHeaders);
@@ -622,7 +617,7 @@ ScVbaChart::setSourceData( const css::uno::Reference< ::ooo::vba::excel::XRange
     }
     catch (const uno::Exception&)
     {
-        throw script::BasicErrorException( OUString(), uno::Reference< uno::XInterface >(), SbERR_METHOD_FAILED, OUString() );
+        throw script::BasicErrorException( OUString(), uno::Reference< uno::XInterface >(), ERRCODE_BASIC_METHOD_FAILED, OUString() );
     }
 }
 
@@ -645,7 +640,7 @@ ScVbaChart::setDefaultChartType() throw ( script::BasicErrorException )
 }
 
 void
-ScVbaChart::setPlotBy( ::sal_Int32 _nPlotBy ) throw (css::script::BasicErrorException, css::uno::RuntimeException)
+ScVbaChart::setPlotBy( ::sal_Int32 _nPlotBy ) throw (css::script::BasicErrorException, css::uno::RuntimeException, std::exception)
 {
     try
     {
@@ -660,17 +655,17 @@ ScVbaChart::setPlotBy( ::sal_Int32 _nPlotBy ) throw (css::script::BasicErrorExce
                 mxDiagramPropertySet->setPropertyValue( DATAROWSOURCE, uno::makeAny( chart::ChartDataRowSource_COLUMNS) );
                 break;
             default:
-                throw script::BasicErrorException( OUString(), uno::Reference< uno::XInterface >(), SbERR_METHOD_FAILED, OUString() );
+                throw script::BasicErrorException( OUString(), uno::Reference< uno::XInterface >(), ERRCODE_BASIC_METHOD_FAILED, OUString() );
         }
     }
     catch (const uno::Exception&)
     {
-        throw script::BasicErrorException( OUString(), uno::Reference< uno::XInterface >(), SbERR_METHOD_FAILED, OUString() );
+        throw script::BasicErrorException( OUString(), uno::Reference< uno::XInterface >(), ERRCODE_BASIC_METHOD_FAILED, OUString() );
     }
 }
 
 ::sal_Int32 SAL_CALL
-ScVbaChart::getPlotBy(  ) throw (script::BasicErrorException, uno::RuntimeException)
+ScVbaChart::getPlotBy(  ) throw (script::BasicErrorException, uno::RuntimeException, std::exception)
 {
     try
     {
@@ -687,7 +682,7 @@ ScVbaChart::getPlotBy(  ) throw (script::BasicErrorException, uno::RuntimeExcept
     }
     catch (const uno::Exception&)
     {
-        throw script::BasicErrorException( OUString(), uno::Reference< uno::XInterface >(), SbERR_METHOD_FAILED, OUString() );
+        throw script::BasicErrorException( OUString(), uno::Reference< uno::XInterface >(), ERRCODE_BASIC_METHOD_FAILED, OUString() );
     }
 }
 
@@ -703,26 +698,26 @@ ScVbaChart::setDiagram( const OUString& _sDiagramType ) throw( script::BasicErro
     }
     catch ( const uno::Exception& )
     {
-        throw script::BasicErrorException( OUString(), uno::Reference< uno::XInterface >(), SbERR_METHOD_FAILED, OUString() );
+        throw script::BasicErrorException( OUString(), uno::Reference< uno::XInterface >(), ERRCODE_BASIC_METHOD_FAILED, OUString() );
     }
 }
 
-// #TODO find out why we have Location/getLocation ? there is afaiks no
+// #TODO find out why we have Location/getLocation? there is afaik no
 // Location property, just a Location function for the Chart object
 sal_Int32 SAL_CALL
-ScVbaChart::Location() throw (css::script::BasicErrorException, css::uno::RuntimeException)
+ScVbaChart::Location() throw (css::script::BasicErrorException, css::uno::RuntimeException, std::exception)
 {
     return getLocation();
 }
 
 sal_Int32 SAL_CALL
-ScVbaChart::getLocation() throw (css::script::BasicErrorException, css::uno::RuntimeException)
+ScVbaChart::getLocation() throw (css::script::BasicErrorException, css::uno::RuntimeException, std::exception)
 {
      return -1;
 }
 
 void SAL_CALL
-ScVbaChart::setLocation( ::sal_Int32 /*where*/, const css::uno::Any& /*Name*/ ) throw (script::BasicErrorException, uno::RuntimeException)
+ScVbaChart::setLocation( ::sal_Int32 /*where*/, const css::uno::Any& /*Name*/ ) throw (script::BasicErrorException, uno::RuntimeException, std::exception)
 {
     // Helper api just stubs out the code <shrug>
     // #TODO come back and make sense out of this
@@ -810,22 +805,22 @@ ScVbaChart::setLocation( ::sal_Int32 /*where*/, const css::uno::Any& /*Name*/ )
 }
 
 sal_Bool SAL_CALL
-ScVbaChart::getHasTitle(  ) throw (script::BasicErrorException, uno::RuntimeException)
+ScVbaChart::getHasTitle(  ) throw (script::BasicErrorException, uno::RuntimeException, std::exception)
 {
-    sal_Bool bHasTitle = false;
+    bool bHasTitle = false;
     try
     {
         mxChartPropertySet->getPropertyValue(HASMAINTITLE) >>= bHasTitle;
     }
     catch (const uno::Exception&)
     {
-        throw script::BasicErrorException( OUString(), uno::Reference< uno::XInterface >(), SbERR_METHOD_FAILED, OUString() );
+        throw script::BasicErrorException( OUString(), uno::Reference< uno::XInterface >(), ERRCODE_BASIC_METHOD_FAILED, OUString() );
     }
     return bHasTitle;
 }
 
 void SAL_CALL
-ScVbaChart::setHasTitle( ::sal_Bool bTitle ) throw (script::BasicErrorException, uno::RuntimeException)
+ScVbaChart::setHasTitle( sal_Bool bTitle ) throw (script::BasicErrorException, uno::RuntimeException, std::exception)
 {
     try
     {
@@ -833,28 +828,28 @@ ScVbaChart::setHasTitle( ::sal_Bool bTitle ) throw (script::BasicErrorException,
     }
     catch (const uno::Exception&)
     {
-        throw script::BasicErrorException( OUString(), uno::Reference< uno::XInterface >(), SbERR_METHOD_FAILED, OUString() );
+        throw script::BasicErrorException( OUString(), uno::Reference< uno::XInterface >(), ERRCODE_BASIC_METHOD_FAILED, OUString() );
     }
 
 }
 
-::sal_Bool SAL_CALL
-ScVbaChart::getHasLegend(  ) throw (script::BasicErrorException, uno::RuntimeException)
+sal_Bool SAL_CALL
+ScVbaChart::getHasLegend(  ) throw (script::BasicErrorException, uno::RuntimeException, std::exception)
 {
-    sal_Bool bHasLegend = false;
+    bool bHasLegend = false;
     try
     {
         mxChartPropertySet->getPropertyValue(HASLEGEND) >>= bHasLegend;
     }
     catch (const uno::Exception&)
     {
-        throw script::BasicErrorException( OUString(), uno::Reference< uno::XInterface >(), SbERR_METHOD_FAILED, OUString() );
+        throw script::BasicErrorException( OUString(), uno::Reference< uno::XInterface >(), ERRCODE_BASIC_METHOD_FAILED, OUString() );
     }
     return bHasLegend;
 }
 
 void SAL_CALL
-ScVbaChart::setHasLegend( ::sal_Bool bLegend ) throw (script::BasicErrorException, uno::RuntimeException)
+ScVbaChart::setHasLegend( sal_Bool bLegend ) throw (script::BasicErrorException, uno::RuntimeException, std::exception)
 {
     try
     {
@@ -862,12 +857,12 @@ ScVbaChart::setHasLegend( ::sal_Bool bLegend ) throw (script::BasicErrorExceptio
     }
     catch (const uno::Exception&)
     {
-        throw script::BasicErrorException( OUString(), uno::Reference< uno::XInterface >(), SbERR_METHOD_FAILED, OUString() );
+        throw script::BasicErrorException( OUString(), uno::Reference< uno::XInterface >(), ERRCODE_BASIC_METHOD_FAILED, OUString() );
     }
 }
 
 uno::Reference< excel::XChartTitle > SAL_CALL
-ScVbaChart::getChartTitle(  ) throw (script::BasicErrorException, uno::RuntimeException)
+ScVbaChart::getChartTitle(  ) throw (script::BasicErrorException, uno::RuntimeException, std::exception)
 {
     uno::Reference< drawing::XShape > xTitleShape = mxChartDocument->getTitle();
     // #TODO check parent
@@ -875,7 +870,7 @@ ScVbaChart::getChartTitle(  ) throw (script::BasicErrorException, uno::RuntimeEx
 }
 
 uno::Any SAL_CALL
-ScVbaChart::Axes( const uno::Any& Type, const uno::Any& AxisGroup ) throw (script::BasicErrorException, uno::RuntimeException)
+ScVbaChart::Axes( const uno::Any& Type, const uno::Any& AxisGroup ) throw (script::BasicErrorException, uno::RuntimeException, std::exception)
 {
     // mmm chart probably is the parent, #TODO check parent
     uno::Reference< excel::XAxes > xAxes = new ScVbaAxes( this, mxContext, this );
@@ -887,7 +882,7 @@ bool
 ScVbaChart::is3D() throw ( uno::RuntimeException )
 {
     // #TODO perhaps provide limited Debughelper functionality
-    sal_Bool is3d = false;
+    bool is3d = false;
     mxDiagramPropertySet->getPropertyValue(DIM3D) >>= is3d;
     return is3d;
 }
@@ -911,7 +906,7 @@ bool
 ScVbaChart::isStacked() throw ( uno::RuntimeException )
 {
     // #TODO perhaps provide limited Debughelper functionality
-    sal_Bool bStacked = false;
+    bool bStacked = false;
     mxDiagramPropertySet->getPropertyValue(STACKED) >>= bStacked;
     return bStacked;
 }
@@ -920,7 +915,7 @@ bool
 ScVbaChart::is100PercentStacked() throw ( uno::RuntimeException )
 {
     // #TODO perhaps provide limited Debughelper functionality
-    sal_Bool b100Percent = false;
+    bool b100Percent = false;
     mxDiagramPropertySet->getPropertyValue(PERCENT) >>= b100Percent;
     return b100Percent;
 }
@@ -928,11 +923,11 @@ ScVbaChart::is100PercentStacked() throw ( uno::RuntimeException )
 sal_Int32
 ScVbaChart::getSolidType(sal_Int32 _nDeep, sal_Int32 _nVertiStacked, sal_Int32 _nVerti100PercentStacked, sal_Int32 _nVertiUnStacked, sal_Int32 _nHoriStacked, sal_Int32 _nHori100PercentStacked, sal_Int32 _nHoriUnStacked) throw ( script::BasicErrorException )
 {
-    sal_Bool bIsVertical = true;
     try
     {
+        bool bIsVertical = true;
         mxDiagramPropertySet->getPropertyValue(VERTICAL) >>= bIsVertical;
-        sal_Bool bIsDeep = false;
+        bool bIsDeep = false;
         mxDiagramPropertySet->getPropertyValue(DEEP) >>= bIsDeep;
 
         if (bIsDeep)
@@ -953,17 +948,16 @@ ScVbaChart::getSolidType(sal_Int32 _nDeep, sal_Int32 _nVertiStacked, sal_Int32 _
     }
     catch (const uno::Exception&)
     {
-        throw script::BasicErrorException( OUString(), uno::Reference< uno::XInterface >(), SbERR_METHOD_FAILED, OUString() );
+        throw script::BasicErrorException( OUString(), uno::Reference< uno::XInterface >(), ERRCODE_BASIC_METHOD_FAILED, OUString() );
     }
 }
 
-
 sal_Int32
 ScVbaChart::getStockUpDownValue(sal_Int32 _nUpDown, sal_Int32 _nNotUpDown) throw (script::BasicErrorException)
 {
-    sal_Bool bUpDown = false;
     try
     {
+        bool bUpDown = false;
         mxDiagramPropertySet->getPropertyValue(UPDOWN) >>= bUpDown;
         if (bUpDown)
         {
@@ -977,7 +971,7 @@ ScVbaChart::getStockUpDownValue(sal_Int32 _nUpDown, sal_Int32 _nNotUpDown) throw
     catch (const uno::Exception&)
     {
         OUString aTemp;    // temporary needed for g++ 3.3.5
-        script::BasicErrorException( aTemp, uno::Reference< uno::XInterface >(), SbERR_METHOD_FAILED, OUString() );
+        script::BasicErrorException( aTemp, uno::Reference< uno::XInterface >(), ERRCODE_BASIC_METHOD_FAILED, OUString() );
     }
     return _nNotUpDown;
 }
@@ -995,7 +989,7 @@ ScVbaChart::hasMarkers() throw ( script::BasicErrorException )
     catch (const uno::Exception&)
     {
         OUString aTemp;    // temporary needed for g++ 3.3.5
-        script::BasicErrorException( aTemp, uno::Reference< uno::XInterface >(), SbERR_METHOD_FAILED, OUString() );
+        script::BasicErrorException( aTemp, uno::Reference< uno::XInterface >(), ERRCODE_BASIC_METHOD_FAILED, OUString() );
     }
     return bHasMarkers;
 }
@@ -1018,9 +1012,8 @@ ScVbaChart::assignDiagramAttributes()
     xTwoAxisYSupplier.set( mxDiagramPropertySet, uno::UNO_QUERY_THROW );
 }
 
-
 uno::Reference< beans::XPropertySet >
-ScVbaChart::getAxisPropertySet(sal_Int32 _nAxisType, sal_Int32 _nAxisGroup) throw ( script::BasicErrorException )
+ScVbaChart::getAxisPropertySet(sal_Int32 _nAxisType, sal_Int32 _nAxisGroup) throw ( script::BasicErrorException, uno::RuntimeException )
 {
     assignDiagramAttributes();
     uno::Reference< beans::XPropertySet > xAxisProps;
@@ -1051,7 +1044,6 @@ ScVbaChart::getAxisPropertySet(sal_Int32 _nAxisType, sal_Int32 _nAxisGroup) thro
     return xAxisProps;
 }
 
-
 OUString
 ScVbaChart::getServiceImplName()
 {
