@@ -18,6 +18,7 @@
  */
 #include "vbaformatcondition.hxx"
 #include "vbaformatconditions.hxx"
+#include "unonames.hxx"
 #include <ooo/vba/excel/XlFormatConditionType.hpp>
 
 using namespace ::ooo::vba;
@@ -28,10 +29,19 @@ lcl_getScVbaFormatConditionsPtr( const uno::Reference< excel::XFormatConditions
 {
     ScVbaFormatConditions* pFormatConditions = static_cast< ScVbaFormatConditions* >( xFormatConditions.get() );
     if ( !pFormatConditions )
-        DebugHelper::exception(SbERR_METHOD_FAILED, OUString() );
+        DebugHelper::basicexception(ERRCODE_BASIC_METHOD_FAILED, OUString() );
     return pFormatConditions;
 }
-ScVbaFormatCondition::ScVbaFormatCondition(  const uno::Reference< XHelperInterface >& xParent, const uno::Reference< uno::XComponentContext > & xContext, const uno::Reference< sheet::XSheetConditionalEntry >& _xSheetConditionalEntry, const uno::Reference< excel::XStyle >& _xStyle, const uno::Reference< excel::XFormatConditions >& _xFormatConditions, const uno::Reference< css::beans::XPropertySet >& _xPropertySet ) throw ( css::uno::RuntimeException ) : ScVbaFormatCondition_BASE( xParent, xContext, uno::Reference< sheet::XSheetCondition >( _xSheetConditionalEntry, css::uno::UNO_QUERY_THROW ) ), moFormatConditions( _xFormatConditions ), mxStyle( _xStyle ), mxParentRangePropertySet( _xPropertySet )
+
+ScVbaFormatCondition::ScVbaFormatCondition( const uno::Reference< XHelperInterface >& xParent,
+                                            const uno::Reference< uno::XComponentContext > & xContext,
+                                            const uno::Reference< sheet::XSheetConditionalEntry >& _xSheetConditionalEntry,
+                                            const uno::Reference< excel::XStyle >& _xStyle,
+                                            const uno::Reference< excel::XFormatConditions >& _xFormatConditions,
+                                            const uno::Reference< css::beans::XPropertySet >& _xPropertySet ) throw ( css::uno::RuntimeException, css::script::BasicErrorException )
+    : ScVbaFormatCondition_BASE( xParent, xContext,
+                                 uno::Reference< sheet::XSheetCondition >( _xSheetConditionalEntry, css::uno::UNO_QUERY_THROW ) ),
+                                 moFormatConditions( _xFormatConditions ), mxStyle( _xStyle ), mxParentRangePropertySet( _xPropertySet )
 {
         mxSheetConditionalEntries = lcl_getScVbaFormatConditionsPtr( moFormatConditions )->getSheetConditionalEntries();
 
@@ -39,17 +49,16 @@ ScVbaFormatCondition::ScVbaFormatCondition(  const uno::Reference< XHelperInterf
         msStyleName = mxStyle->getName();
 }
 
-
 void SAL_CALL
-ScVbaFormatCondition::Delete(  ) throw (script::BasicErrorException, uno::RuntimeException)
+ScVbaFormatCondition::Delete(  ) throw (script::BasicErrorException, uno::RuntimeException, std::exception)
 {
     ScVbaFormatConditions* pFormatConditions = lcl_getScVbaFormatConditionsPtr( moFormatConditions );
-    pFormatConditions->removeFormatCondition(msStyleName, sal_True);
+    pFormatConditions->removeFormatCondition(msStyleName, true);
         notifyRange();
 }
 
 void SAL_CALL
-ScVbaFormatCondition::Modify( ::sal_Int32 _nType, const uno::Any& _aOperator, const uno::Any& _aFormula1, const uno::Any& _aFormula2 ) throw (script::BasicErrorException, uno::RuntimeException)
+ScVbaFormatCondition::Modify( ::sal_Int32 _nType, const uno::Any& _aOperator, const uno::Any& _aFormula1, const uno::Any& _aFormula2 ) throw (script::BasicErrorException, uno::RuntimeException, std::exception)
 {
     try
     {
@@ -57,25 +66,25 @@ ScVbaFormatCondition::Modify( ::sal_Int32 _nType, const uno::Any& _aOperator, co
         pFormatConditions->removeFormatCondition(msStyleName, false);
         pFormatConditions->Add(_nType, _aOperator, _aFormula1, _aFormula2, mxStyle);
     }
-    catch (uno::Exception& )
+    catch (const uno::Exception&)
     {
-        DebugHelper::exception(SbERR_METHOD_FAILED, OUString() );
+        DebugHelper::basicexception(ERRCODE_BASIC_METHOD_FAILED, OUString() );
     }
 }
 
 uno::Reference< excel::XInterior > SAL_CALL
-ScVbaFormatCondition::Interior(  ) throw (script::BasicErrorException, uno::RuntimeException)
+ScVbaFormatCondition::Interior(  ) throw (script::BasicErrorException, uno::RuntimeException, std::exception)
 {
     return mxStyle->Interior();
 }
 
 uno::Reference< excel::XFont > SAL_CALL
-ScVbaFormatCondition::Font(  ) throw (script::BasicErrorException, uno::RuntimeException)
+ScVbaFormatCondition::Font(  ) throw (script::BasicErrorException, uno::RuntimeException, std::exception)
 {
     return mxStyle->Font();
 }
 uno::Any SAL_CALL
-ScVbaFormatCondition::Borders( const uno::Any& Index ) throw (script::BasicErrorException, uno::RuntimeException)
+ScVbaFormatCondition::Borders( const uno::Any& Index ) throw (script::BasicErrorException, uno::RuntimeException, std::exception)
 { return mxStyle->Borders( Index );
 }
 
@@ -93,7 +102,7 @@ ScVbaFormatCondition::retrieveAPIType(sal_Int32 _nVBAType, const uno::Reference<
                 aAPIType = sheet::ConditionOperator_NONE;
             break;
         default:
-            DebugHelper::exception(SbERR_METHOD_FAILED, OUString() );
+            DebugHelper::basicexception(ERRCODE_BASIC_METHOD_FAILED, OUString() );
     }
     return aAPIType;
 }
@@ -103,17 +112,11 @@ ScVbaFormatCondition::setFormula1( const uno::Any& _aFormula1) throw ( script::B
 {
     // getA1Formula *SHOULD* detect whether the formula is r1c1 or A1 syntax
     // and if R1C1 convert to A1
-    ScVbaFormatCondition_BASE::setFormula1( uno::makeAny( lcl_getScVbaFormatConditionsPtr( moFormatConditions )->getA1Formula(_aFormula1) ) );
-}
-
-void
-ScVbaFormatCondition::setFormula2( const uno::Any& _aFormula2) throw ( script::BasicErrorException )
-{
-    ScVbaFormatCondition_BASE::setFormula1( uno::makeAny( lcl_getScVbaFormatConditionsPtr( moFormatConditions )->getA1Formula(_aFormula2)) );
+    ScVbaFormatCondition_BASE::setFormula1( uno::makeAny( ScVbaFormatConditions::getA1Formula(_aFormula1) ) );
 }
 
 ::sal_Int32 SAL_CALL
-ScVbaFormatCondition::Type(  ) throw ( script::BasicErrorException, uno::RuntimeException )
+ScVbaFormatCondition::Type(  ) throw ( script::BasicErrorException, uno::RuntimeException, std::exception )
 {
     sal_Int32 nReturnType = 0;
     if ( mxSheetCondition->getOperator() == sheet::ConditionOperator_FORMULA)
@@ -123,16 +126,15 @@ ScVbaFormatCondition::Type(  ) throw ( script::BasicErrorException, uno::Runtime
     return nReturnType;
 }
 
-
 ::sal_Int32
-ScVbaFormatCondition::Operator( sal_Bool bVal ) throw (script::BasicErrorException )
+ScVbaFormatCondition::Operator( bool bVal ) throw (script::BasicErrorException )
 {
     return ScVbaFormatCondition_BASE::Operator( bVal );
 }
 ::sal_Int32 SAL_CALL
 ScVbaFormatCondition::Operator(  ) throw (script::BasicErrorException, uno::RuntimeException)
 {
-    return ScVbaFormatCondition_BASE::Operator( sal_True );
+    return ScVbaFormatCondition_BASE::Operator( true );
 }
 
 void
@@ -140,11 +142,11 @@ ScVbaFormatCondition::notifyRange() throw ( script::BasicErrorException )
 {
     try
     {
-        mxParentRangePropertySet->setPropertyValue("ConditionalFormat", uno::makeAny( mxSheetConditionalEntries) );
+        mxParentRangePropertySet->setPropertyValue(SC_UNONAME_CONDFMT, uno::makeAny( mxSheetConditionalEntries));
     }
     catch (uno::Exception& )
     {
-        DebugHelper::exception(SbERR_METHOD_FAILED, OUString() );
+        DebugHelper::basicexception(ERRCODE_BASIC_METHOD_FAILED, OUString() );
     }
 }
 
