@@ -66,7 +66,7 @@
 
 #include <config_orcus.h>
 
-#include <boost/scoped_ptr.hpp>
+#include <memory>
 
 using namespace com::sun::star;
 
@@ -179,7 +179,7 @@ static bool lcl_GetSortParam( const ScViewData* pData, ScSortParam& rSortParam )
         ScAbstractDialogFactory* pFact = ScAbstractDialogFactory::Create();
         OSL_ENSURE(pFact, "ScAbstractFactory create fail!");
 
-        boost::scoped_ptr<AbstractScSortWarningDlg> pWarningDlg(pFact->CreateScSortWarningDlg( pTabViewShell->GetDialogParent(), aExtendStr, aCurrentStr ));
+        std::unique_ptr<AbstractScSortWarningDlg> pWarningDlg(pFact->CreateScSortWarningDlg( pTabViewShell->GetDialogParent(), aExtendStr, aCurrentStr ));
         OSL_ENSURE(pWarningDlg, "Dialog create fail!");
         short bResult = pWarningDlg->Execute();
         if( bResult == BTN_EXTEND_RANGE || bResult == BTN_CURRENT_SELECTION )
@@ -204,10 +204,9 @@ static bool lcl_GetSortParam( const ScViewData* pData, ScSortParam& rSortParam )
 //after end execute from !IsModalInputMode, it is safer to delay deleting
 namespace
 {
-    sal_IntPtr DelayDeleteAbstractDialog( void *pAbstractDialog, void * /*pArg*/ )
+    void DelayDeleteAbstractDialog( void *pAbstractDialog, void * /*pArg*/ )
     {
         delete static_cast<SfxAbstractTabDialog*>( pAbstractDialog );
-        return 0;
     }
 }
 
@@ -237,7 +236,7 @@ void ScCellShell::ExecuteDB( SfxRequest& rReq )
                 {
                     uno::Reference<frame::XFrame> xFrame = pViewFrame->GetFrame().GetFrameInterface();
                     uno::Reference<frame::XFrame> xBeamerFrame = xFrame->findFrame(
-                                                        OUString("_beamer"),
+                                                        "_beamer",
                                                         frame::FrameSearchFlag::CHILDREN);
                     if ( xBeamerFrame.is() )
                         bWasOpen = true;
@@ -500,7 +499,7 @@ void ScCellShell::ExecuteDB( SfxRequest& rReq )
                         ScAbstractDialogFactory* pFact = ScAbstractDialogFactory::Create();
                         assert(pFact); //ScAbstractFactory create fail!
 
-                        boost::scoped_ptr<SfxAbstractTabDialog> pDlg(pFact->CreateScSortDlg(pTabViewShell->GetDialogParent(),  &aArgSet));
+                        std::unique_ptr<SfxAbstractTabDialog> pDlg(pFact->CreateScSortDlg(pTabViewShell->GetDialogParent(),  &aArgSet));
                         assert(pDlg); //Dialog create fail!
                         pDlg->SetCurPageId("criteria");  // 1=sort field tab  2=sort options tab
 
@@ -522,8 +521,8 @@ void ScCellShell::ExecuteDB( SfxRequest& rReq )
                                     rOutParam.bHasHeader ) );
                                 rReq.AppendItem( SfxBoolItem( SID_SORT_CASESENS,
                                     rOutParam.bCaseSens ) );
-                            rReq.AppendItem( SfxBoolItem( SID_SORT_NATURALSORT,
-                                                rOutParam.bNaturalSort ) );
+                                rReq.AppendItem( SfxBoolItem( SID_SORT_NATURALSORT,
+                                            rOutParam.bNaturalSort ) );
                                 rReq.AppendItem( SfxBoolItem( SID_SORT_ATTRIBS,
                                     rOutParam.bIncludePattern ) );
                                 sal_uInt16 nUser = rOutParam.bUserDef ? ( rOutParam.nUserIndex + 1 ) : 0;
@@ -567,7 +566,7 @@ void ScCellShell::ExecuteDB( SfxRequest& rReq )
                 {
                     OSL_FAIL("SID_FILTER with arguments?");
                     pTabViewShell->Query( static_cast<const ScQueryItem&>(
-                            pArgs->Get( SCITEM_QUERYDATA )).GetQueryData(), NULL, true );
+                            pArgs->Get( SCITEM_QUERYDATA )).GetQueryData(), nullptr, true );
                     rReq.Done();
                 }
                 else
@@ -588,7 +587,7 @@ void ScCellShell::ExecuteDB( SfxRequest& rReq )
                 {
                     OSL_FAIL("SID_SPECIAL_FILTER with arguments?");
                     pTabViewShell->Query( static_cast<const ScQueryItem&>(
-                            pArgs->Get( SCITEM_QUERYDATA )).GetQueryData(), NULL, true );
+                            pArgs->Get( SCITEM_QUERYDATA )).GetQueryData(), nullptr, true );
                     rReq.Done();
                 }
                 else
@@ -626,7 +625,7 @@ void ScCellShell::ExecuteDB( SfxRequest& rReq )
                     if (rQueryItem.GetAdvancedQuerySource(aAdvSource))
                         pTabViewShell->Query( rQueryItem.GetQueryData(), &aAdvSource, true );
                     else
-                        pTabViewShell->Query( rQueryItem.GetQueryData(), NULL, true );
+                        pTabViewShell->Query( rQueryItem.GetQueryData(), nullptr, true );
                     rReq.Done( *pReqArgs );
                 }
             }
@@ -642,7 +641,7 @@ void ScCellShell::ExecuteDB( SfxRequest& rReq )
                 for (SCSIZE i=0; i<nEC; i++)
                     aParam.GetEntry(i).bDoQuery = false;
                 aParam.bDuplicate = true;
-                pTabViewShell->Query( aParam, NULL, true );
+                pTabViewShell->Query( aParam, nullptr, true );
                 rReq.Done();
             }
             break;
@@ -688,7 +687,7 @@ void ScCellShell::ExecuteDB( SfxRequest& rReq )
                 }
 #if HAVE_FEATURE_SCRIPTING
                 else if (rReq.IsAPI())
-                    SbxBase::SetError(SbxERR_BAD_PARAMETER);
+                    SbxBase::SetError(ERRCODE_SBX_BAD_PARAMETER);
 #endif
             }
             break;
@@ -736,12 +735,12 @@ void ScCellShell::ExecuteDB( SfxRequest& rReq )
                         const ScDBCollection::NamedDBs& rDBs = pDBCol->getNamedDBs();
                         ScDBCollection::NamedDBs::const_iterator itr = rDBs.begin(), itrEnd = rDBs.end();
                         for (; itr != itrEnd; ++itr)
-                            aList.push_back(itr->GetName());
+                            aList.push_back((*itr)->GetName());
 
                         ScAbstractDialogFactory* pFact = ScAbstractDialogFactory::Create();
                         OSL_ENSURE(pFact, "ScAbstractFactory create fail!");
 
-                        boost::scoped_ptr<AbstractScSelEntryDlg> pDlg(pFact->CreateScSelEntryDlg( pTabViewShell->GetDialogParent(),
+                        std::unique_ptr<AbstractScSelEntryDlg> pDlg(pFact->CreateScSelEntryDlg( pTabViewShell->GetDialogParent(),
                                                                                                   aList ));
                         OSL_ENSURE(pDlg, "Dialog create fail!");
                         if ( pDlg->Execute() == RET_OK )
@@ -862,7 +861,7 @@ void ScCellShell::ExecuteDB( SfxRequest& rReq )
                     }
 
                     // cell range picker
-                    SfxAbstractTabDialog* pDlg = pFact->CreateScValidationDlg(NULL, &aArgSet, pTabViewShell);
+                    SfxAbstractTabDialog* pDlg = pFact->CreateScValidationDlg(nullptr, &aArgSet, pTabViewShell);
                     assert(pDlg); //Dialog create fail!
 
                     short nResult = pDlg->Execute();
@@ -904,11 +903,27 @@ void ScCellShell::ExecuteDB( SfxRequest& rReq )
                                             ScGlobal::pLocaleData->getNumDecimalSep()[0], true));
                                 else
                                     aExpr2 = aTemp2;
+                                if ( eMode == SC_VALID_TIME ) {
+                                    sal_Int32 wraparound = aExpr1.compareTo(aExpr2);
+                                    if (wraparound > 0) {
+                                        if (eOper == SC_COND_BETWEEN) {
+                                            eOper = SC_COND_NOTBETWEEN;
+                                            OUString tmp = aExpr1;
+                                            aExpr1 = aExpr2;
+                                            aExpr2 = tmp;
+                                        }
+                                        else if (eOper == SC_COND_NOTBETWEEN) {
+                                            eOper = SC_COND_BETWEEN;
+                                            OUString tmp = aExpr1;
+                                            aExpr1 = aExpr2;
+                                            aExpr2 = tmp;
+                                        }
+                                    }
+                                }
                             }
                             else
                                 aExpr2 = aTemp2;
                         }
-
                         if ( pOutSet->GetItemState( FID_VALID_BLANK, true, &pItem ) == SfxItemState::SET )
                             bBlank = static_cast<const SfxBoolItem*>(pItem)->GetValue();
                         if ( pOutSet->GetItemState( FID_VALID_LISTTYPE, true, &pItem ) == SfxItemState::SET )
@@ -948,7 +963,7 @@ void ScCellShell::ExecuteDB( SfxRequest& rReq )
                     }
                     //after end execute from !IsModalInputMode, it is safer to delay deleting
                     //delete pDlg;
-                    Application::PostUserEvent( Link<>( pDlg, &DelayDeleteAbstractDialog ) );
+                    Application::PostUserEvent( Link<void*,void>( pDlg, &DelayDeleteAbstractDialog ) );
                 }
             }
             break;
@@ -973,12 +988,12 @@ void ScCellShell::ExecuteDB( SfxRequest& rReq )
                     SvMemoryStream aStream;
                     aStream.SetStreamCharSet( RTL_TEXTENCODING_UNICODE );
                     ScImportExport::SetNoEndianSwap( aStream );
-                    aExport.ExportStream( aStream, OUString(), SotClipboardFormatId::STRING );
+                    aExport.ExportStream( aStream, OUString() );
 
                     ScAbstractDialogFactory* pFact = ScAbstractDialogFactory::Create();
                     OSL_ENSURE( pFact, "ScCellShell::ExecuteDB: SID_TEXT_TO_COLUMNS - pFact is null!" );
-                    boost::scoped_ptr<AbstractScImportAsciiDlg> pDlg(pFact->CreateScImportAsciiDlg(
-                        NULL, OUString(), &aStream, SC_TEXTTOCOLUMNS));
+                    std::unique_ptr<AbstractScImportAsciiDlg> pDlg(pFact->CreateScImportAsciiDlg(
+                        nullptr, OUString(), &aStream, SC_TEXTTOCOLUMNS));
                     OSL_ENSURE( pDlg, "ScCellShell::ExecuteDB: SID_TEXT_TO_COLUMNS - pDlg is null!" );
 
                     if ( pDlg->Execute() == RET_OK )
@@ -998,7 +1013,7 @@ void ScCellShell::ExecuteDB( SfxRequest& rReq )
                         aImport.SetImportBroadcast( true );
                         aImport.SetOverwriting( true );
                         aStream.Seek( 0 );
-                        aImport.ImportStream( aStream, OUString(), SotClipboardFormatId::STRING );
+                        aImport.ImportStream( aStream, OUString() );
 
                         pDocSh->GetUndoManager()->LeaveListAction();
                     }
@@ -1033,7 +1048,7 @@ void ScCellShell::GetDBState( SfxItemSet& rSet )
                     //  or filter,sort,subtotal (also without import)
                     bool bOk = false;
                     ScDBData* pDBData = pTabViewShell->GetDBData(false,SC_DB_OLD);
-                    if (pDBData && rDoc.GetChangeTrack() == NULL)
+                    if (pDBData && rDoc.GetChangeTrack() == nullptr)
                     {
                         if ( pDBData->HasImportParam() )
                             bOk = !pDBData->HasImportSelection();
@@ -1070,7 +1085,7 @@ void ScCellShell::GetDBState( SfxItemSet& rSet )
                 {
                     //! move ReadOnly check to idl flags
 
-                    if ( pDocSh->IsReadOnly() || rDoc.GetChangeTrack()!=NULL ||
+                    if ( pDocSh->IsReadOnly() || rDoc.GetChangeTrack()!=nullptr ||
                             GetViewData()->IsMultiMarked() )
                     {
                         rSet.DisableItem( nWhich );
@@ -1083,7 +1098,7 @@ void ScCellShell::GetDBState( SfxItemSet& rSet )
                     //  only imported data without selection
                     ScDBData* pDBData = pTabViewShell->GetDBData(false,SC_DB_OLD);
                     if (!pDBData || !pDBData->HasImportParam() || pDBData->HasImportSelection() ||
-                        rDoc.GetChangeTrack()!=NULL)
+                        rDoc.GetChangeTrack()!=nullptr)
                     {
                         rSet.DisableItem( nWhich );
                     }
@@ -1096,7 +1111,7 @@ void ScCellShell::GetDBState( SfxItemSet& rSet )
                         rSet.Put(SfxVisibilityItem(nWhich, false));
                     else
                         //  get state (BoolItem) from SfxViewFrame
-                        pTabViewShell->GetViewFrame()->GetSlotState( nWhich, NULL, &rSet );
+                        pTabViewShell->GetViewFrame()->GetSlotState( nWhich, nullptr, &rSet );
                 }
                 break;
             case SID_SBA_BRW_INSERT:
@@ -1162,7 +1177,7 @@ void ScCellShell::GetDBState( SfxItemSet& rSet )
 
                     ScDBData* pDBData = bSelected
                                 ? rDoc.GetDBAtArea( nStartTab, nStartCol, nStartRow, nEndCol, nEndRow )
-                                : rDoc.GetDBAtCursor( nStartCol, nStartRow, nStartTab );
+                                : rDoc.GetDBAtCursor( nStartCol, nStartRow, nStartTab, ScDBDataPortion::AREA );
 
                     if ( pDBData )
                     {
