@@ -24,7 +24,6 @@
 #include "global.hxx"
 #include "viewdata.hxx"
 
-
 void ScDrawUtil::CalcScale( ScDocument* pDoc, SCTAB nTab,
                             SCCOL nStartCol, SCROW nStartRow, SCCOL nEndCol, SCROW nEndRow,
                             OutputDevice* pDev,
@@ -46,7 +45,7 @@ void ScDrawUtil::CalcScale( ScDocument* pDoc, SCTAB nTab,
     for (SCROW nRow = nStartRow; nRow <= nEndRow-1; ++nRow)
     {
         SCROW nLastRow = nRow;
-        if (pDoc->RowHidden(nRow, nTab, NULL, &nLastRow))
+        if (pDoc->RowHidden(nRow, nTab, nullptr, &nLastRow))
         {
             nRow = nLastRow;
             continue;
@@ -87,7 +86,4 @@ void ScDrawUtil::CalcScale( ScDocument* pDoc, SCTAB nTab,
     rScaleY.ReduceInaccurate( 25 );
 }
 
-
-
-
 /* vim:set shiftwidth=4 softtabstop=4 expandtab: */
