@@ -27,6 +27,7 @@
 #include <svtools/imapobj.hxx>
 #include <vcl/cursor.hxx>
 #include <vcl/help.hxx>
+#include <vcl/svapp.hxx>
 #include <tools/urlobj.hxx>
 #include <sfx2/viewfrm.hxx>
 
@@ -52,7 +53,6 @@
 #include "postit.hxx"
 #include "global.hxx"
 #include "globstr.hrc"
-// -----------------------------------------------------------------------
 
 bool ScGridWindow::ShowNoteMarker( SCsCOL nPosX, SCsROW nPosY, bool bKeyboard )
 {
@@ -65,15 +65,15 @@ bool ScGridWindow::ShowNoteMarker( SCsCOL nPosX, SCsROW nPosY, bool bKeyboard )
     OUString aTrackText;
     bool bLeftEdge = false;
 
-    //  Change-Tracking
+    // change tracking
 
     ScChangeTrack* pTrack = pDoc->GetChangeTrack();
     ScChangeViewSettings* pSettings = pDoc->GetChangeViewSettings();
     if ( pTrack && pTrack->GetFirst() && pSettings && pSettings->ShowChanges())
     {
-        const ScChangeAction* pFound = NULL;
-        const ScChangeAction* pFoundContent = NULL;
-        const ScChangeAction* pFoundMove = NULL;
+        const ScChangeAction* pFound = nullptr;
+        const ScChangeAction* pFoundContent = nullptr;
+        const ScChangeAction* pFoundMove = nullptr;
         long nModified = 0;
         const ScChangeAction* pAction = pTrack->GetFirst();
         while (pAction)
@@ -94,7 +94,7 @@ bool ScGridWindow::ShowNoteMarker( SCsCOL nPosX, SCsROW nPosY, bool bKeyboard )
 
                     if ( aRange.In( aCellPos ) )
                     {
-                        pFound = pAction;       // der letzte gewinnt
+                        pFound = pAction;       // the last one wins
                         switch ( eType )
                         {
                             case SC_CAT_CONTENT :
@@ -114,7 +114,7 @@ bool ScGridWindow::ShowNoteMarker( SCsCOL nPosX, SCsROW nPosY, bool bKeyboard )
                 if ( eType == SC_CAT_MOVE )
                 {
                     ScRange aRange =
-                        ((const ScChangeActionMove*)pAction)->
+                        static_cast<const ScChangeActionMove*>(pAction)->
                         GetFromRange().MakeRange();
                     if ( aRange.In( aCellPos ) )
                     {
@@ -129,13 +129,13 @@ bool ScGridWindow::ShowNoteMarker( SCsCOL nPosX, SCsROW nPosY, bool bKeyboard )
         if ( pFound )
         {
             if ( pFoundContent && pFound->GetType() != SC_CAT_CONTENT )
-                pFound = pFoundContent;     // Content gewinnt
+                pFound = pFoundContent;     // content wins
             if ( pFoundMove && pFound->GetType() != SC_CAT_MOVE &&
                     pFoundMove->GetActionNumber() >
                     pFound->GetActionNumber() )
-                pFound = pFoundMove;        // Move gewinnt
+                pFound = pFoundMove;        // move wins
 
-            //  bei geloeschten Spalten: Pfeil auf die linke Seite der Zelle
+            // for deleted columns: Arrow on the left side of the cell
             if ( pFound->GetType() == SC_CAT_DELETE_COLS )
                 bLeftEdge = true;
 
@@ -162,37 +162,37 @@ bool ScGridWindow::ShowNoteMarker( SCsCOL nPosX, SCsROW nPosY, bool bKeyboard )
         }
     }
 
-    //  Notiz nur, wenn sie nicht schon auf dem Drawing-Layer angezeigt wird:
+    // Note, only if it is not already displayed on the Drawing Layer:
     const ScPostIt* pNote = pDoc->GetNote( aCellPos );
     if ( (!aTrackText.isEmpty()) || (pNote && !pNote->IsCaptionShown()) )
     {
         bool bNew = true;
         bool bFast = false;
-        if ( pNoteMarker )          // schon eine Notiz angezeigt
+        if (mpNoteMarker) // A note already shown
         {
-            if ( pNoteMarker->GetDocPos() == aCellPos ) // dieselbe
-                bNew = false;                           // dann stehenlassen
+            if (mpNoteMarker->GetDocPos() == aCellPos)
+                bNew = false; // then stop
             else
-                bFast = true;                           // sonst sofort
+                bFast = true; // otherwise, at once
 
             //  marker which was shown for ctrl-F1 isn't removed by mouse events
-            if ( pNoteMarker->IsByKeyboard() && !bKeyboard )
+            if (mpNoteMarker->IsByKeyboard() && !bKeyboard)
                 bNew = false;
         }
-        if ( bNew )
+        if (bNew)
         {
-            if ( bKeyboard )
-                bFast = true;           // keyboard also shows the marker immediately
+            if (bKeyboard)
+                bFast = true; // keyboard also shows the marker immediately
 
-            delete pNoteMarker;
+            mpNoteMarker.reset();
 
             bool bHSplit = pViewData->GetHSplitMode() != SC_SPLIT_NONE;
             bool bVSplit = pViewData->GetVSplitMode() != SC_SPLIT_NONE;
 
-            Window* pLeft = pViewData->GetView()->GetWindowByPos( bVSplit ? SC_SPLIT_TOPLEFT : SC_SPLIT_BOTTOMLEFT );
-            Window* pRight = bHSplit ? pViewData->GetView()->GetWindowByPos( bVSplit ? SC_SPLIT_TOPRIGHT : SC_SPLIT_BOTTOMRIGHT ) : 0;
-            Window* pBottom = bVSplit ? pViewData->GetView()->GetWindowByPos( SC_SPLIT_BOTTOMLEFT ) : 0;
-            Window* pDiagonal = (bHSplit && bVSplit) ? pViewData->GetView()->GetWindowByPos( SC_SPLIT_BOTTOMRIGHT ) : 0;
+            vcl::Window* pLeft = pViewData->GetView()->GetWindowByPos( bVSplit ? SC_SPLIT_TOPLEFT : SC_SPLIT_BOTTOMLEFT );
+            vcl::Window* pRight = bHSplit ? pViewData->GetView()->GetWindowByPos( bVSplit ? SC_SPLIT_TOPRIGHT : SC_SPLIT_BOTTOMRIGHT ) : nullptr;
+            vcl::Window* pBottom = bVSplit ? pViewData->GetView()->GetWindowByPos( SC_SPLIT_BOTTOMLEFT ) : nullptr;
+            vcl::Window* pDiagonal = (bHSplit && bVSplit) ? pViewData->GetView()->GetWindowByPos( SC_SPLIT_BOTTOMRIGHT ) : nullptr;
             OSL_ENSURE( pLeft, "ScGridWindow::ShowNoteMarker - missing top-left grid window" );
 
             /*  If caption is shown from right or bottom windows, adjust
@@ -206,30 +206,27 @@ bool ScGridWindow::ShowNoteMarker( SCsCOL nPosX, SCsROW nPosY, bool bKeyboard )
                 aOrigin.Y() += aLeftSize.Height();
             aMapMode.SetOrigin( aOrigin );
 
-            pNoteMarker = new ScNoteMarker(  pLeft, pRight, pBottom, pDiagonal,
-                                            pDoc, aCellPos, aTrackText,
-                                            aMapMode, bLeftEdge, bFast, bKeyboard );
+            mpNoteMarker.reset(new ScNoteMarker(pLeft, pRight, pBottom, pDiagonal,
+                                                pDoc, aCellPos, aTrackText,
+                                                aMapMode, bLeftEdge, bFast, bKeyboard));
             if ( pViewData->GetScDrawView() )
             {
                 // get position for aCellPos
-                if ( pDoc )
-                {
-                    // get draw position in hmm for aCellPos
-                    Point aOldPos( pDoc->GetColOffset( aCellPos.Col(), aCellPos.Tab() ), pDoc->GetRowOffset( aCellPos.Row(), aCellPos.Tab() ) );
-                    aOldPos.X() = sc::TwipsToHMM( aOldPos.X() );
-                    aOldPos.Y() = sc::TwipsToHMM( aOldPos.Y() );
-                    // get screen pos in hmm for aCellPos
-                    // and equiv screen pos
-                    Point aScreenPos = pViewData->GetScrPos( aCellPos.Col(), aCellPos.Row(), eWhich, sal_True );
-                    MapMode aDrawMode = GetDrawMapMode();
-                    Point aCurPosHmm = PixelToLogic(aScreenPos, aDrawMode );
-                    Point aGridOff = aCurPosHmm -aOldPos;
-                    // fdo#63323 fix the X Position for the showing comment when
-                    // the mouse over the cell when the sheet are RTL
-                    if ( pDoc->IsNegativePage(nTab))
-                        aGridOff.setX(aCurPosHmm.getX() + aOldPos.getX());
-                    pNoteMarker->SetGridOff( aGridOff );
-                }
+                // get draw position in hmm for aCellPos
+                Point aOldPos( pDoc->GetColOffset( aCellPos.Col(), aCellPos.Tab() ), pDoc->GetRowOffset( aCellPos.Row(), aCellPos.Tab() ) );
+                aOldPos.X() = sc::TwipsToHMM( aOldPos.X() );
+                aOldPos.Y() = sc::TwipsToHMM( aOldPos.Y() );
+                // get screen pos in hmm for aCellPos
+                // and equiv screen pos
+                Point aScreenPos = pViewData->GetScrPos( aCellPos.Col(), aCellPos.Row(), eWhich, true );
+                MapMode aDrawMode = GetDrawMapMode();
+                Point aCurPosHmm = PixelToLogic(aScreenPos, aDrawMode );
+                Point aGridOff = aCurPosHmm -aOldPos;
+                // fdo#63323 fix the X Position for the showing comment when
+                // the mouse over the cell when the sheet are RTL
+                if ( pDoc->IsNegativePage(nTab))
+                    aGridOff.setX(aCurPosHmm.getX() + aOldPos.getX());
+                mpNoteMarker->SetGridOff( aGridOff );
             }
         }
 
@@ -239,22 +236,29 @@ bool ScGridWindow::ShowNoteMarker( SCsCOL nPosX, SCsROW nPosY, bool bKeyboard )
     return bDone;
 }
 
-// -----------------------------------------------------------------------
-
 void ScGridWindow::RequestHelp(const HelpEvent& rHEvt)
 {
     //To know whether to prefix STR_CTRLCLICKHYERLINK or STR_CLICKHYPERLINK
     //to hyperlink tooltips/help text
     SvtSecurityOptions aSecOpt;
     bool bCtrlClickHlink = aSecOpt.IsOptionSet( SvtSecurityOptions::E_CTRLCLICK_HYPERLINK );
-    //Global string STR_CTRLCLICKHYPERLINK i.e, "ctrl+click to open hyperlink:"
+    //Global string STR_CTRLCLICKHYPERLINK i.e,
+    // "ctrl-click to follow link:" for not MacOS
+    // "⌘-click to follow link:" for MacOs
+    vcl::KeyCode aCode( KEY_SPACE );
+    vcl::KeyCode aModifiedCode( KEY_SPACE, KEY_MOD1 );
+    OUString aModStr( aModifiedCode.GetName() );
+    aModStr = aModStr.replaceFirst(aCode.GetName(), "");
+    aModStr = aModStr.replaceAll("+", "");
     OUString aCtrlClickHlinkStr = ScGlobal::GetRscString( STR_CTRLCLICKHYPERLINK );
+
+    aCtrlClickHlinkStr = aCtrlClickHlinkStr.replaceAll("%s", aModStr);
     //Global string STR_CLICKHYPERLINK i.e, "click to open hyperlink"
     OUString aClickHlinkStr = ScGlobal::GetRscString( STR_CLICKHYPERLINK );
-    sal_Bool bDone = false;
-    sal_Bool bHelpEnabled = ( rHEvt.GetMode() & ( HELPMODE_BALLOON | HELPMODE_QUICK ) ) != 0;
+    bool bDone = false;
+    bool bHelpEnabled = bool(rHEvt.GetMode() & ( HelpEventMode::BALLOON | HelpEventMode::QUICK ));
     SdrView* pDrView = pViewData->GetScDrawView();
-    sal_Bool bDrawTextEdit = false;
+    bool bDrawTextEdit = false;
     if (pDrView)
         bDrawTextEdit = pDrView->IsTextEdit();
     //  notes or change tracking
@@ -267,24 +271,26 @@ void ScGridWindow::RequestHelp(const HelpEvent& rHEvt)
 
         if ( ShowNoteMarker( nPosX, nPosY, false ) )
         {
-            Window::RequestHelp( rHEvt );   // alte Tip/Balloon ausschalten
-            bDone = sal_True;
+            Window::RequestHelp( rHEvt );   // turn off old Tip/Balloon
+            bDone = true;
         }
     }
 
-    if ( !bDone && pNoteMarker )
+    if (!bDone && mpNoteMarker)
     {
-        if ( pNoteMarker->IsByKeyboard() )
+        if (mpNoteMarker->IsByKeyboard())
         {
             //  marker which was shown for ctrl-F1 isn't removed by mouse events
         }
         else
-            DELETEZ(pNoteMarker);
+        {
+            mpNoteMarker.reset();
+        }
     }
 
     //  Image-Map / Text-URL
 
-    if ( bHelpEnabled && !bDone && !nButtonDown )       // nur ohne gedrueckten Button
+    if ( bHelpEnabled && !bDone && !nButtonDown )       // only without pressed button
     {
         OUString aHelpText;
         Rectangle aPixRect;
@@ -293,12 +299,12 @@ void ScGridWindow::RequestHelp(const HelpEvent& rHEvt)
         if ( pDrView )                                      // URL / Image-Map
         {
             SdrViewEvent aVEvt;
-            MouseEvent aMEvt( aPosPixel, 1, 0, MOUSE_LEFT );
-            SdrHitKind eHit = pDrView->PickAnything( aMEvt, SDRMOUSEBUTTONDOWN, aVEvt );
+            MouseEvent aMEvt( aPosPixel, 1, MouseEventModifiers::NONE, MOUSE_LEFT );
+            SdrHitKind eHit = pDrView->PickAnything( aMEvt, SdrMouseEventKind::BUTTONDOWN, aVEvt );
 
-            if ( eHit != SDRHIT_NONE && aVEvt.pObj != NULL )
+            if ( eHit != SDRHIT_NONE && aVEvt.pObj != nullptr )
             {
-                // URL fuer IMapObject unter Pointer ist Hilfetext
+                // URL for IMapObject below Pointer is help text
                 if ( ScDrawLayer::GetIMapInfo( aVEvt.pObj ) )
                 {
                     Point aLogicPos = PixelToLogic( aPosPixel );
@@ -307,7 +313,7 @@ void ScGridWindow::RequestHelp(const HelpEvent& rHEvt)
 
                     if ( pIMapObj )
                     {
-                        //  Bei ImageMaps die Description anzeigen, wenn vorhanden
+                        // For image maps show the description, if available
                         aHelpText = pIMapObj->GetAltText();
                         if (aHelpText.isEmpty())
                             aHelpText = pIMapObj->GetURL();
@@ -334,15 +340,15 @@ void ScGridWindow::RequestHelp(const HelpEvent& rHEvt)
                     }
                     else
                     {
-                        SdrObject* pObj = 0;
-                        SdrPageView* pPV = 0;
+                        SdrObject* pObj = nullptr;
+                        SdrPageView* pPV = nullptr;
                         Point aMDPos = PixelToLogic( aPosPixel );
-                        if ( pDrView->PickObj(aMDPos, pDrView->getHitTolLog(), pObj, pPV, SDRSEARCH_ALSOONMASTER) )
+                        if ( pDrView->PickObj(aMDPos, pDrView->getHitTolLog(), pObj, pPV, SdrSearchOptions::ALSOONMASTER) )
                         {
                             if ( pObj->IsGroupObject() )
                             {
-                                    SdrObject* pHit = 0;
-                                    if ( pDrView->PickObj(aMDPos, pDrView->getHitTolLog(), pHit, pPV, SDRSEARCH_DEEP ) )
+                                    SdrObject* pHit = nullptr;
+                                    if ( pDrView->PickObj(aMDPos, pDrView->getHitTolLog(), pHit, pPV, SdrSearchOptions::DEEP ) )
                                         pObj = pHit;
                             }
                             ScMacroInfo* pInfo = ScDrawLayer::GetMacroInfo( pObj );
@@ -371,9 +377,9 @@ void ScGridWindow::RequestHelp(const HelpEvent& rHEvt)
         if ( aHelpText.isEmpty() )                                 // Text-URL
         {
             OUString aUrl;
-            if ( GetEditUrl( aPosPixel, NULL, &aUrl, NULL ) )
+            if ( GetEditUrl( aPosPixel, nullptr, &aUrl ) )
             {
-                aHelpText = INetURLObject::decode( aUrl, INET_HEX_ESCAPE,
+                aHelpText = INetURLObject::decode( aUrl,
                     INetURLObject::DECODE_UNAMBIGUOUS );
 
                 if( bCtrlClickHlink )
@@ -387,7 +393,6 @@ void ScGridWindow::RequestHelp(const HelpEvent& rHEvt)
                     aHelpText = aClickHlinkStr + aHelpText;
                 }
 
-
                 ScDocument* pDoc = pViewData->GetDocument();
                 SCsCOL nPosX;
                 SCsROW nPosY;
@@ -405,30 +410,30 @@ void ScGridWindow::RequestHelp(const HelpEvent& rHEvt)
             Rectangle aScreenRect(OutputToScreenPixel(aPixRect.TopLeft()),
                                     OutputToScreenPixel(aPixRect.BottomRight()));
 
-            if ( rHEvt.GetMode() & HELPMODE_BALLOON )
+            if ( rHEvt.GetMode() & HelpEventMode::BALLOON )
                 Help::ShowBalloon(this,rHEvt.GetMousePosPixel(), aScreenRect, aHelpText);
-            else if ( rHEvt.GetMode() & HELPMODE_QUICK )
+            else if ( rHEvt.GetMode() & HelpEventMode::QUICK )
                 Help::ShowQuickHelp(this,aScreenRect, aHelpText);
 
-            bDone = sal_True;
+            bDone = true;
         }
     }
 
-    //  Basic-Controls
+    // basic controls
 
     if ( pDrView && bHelpEnabled && !bDone )
     {
         SdrPageView* pPV = pDrView->GetSdrPageView();
         OSL_ENSURE( pPV, "SdrPageView* ist NULL" );
         if (pPV)
-            bDone = ((ScDrawPage*)pPV->GetPage())->RequestHelp( this, pDrView, rHEvt );
+            bDone = FmFormPage::RequestHelp( this, pDrView, rHEvt );
     }
 
-    //  Wenn QuickHelp fuer AutoFill angezeigt wird, nicht wieder wegnehmen lassen
+    // If QuickHelp for AutoFill is shown, do not allow it to be removed
 
     if ( nMouseStatus == SC_GM_TABDOWN && pViewData->GetRefType() == SC_REFTYPE_FILL &&
             Help::IsQuickHelpEnabled() )
-        bDone = sal_True;
+        bDone = true;
 
     if (!bDone)
         Window::RequestHelp( rHEvt );
@@ -442,21 +447,29 @@ bool ScGridWindow::IsMyModel(SdrEditView* pSdrView)
 
 void ScGridWindow::HideNoteMarker()
 {
-    DELETEZ(pNoteMarker);
+    mpNoteMarker.reset();
 }
 
-com::sun::star::uno::Reference< ::com::sun::star::accessibility::XAccessible >
+css::uno::Reference< css::accessibility::XAccessible >
     ScGridWindow::CreateAccessible()
 {
+    css::uno::Reference< css::accessibility::XAccessible > xAcc= GetAccessible(false);
+    if (xAcc.is())
+    {
+        return xAcc;
+    }
+
     ScAccessibleDocument* pAccessibleDocument =
         new ScAccessibleDocument(GetAccessibleParentWindow()->GetAccessible(),
             pViewData->GetViewShell(), eWhich);
+    pAccessibleDocument->PreInit();
 
-    com::sun::star::uno::Reference < ::com::sun::star::accessibility::XAccessible > xAccessible = pAccessibleDocument;
+    xAcc = pAccessibleDocument;
+    SetAccessible(xAcc);
 
     pAccessibleDocument->Init();
 
-    return xAccessible;
+    return xAcc;
 }
 
 /* vim:set shiftwidth=4 softtabstop=4 expandtab: */
