@@ -19,7 +19,7 @@
 
 #include <config_features.h>
 
-#include <boost/scoped_ptr.hpp>
+#include <memory>
 
 #include "scitems.hxx"
 #include <sfx2/request.hxx>
@@ -53,7 +53,7 @@
 
 #include <vector>
 
-using ::boost::scoped_ptr;
+using std::unique_ptr;
 using namespace com::sun::star;
 
 void ScTabViewShell::ExecuteTable( SfxRequest& rReq )
@@ -76,7 +76,7 @@ void ScTabViewShell::ExecuteTable( SfxRequest& rReq )
                 pDoc->GetName( nCurrentTab, aName );
 
                 bool bVisible=true;
-                if( pReqArgs != NULL )
+                if( pReqArgs != nullptr )
                 {
                     const SfxPoolItem* pItem;
                     if( pReqArgs->HasItem( FID_TABLE_VISIBLE, &pItem ) )
@@ -132,7 +132,7 @@ void ScTabViewShell::ExecuteTable( SfxRequest& rReq )
                     ScAbstractDialogFactory* pFact = ScAbstractDialogFactory::Create();
                     OSL_ENSURE(pFact, "ScAbstractFactory create fail!");
 
-                    boost::scoped_ptr<AbstractScShowTabDlg> pDlg(pFact->CreateScShowTabDlg(GetDialogParent()));
+                    std::unique_ptr<AbstractScShowTabDlg> pDlg(pFact->CreateScShowTabDlg(GetDialogParent()));
                     OSL_ENSURE(pDlg, "Dialog create fail!");
 
                     OUString aTabName;
@@ -149,8 +149,8 @@ void ScTabViewShell::ExecuteTable( SfxRequest& rReq )
 
                     if ( pDlg->Execute() == RET_OK )
                     {
-                        sal_uInt16 nCount = pDlg->GetSelectEntryCount();
-                        for (sal_uInt16 nPos=0; nPos<nCount; nPos++)
+                        const sal_Int32 nCount = pDlg->GetSelectEntryCount();
+                        for (sal_Int32 nPos=0; nPos<nCount; ++nPos)
                         {
                             aName = pDlg->GetSelectEntry(nPos);
                             rReq.AppendItem( SfxStringItem( FID_TABLE_SHOW, aName ) );
@@ -173,7 +173,7 @@ void ScTabViewShell::ExecuteTable( SfxRequest& rReq )
                 if ( !pDoc->IsDocEditable() )
                     break;                          // locked
 
-                if ( pReqArgs != NULL )             // from basic
+                if ( pReqArgs != nullptr )             // from basic
                 {
                     bool bOk = false;
                     const SfxPoolItem*  pTabItem;
@@ -183,7 +183,7 @@ void ScTabViewShell::ExecuteTable( SfxRequest& rReq )
                     if ( pReqArgs->HasItem( FN_PARAM_1, &pTabItem ) &&
                          pReqArgs->HasItem( nSlot, &pNameItem ) )
                     {
-                        //  tablenumber from basic: 1-based
+                        // sheet number from basic: 1-based
 
                         aName = static_cast<const SfxStringItem*>(pNameItem)->GetValue();
                         nTabNr = static_cast<const SfxUInt16Item*>(pTabItem)->GetValue() - 1;
@@ -200,7 +200,7 @@ void ScTabViewShell::ExecuteTable( SfxRequest& rReq )
                     ScAbstractDialogFactory* pFact = ScAbstractDialogFactory::Create();
                     OSL_ENSURE(pFact, "ScAbstractFactory create fail!");
 
-                    boost::scoped_ptr<AbstractScInsertTableDlg> pDlg(pFact->CreateScInsertTableDlg(GetDialogParent(), rViewData,
+                    std::unique_ptr<AbstractScInsertTableDlg> pDlg(pFact->CreateScInsertTableDlg(GetDialogParent(), rViewData,
                         nTabSelCount, nSlot == FID_INS_TABLE_EXT));
                     OSL_ENSURE(pDlg, "Dialog create fail!");
                     if ( RET_OK == pDlg->Execute() )
@@ -312,13 +312,13 @@ void ScTabViewShell::ExecuteTable( SfxRequest& rReq )
                 SCTAB nTabSelCount = rMark.GetSelectCount();
 
                 if ( !pDoc->IsDocEditable() )
-                    break; // evrything locked
+                    break; // everything locked
 
                 if ( nSlot != FID_TAB_APPEND &&
                         ( pDoc->IsTabProtected( nTabNr ) || nTabSelCount > 1 ) )
                     break; // no rename
 
-                if( pReqArgs != NULL )
+                if( pReqArgs != nullptr )
                 {
                     bool        bDone   = false;
                     const SfxPoolItem* pItem;
@@ -352,7 +352,7 @@ void ScTabViewShell::ExecuteTable( SfxRequest& rReq )
                     OUString      aErrMsg ( ScGlobal::GetRscString( STR_INVALIDTABNAME ) );
                     OUString aName;
                     OUString      aDlgTitle;
-                    const sal_Char* pHelpId = 0;
+                    const sal_Char* pHelpId = nullptr;
 
                     switch ( nSlot )
                     {
@@ -372,7 +372,7 @@ void ScTabViewShell::ExecuteTable( SfxRequest& rReq )
                     ScAbstractDialogFactory* pFact = ScAbstractDialogFactory::Create();
                     OSL_ENSURE(pFact, "ScAbstractFactory create fail!");
 
-                    boost::scoped_ptr<AbstractScStringInputDlg> pDlg(pFact->CreateScStringInputDlg(
+                    std::unique_ptr<AbstractScStringInputDlg> pDlg(pFact->CreateScStringInputDlg(
                         GetDialogParent(), aDlgTitle, OUString(ScResId(SCSTR_NAME)),
                         aName, GetStaticInterface()->GetSlot(nSlot)->GetCommand(),
                         pHelpId));
@@ -407,7 +407,7 @@ void ScTabViewShell::ExecuteTable( SfxRequest& rReq )
                                 if( rReq.IsAPI() )
                                 {
 #if HAVE_FEATURE_SCRIPTING
-                                    StarBASIC::Error( SbERR_SETPROP_FAILED ); // XXX error handling???
+                                    StarBASIC::Error( ERRCODE_BASIC_SETPROP_FAILED ); // XXX error handling???
 #endif
                                 }
                                 else
@@ -425,7 +425,7 @@ void ScTabViewShell::ExecuteTable( SfxRequest& rReq )
 
         case FID_TAB_MOVE:
             {
-                if ( pDoc->GetChangeTrack() != NULL )
+                if ( pDoc->GetChangeTrack() != nullptr )
                     break;    // if ChangeTracking is active, then no TabMove
 
                 bool   bDoIt = false;
@@ -435,7 +435,7 @@ void ScTabViewShell::ExecuteTable( SfxRequest& rReq )
                 OUString aDocName;
                 OUString aTabName;
 
-                if( pReqArgs != NULL )
+                if( pReqArgs != nullptr )
                 {
                     SCTAB nTableCount = pDoc->GetTableCount();
                     const SfxPoolItem* pItem;
@@ -455,12 +455,12 @@ void ScTabViewShell::ExecuteTable( SfxRequest& rReq )
                     if (!aDocName.isEmpty())
                     {
                         SfxObjectShell* pSh     = SfxObjectShell::GetFirst();
-                        ScDocShell*     pScSh   = NULL;
+                        ScDocShell*     pScSh   = nullptr;
                         sal_uInt16          i=0;
 
                         while ( pSh )
                         {
-                            pScSh = PTR_CAST( ScDocShell, pSh );
+                            pScSh = dynamic_cast<ScDocShell*>( pSh  );
 
                             if( pScSh )
                             {
@@ -497,7 +497,7 @@ void ScTabViewShell::ExecuteTable( SfxRequest& rReq )
                     ScAbstractDialogFactory* pFact = ScAbstractDialogFactory::Create();
                     OSL_ENSURE(pFact, "ScAbstractFactory create fail!");
 
-                    boost::scoped_ptr<AbstractScMoveTableDlg> pDlg(pFact->CreateScMoveTableDlg(GetDialogParent(),
+                    std::unique_ptr<AbstractScMoveTableDlg> pDlg(pFact->CreateScMoveTableDlg(GetDialogParent(),
                         aDefaultName));
                     OSL_ENSURE(pDlg, "Dialog create fail!");
 
@@ -651,7 +651,7 @@ void ScTabViewShell::ExecuteTable( SfxRequest& rReq )
                 if ( pDoc->IsTabProtected( nTabNr ) ) // ||nTabSelCount > 1
                     break;
 
-                if( pReqArgs != NULL )
+                if( pReqArgs != nullptr )
                 {
                     bool                bDone = false;
                     const SfxPoolItem*  pItem;
@@ -664,7 +664,7 @@ void ScTabViewShell::ExecuteTable( SfxRequest& rReq )
 
                     if ( nTabSelCount > 1 )
                     {
-                        scoped_ptr<ScUndoTabColorInfo::List>
+                        std::unique_ptr<ScUndoTabColorInfo::List>
                             pTabColorList(new ScUndoTabColorInfo::List);
                         ScMarkData::iterator itr = rMark.begin(), itrEnd = rMark.end();
                         for (; itr != itrEnd; ++itr)
@@ -696,7 +696,7 @@ void ScTabViewShell::ExecuteTable( SfxRequest& rReq )
                     aTabBgColor = pDoc->GetTabBgColor( nCurrentTab );
                     ScAbstractDialogFactory* pFact = ScAbstractDialogFactory::Create();
                     OSL_ENSURE(pFact, "ScAbstractFactory create fail!");
-                    boost::scoped_ptr<AbstractScTabBgColorDlg> pDlg(pFact->CreateScTabBgColorDlg(
+                    std::unique_ptr<AbstractScTabBgColorDlg> pDlg(pFact->CreateScTabBgColorDlg(
                                                                 GetDialogParent(),
                                                                 OUString(ScResId(SCSTR_SET_TAB_BG_COLOR)),
                                                                 OUString(ScResId(SCSTR_NO_TAB_BG_COLOR)),
@@ -709,7 +709,7 @@ void ScTabViewShell::ExecuteTable( SfxRequest& rReq )
                         {
                             Color aSelectedColor;
                             pDlg->GetSelectedColor(aSelectedColor);
-                            scoped_ptr<ScUndoTabColorInfo::List>
+                            std::unique_ptr<ScUndoTabColorInfo::List>
                                 pTabColorList(new ScUndoTabColorInfo::List);
                             if ( nTabSelCount > 1 )
                             {
@@ -739,7 +739,7 @@ void ScTabViewShell::ExecuteTable( SfxRequest& rReq )
                                     if( rReq.IsAPI() )
                                     {
 #if HAVE_FEATURE_SCRIPTING
-                                        StarBASIC::Error( SbERR_SETPROP_FAILED );
+                                        StarBASIC::Error( ERRCODE_BASIC_SETPROP_FAILED );
 #endif
                                     }
                                 }
@@ -757,7 +757,7 @@ void ScTabViewShell::ExecuteTable( SfxRequest& rReq )
                     SvxAbstractDialogFactory* pDlgFactory = SvxAbstractDialogFactory::Create();
                     if (pDlgFactory)
                     {
-                        boost::scoped_ptr<VclAbstractDialog> pDialog( pDlgFactory->CreateSvxMacroAssignDlg(
+                        std::unique_ptr<VclAbstractDialog> pDialog( pDlgFactory->CreateSvxMacroAssignDlg(
                             GetDialogParent(), xFrame, false, xEvents, 0 ) );
                         if ( pDialog.get() && pDialog->Execute() == RET_OK )
                         {
@@ -768,7 +768,7 @@ void ScTabViewShell::ExecuteTable( SfxRequest& rReq )
                 break;
 
         default:
-                OSL_FAIL("Unbekannte Message bei ViewShell");
+                OSL_FAIL("unknown message for ViewShell");
                 break;
     }
 }
@@ -849,7 +849,7 @@ void ScTabViewShell::GetStateTable( SfxItemSet& rSet )
 
             case FID_TAB_MOVE:
                 if (   !pDoc->IsDocEditable()
-                    || pDoc->GetChangeTrack() != NULL
+                    || pDoc->GetChangeTrack() != nullptr
                     || nTabCount > MAXTAB)
                     rSet.DisableItem( nWhich );
                 break;
