@@ -24,6 +24,7 @@
 #include <editeng/editstat.hxx>
 #include <editeng/editview.hxx>
 #include <editeng/flditem.hxx>
+#include <sot/storage.hxx>
 #include <svx/hlnkitem.hxx>
 #include <editeng/langitem.hxx>
 #include <svx/svxerr.hxx>
@@ -38,6 +39,7 @@
 #include <svl/stritem.hxx>
 #include <svtools/transfer.hxx>
 #include <svl/urlbmk.hxx>
+#include <svl/sharedstringpool.hxx>
 #include <vcl/msgbox.hxx>
 #include <avmedia/mediawindow.hxx>
 
@@ -66,47 +68,42 @@
 #include "compiler.hxx"
 #include "tokenarray.hxx"
 #include <refupdatecontext.hxx>
-
-#include <boost/scoped_ptr.hpp>
+#include <gridwin.hxx>
 
 using namespace com::sun::star;
 
 // STATIC DATA -----------------------------------------------------------
 
-sal_Bool bPasteIsDrop = false;
-
-//==================================================================
+bool bPasteIsDrop = false;
 
 void ScViewFunc::PasteRTF( SCCOL nStartCol, SCROW nStartRow,
-                                const ::com::sun::star::uno::Reference<
-                                    ::com::sun::star::datatransfer::XTransferable >& rxTransferable )
+                                const css::uno::Reference< css::datatransfer::XTransferable >& rxTransferable )
 {
     TransferableDataHelper aDataHelper( rxTransferable );
-    if ( aDataHelper.HasFormat( SOT_FORMATSTR_ID_EDITENGINE ) )
+    if ( aDataHelper.HasFormat( SotClipboardFormatId::EDITENGINE ) )
     {
         HideAllCursors();
 
+        ScDocShell* pDocSh = GetViewData().GetDocShell();
+        ScDocument& rDoc = pDocSh->GetDocument();
+        SCTAB nTab = GetViewData().GetTabNo();
+        const bool bRecord (rDoc.IsUndoEnabled());
 
-        ScDocShell* pDocSh = GetViewData()->GetDocShell();
-        ScDocument* pDoc = pDocSh->GetDocument();
-        SCTAB nTab = GetViewData()->GetTabNo();
-        const sal_Bool bRecord (pDoc->IsUndoEnabled());
-
-        const ScPatternAttr* pPattern = pDoc->GetPattern( nStartCol, nStartRow, nTab );
-        ScTabEditEngine* pEngine = new ScTabEditEngine( *pPattern, pDoc->GetEnginePool() );
+        const ScPatternAttr* pPattern = rDoc.GetPattern( nStartCol, nStartRow, nTab );
+        std::unique_ptr<ScTabEditEngine> pEngine(new ScTabEditEngine( *pPattern, rDoc.GetEnginePool() ));
         pEngine->EnableUndo( false );
 
-        Window* pActWin = GetActiveWin();
+        vcl::Window* pActWin = GetActiveWin();
         if (pActWin)
         {
             pEngine->SetPaperSize(Size(100000,100000));
-            Window aWin( pActWin );
-            EditView aEditView( pEngine, &aWin );
+            ScopedVclPtrInstance< vcl::Window > aWin( pActWin );
+            EditView aEditView( pEngine.get(), aWin.get() );
             aEditView.SetOutputArea(Rectangle(0,0,100000,100000));
 
             // same method now for clipboard or drag&drop
             // mba: clipboard always must contain absolute URLs (could be from alien source)
-            aEditView.InsertText( rxTransferable, OUString(), sal_True );
+            aEditView.InsertText( rxTransferable, OUString(), true );
         }
 
         sal_Int32 nParCnt = pEngine->GetParagraphCount();
@@ -116,86 +113,86 @@ void ScViewFunc::PasteRTF( SCCOL nStartCol, SCROW nStartRow,
             if (nEndRow > MAXROW)
                 nEndRow = MAXROW;
 
-            ScDocument* pUndoDoc = NULL;
+            ScDocument* pUndoDoc = nullptr;
             if (bRecord)
             {
                 pUndoDoc = new ScDocument( SCDOCMODE_UNDO );
-                pUndoDoc->InitUndo( pDoc, nTab, nTab );
-                pDoc->CopyToDocument( nStartCol,nStartRow,nTab, nStartCol,nEndRow,nTab, IDF_ALL, false, pUndoDoc );
+                pUndoDoc->InitUndo( &rDoc, nTab, nTab );
+                rDoc.CopyToDocument( nStartCol,nStartRow,nTab, nStartCol,nEndRow,nTab, InsertDeleteFlags::ALL, false, pUndoDoc );
             }
 
             SCROW nRow = nStartRow;
 
             // Temporarily turn off undo generation for this lot
-            bool bUndoEnabled = pDoc->IsUndoEnabled();
-            pDoc->EnableUndo( false );
+            bool bUndoEnabled = rDoc.IsUndoEnabled();
+            rDoc.EnableUndo( false );
             for( sal_Int32 n = 0; n < nParCnt; n++ )
             {
-                boost::scoped_ptr<EditTextObject> pObject(pEngine->CreateTextObject(n));
+                std::unique_ptr<EditTextObject> pObject(pEngine->CreateTextObject(n));
                 EnterData(nStartCol, nRow, nTab, *pObject, true);
                 if( ++nRow > MAXROW )
                     break;
             }
-            pDoc->EnableUndo(bUndoEnabled);
+            rDoc.EnableUndo(bUndoEnabled);
 
             if (bRecord)
             {
                 ScDocument* pRedoDoc = new ScDocument( SCDOCMODE_UNDO );
-                pRedoDoc->InitUndo( pDoc, nTab, nTab );
-                pDoc->CopyToDocument( nStartCol,nStartRow,nTab, nStartCol,nEndRow,nTab, IDF_ALL|IDF_NOCAPTIONS, false, pRedoDoc );
+                pRedoDoc->InitUndo( &rDoc, nTab, nTab );
+                rDoc.CopyToDocument( nStartCol,nStartRow,nTab, nStartCol,nEndRow,nTab, InsertDeleteFlags::ALL|InsertDeleteFlags::NOCAPTIONS, false, pRedoDoc );
 
                 ScRange aMarkRange(nStartCol, nStartRow, nTab, nStartCol, nEndRow, nTab);
                 ScMarkData aDestMark;
                 aDestMark.SetMarkArea( aMarkRange );
                 pDocSh->GetUndoManager()->AddUndoAction(
                     new ScUndoPaste( pDocSh, aMarkRange, aDestMark,
-                                     pUndoDoc, pRedoDoc, IDF_ALL, NULL));
+                                     pUndoDoc, pRedoDoc, InsertDeleteFlags::ALL, nullptr));
             }
         }
 
-        delete pEngine;
+        pEngine.reset();
 
         ShowAllCursors();
     }
     else
     {
         HideAllCursors();
-        ScDocShell* pDocSh = GetViewData()->GetDocShell();
-        ScImportExport aImpEx( pDocSh->GetDocument(),
-            ScAddress( nStartCol, nStartRow, GetViewData()->GetTabNo() ) );
+        ScDocShell* pDocSh = GetViewData().GetDocShell();
+        ScImportExport aImpEx( &pDocSh->GetDocument(),
+            ScAddress( nStartCol, nStartRow, GetViewData().GetTabNo() ) );
 
         OUString aStr;
-        SotStorageStreamRef xStream;
-        if ( aDataHelper.GetSotStorageStream( SOT_FORMAT_RTF, xStream ) && xStream.Is() )
+        tools::SvRef<SotStorageStream> xStream;
+        if ( aDataHelper.GetSotStorageStream( SotClipboardFormatId::RTF, xStream ) && xStream.Is() )
             // mba: clipboard always must contain absolute URLs (could be from alien source)
-            aImpEx.ImportStream( *xStream, OUString(), SOT_FORMAT_RTF );
-        else if ( aDataHelper.GetString( SOT_FORMAT_RTF, aStr ) )
-            aImpEx.ImportString( aStr, SOT_FORMAT_RTF );
+            aImpEx.ImportStream( *xStream, OUString(), SotClipboardFormatId::RTF );
+        else if ( aDataHelper.GetString( SotClipboardFormatId::RTF, aStr ) )
+            aImpEx.ImportString( aStr, SotClipboardFormatId::RTF );
 
         AdjustRowHeight( nStartRow, aImpEx.GetRange().aEnd.Row() );
-        pDocSh->UpdateOle(GetViewData());
+        pDocSh->UpdateOle(&GetViewData());
         ShowAllCursors();
     }
 }
-void ScViewFunc::DoRefConversion( sal_Bool bRecord )
+void ScViewFunc::DoRefConversion( bool bRecord )
 {
-    ScDocument* pDoc = GetViewData()->GetDocument();
-    ScMarkData& rMark = GetViewData()->GetMarkData();
+    ScDocument* pDoc = GetViewData().GetDocument();
+    ScMarkData& rMark = GetViewData().GetMarkData();
     SCTAB nTabCount = pDoc->GetTableCount();
     if (bRecord && !pDoc->IsUndoEnabled())
         bRecord = false;
 
     ScRange aMarkRange;
     rMark.MarkToSimple();
-    sal_Bool bMulti = rMark.IsMultiMarked();
+    bool bMulti = rMark.IsMultiMarked();
     if (bMulti)
         rMark.GetMultiMarkArea( aMarkRange );
     else if (rMark.IsMarked())
         rMark.GetMarkArea( aMarkRange );
     else
     {
-        aMarkRange = ScRange( GetViewData()->GetCurX(),
-            GetViewData()->GetCurY(), GetViewData()->GetTabNo() );
+        aMarkRange = ScRange( GetViewData().GetCurX(),
+            GetViewData().GetCurY(), GetViewData().GetTabNo() );
     }
     ScEditableTester aTester( pDoc, aMarkRange.aStart.Col(), aMarkRange.aStart.Row(),
                             aMarkRange.aEnd.Col(), aMarkRange.aEnd.Row(),rMark );
@@ -205,10 +202,10 @@ void ScViewFunc::DoRefConversion( sal_Bool bRecord )
         return;
     }
 
-    ScDocShell* pDocSh = GetViewData()->GetDocShell();
-    sal_Bool bOk = false;
+    ScDocShell* pDocSh = GetViewData().GetDocShell();
+    bool bOk = false;
 
-    ScDocument* pUndoDoc = NULL;
+    ScDocument* pUndoDoc = nullptr;
     if (bRecord)
     {
         pUndoDoc = new ScDocument( SCDOCMODE_UNDO );
@@ -225,11 +222,11 @@ void ScViewFunc::DoRefConversion( sal_Bool bRecord )
         ScRange aCopyRange = aMarkRange;
         aCopyRange.aStart.SetTab(0);
         aCopyRange.aEnd.SetTab(nTabCount-1);
-        pDoc->CopyToDocument( aCopyRange, IDF_ALL, bMulti, pUndoDoc, &rMark );
+        pDoc->CopyToDocument( aCopyRange, InsertDeleteFlags::ALL, bMulti, pUndoDoc, &rMark );
     }
 
     ScRangeListRef xRanges;
-    GetViewData()->GetMultiArea( xRanges );
+    GetViewData().GetMultiArea( xRanges );
     size_t nCount = xRanges->size();
 
     ScMarkData::iterator itr = rMark.begin(), itrEnd = rMark.end();
@@ -259,7 +256,7 @@ void ScViewFunc::DoRefConversion( sal_Bool bRecord )
                     OUString aNew = aFinder.GetText();
                     ScCompiler aComp( pDoc, aPos);
                     aComp.SetGrammar(pDoc->GetGrammar());
-                    boost::scoped_ptr<ScTokenArray> pArr(aComp.CompileString(aNew));
+                    std::unique_ptr<ScTokenArray> pArr(aComp.CompileString(aNew));
                     ScFormulaCell* pNewCell =
                         new ScFormulaCell(
                             pDoc, aPos, *pArr, formula::FormulaGrammar::GRAM_DEFAULT, MM_NONE);
@@ -286,15 +283,15 @@ void ScViewFunc::DoRefConversion( sal_Bool bRecord )
         ScRange aCopyRange = aMarkRange;
         aCopyRange.aStart.SetTab(0);
         aCopyRange.aEnd.SetTab(nTabCount-1);
-        pDoc->CopyToDocument( aCopyRange, IDF_ALL, bMulti, pRedoDoc, &rMark );
+        pDoc->CopyToDocument( aCopyRange, InsertDeleteFlags::ALL, bMulti, pRedoDoc, &rMark );
 
         pDocSh->GetUndoManager()->AddUndoAction(
             new ScUndoRefConversion( pDocSh,
-                                    aMarkRange, rMark, pUndoDoc, pRedoDoc, bMulti, IDF_ALL) );
+                                    aMarkRange, rMark, pUndoDoc, pRedoDoc, bMulti, InsertDeleteFlags::ALL) );
     }
 
     pDocSh->PostPaint( aMarkRange, PAINT_GRID );
-    pDocSh->UpdateOle(GetViewData());
+    pDocSh->UpdateOle(&GetViewData());
     pDocSh->SetDocumentModified();
     CellContentChanged();
 
@@ -302,49 +299,47 @@ void ScViewFunc::DoRefConversion( sal_Bool bRecord )
         ErrorMessage(STR_ERR_NOREF);
 }
 //  Thesaurus - Undo ok
-void ScViewFunc::DoThesaurus( sal_Bool bRecord )
+void ScViewFunc::DoThesaurus( bool bRecord )
 {
     SCCOL nCol;
     SCROW nRow;
     SCTAB nTab;
-    ScDocShell* pDocSh = GetViewData()->GetDocShell();
-    ScDocument* pDoc = pDocSh->GetDocument();
-    ScMarkData& rMark = GetViewData()->GetMarkData();
-    ScSplitPos eWhich = GetViewData()->GetActivePart();
+    ScDocShell* pDocSh = GetViewData().GetDocShell();
+    ScDocument& rDoc = pDocSh->GetDocument();
+    ScMarkData& rMark = GetViewData().GetMarkData();
+    ScSplitPos eWhich = GetViewData().GetActivePart();
     EESpellState eState;
-    OUString sOldText, sNewString;
-    EditTextObject* pOldTObj = NULL;
-    const EditTextObject* pTObject = NULL;
-    EditView* pEditView = NULL;
-    boost::scoped_ptr<ESelection> pEditSel;
-    ScEditEngineDefaulter* pThesaurusEngine;
-    sal_Bool bIsEditMode = GetViewData()->HasEditView(eWhich);
-    if (bRecord && !pDoc->IsUndoEnabled())
+    EditView* pEditView = nullptr;
+    std::unique_ptr<ESelection> pEditSel;
+    std::unique_ptr<ScEditEngineDefaulter> pThesaurusEngine;
+    bool bIsEditMode = GetViewData().HasEditView(eWhich);
+    if (bRecord && !rDoc.IsUndoEnabled())
         bRecord = false;
-    if (bIsEditMode)                                            // Edit-Mode aktiv
+    if (bIsEditMode)                                            // edit mode active
     {
-        GetViewData()->GetEditView(eWhich, pEditView, nCol, nRow);
+        GetViewData().GetEditView(eWhich, pEditView, nCol, nRow);
         pEditSel.reset(new ESelection(pEditView->GetSelection()));
         SC_MOD()->InputEnterHandler();
-        GetViewData()->GetBindings().Update();          // sonst kommt der Sfx durcheinander...
+        GetViewData().GetBindings().Update();          // otherwise the Sfx becomes mixed-up...
     }
     else
     {
-        nCol = GetViewData()->GetCurX();
-        nRow = GetViewData()->GetCurY();
+        nCol = GetViewData().GetCurX();
+        nRow = GetViewData().GetCurY();
     }
-    nTab = GetViewData()->GetTabNo();
+    nTab = GetViewData().GetTabNo();
 
     ScAddress aPos(nCol, nRow, nTab);
-    ScEditableTester aTester( pDoc, nCol, nRow, nCol, nRow, rMark );
+    ScEditableTester aTester( &rDoc, nCol, nRow, nCol, nRow, rMark );
     if (!aTester.IsEditable())
     {
         ErrorMessage(aTester.GetMessageId());
         return;
     }
 
-    CellType eCellType = pDoc->GetCellType(aPos);
-    if (eCellType != CELLTYPE_STRING && eCellType != CELLTYPE_EDIT)
+    ScCellValue aOldText;
+    aOldText.assign(rDoc, aPos);
+    if (aOldText.meType != CELLTYPE_STRING && aOldText.meType != CELLTYPE_EDIT)
     {
         ErrorMessage(STR_THESAURUS_NO_STRING);
         return;
@@ -352,39 +347,27 @@ void ScViewFunc::DoThesaurus( sal_Bool bRecord )
 
     uno::Reference<linguistic2::XSpellChecker1> xSpeller = LinguMgr::GetSpellChecker();
 
-    pThesaurusEngine = new ScEditEngineDefaulter( pDoc->GetEnginePool() );
-    pThesaurusEngine->SetEditTextObjectPool( pDoc->GetEditPool() );
-    pThesaurusEngine->SetRefDevice(GetViewData()->GetActiveWin());
+    pThesaurusEngine.reset(new ScEditEngineDefaulter(rDoc.GetEnginePool()));
+    pThesaurusEngine->SetEditTextObjectPool( rDoc.GetEditPool() );
+    pThesaurusEngine->SetRefDevice(GetViewData().GetActiveWin());
     pThesaurusEngine->SetSpeller(xSpeller);
-    MakeEditView(pThesaurusEngine, nCol, nRow );
-    const ScPatternAttr* pPattern = NULL;
-    SfxItemSet* pEditDefaults = new SfxItemSet(pThesaurusEngine->GetEmptyItemSet());
-    pPattern = pDoc->GetPattern(nCol, nRow, nTab);
+    MakeEditView(pThesaurusEngine.get(), nCol, nRow );
+    const ScPatternAttr* pPattern = nullptr;
+    std::unique_ptr<SfxItemSet> pEditDefaults(
+        new SfxItemSet(pThesaurusEngine->GetEmptyItemSet()));
+    pPattern = rDoc.GetPattern(nCol, nRow, nTab);
     if (pPattern)
     {
-        pPattern->FillEditItemSet( pEditDefaults );
+        pPattern->FillEditItemSet( pEditDefaults.get() );
         pThesaurusEngine->SetDefaults( *pEditDefaults );
     }
 
-    if (eCellType == CELLTYPE_STRING)
-    {
-        sOldText = pDoc->GetString(aPos);
-        pThesaurusEngine->SetText(sOldText);
-    }
-    else if (eCellType == CELLTYPE_EDIT)
-    {
-        pTObject = pDoc->GetEditText(aPos);
-        if (pTObject)
-        {
-            pOldTObj = pTObject->Clone();
-            pThesaurusEngine->SetText(*pTObject);
-        }
-    }
+    if (aOldText.meType == CELLTYPE_EDIT)
+        pThesaurusEngine->SetText(*aOldText.mpEditText);
     else
-    {
-        OSL_FAIL("DoThesaurus: Keine String oder Editzelle");
-    }
-    pEditView = GetViewData()->GetEditView(GetViewData()->GetActivePart());
+        pThesaurusEngine->SetText(aOldText.getString(&rDoc));
+
+    pEditView = GetViewData().GetEditView(GetViewData().GetActivePart());
     if (pEditSel)
         pEditView->SetSelection(*pEditSel);
     else
@@ -397,69 +380,66 @@ void ScViewFunc::DoThesaurus( sal_Bool bRecord )
     eState = pEditView->StartThesaurus();
     OSL_ENSURE(eState != EE_SPELL_NOSPELLER, "No SpellChecker");
 
-    if (eState == EE_SPELL_ERRORFOUND)              // sollte spaeter durch Wrapper geschehen!
+    if (eState == EE_SPELL_ERRORFOUND)              // should happen later through Wrapper!
     {
-        LanguageType eLnge = ScViewUtil::GetEffLanguage( pDoc, ScAddress( nCol, nRow, nTab ) );
-        SvtLanguageTable aLangTab;
-        OUString aErr = aLangTab.GetString(eLnge);
+        LanguageType eLnge = ScViewUtil::GetEffLanguage( &rDoc, ScAddress( nCol, nRow, nTab ) );
+        OUString aErr = SvtLanguageTable::GetLanguageString(eLnge);
         aErr += ScGlobal::GetRscString( STR_SPELLING_NO_LANG );
-        InfoBox aBox( GetViewData()->GetDialogParent(), aErr );
-        aBox.Execute();
+        ScopedVclPtrInstance< InfoBox > aBox( GetViewData().GetDialogParent(), aErr );
+        aBox->Execute();
     }
     if (pThesaurusEngine->IsModified())
     {
-        EditTextObject* pNewTObj = NULL;
-        if (pTObject)
+        ScCellValue aNewText;
+
+        if (aOldText.meType == CELLTYPE_EDIT)
         {
             // The cell will own the text object instance.
-            pDoc->SetEditText(
-                ScAddress(nCol,nRow,nTab), pThesaurusEngine->CreateTextObject());
+            EditTextObject* pText = pThesaurusEngine->CreateTextObject();
+            if (rDoc.SetEditText(ScAddress(nCol,nRow,nTab), pText))
+                aNewText.set(*pText);
         }
         else
         {
-            sNewString = pThesaurusEngine->GetText();
-            pDoc->SetString(nCol, nRow, nTab, sNewString);
+            OUString aStr = pThesaurusEngine->GetText();
+            aNewText.set(rDoc.GetSharedStringPool().intern(aStr));
+            rDoc.SetString(nCol, nRow, nTab, aStr);
         }
-// erack! it's broadcasted
-//      pDoc->SetDirty();
+
         pDocSh->SetDocumentModified();
         if (bRecord)
         {
-            GetViewData()->GetDocShell()->GetUndoManager()->AddUndoAction(
-                new ScUndoThesaurus( GetViewData()->GetDocShell(),
-                                     nCol, nRow, nTab,
-                                     sOldText, pOldTObj, sNewString, pNewTObj));
+            GetViewData().GetDocShell()->GetUndoManager()->AddUndoAction(
+                new ScUndoThesaurus(
+                    GetViewData().GetDocShell(), nCol, nRow, nTab, aOldText, aNewText));
         }
-        delete pNewTObj;
     }
-    KillEditView(sal_True);
-    delete pEditDefaults;
-    delete pThesaurusEngine;
-    delete pOldTObj;
+
+    KillEditView(true);
     pDocSh->PostPaintGridAll();
 }
 
-void ScViewFunc::DoHangulHanjaConversion( sal_Bool bRecord )
+void ScViewFunc::DoHangulHanjaConversion( bool bRecord )
 {
     ScConversionParam aConvParam( SC_CONVERSION_HANGULHANJA, LANGUAGE_KOREAN, 0, true );
     DoSheetConversion( aConvParam, bRecord );
 }
 
-void ScViewFunc::DoSheetConversion( const ScConversionParam& rConvParam, sal_Bool bRecord )
+void ScViewFunc::DoSheetConversion( const ScConversionParam& rConvParam, bool bRecord )
 {
     SCCOL nCol;
     SCROW nRow;
     SCTAB nTab;
-    ScViewData& rViewData = *GetViewData();
+    ScViewData& rViewData = GetViewData();
     ScDocShell* pDocSh = rViewData.GetDocShell();
-    ScDocument* pDoc = pDocSh->GetDocument();
+    ScDocument& rDoc = pDocSh->GetDocument();
     ScMarkData& rMark = rViewData.GetMarkData();
     ScSplitPos eWhich = rViewData.GetActivePart();
-    EditView* pEditView = NULL;
-    sal_Bool bIsEditMode = rViewData.HasEditView(eWhich);
-    if (bRecord && !pDoc->IsUndoEnabled())
+    EditView* pEditView = nullptr;
+    bool bIsEditMode = rViewData.HasEditView(eWhich);
+    if (bRecord && !rDoc.IsUndoEnabled())
         bRecord = false;
-    if (bIsEditMode)                                            // Edit-Mode aktiv
+    if (bIsEditMode)                                            // edit mode active
     {
         rViewData.GetEditView(eWhich, pEditView, nCol, nRow);
         SC_MOD()->InputEnterHandler();
@@ -474,10 +454,10 @@ void ScViewFunc::DoSheetConversion( const ScConversionParam& rConvParam, sal_Boo
     nTab = rViewData.GetTabNo();
 
     rMark.MarkToMulti();
-    sal_Bool bMarked = rMark.IsMultiMarked();
+    bool bMarked = rMark.IsMultiMarked();
     if (bMarked)
     {
-        ScEditableTester aTester( pDoc, rMark );
+        ScEditableTester aTester( &rDoc, rMark );
         if (!aTester.IsEditable())
         {
             ErrorMessage(aTester.GetMessageId());
@@ -485,14 +465,14 @@ void ScViewFunc::DoSheetConversion( const ScConversionParam& rConvParam, sal_Boo
         }
     }
 
-    ScDocument* pUndoDoc = NULL;
-    ScDocument* pRedoDoc = NULL;
+    ScDocument* pUndoDoc = nullptr;
+    ScDocument* pRedoDoc = nullptr;
     if (bRecord)
     {
         pUndoDoc = new ScDocument( SCDOCMODE_UNDO );
-        pUndoDoc->InitUndo( pDoc, nTab, nTab );
+        pUndoDoc->InitUndo( &rDoc, nTab, nTab );
         pRedoDoc = new ScDocument( SCDOCMODE_UNDO );
-        pRedoDoc->InitUndo( pDoc, nTab, nTab );
+        pRedoDoc->InitUndo( &rDoc, nTab, nTab );
 
         if ( rMark.GetSelectCount() > 1 )
         {
@@ -506,37 +486,37 @@ void ScViewFunc::DoSheetConversion( const ScConversionParam& rConvParam, sal_Boo
         }
     }
 
-    //  ab hier kein return mehr
+    // from here no return
 
-    bool bOldEnabled = pDoc->IsIdleEnabled();
-    pDoc->EnableIdle(false);   // stop online spelling
+    bool bOldEnabled = rDoc.IsIdleEnabled();
+    rDoc.EnableIdle(false);   // stop online spelling
 
     // *** create and init the edit engine *** --------------------------------
 
-    ScConversionEngineBase* pEngine = NULL;
+    std::unique_ptr<ScConversionEngineBase> pEngine;
     switch( rConvParam.GetType() )
     {
         case SC_CONVERSION_SPELLCHECK:
-            pEngine = new ScSpellingEngine(
-                pDoc->GetEnginePool(), rViewData, pUndoDoc, pRedoDoc, LinguMgr::GetSpellChecker() );
+            pEngine.reset(new ScSpellingEngine(
+                rDoc.GetEnginePool(), rViewData, pUndoDoc, pRedoDoc, LinguMgr::GetSpellChecker() ));
         break;
         case SC_CONVERSION_HANGULHANJA:
         case SC_CONVERSION_CHINESE_TRANSL:
-            pEngine = new ScTextConversionEngine(
-                pDoc->GetEnginePool(), rViewData, rConvParam, pUndoDoc, pRedoDoc );
+            pEngine.reset(new ScTextConversionEngine(
+                rDoc.GetEnginePool(), rViewData, rConvParam, pUndoDoc, pRedoDoc ));
         break;
         default:
             OSL_FAIL( "ScViewFunc::DoSheetConversion - unknown conversion type" );
     }
 
-    MakeEditView( pEngine, nCol, nRow );
+    MakeEditView( pEngine.get(), nCol, nRow );
     pEngine->SetRefDevice( rViewData.GetActiveWin() );
-                                        // dummy Zelle simulieren:
+                                        // simulate dummy cell:
     pEditView = rViewData.GetEditView( rViewData.GetActivePart() );
     rViewData.SetSpellingView( pEditView );
     Rectangle aRect( Point( 0, 0 ), Point( 0, 0 ) );
     pEditView->SetOutputArea( aRect );
-    pEngine->SetControlWord( EE_CNTRL_USECHARATTRIBS );
+    pEngine->SetControlWord( EEControlBits::USECHARATTRIBS );
     pEngine->EnableUndo( false );
     pEngine->SetPaperSize( aRect.GetSize() );
     pEngine->SetText( EMPTY_OUSTRING );
@@ -562,7 +542,7 @@ void ScViewFunc::DoSheetConversion( const ScConversionParam& rConvParam, sal_Boo
         }
 
         sc::SetFormulaDirtyContext aCxt;
-        pDoc->SetAllFormulasDirty(aCxt);
+        rDoc.SetAllFormulasDirty(aCxt);
 
         pDocSh->SetDocumentModified();
     }
@@ -574,18 +554,18 @@ void ScViewFunc::DoSheetConversion( const ScConversionParam& rConvParam, sal_Boo
 
     // *** final cleanup *** --------------------------------------------------
 
-    rViewData.SetSpellingView( NULL );
-    KillEditView(sal_True);
-    delete pEngine;
+    rViewData.SetSpellingView( nullptr );
+    KillEditView(true);
+    pEngine.reset();
     pDocSh->PostPaintGridAll();
     rViewData.GetViewShell()->UpdateInputHandler();
-    pDoc->EnableIdle(bOldEnabled);
+    rDoc.EnableIdle(bOldEnabled);
 }
 
-// Pasten von FORMAT_FILE-Items
-//  wird nicht direkt aus Drop aufgerufen, sondern asynchron -> Dialoge sind erlaubt
+// past from SotClipboardFormatId::FILE items
+// is not called directly from Drop, but asynchronously -> dialogs are allowed
 
-sal_Bool ScViewFunc::PasteFile( const Point& rPos, const OUString& rFile, sal_Bool bLink )
+bool ScViewFunc::PasteFile( const Point& rPos, const OUString& rFile, bool bLink )
 {
     INetURLObject aURL;
     aURL.SetSmartURL( rFile );
@@ -595,48 +575,47 @@ sal_Bool ScViewFunc::PasteFile( const Point& rPos, const OUString& rFile, sal_Bo
     if( ::avmedia::MediaWindow::isMediaURL( aStrURL, ""/*TODO?*/ ) )
     {
         const SfxStringItem aMediaURLItem( SID_INSERT_AVMEDIA, aStrURL );
-        return sal_Bool( 0 != GetViewData()->GetDispatcher().Execute(
-                                SID_INSERT_AVMEDIA, SFX_CALLMODE_SYNCHRON,
+        return ( nullptr != GetViewData().GetDispatcher().Execute(
+                                SID_INSERT_AVMEDIA, SfxCallMode::SYNCHRON,
                                 &aMediaURLItem, 0L ) );
     }
 
-    if (!bLink)     // bei bLink nur Grafik oder URL
+    if (!bLink)     // for bLink only graphics or URL
     {
-        // 1. Kann ich die Datei oeffnen?
-        const SfxFilter* pFlt = NULL;
+        // 1. can I open the file?
+        const SfxFilter* pFlt = nullptr;
 
-        // nur nach eigenen Filtern suchen, ohne Auswahlbox (wie in ScDocumentLoader)
+        // search only for its own filters, without selection box (as in ScDocumentLoader)
         SfxFilterMatcher aMatcher( ScDocShell::Factory().GetFilterContainer()->GetName() );
-        SfxMedium aSfxMedium( aStrURL, (STREAM_READ | STREAM_SHARE_DENYNONE) );
+        SfxMedium aSfxMedium( aStrURL, (StreamMode::READ | StreamMode::SHARE_DENYNONE) );
         // #i73992# GuessFilter no longer calls UseInteractionHandler.
         // This is UI, so it can be called here.
-        aSfxMedium.UseInteractionHandler(sal_True);
+        aSfxMedium.UseInteractionHandler(true);
         ErrCode nErr = aMatcher.GuessFilter( aSfxMedium, &pFlt );
 
         if ( pFlt && !nErr )
         {
-            // Code aus dem SFX geklaut!
-            SfxDispatcher &rDispatcher = GetViewData()->GetDispatcher();
+            // code stolen from the SFX!
+            SfxDispatcher &rDispatcher = GetViewData().GetDispatcher();
             SfxStringItem aFileNameItem( SID_FILE_NAME, aStrURL );
             SfxStringItem aFilterItem( SID_FILTER_NAME, pFlt->GetName() );
             // #i69524# add target, as in SfxApplication when the Open dialog is used
             SfxStringItem aTargetItem( SID_TARGETNAME, OUString("_default") );
 
-            // Asynchron oeffnen, kann naemlich auch aus D&D heraus passieren
-            // und das bekommt dem MAC nicht so gut ...
-            return sal_Bool( 0 != rDispatcher.Execute( SID_OPENDOC,
-                                    SFX_CALLMODE_ASYNCHRON, &aFileNameItem, &aFilterItem, &aTargetItem, 0L) );
+            // Open Asynchronously, because it can also happen from D&D
+            // and that is not so good for the MAC...
+            return ( nullptr != rDispatcher.Execute( SID_OPENDOC,
+                                    SfxCallMode::ASYNCHRON, &aFileNameItem, &aFilterItem, &aTargetItem, 0L) );
         }
     }
 
-    // 2. Kann die Datei ueber die Grafik-Filter eingefuegt werden?
-    // (als Link, weil Gallery das so anbietet)
+    // 2. can the file be inserted using the graphics filter?
+    // (as a link, since the Gallery provides it in this way)
 
     sal_uInt16 nFilterFormat;
     Graphic aGraphic;
     GraphicFilter& rGraphicFilter = GraphicFilter::GetGraphicFilter();
 
-
     if (!rGraphicFilter.ImportGraphic(aGraphic, aURL,
             GRFILTER_FORMAT_DONTKNOW, &nFilterFormat ))
     {
@@ -652,21 +631,21 @@ sal_Bool ScViewFunc::PasteFile( const Point& rPos, const OUString& rFile, sal_Bo
         }
     }
 
-    if (bLink)                      // bei bLink alles, was nicht Grafik ist, als URL
+    if (bLink)                      // for bLink everything, which is not graphics, as URL
     {
         Rectangle aRect( rPos, Size(0,0) );
-        ScRange aRange = GetViewData()->GetDocument()->
-                            GetRange( GetViewData()->GetTabNo(), aRect );
+        ScRange aRange = GetViewData().GetDocument()->
+                            GetRange( GetViewData().GetTabNo(), aRect );
         SCCOL nPosX = aRange.aStart.Col();
         SCROW nPosY = aRange.aStart.Row();
 
         InsertBookmark( aStrURL, aStrURL, nPosX, nPosY );
-        return sal_True;
+        return true;
     }
     else
     {
-        // 3. Kann die Datei als OLE eingefuegt werden?
-        // auch nicht-Storages, z.B. Sounds (#38282#)
+        // 3. can the file be inserted as OLE?
+        // also non-storages, for instance sounds (#38282#)
         uno::Reference < embed::XStorage > xStorage = comphelper::OStorageHelper::GetTemporaryStorage();
 
         //TODO/LATER: what about "bLink"?
@@ -683,14 +662,13 @@ sal_Bool ScViewFunc::PasteFile( const Point& rPos, const OUString& rFile, sal_Bo
 
         // If an OLE object can't be created, insert a URL button
 
-        GetViewData()->GetViewShell()->InsertURLButton( aStrURL, aStrURL, EMPTY_OUSTRING, &rPos );
-        return sal_True;
+        GetViewData().GetViewShell()->InsertURLButton( aStrURL, aStrURL, EMPTY_OUSTRING, &rPos );
+        return true;
     }
 }
 
-sal_Bool ScViewFunc::PasteBookmark( sal_uLong nFormatId,
-                                const ::com::sun::star::uno::Reference<
-                                    ::com::sun::star::datatransfer::XTransferable >& rxTransferable,
+bool ScViewFunc::PasteBookmark( SotClipboardFormatId nFormatId,
+                                const css::uno::Reference< css::datatransfer::XTransferable >& rxTransferable,
                                 SCCOL nPosX, SCROW nPosY )
 {
     INetBookmark aBookmark;
@@ -699,31 +677,31 @@ sal_Bool ScViewFunc::PasteBookmark( sal_uLong nFormatId,
         return false;
 
     InsertBookmark( aBookmark.GetDescription(), aBookmark.GetURL(), nPosX, nPosY );
-    return sal_True;
+    return true;
 }
 
 void ScViewFunc::InsertBookmark( const OUString& rDescription, const OUString& rURL,
                                     SCCOL nPosX, SCROW nPosY, const OUString* pTarget,
-                                    sal_Bool bTryReplace )
+                                    bool bTryReplace )
 {
-    ScViewData* pViewData = GetViewData();
-    if ( pViewData->HasEditView( pViewData->GetActivePart() ) &&
-            nPosX >= pViewData->GetEditStartCol() && nPosX <= pViewData->GetEditEndCol() &&
-            nPosY >= pViewData->GetEditStartRow() && nPosY <= pViewData->GetEditEndRow() )
+    ScViewData& rViewData = GetViewData();
+    if ( rViewData.HasEditView( rViewData.GetActivePart() ) &&
+            nPosX >= rViewData.GetEditStartCol() && nPosX <= rViewData.GetEditEndCol() &&
+            nPosY >= rViewData.GetEditStartRow() && nPosY <= rViewData.GetEditEndRow() )
     {
-        //  in die gerade editierte Zelle einfuegen
+        // insert into the cell which just got edited
 
         OUString aTargetFrame;
         if (pTarget)
             aTargetFrame = *pTarget;
-        pViewData->GetViewShell()->InsertURLField( rDescription, rURL, aTargetFrame );
+        rViewData.GetViewShell()->InsertURLField( rDescription, rURL, aTargetFrame );
         return;
     }
 
-    //  in nicht editierte Zelle einfuegen
+    // insert into not edited cell
 
-    ScDocument* pDoc = GetViewData()->GetDocument();
-    SCTAB nTab = GetViewData()->GetTabNo();
+    ScDocument* pDoc = GetViewData().GetDocument();
+    SCTAB nTab = GetViewData().GetTabNo();
     ScAddress aCellPos( nPosX, nPosY, nTab );
     EditEngine aEngine( pDoc->GetEnginePool() );
 
@@ -741,10 +719,10 @@ void ScViewFunc::InsertBookmark( const OUString& rDescription, const OUString& r
     sal_Int32 nPara = aEngine.GetParagraphCount();
     if (nPara)
         --nPara;
-    xub_StrLen nTxtLen = aEngine.GetTextLen(nPara);
+    sal_Int32 nTxtLen = aEngine.GetTextLen(nPara);
     ESelection aInsSel( nPara, nTxtLen, nPara, nTxtLen );
 
-    if ( bTryReplace && HasBookmarkAtCursor( NULL ) )
+    if ( bTryReplace && HasBookmarkAtCursor( nullptr ) )
     {
         //  if called from hyperlink slot and cell contains only a URL,
         //  replace old URL with new one
@@ -757,16 +735,16 @@ void ScViewFunc::InsertBookmark( const OUString& rDescription, const OUString& r
         aField.SetTargetFrame(*pTarget);
     aEngine.QuickInsertField( SvxFieldItem( aField, EE_FEATURE_FIELD ), aInsSel );
 
-    boost::scoped_ptr<EditTextObject> pData(aEngine.CreateTextObject());
+    std::unique_ptr<EditTextObject> pData(aEngine.CreateTextObject());
     EnterData(nPosX, nPosY, nTab, *pData);
 }
 
 bool ScViewFunc::HasBookmarkAtCursor( SvxHyperlinkItem* pContent )
 {
-    ScAddress aPos( GetViewData()->GetCurX(), GetViewData()->GetCurY(), GetViewData()->GetTabNo() );
-    ScDocument* pDoc = GetViewData()->GetDocShell()->GetDocument();
+    ScAddress aPos( GetViewData().GetCurX(), GetViewData().GetCurY(), GetViewData().GetTabNo() );
+    ScDocument& rDoc = GetViewData().GetDocShell()->GetDocument();
 
-    const EditTextObject* pData = pDoc->GetEditText(aPos);
+    const EditTextObject* pData = rDoc.GetEditText(aPos);
     if (!pData)
         return false;
 
@@ -784,7 +762,7 @@ bool ScViewFunc::HasBookmarkAtCursor( SvxHyperlinkItem* pContent )
         // doesn't have a field item data.
         return false;
 
-    if (pField->GetClassId() != com::sun::star::text::textfield::Type::URL)
+    if (pField->GetClassId() != css::text::textfield::Type::URL)
         // not a URL field.
         return false;
 
@@ -798,5 +776,4 @@ bool ScViewFunc::HasBookmarkAtCursor( SvxHyperlinkItem* pContent )
     return true;
 }
 
-
 /* vim:set shiftwidth=4 softtabstop=4 expandtab: */
