@@ -145,6 +145,7 @@ public:
     void testMathObjectPPT2010();
     void testTdf80224();
     void testTdf92527();
+    void testTdf99224();
 
     CPPUNIT_TEST_SUITE(SdExportTest);
     CPPUNIT_TEST(testFdo90607);
@@ -188,6 +189,7 @@ public:
 
     CPPUNIT_TEST(testExportTransitionsPPTX);
     CPPUNIT_TEST(testTdf92527);
+    CPPUNIT_TEST(testTdf99224);
 
     CPPUNIT_TEST_SUITE_END();
 
@@ -1478,6 +1480,16 @@ void SdExportTest::testTdf92527()
     xDocShRef->DoClose();
 }
 
+void SdExportTest::testTdf99224()
+{
+    sd::DrawDocShellRef xShell = loadURL(getURLFromSrc("/sd/qa/unit/data/odp/tdf99224.odp"), ODP);
+    xShell = saveAndReload(xShell, PPTX);
+    uno::Reference<drawing::XDrawPage> xPage = getPage(0, xShell);
+    // This was 0: the image with text was lost on export.
+    CPPUNIT_ASSERT_EQUAL(static_cast<sal_Int32>(1), xPage->getCount());
+    xShell->DoClose();
+}
+
 CPPUNIT_TEST_SUITE_REGISTRATION(SdExportTest);
 
 CPPUNIT_PLUGIN_IMPLEMENT();
