@@ -17,6 +17,8 @@
  *   the License at http://www.apache.org/licenses/LICENSE-2.0 .
  */
 
+#include <libxml/xmlwriter.h>
+
 #include "PageListWatcher.hxx"
 #include <com/sun/star/text/WritingMode.hpp>
 #include <com/sun/star/document/PrinterIndependentLayout.hpp>
@@ -28,6 +30,7 @@
 #include <editeng/eeitem.hxx>
 #include <editeng/scriptspaceitem.hxx>
 
+#include <unotools/configmgr.hxx>
 #include <unotools/useroptions.hxx>
 #include <officecfg/Office/Impress.hxx>
 
@@ -55,6 +58,7 @@
 #include <editeng/outlobj.hxx>
 #include <unotools/saveopt.hxx>
 #include <comphelper/extract.hxx>
+#include <comphelper/getexpandeduri.hxx>
 #include <i18nlangtag/mslangid.hxx>
 #include <i18nlangtag/languagetag.hxx>
 #include <unotools/charclass.hxx>
@@ -72,7 +76,6 @@
 #include <com/sun/star/uno/XComponentContext.hpp>
 #include <rtl/ustring.hxx>
 #include <rtl/uri.hxx>
-#include <comphelper/expandmacro.hxx>
 
 #include <editeng/outliner.hxx>
 #include "drawdoc.hxx"
@@ -95,6 +98,7 @@
 
 #include <tools/tenccvt.hxx>
 #include <vcl/settings.hxx>
+#include <comphelper/lok.hxx>
 
 using namespace ::sd;
 using namespace ::com::sun::star;
@@ -107,9 +111,8 @@ using ::com::sun::star::uno::Reference;
 using ::com::sun::star::lang::XMultiServiceFactory;
 using ::com::sun::star::beans::PropertyValue;
 
-TYPEINIT1( SdDrawDocument, FmFormModel );
 
-SdDrawDocument* SdDrawDocument::pDocLockedInsertingLinks = NULL;
+SdDrawDocument* SdDrawDocument::s_pDocLockedInsertingLinks = nullptr;
 
 PresentationSettings::PresentationSettings()
 :   mbAll( true ),
@@ -147,20 +150,21 @@ PresentationSettings::PresentationSettings( const PresentationSettings& r )
 }
 
 SdDrawDocument::SdDrawDocument(DocumentType eType, SfxObjectShell* pDrDocSh)
-: FmFormModel( SvtPathOptions().GetPalettePath(), NULL, pDrDocSh )
+: FmFormModel( !utl::ConfigManager::IsAvoidConfig() ? SvtPathOptions().GetPalettePath() : OUString(), nullptr, pDrDocSh )
 , bReadOnly(false)
-, mpOutliner(NULL)
-, mpInternalOutliner(NULL)
-, mpWorkStartupTimer(NULL)
-, mpOnlineSpellingTimer(NULL)
-, mpOnlineSpellingList(NULL)
-, mpOnlineSearchItem(NULL)
-, mpCustomShowList(NULL)
+, mpOutliner(nullptr)
+, mpInternalOutliner(nullptr)
+, mpWorkStartupTimer(nullptr)
+, mpOnlineSpellingIdle(nullptr)
+, mpOnlineSpellingList(nullptr)
+, mpOnlineSearchItem(nullptr)
+, mpCustomShowList(nullptr)
 , mpDocSh(static_cast< ::sd::DrawDocShell*>(pDrDocSh))
-, mpCreatingTransferable( NULL )
+, mpCreatingTransferable( nullptr )
 , mbHasOnlineSpellErrors(false)
 , mbInitialOnlineSpellingEnabled(true)
 , mbNewOrLoadCompleted(false)
+, mbOnlineSpell(false)
 , mbStartWithPresentation( false )
 , mbExitAfterPresenting( false )
 , meLanguage( LANGUAGE_SYSTEM )
@@ -169,10 +173,8 @@ SdDrawDocument::SdDrawDocument(DocumentType eType, SfxObjectShell* pDrDocSh)
 , mePageNumType(SVX_ARABIC)
 , mbAllocDocSh(false)
 , meDocType(eType)
-, mpCharClass(NULL)
-, mpLocale(NULL)
-, mpDrawPageListWatcher(0)
-, mpMasterPageListWatcher(0)
+, mpCharClass(nullptr)
+, mpLocale(nullptr)
 , mbUseEmbedFonts(false)
 {
     mpDrawPageListWatcher.reset(new ImpDrawPageListWatcher(*this));
@@ -184,7 +186,7 @@ SdDrawDocument::SdDrawDocument(DocumentType eType, SfxObjectShell* pDrDocSh)
 
     if (mpDocSh)
     {
-        SetSwapGraphics(true);
+        SetSwapGraphics();
     }
 
     // Set measuring unit (of the application) and scale (of SdMod)
@@ -213,28 +215,30 @@ SdDrawDocument::SdDrawDocument(DocumentType eType, SfxObjectShell* pDrDocSh)
     // The link to the StyleRequest handler of the document is set later, in
     // NewOrLoadCompleted, because only then do all the templates exist.
     SdrOutliner& rOutliner = GetDrawOutliner();
-    rOutliner.SetStyleSheetPool((SfxStyleSheetPool*)GetStyleSheetPool());
+    rOutliner.SetStyleSheetPool(static_cast<SfxStyleSheetPool*>(GetStyleSheetPool()));
     SetCalcFieldValueHdl( &rOutliner );
 
     // set linguistic options
+    if (!utl::ConfigManager::IsAvoidConfig())
     {
         const SvtLinguConfig    aLinguConfig;
         SvtLinguOptions         aOptions;
         aLinguConfig.GetOptions( aOptions );
 
         SetLanguage( MsLangId::resolveSystemLanguageByScriptType(aOptions.nDefaultLanguage,
-            ::com::sun::star::i18n::ScriptType::LATIN), EE_CHAR_LANGUAGE );
+            css::i18n::ScriptType::LATIN), EE_CHAR_LANGUAGE );
         SetLanguage( MsLangId::resolveSystemLanguageByScriptType(aOptions.nDefaultLanguage_CJK,
-            ::com::sun::star::i18n::ScriptType::ASIAN), EE_CHAR_LANGUAGE_CJK );
+            css::i18n::ScriptType::ASIAN), EE_CHAR_LANGUAGE_CJK );
         SetLanguage( MsLangId::resolveSystemLanguageByScriptType(aOptions.nDefaultLanguage_CTL,
-            ::com::sun::star::i18n::ScriptType::COMPLEX), EE_CHAR_LANGUAGE_CTL );
+            css::i18n::ScriptType::COMPLEX), EE_CHAR_LANGUAGE_CTL );
 
-        mbOnlineSpell = aOptions.bIsSpellAuto;
+        if (!comphelper::LibreOfficeKit::isActive())
+            mbOnlineSpell = aOptions.bIsSpellAuto;
     }
 
     LanguageType eRealLanguage = MsLangId::getRealLanguage( meLanguage );
     LanguageTag aLanguageTag( eRealLanguage);
-    mpLocale = new ::com::sun::star::lang::Locale( aLanguageTag.getLocale());
+    mpLocale = new css::lang::Locale( aLanguageTag.getLocale());
     mpCharClass = new CharClass( aLanguageTag );
 
     // If the current application language is a language that uses right-to-left text...
@@ -242,7 +246,7 @@ SdDrawDocument::SdDrawDocument(DocumentType eType, SfxObjectShell* pDrDocSh)
     if( MsLangId::isRightToLeft( eRealCTLLanguage ) )
     {
         // ... then we have to set this as a default
-        SetDefaultWritingMode( ::com::sun::star::text::WritingMode_RL_TB );
+        SetDefaultWritingMode( css::text::WritingMode_RL_TB );
     }
 
     // for korean and japanese languages we have a different default for apply spacing between asian, latin and ctl text
@@ -279,23 +283,22 @@ SdDrawDocument::SdDrawDocument(DocumentType eType, SfxObjectShell* pDrDocSh)
         SetLinkManager( new sfx2::LinkManager(mpDocSh) );
     }
 
-    sal_uLong nCntrl = rOutliner.GetControlWord();
-    nCntrl |= EE_CNTRL_ALLOWBIGOBJS;
-    nCntrl |= EE_CNTRL_URLSFXEXECUTE;
+    EEControlBits nCntrl = rOutliner.GetControlWord();
+    nCntrl |= EEControlBits::ALLOWBIGOBJS;
 
     if (mbOnlineSpell)
-        nCntrl |= EE_CNTRL_ONLINESPELLING;
+        nCntrl |= EEControlBits::ONLINESPELLING;
     else
-        nCntrl &= ~EE_CNTRL_ONLINESPELLING;
+        nCntrl &= ~EEControlBits::ONLINESPELLING;
 
-    nCntrl &= ~ EE_CNTRL_ULSPACESUMMATION;
+    nCntrl &= ~ EEControlBits::ULSPACESUMMATION;
     if ( meDocType != DOCUMENT_TYPE_IMPRESS )
         SetSummationOfParagraphs( false );
     else
     {
         SetSummationOfParagraphs( pOptions->IsSummationOfParagraphs() );
         if ( pOptions->IsSummationOfParagraphs() )
-            nCntrl |= EE_CNTRL_ULSPACESUMMATION;
+            nCntrl |= EEControlBits::ULSPACESUMMATION;
     }
     rOutliner.SetControlWord(nCntrl);
 
@@ -306,7 +309,7 @@ SdDrawDocument::SdDrawDocument(DocumentType eType, SfxObjectShell* pDrDocSh)
     // The link to the StyleRequest handler of the document is set later, in
     // NewOrLoadCompleted, because only then do all the templates exist.
     SfxItemSet aSet2( pHitTestOutliner->GetEmptyItemSet() );
-    pHitTestOutliner->SetStyleSheetPool( (SfxStyleSheetPool*)GetStyleSheetPool() );
+    pHitTestOutliner->SetStyleSheetPool( static_cast<SfxStyleSheetPool*>(GetStyleSheetPool()) );
 
     SetCalcFieldValueHdl( pHitTestOutliner );
 
@@ -327,14 +330,13 @@ SdDrawDocument::SdDrawDocument(DocumentType eType, SfxObjectShell* pDrDocSh)
 
     pHitTestOutliner->SetDefaultLanguage( Application::GetSettings().GetLanguageTag().getLanguageType() );
 
-    sal_uLong nCntrl2 = pHitTestOutliner->GetControlWord();
-    nCntrl2 |= EE_CNTRL_ALLOWBIGOBJS;
-    nCntrl2 |= EE_CNTRL_URLSFXEXECUTE;
-    nCntrl2 &= ~EE_CNTRL_ONLINESPELLING;
+    EEControlBits nCntrl2 = pHitTestOutliner->GetControlWord();
+    nCntrl2 |= EEControlBits::ALLOWBIGOBJS;
+    nCntrl2 &= ~EEControlBits::ONLINESPELLING;
 
-    nCntrl2 &= ~ EE_CNTRL_ULSPACESUMMATION;
+    nCntrl2 &= ~ EEControlBits::ULSPACESUMMATION;
     if ( pOptions->IsSummationOfParagraphs() )
-        nCntrl2 |= EE_CNTRL_ULSPACESUMMATION;
+        nCntrl2 |= EEControlBits::ULSPACESUMMATION;
 
     pHitTestOutliner->SetControlWord( nCntrl2 );
 
@@ -366,7 +368,6 @@ SdDrawDocument::SdDrawDocument(DocumentType eType, SfxObjectShell* pDrDocSh)
         rLayerAdmin.SetControlLayerName(aControlLayerName);
     }
 
-
 }
 
 // Destructor
@@ -380,12 +381,12 @@ SdDrawDocument::~SdDrawDocument()
             mpWorkStartupTimer->Stop();
 
         delete mpWorkStartupTimer;
-        mpWorkStartupTimer = NULL;
+        mpWorkStartupTimer = nullptr;
     }
 
     StopOnlineSpelling();
     delete mpOnlineSearchItem;
-    mpOnlineSearchItem = NULL;
+    mpOnlineSearchItem = nullptr;
 
     CloseBookmarkDoc();
     SetAllocDocSh(false);
@@ -401,7 +402,7 @@ SdDrawDocument::~SdDrawDocument()
         }
 
         delete pLinkManager;
-        pLinkManager = NULL;
+        pLinkManager = nullptr;
     }
 
     std::vector<sd::FrameView*>::iterator pIter;
@@ -418,61 +419,65 @@ SdDrawDocument::~SdDrawDocument()
         }
 
         delete mpCustomShowList;
-        mpCustomShowList = NULL;
+        mpCustomShowList = nullptr;
     }
 
     delete mpOutliner;
-    mpOutliner = NULL;
+    mpOutliner = nullptr;
 
     delete mpInternalOutliner;
-    mpInternalOutliner = NULL;
+    mpInternalOutliner = nullptr;
 
     delete mpLocale;
-    mpLocale = NULL;
+    mpLocale = nullptr;
 
     delete mpCharClass;
-    mpCharClass = NULL;
+    mpCharClass = nullptr;
+}
+
+SdrModel* SdDrawDocument::AllocModel() const
+{
+    return AllocSdDrawDocument();
 }
 
 // This method creates a new document (SdDrawDocument) and returns a pointer to
 // said document. The drawing engine uses this method to put the document (or
 // parts of it) into the clipboard/DragServer.
-SdrModel* SdDrawDocument::AllocModel() const
+SdDrawDocument* SdDrawDocument::AllocSdDrawDocument() const
 {
-    SdDrawDocument* pNewModel = NULL;
+    SdDrawDocument* pNewModel = nullptr;
 
     if( mpCreatingTransferable )
     {
         // Document is created for drag & drop/clipboard. To be able to
         // do this, the document has to know a DocShell (SvPersist).
-        SfxObjectShell*   pObj = NULL;
-        ::sd::DrawDocShell*     pNewDocSh = NULL;
+        SfxObjectShell*   pObj = nullptr;
+        ::sd::DrawDocShell*     pNewDocSh = nullptr;
 
         if( meDocType == DOCUMENT_TYPE_IMPRESS )
             mpCreatingTransferable->SetDocShell( new ::sd::DrawDocShell(
-                SFX_CREATE_MODE_EMBEDDED, true, meDocType ) );
+                SfxObjectCreateMode::EMBEDDED, true, meDocType ) );
         else
             mpCreatingTransferable->SetDocShell( new ::sd::GraphicDocShell(
-                SFX_CREATE_MODE_EMBEDDED, true, meDocType ) );
+                SfxObjectCreateMode::EMBEDDED, true, meDocType ) );
 
         pNewDocSh = static_cast< ::sd::DrawDocShell*>( pObj = mpCreatingTransferable->GetDocShell() );
-        pNewDocSh->DoInitNew( NULL );
+        pNewDocSh->DoInitNew();
         pNewModel = pNewDocSh->GetDoc();
 
         // Only necessary for clipboard -
         // for drag & drop this is handled by DragServer
-        SdStyleSheetPool* pOldStylePool = (SdStyleSheetPool*) GetStyleSheetPool();
-        SdStyleSheetPool* pNewStylePool = (SdStyleSheetPool*) pNewModel->GetStyleSheetPool();
+        SdStyleSheetPool* pOldStylePool = static_cast<SdStyleSheetPool*>( GetStyleSheetPool() );
+        SdStyleSheetPool* pNewStylePool = static_cast<SdStyleSheetPool*>( pNewModel->GetStyleSheetPool() );
 
         pNewStylePool->CopyGraphicSheets(*pOldStylePool);
         pNewStylePool->CopyCellSheets(*pOldStylePool);
         pNewStylePool->CopyTableStyles(*pOldStylePool);
 
-
         for (sal_uInt16 i = 0; i < GetMasterSdPageCount(PK_STANDARD); i++)
         {
             // Move with all of the master page's layouts
-            OUString aOldLayoutName(((SdDrawDocument*) this)->GetMasterSdPage(i, PK_STANDARD)->GetLayoutName());
+            OUString aOldLayoutName(const_cast<SdDrawDocument*>(this)->GetMasterSdPage(i, PK_STANDARD)->GetLayoutName());
             aOldLayoutName = aOldLayoutName.copy( 0, aOldLayoutName.indexOf( SD_LT_SEPARATOR ) );
             SdStyleSheetVector aCreatedSheets;
             pNewStylePool->CopyLayoutSheets(aOldLayoutName, *pOldStylePool, aCreatedSheets );
@@ -483,27 +488,32 @@ SdrModel* SdDrawDocument::AllocModel() const
     else if( mbAllocDocSh )
     {
         // Create a DocShell which is then returned with GetAllocedDocSh()
-        SdDrawDocument* pDoc = (SdDrawDocument*) this;
+        SdDrawDocument* pDoc = const_cast<SdDrawDocument*>(this);
         pDoc->SetAllocDocSh(false);
         pDoc->mxAllocedDocShRef = new ::sd::DrawDocShell(
-            SFX_CREATE_MODE_EMBEDDED, true, meDocType);
-        pDoc->mxAllocedDocShRef->DoInitNew(NULL);
+            SfxObjectCreateMode::EMBEDDED, true, meDocType);
+        pDoc->mxAllocedDocShRef->DoInitNew();
         pNewModel = pDoc->mxAllocedDocShRef->GetDoc();
     }
     else
     {
-        pNewModel = new SdDrawDocument(meDocType, NULL);
+        pNewModel = new SdDrawDocument(meDocType, nullptr);
     }
 
     return pNewModel;
 }
 
+SdPage* SdDrawDocument::AllocSdPage(bool bMasterPage)
+{
+    return new SdPage(*this, bMasterPage);
+}
+
 // This method creates a new page (SdPage) and returns a pointer to said page.
 // The drawing engine uses this method to create pages (whose types it does
 // not know, as they are _derivatives_ of SdrPage) when loading.
 SdrPage* SdDrawDocument::AllocPage(bool bMasterPage)
 {
-    return new SdPage(*this, bMasterPage);
+    return AllocSdPage(bMasterPage);
 }
 
 // When the model has changed
@@ -555,16 +565,16 @@ void SdDrawDocument::NewOrLoadCompleted(DocCreationMode eMode)
         CheckMasterPages();
 
         if ( GetMasterSdPageCount(PK_STANDARD) > 1 )
-            RemoveUnnecessaryMasterPages( NULL, true, false );
+            RemoveUnnecessaryMasterPages( nullptr, true, false );
 
         for ( sal_uInt16 i = 0; i < GetPageCount(); i++ )
         {
             // Check for correct layout names
-            SdPage* pPage = (SdPage*) GetPage( i );
+            SdPage* pPage = static_cast<SdPage*>( GetPage( i ) );
 
             if(pPage->TRG_HasMasterPage())
             {
-                SdPage& rMaster = (SdPage&)pPage->TRG_GetMasterPage();
+                SdPage& rMaster = static_cast<SdPage&>(pPage->TRG_GetMasterPage() );
 
                 if(rMaster.GetLayoutName() != pPage->GetLayoutName())
                 {
@@ -576,7 +586,7 @@ void SdDrawDocument::NewOrLoadCompleted(DocCreationMode eMode)
         for ( sal_uInt16 nPage = 0; nPage < GetMasterPageCount(); nPage++)
         {
             // LayoutName and PageName must be the same
-            SdPage* pPage = (SdPage*) GetMasterPage( nPage );
+            SdPage* pPage = static_cast<SdPage*>( GetMasterPage( nPage ) );
 
             OUString aName( pPage->GetLayoutName() );
             aName = aName.copy( 0, aName.indexOf( SD_LT_SEPARATOR ) );
@@ -606,32 +616,32 @@ void SdDrawDocument::NewOrLoadCompleted(DocCreationMode eMode)
     // global outliner, as it is not document specific like StyleSheetPool and
     // StyleRequestHandler are.
     ::Outliner& rDrawOutliner = GetDrawOutliner();
-    rDrawOutliner.SetStyleSheetPool((SfxStyleSheetPool*)GetStyleSheetPool());
-    sal_uLong nCntrl = rDrawOutliner.GetControlWord();
+    rDrawOutliner.SetStyleSheetPool(static_cast<SfxStyleSheetPool*>(GetStyleSheetPool()));
+    EEControlBits nCntrl = rDrawOutliner.GetControlWord();
     if (mbOnlineSpell)
-        nCntrl |= EE_CNTRL_ONLINESPELLING;
+        nCntrl |= EEControlBits::ONLINESPELLING;
     else
-        nCntrl &= ~EE_CNTRL_ONLINESPELLING;
+        nCntrl &= ~EEControlBits::ONLINESPELLING;
     rDrawOutliner.SetControlWord(nCntrl);
 
     // Initialize HitTestOutliner and DocumentOutliner, but don't initialize the
     // global outliner, as it is not document specific like StyleSheetPool and
     // StyleRequestHandler are.
-    pHitTestOutliner->SetStyleSheetPool((SfxStyleSheetPool*)GetStyleSheetPool());
+    pHitTestOutliner->SetStyleSheetPool(static_cast<SfxStyleSheetPool*>(GetStyleSheetPool()));
 
     if(mpOutliner)
     {
-        mpOutliner->SetStyleSheetPool((SfxStyleSheetPool*)GetStyleSheetPool());
+        mpOutliner->SetStyleSheetPool(static_cast<SfxStyleSheetPool*>(GetStyleSheetPool()));
     }
     if(mpInternalOutliner)
     {
-        mpInternalOutliner->SetStyleSheetPool((SfxStyleSheetPool*)GetStyleSheetPool());
+        mpInternalOutliner->SetStyleSheetPool(static_cast<SfxStyleSheetPool*>(GetStyleSheetPool()));
     }
 
     if ( eMode == DOC_LOADED )
     {
         // Make presentation objects listeners of the appropriate styles
-        SdStyleSheetPool* pSPool = (SdStyleSheetPool*) GetStyleSheetPool();
+        SdStyleSheetPool* pSPool = static_cast<SdStyleSheetPool*>( GetStyleSheetPool() );
         sal_uInt16 nPage, nPageCount;
 
         // create missing layout style sheets for broken documents
@@ -646,14 +656,14 @@ void SdDrawDocument::NewOrLoadCompleted(DocCreationMode eMode)
         // Default and notes pages:
         for (nPage = 0; nPage < GetPageCount(); nPage++)
         {
-            SdPage* pPage = (SdPage*)GetPage(nPage);
+            SdPage* pPage = static_cast<SdPage*>(GetPage(nPage));
             NewOrLoadCompleted( pPage, pSPool );
         }
 
         // Master pages:
         for (nPage = 0; nPage < GetMasterPageCount(); nPage++)
         {
-            SdPage* pPage = (SdPage*)GetMasterPage(nPage);
+            SdPage* pPage = static_cast<SdPage*>(GetMasterPage(nPage));
 
             NewOrLoadCompleted( pPage, pSPool );
         }
@@ -662,12 +672,11 @@ void SdDrawDocument::NewOrLoadCompleted(DocCreationMode eMode)
     mbNewOrLoadCompleted = true;
 
     // Update all linked pages
-    SdPage* pPage = NULL;
     sal_uInt16 nMaxSdPages = GetSdPageCount(PK_STANDARD);
 
     for (sal_uInt16 nSdPage=0; nSdPage < nMaxSdPages; nSdPage++)
     {
-        pPage = (SdPage*) GetSdPage(nSdPage, PK_STANDARD);
+        SdPage* pPage = GetSdPage(nSdPage, PK_STANDARD);
 
         if (pPage && !pPage->GetFileName().isEmpty() && pPage->GetBookmarkName().getLength())
         {
@@ -683,14 +692,14 @@ void SdDrawDocument::NewOrLoadCompleted(DocCreationMode eMode)
 /** updates all links, only links in this document should by resolved */
 void SdDrawDocument::UpdateAllLinks()
 {
-    if ( !pDocLockedInsertingLinks && pLinkManager && !pLinkManager->GetLinks().empty() )
+    if (!s_pDocLockedInsertingLinks && pLinkManager && !pLinkManager->GetLinks().empty())
     {
-        pDocLockedInsertingLinks = this; // lock inserting links. only links in this document should by resolved
+        s_pDocLockedInsertingLinks = this; // lock inserting links. only links in this document should by resolved
 
         pLinkManager->UpdateAllLinks();  // query box: update all links?
 
-        if( pDocLockedInsertingLinks == this )
-            pDocLockedInsertingLinks = NULL;  // unlock inserting links
+        if (s_pDocLockedInsertingLinks == this)
+            s_pDocLockedInsertingLinks = nullptr;  // unlock inserting links
     }
 }
 
@@ -709,9 +718,9 @@ void SdDrawDocument::NewOrLoadCompleted( SdPage* pPage, SdStyleSheetPool* pSPool
         std::vector<SfxStyleSheetBase*> aOutlineList;
         pSPool->CreateOutlineSheetList(aName,aOutlineList);
 
-        SfxStyleSheet* pTitleSheet = (SfxStyleSheet*)pSPool->GetTitleSheet(aName);
+        SfxStyleSheet* pTitleSheet = static_cast<SfxStyleSheet*>(pSPool->GetTitleSheet(aName));
 
-        SdrObject* pObj = 0;
+        SdrObject* pObj = nullptr;
         rPresentationShapes.seekShape(0);
 
         // Now look for title and outline text objects, then make those objects
@@ -753,15 +762,15 @@ void SdDrawDocument::NewOrLoadCompleted( SdPage* pPage, SdStyleSheetPool* pSPool
                     }
                 }
 
-                if (pObj->ISA(SdrTextObj) && pObj->IsEmptyPresObj())
+                if( dynamic_cast< const SdrTextObj *>( pObj ) !=  nullptr && pObj->IsEmptyPresObj())
                 {
                     PresObjKind ePresObjKind = pPage->GetPresObjKind(pObj);
                     OUString aString( pPage->GetPresObjText(ePresObjKind) );
 
                     if (!aString.isEmpty())
                     {
-                        sd::Outliner* pInternalOutl = GetInternalOutliner(true);
-                        pPage->SetObjText( (SdrTextObj*) pObj, pInternalOutl, ePresObjKind, aString );
+                        sd::Outliner* pInternalOutl = GetInternalOutliner();
+                        pPage->SetObjText( static_cast<SdrTextObj*>(pObj), pInternalOutl, ePresObjKind, aString );
                         pObj->NbcSetStyleSheet( pPage->GetStyleSheetForPresObj( ePresObjKind ), true );
                         pInternalOutl->Clear();
                     }
@@ -783,10 +792,10 @@ void SdDrawDocument::NewOrLoadCompleted( SdPage* pPage, SdStyleSheetPool* pSPool
             mpOutliner->SetRefDevice( SD_MOD()->GetRefDevice( *mpDocSh ) );
 
         mpOutliner->SetDefTab( nDefaultTabulator );
-        mpOutliner->SetStyleSheetPool((SfxStyleSheetPool*)GetStyleSheetPool());
+        mpOutliner->SetStyleSheetPool(static_cast<SfxStyleSheetPool*>(GetStyleSheetPool()));
     }
 
-    return(mpOutliner);
+    return mpOutliner;
 }
 
 // Internal outliner that is used to create text objects. We don't insert any
@@ -807,7 +816,7 @@ void SdDrawDocument::NewOrLoadCompleted( SdPage* pPage, SdStyleSheetPool* pSPool
             mpInternalOutliner->SetRefDevice( SD_MOD()->GetRefDevice( *mpDocSh ) );
 
         mpInternalOutliner->SetDefTab( nDefaultTabulator );
-        mpInternalOutliner->SetStyleSheetPool((SfxStyleSheetPool*)GetStyleSheetPool());
+        mpInternalOutliner->SetStyleSheetPool(static_cast<SfxStyleSheetPool*>(GetStyleSheetPool()));
     }
 
     DBG_ASSERT( !mpInternalOutliner || ( ! mpInternalOutliner->GetUpdateMode() ) , "InternalOutliner: UpdateMode = sal_True !" );
@@ -826,16 +835,16 @@ void SdDrawDocument::NewOrLoadCompleted( SdPage* pPage, SdStyleSheetPool* pSPool
 void SdDrawDocument::SetOnlineSpell(bool bIn)
 {
     mbOnlineSpell = bIn;
-    sal_uLong nCntrl = 0;
+    EEControlBits nCntrl;
 
     if(mpOutliner)
     {
         nCntrl = mpOutliner->GetControlWord();
 
         if(mbOnlineSpell)
-            nCntrl |= EE_CNTRL_ONLINESPELLING;
+            nCntrl |= EEControlBits::ONLINESPELLING;
         else
-            nCntrl &= ~EE_CNTRL_ONLINESPELLING;
+            nCntrl &= ~EEControlBits::ONLINESPELLING;
 
         mpOutliner->SetControlWord(nCntrl);
     }
@@ -845,9 +854,9 @@ void SdDrawDocument::SetOnlineSpell(bool bIn)
         nCntrl = mpInternalOutliner->GetControlWord();
 
         if (mbOnlineSpell)
-            nCntrl |= EE_CNTRL_ONLINESPELLING;
+            nCntrl |= EEControlBits::ONLINESPELLING;
         else
-            nCntrl &= ~EE_CNTRL_ONLINESPELLING;
+            nCntrl &= ~EEControlBits::ONLINESPELLING;
 
         mpInternalOutliner->SetControlWord(nCntrl);
     }
@@ -857,9 +866,9 @@ void SdDrawDocument::SetOnlineSpell(bool bIn)
     nCntrl = rOutliner.GetControlWord();
 
     if (mbOnlineSpell)
-        nCntrl |= EE_CNTRL_ONLINESPELLING;
+        nCntrl |= EEControlBits::ONLINESPELLING;
     else
-        nCntrl &= ~EE_CNTRL_ONLINESPELLING;
+        nCntrl &= ~EEControlBits::ONLINESPELLING;
 
     rOutliner.SetControlWord(nCntrl);
 
@@ -899,8 +908,8 @@ void SdDrawDocument::SetPrinterIndependentLayout (sal_Int32 nMode)
 {
     switch (nMode)
     {
-        case ::com::sun::star::document::PrinterIndependentLayout::DISABLED:
-        case ::com::sun::star::document::PrinterIndependentLayout::ENABLED:
+        case css::document::PrinterIndependentLayout::DISABLED:
+        case css::document::PrinterIndependentLayout::ENABLED:
             // Just store supported modes and inform the doc shell
             mnPrinterIndependentLayout = nMode;
 
@@ -920,26 +929,11 @@ void SdDrawDocument::SetPrinterIndependentLayout (sal_Int32 nMode)
     }
 }
 
-sal_Int32 SdDrawDocument::GetPrinterIndependentLayout (void)
-{
-    return mnPrinterIndependentLayout;
-}
-
-bool SdDrawDocument::IsStartWithPresentation() const
-{
-    return mbStartWithPresentation;
-}
-
 void SdDrawDocument::SetStartWithPresentation( bool bStartWithPresentation )
 {
     mbStartWithPresentation = bStartWithPresentation;
 }
 
-bool SdDrawDocument::IsExitAfterPresenting() const
-{
-    return mbExitAfterPresenting;
-}
-
 void SdDrawDocument::SetExitAfterPresenting( bool bExitAfterPresenting )
 {
     mbExitAfterPresenting = bExitAfterPresenting;
@@ -990,6 +984,9 @@ sal_uInt16 SdDrawDocument::GetAnnotationAuthorIndex( const OUString& rAuthor )
 
 void SdDrawDocument::InitLayoutVector()
 {
+    if (utl::ConfigManager::IsAvoidConfig())
+        return;
+
     const Reference<css::uno::XComponentContext> xContext(
         ::comphelper::getProcessComponentContext() );
 
@@ -1000,7 +997,7 @@ void SdDrawDocument::InitLayoutVector()
     rtl::OUString sFilename;
     for( sal_Int32 i=0; i < aFiles.getLength(); ++i )
     {
-        sFilename = ::comphelper::getExpandedFilePath(aFiles[i]);
+        sFilename = comphelper::getExpandedUri(xContext, aFiles[i]);
 
         // load layout file into DOM
         Reference< XMultiServiceFactory > xServiceFactory(
@@ -1026,6 +1023,9 @@ void SdDrawDocument::InitLayoutVector()
 
 void SdDrawDocument::InitObjectVector()
 {
+    if (utl::ConfigManager::IsAvoidConfig())
+        return;
+
     const Reference<css::uno::XComponentContext> xContext(
         ::comphelper::getProcessComponentContext() );
 
@@ -1036,7 +1036,7 @@ void SdDrawDocument::InitObjectVector()
     rtl::OUString sFilename;
     for( sal_Int32 i=0; i < aFiles.getLength(); ++i )
     {
-        sFilename = ::comphelper::getExpandedFilePath(aFiles[i]);
+        sFilename = comphelper::getExpandedUri(xContext, aFiles[i]);
 
         // load presentation object file into DOM
         Reference< XMultiServiceFactory > xServiceFactory(
@@ -1059,4 +1059,22 @@ void SdDrawDocument::InitObjectVector()
         }
     }
 }
+
+void SdDrawDocument::dumpAsXml(xmlTextWriterPtr pWriter) const
+{
+    bool bOwns = false;
+    if (!pWriter)
+    {
+        pWriter = xmlNewTextWriterFilename("model.xml", 0);
+        xmlTextWriterStartDocument(pWriter, nullptr, nullptr, nullptr);
+        bOwns = true;
+    }
+    FmFormModel::dumpAsXml(pWriter);
+    if (bOwns)
+    {
+        xmlTextWriterEndDocument(pWriter);
+        xmlFreeTextWriter(pWriter);
+    }
+}
+
 /* vim:set shiftwidth=4 softtabstop=4 expandtab: */
