@@ -17,9 +17,8 @@
  *   the License at http://www.apache.org/licenses/LICENSE-2.0 .
  */
 
-
 #include <vector>
-#include <boost/ptr_container/ptr_vector.hpp>
+#include <libxml/xmlwriter.h>
 
 #include <sfx2/docfile.hxx>
 #include <vcl/svapp.hxx>
@@ -31,6 +30,8 @@
 #include <editeng/xmlcnitm.hxx>
 #include <svx/svditer.hxx>
 
+#include "Annotation.hxx"
+#include "notifydocumentevent.hxx"
 #include "sdresid.hxx"
 #include "sdpage.hxx"
 #include "glob.hxx"
@@ -45,14 +46,13 @@
 
 #include <tools/tenccvt.hxx>
 #include <svl/itemset.hxx>
+#include <rtl/strbuf.hxx>
 
 using namespace ::sd;
 using namespace ::com::sun::star;
 using namespace ::com::sun::star::uno;
 using namespace ::com::sun::star::office;
 
-extern void NotifyDocumentEvent( SdDrawDocument* pDocument, const OUString& rEventName, const Reference< XInterface >& xSource );
-
 /*************************************************************************
 |*
 |* Sets: names of layout, master page links and templates for presentation
@@ -75,9 +75,9 @@ extern void NotifyDocumentEvent( SdDrawDocument* pDocument, const OUString& rEve
 \************************************************************************/
 
 void SdPage::SetPresentationLayout(const OUString& rLayoutName,
-                                   sal_Bool bReplaceStyleSheets,
-                                   sal_Bool bSetMasterPage,
-                                   sal_Bool bReverseOrder)
+                                   bool bReplaceStyleSheets,
+                                   bool bSetMasterPage,
+                                   bool bReverseOrder)
 {
     /*********************************************************************
     |* Name of the layout of the page
@@ -93,7 +93,7 @@ void SdPage::SetPresentationLayout(const OUString& rLayoutName,
     if (bSetMasterPage && !IsMasterPage())
     {
         SdPage* pMaster;
-        SdPage* pFoundMaster = 0;
+        SdPage* pFoundMaster = nullptr;
         sal_uInt16 nMaster = 0;
         sal_uInt16 nMasterCount = pModel->GetMasterPageCount();
 
@@ -125,7 +125,7 @@ void SdPage::SetPresentationLayout(const OUString& rLayoutName,
         DBG_ASSERT(pFoundMaster, "Masterpage for presentation layout not found!");
 
         // this should never happen, but we play failsafe here
-        if( pFoundMaster == 0 )
+        if( pFoundMaster == nullptr )
             pFoundMaster = static_cast< SdDrawDocument *>(pModel)->GetSdPage( 0, mePageKind );
 
         if( pFoundMaster )
@@ -140,14 +140,14 @@ void SdPage::SetPresentationLayout(const OUString& rLayoutName,
     // - replace-data for OutlinerParaObject
     std::vector<SfxStyleSheetBase*> aOutlineStyles;
     std::vector<SfxStyleSheetBase*> aOldOutlineStyles;
-    boost::ptr_vector<StyleReplaceData> aReplList;
+    std::vector<StyleReplaceData> aReplList;
     bool bListsFilled = false;
 
-    sal_uLong nObjCount = GetObjCount();
+    const size_t nObjCount = GetObjCount();
 
-    for (sal_uLong nObj = 0; nObj < nObjCount; nObj++)
+    for (size_t nObj = 0; nObj < nObjCount; ++nObj)
     {
-        SdrTextObj* pObj = (SdrTextObj*) GetObj(nObj);
+        auto pObj = GetObj(nObj);
 
         if (pObj->GetObjInventor() == SdrInventor &&
             pObj->GetObjIdentifier() == OBJ_OUTLINETEXT)
@@ -156,15 +156,15 @@ void SdPage::SetPresentationLayout(const OUString& rLayoutName,
             {
                 OUString aFullName;
                 OUString aOldFullName;
-                SfxStyleSheetBase* pSheet = NULL;
+                SfxStyleSheetBase* pSheet = nullptr;
                 SfxStyleSheetBasePool* pStShPool = pModel->GetStyleSheetPool();
 
                 for (sal_Int16 i = -1; i < 9; i++)
                 {
                     aOldFullName = aOldLayoutName + " " +
-                                OUString::number( (sal_Int32) (i <= 0 ) ? 1 : i + 1 );
+                                OUString::number( (i <= 0 ) ? 1 : i + 1 );
                     aFullName = maLayoutName + " " +
-                                OUString::number( (sal_Int32) (i <= 0 ) ? 1 : i + 1);
+                                OUString::number( (i <= 0 ) ? 1 : i + 1);
                     pSheet = pStShPool->Find(aOldFullName, SD_STYLE_FAMILY_MASTERPAGE);
                     DBG_ASSERT(pSheet, "Old outline style sheet not found");
                     aOldOutlineStyles.push_back(pSheet);
@@ -176,16 +176,16 @@ void SdPage::SetPresentationLayout(const OUString& rLayoutName,
                     if (bReplaceStyleSheets && pSheet)
                     {
                         // Replace instead Set
-                        StyleReplaceData* pReplData = new StyleReplaceData;
-                        pReplData->nNewFamily = pSheet->GetFamily();
-                        pReplData->nFamily    = pSheet->GetFamily();
-                        pReplData->aNewName   = aFullName;
-                        pReplData->aName      = aOldFullName;
-                        aReplList.push_back(pReplData);
+                        StyleReplaceData aReplData;
+                        aReplData.nNewFamily = pSheet->GetFamily();
+                        aReplData.nFamily    = pSheet->GetFamily();
+                        aReplData.aNewName   = aFullName;
+                        aReplData.aName      = aOldFullName;
+                        aReplList.push_back(aReplData);
                     }
                     else
                     {
-                        OutlinerParaObject* pOPO = ((SdrTextObj*)pObj)->GetOutlinerParaObject();
+                        OutlinerParaObject* pOPO = pObj->GetOutlinerParaObject();
 
                         if( pOPO )
                             pOPO->SetStyleSheets( i,  aFullName, SD_STYLE_FAMILY_MASTERPAGE );
@@ -195,16 +195,14 @@ void SdPage::SetPresentationLayout(const OUString& rLayoutName,
                 bListsFilled = true;
             }
 
-            SfxStyleSheet* pSheet = NULL;
-            SfxStyleSheet* pOldSheet = NULL;
 
             std::vector<SfxStyleSheetBase*>::iterator iterOut = aOutlineStyles.begin();
             std::vector<SfxStyleSheetBase*>::iterator iterOldOut = aOldOutlineStyles.begin();
 
             while (iterOut != aOutlineStyles.end())
             {
-                pSheet = static_cast<SfxStyleSheet*>(*iterOut);
-                pOldSheet = static_cast<SfxStyleSheet*>(*iterOldOut);
+                SfxStyleSheet* pSheet = static_cast<SfxStyleSheet*>(*iterOut);
+                SfxStyleSheet* pOldSheet = static_cast<SfxStyleSheet*>(*iterOldOut);
 
                 if (pSheet != pOldSheet)
                 {
@@ -219,10 +217,10 @@ void SdPage::SetPresentationLayout(const OUString& rLayoutName,
                 ++iterOldOut;
             }
 
-            OutlinerParaObject* pOPO = ((SdrTextObj*)pObj)->GetOutlinerParaObject();
+            OutlinerParaObject* pOPO = pObj->GetOutlinerParaObject();
             if ( bReplaceStyleSheets && pOPO )
             {
-                boost::ptr_vector<StyleReplaceData>::const_iterator it = aReplList.begin();
+                std::vector<StyleReplaceData>::const_iterator it = aReplList.begin();
                 while (it != aReplList.end())
                 {
                     pOPO->ChangeStyleSheets( it->aName, it->nFamily, it->aNewName, it->nNewFamily );
@@ -239,19 +237,18 @@ void SdPage::SetPresentationLayout(const OUString& rLayoutName,
             SfxStyleSheet* pSheet = GetStyleSheetForPresObj(PRESOBJ_TITLE);
 
             if (pSheet)
-                pObj->SetStyleSheet(pSheet, sal_True);
+                pObj->SetStyleSheet(pSheet, true);
         }
         else
         {
             SfxStyleSheet* pSheet = GetStyleSheetForPresObj(GetPresObjKind(pObj));
 
             if (pSheet)
-                pObj->SetStyleSheet(pSheet, sal_True);
+                pObj->SetStyleSheet(pSheet, true);
         }
     }
 }
 
-
 /*************************************************************************
 |*
 |* disconnect outline text object from templates for outline levels
@@ -264,21 +261,20 @@ void SdPage::EndListenOutlineText()
 
     if (pOutlineTextObj)
     {
-        SdStyleSheetPool* pSPool = (SdStyleSheetPool*)pModel->GetStyleSheetPool();
+        SdStyleSheetPool* pSPool = static_cast<SdStyleSheetPool*>(pModel->GetStyleSheetPool());
         DBG_ASSERT(pSPool, "StyleSheetPool missing");
         OUString aTrueLayoutName(maLayoutName);
         sal_Int32 nIndex = aTrueLayoutName.indexOf( SD_LT_SEPARATOR );
         if( nIndex != -1 )
             aTrueLayoutName = aTrueLayoutName.copy(0, nIndex);
 
-        SfxStyleSheet *pSheet = NULL;
         std::vector<SfxStyleSheetBase*> aOutlineStyles;
         pSPool->CreateOutlineSheetList(aTrueLayoutName,aOutlineStyles);
 
         std::vector<SfxStyleSheetBase*>::iterator iter;
         for (iter = aOutlineStyles.begin(); iter != aOutlineStyles.end(); ++iter)
         {
-            pSheet = static_cast<SfxStyleSheet*>(*iter);
+            SfxStyleSheet *pSheet = static_cast<SfxStyleSheet*>(*iter);
             pOutlineTextObj->EndListening(*pSheet);
         }
     }
@@ -319,17 +315,17 @@ bool SdPage::IsReadOnly() const
 
 void SdPage::ConnectLink()
 {
-    sfx2::LinkManager* pLinkManager = pModel!=NULL ? pModel->GetLinkManager() : NULL;
+    sfx2::LinkManager* pLinkManager = pModel!=nullptr ? pModel->GetLinkManager() : nullptr;
 
     if (pLinkManager && !mpPageLink && !maFileName.isEmpty() && !maBookmarkName.isEmpty() &&
         mePageKind==PK_STANDARD && !IsMasterPage() &&
-        ( (SdDrawDocument*) pModel)->IsNewOrLoadCompleted())
+        static_cast<SdDrawDocument*>(pModel)->IsNewOrLoadCompleted())
     {
         /**********************************************************************
         * Connect
         * Only standard pages are allowed to be linked
         **********************************************************************/
-        ::sd::DrawDocShell* pDocSh = ((SdDrawDocument*) pModel)->GetDocSh();
+        ::sd::DrawDocShell* pDocSh = static_cast<SdDrawDocument*>(pModel)->GetDocSh();
 
         if (!pDocSh || !pDocSh->GetMedium()->GetOrigURL().equals(maFileName))
         {
@@ -343,7 +339,6 @@ void SdPage::ConnectLink()
     }
 }
 
-
 /*************************************************************************
 |*
 |* Disconnect from sfx2::LinkManager
@@ -352,7 +347,7 @@ void SdPage::ConnectLink()
 
 void SdPage::DisconnectLink()
 {
-    sfx2::LinkManager* pLinkManager = pModel!=NULL ? pModel->GetLinkManager() : NULL;
+    sfx2::LinkManager* pLinkManager = pModel!=nullptr ? pModel->GetLinkManager() : nullptr;
 
     if (pLinkManager && mpPageLink)
     {
@@ -361,7 +356,7 @@ void SdPage::DisconnectLink()
         * (remove deletes *pGraphicLink implicit)
         **********************************************************************/
         pLinkManager->Remove(mpPageLink);
-        mpPageLink=NULL;
+        mpPageLink=nullptr;
     }
 }
 
@@ -374,21 +369,12 @@ void SdPage::DisconnectLink()
 SdPage::SdPage(const SdPage& rSrcPage)
 :   FmFormPage(rSrcPage)
 ,   SdrObjUserCall()
-,   mpItems(NULL)
+,   mpItems(nullptr)
 {
     mePageKind           = rSrcPage.mePageKind;
     meAutoLayout         = rSrcPage.meAutoLayout;
 
-    // use shape list directly to preserve constness of rSrcPage
-    const std::list< SdrObject* >& rShapeList = rSrcPage.maPresentationShapeList.getList();
-    for( std::list< SdrObject* >::const_iterator aIter = rShapeList.begin();
-         aIter != rShapeList.end(); ++aIter )
-    {
-        SdrObject* pObj = *aIter;
-        InsertPresObj(GetObj(pObj->GetOrdNum()), rSrcPage.GetPresObjKind(pObj));
-    }
-
-    mbSelected           = sal_False;
+    mbSelected           = false;
     mnTransitionType    = rSrcPage.mnTransitionType;
     mnTransitionSubtype = rSrcPage.mnTransitionSubtype;
     mbTransitionDirection = rSrcPage.mbTransitionDirection;
@@ -403,7 +389,7 @@ SdPage::SdPage(const SdPage& rSrcPage)
     maSoundFile          = rSrcPage.maSoundFile;
     mbLoopSound          = rSrcPage.mbLoopSound;
     mbStopSound          = rSrcPage.mbStopSound;
-    maCreatedPageName    = "";
+    maCreatedPageName.clear();
     maFileName           = rSrcPage.maFileName;
     maBookmarkName       = rSrcPage.maBookmarkName;
     mbScaleObjects       = rSrcPage.mbScaleObjects;
@@ -412,13 +398,27 @@ SdPage::SdPage(const SdPage& rSrcPage)
     mnPaperBin           = rSrcPage.mnPaperBin;
     meOrientation        = rSrcPage.meOrientation;
 
-    // header footer
-    setHeaderFooterSettings( rSrcPage.getHeaderFooterSettings() );
+    mpPageLink           = nullptr;    // is set when inserting via ConnectLink()
 
-    mpPageLink           = NULL;    // is set when inserting via ConnectLink()
+    mbIsPrecious         = false;
 }
 
+void SdPage::lateInit(const SdPage& rSrcPage)
+{
+    FmFormPage::lateInit(rSrcPage);
 
+    // use shape list directly to preserve constness of rSrcPage
+    const std::list< SdrObject* >& rShapeList = rSrcPage.maPresentationShapeList.getList();
+    for( std::list< SdrObject* >::const_iterator aIter = rShapeList.begin();
+         aIter != rShapeList.end(); ++aIter )
+    {
+        SdrObject* pObj = *aIter;
+        InsertPresObj(GetObj(pObj->GetOrdNum()), rSrcPage.GetPresObjKind(pObj));
+    }
+
+    // header footer
+    setHeaderFooterSettings( rSrcPage.getHeaderFooterSettings() );
+}
 
 /*************************************************************************
 |*
@@ -428,15 +428,16 @@ SdPage::SdPage(const SdPage& rSrcPage)
 
 SdrPage* SdPage::Clone() const
 {
-    return Clone(NULL);
+    return Clone(nullptr);
 }
 
 SdrPage* SdPage::Clone(SdrModel* pNewModel) const
 {
-    DBG_ASSERT( pNewModel == 0, "sd::SdPage::Clone(), new page ignored, please check code! CL" );
+    DBG_ASSERT( pNewModel == nullptr, "sd::SdPage::Clone(), new page ignored, please check code! CL" );
     (void)pNewModel;
 
     SdPage* pNewPage = new SdPage(*this);
+    pNewPage->lateInit( *this );
 
     cloneAnimations( *pNewPage );
 
@@ -462,13 +463,12 @@ SdrPage* SdPage::Clone(SdrModel* pNewModel) const
 |*
 \************************************************************************/
 
-
 SfxStyleSheet* SdPage::GetTextStyleSheetForObject( SdrObject* pObj ) const
 {
-    const PresObjKind eKind = ((SdPage*)this)->GetPresObjKind(pObj);
+    const PresObjKind eKind = GetPresObjKind(pObj);
     if( eKind != PRESOBJ_NONE )
     {
-        return ((SdPage*)this)->GetStyleSheetForPresObj(eKind);
+        return GetStyleSheetForPresObj(eKind);
     }
 
     return FmFormPage::GetTextStyleSheetForObject( pObj );
@@ -476,14 +476,13 @@ SfxStyleSheet* SdPage::GetTextStyleSheetForObject( SdrObject* pObj ) const
 
 SfxItemSet* SdPage::getOrCreateItems()
 {
-    if( mpItems == NULL )
+    if( mpItems == nullptr )
         mpItems = new SfxItemSet( pModel->GetItemPool(), SDRATTR_XMLATTRIBUTES, SDRATTR_XMLATTRIBUTES );
 
     return mpItems;
 }
 
-
-sal_Bool SdPage::setAlienAttributes( const com::sun::star::uno::Any& rAttributes )
+bool SdPage::setAlienAttributes( const css::uno::Any& rAttributes )
 {
     SfxItemSet* pSet = getOrCreateItems();
 
@@ -491,24 +490,24 @@ sal_Bool SdPage::setAlienAttributes( const com::sun::star::uno::Any& rAttributes
     if( aAlienAttributes.PutValue( rAttributes, 0 ) )
     {
         pSet->Put( aAlienAttributes );
-        return sal_True;
+        return true;
     }
 
-    return sal_False;
+    return false;
 }
 
-void SdPage::getAlienAttributes( com::sun::star::uno::Any& rAttributes )
+void SdPage::getAlienAttributes( css::uno::Any& rAttributes )
 {
     const SfxPoolItem* pItem;
 
-    if( (mpItems == NULL) || ( SFX_ITEM_SET != mpItems->GetItemState( SDRATTR_XMLATTRIBUTES, sal_False, &pItem ) ) )
+    if( (mpItems == nullptr) || ( SfxItemState::SET != mpItems->GetItemState( SDRATTR_XMLATTRIBUTES, false, &pItem ) ) )
     {
         SvXMLAttrContainerItem aAlienAttributes;
-        aAlienAttributes.QueryValue( rAttributes, 0 );
+        aAlienAttributes.QueryValue( rAttributes );
     }
     else
     {
-        ((SvXMLAttrContainerItem*)pItem)->QueryValue( rAttributes, 0 );
+        static_cast<const SvXMLAttrContainerItem*>(pItem)->QueryValue( rAttributes );
     }
 }
 
@@ -528,67 +527,62 @@ void SdPage::RemoveEmptyPresentationObjects()
     }
 }
 
-sal_Int16 SdPage::getTransitionType (void) const
-{
-    return mnTransitionType;
-}
-
 void SdPage::setTransitionType( sal_Int16 nTransitionType )
 {
     mnTransitionType = nTransitionType;
     ActionChanged();
 }
 
-sal_Int16 SdPage::getTransitionSubtype (void) const
-{
-    return mnTransitionSubtype;
-}
-
 void SdPage::setTransitionSubtype ( sal_Int16 nTransitionSubtype )
 {
     mnTransitionSubtype = nTransitionSubtype;
     ActionChanged();
 }
 
-sal_Bool SdPage::getTransitionDirection (void) const
-{
-    return mbTransitionDirection;
-}
-
-void SdPage::setTransitionDirection ( sal_Bool bTransitionbDirection )
+void SdPage::setTransitionDirection ( bool bTransitionbDirection )
 {
     mbTransitionDirection = bTransitionbDirection;
     ActionChanged();
 }
 
-sal_Int32 SdPage::getTransitionFadeColor (void) const
-{
-    return mnTransitionFadeColor;
-}
-
 void SdPage::setTransitionFadeColor ( sal_Int32 nTransitionFadeColor )
 {
     mnTransitionFadeColor = nTransitionFadeColor;
     ActionChanged();
 }
 
-double SdPage::getTransitionDuration (void) const
-{
-    return mfTransitionDuration;
-}
-
 void SdPage::setTransitionDuration ( double fTranstionDuration )
 {
     mfTransitionDuration = fTranstionDuration;
     ActionChanged();
 }
 
-namespace sd {
-extern void createAnnotation( Reference< XAnnotation >& xAnnotation, SdPage* pPage );
-extern SdrUndoAction* CreateUndoInsertOrRemoveAnnotation( const Reference< XAnnotation >& xAnnotation, bool bInsert );
+OString SdPage::stringify() const
+{
+    OStringBuffer aString(100);
+    aString.append((sal_Int32)mePageKind).append((sal_Int32)meAutoLayout).append((sal_Int32)mePresChange).append(mfTime).append(mbSoundOn).append(mbExcluded).
+             append(OUStringToOString( maLayoutName, RTL_TEXTENCODING_UTF8 )).
+             append(OUStringToOString(maSoundFile, RTL_TEXTENCODING_UTF8 )).
+             append(mbLoopSound).append(mbStopSound).
+             /*append(OUStringToOString(maCreatedPageName, RTL_TEXTENCODING_UTF8)).
+             append(OUStringToOString(maFileName, RTL_TEXTENCODING_UTF8)).*/
+             append(OUStringToOString(maBookmarkName, RTL_TEXTENCODING_UTF8)).
+             append(mbScaleObjects).append(mbBackgroundFullSize).append((sal_Int32)meCharSet).append((sal_Int32)mnPaperBin).
+             append((sal_Int32)meOrientation).append((sal_Int32)mnTransitionType).append((sal_Int32)mnTransitionSubtype).append(mbTransitionDirection).
+             append(mnTransitionFadeColor).append(mfTransitionDuration);//.append(mbIsPrecious);
+
+    const size_t n = GetObjCount();
+    for(size_t i = 0; i < n; ++i)
+        aString.append(GetObj(i)->stringify());
+    return aString.makeStringAndClear();
 }
 
-void SdPage::createAnnotation( ::com::sun::star::uno::Reference< ::com::sun::star::office::XAnnotation >& xAnnotation )
+sal_Int32 SdPage::getHash() const
+{
+    return stringify().hashCode();
+}
+
+void SdPage::createAnnotation( css::uno::Reference< css::office::XAnnotation >& xAnnotation )
 {
     sd::createAnnotation( xAnnotation, this );
 }
@@ -640,4 +634,29 @@ void SdPage::removeAnnotation( const Reference< XAnnotation >& xAnnotation )
     }
 }
 
+void SdPage::dumpAsXml(xmlTextWriterPtr pWriter) const
+{
+    xmlTextWriterStartElement(pWriter, BAD_CAST("sdPage"));
+
+    const char* pPageKind = nullptr;
+    switch (mePageKind)
+    {
+    case PK_STANDARD:
+        pPageKind = "PK_STANDARD";
+    break;
+    case PK_NOTES:
+        pPageKind = "PK_NOTES";
+        break;
+    case PK_HANDOUT:
+        pPageKind = "PK_HANDOUT";
+        break;
+    }
+    if (pPageKind)
+        xmlTextWriterWriteAttribute(pWriter, BAD_CAST("mePageKind"), BAD_CAST(pPageKind));
+
+
+    FmFormPage::dumpAsXml(pWriter);
+    xmlTextWriterEndElement(pWriter);
+}
+
 /* vim:set shiftwidth=4 softtabstop=4 expandtab: */
