@@ -57,6 +57,7 @@
 #include <rtl/ustrbuf.hxx>
 
 #include <vcl/vclenum.hxx>
+#include <oox/ppt/pptfilterhelpers.hxx>
 #include <svx/svdotext.hxx>
 #include <editeng/outlobj.hxx>
 #include <editeng/editobj.hxx>
@@ -95,7 +96,7 @@ void ImplTranslateAttribute( OUString& rString, const TranslateMode eTranslateMo
     {
         if ( ( eTranslateMode & TRANSLATE_VALUE ) || ( eTranslateMode & TRANSLATE_ATTRIBUTE ) )
         {
-            const ImplAttributeNameConversion* p = gImplConversionList;
+            const oox::ppt::ImplAttributeNameConversion* p = oox::ppt::getAttributeConversionList();
             while( p->mpAPIName )
             {
                 if( rString.equalsAscii( p->mpAPIName ) )
@@ -106,7 +107,7 @@ void ImplTranslateAttribute( OUString& rString, const TranslateMode eTranslateMo
             {
                 if ( eTranslateMode & TRANSLATE_VALUE )
                 {
-                    rString = OUString( (sal_Unicode)'#' );
+                    rString = "#";
                     rString += OUString::createFromAscii( p->mpMSName );
                 }
                 else
@@ -115,8 +116,8 @@ void ImplTranslateAttribute( OUString& rString, const TranslateMode eTranslateMo
         }
         else if ( eTranslateMode & TRANSLATE_MEASURE )
         {
-            const sal_Char* pDest[] = { "#ppt_x", "#ppt_y", "#ppt_w", "#ppt_h", NULL };
-            const sal_Char* pSource[] = { "x", "y", "width", "height", NULL };
+            const sal_Char* pDest[] = { "#ppt_x", "#ppt_y", "#ppt_w", "#ppt_h", nullptr };
+            const sal_Char* pSource[] = { "x", "y", "width", "height", nullptr };
             sal_Int32 nIndex = 0;
 
             const sal_Char** ps = pSource;
@@ -150,7 +151,7 @@ sal_uInt32 AnimationExporter::TranslatePresetSubType( const sal_uInt32 nPresetCl
     sal_uInt32  nPresetSubType = 0;
     bool    bTranslated = false;
 
-    if ( ( nPresetClass == (sal_uInt32)EffectPresetClass::ENTRANCE ) || ( nPresetClass == (sal_uInt32)EffectPresetClass::EXIT ) )
+    if ( ( nPresetClass == sal_uInt32(EffectPresetClass::ENTRANCE) ) || ( nPresetClass == sal_uInt32(EffectPresetClass::EXIT) ) )
     {
         if ( nPresetId != 21 )
         {
@@ -207,7 +208,7 @@ sal_uInt32 AnimationExporter::TranslatePresetSubType( const sal_uInt32 nPresetCl
         }
         if ( !bTranslated )
         {
-            const convert_subtype* p = gConvertArray;
+            const oox::ppt::convert_subtype* p = oox::ppt::convert_subtype::getList();
             while( p->mpStrSubType )
             {
                 if ( rPresetSubType.equalsAscii( p->mpStrSubType ) )
@@ -227,10 +228,10 @@ sal_uInt32 AnimationExporter::TranslatePresetSubType( const sal_uInt32 nPresetCl
 
 const sal_Char* AnimationExporter::FindTransitionName( const sal_Int16 nType, const sal_Int16 nSubType, const bool bDirection )
 {
-    const sal_Char* pRet = NULL;
+    const sal_Char* pRet = nullptr;
     int             nFit = 0;
 
-    const transition* p = gTransitions;
+    const oox::ppt::transition* p = oox::ppt::transition::getList();
     while( p->mpName )
     {
         int nF = 0;
@@ -341,7 +342,7 @@ void AnimationExporter::doexport( const Reference< XDrawPage >& xPage, SvStream&
         if( xRootNode.is() )
         {
             processAfterEffectNodes( xRootNode );
-            exportNode( rStrm, xRootNode, NULL, DFF_msofbtAnimGroup, 1, 0, false, AnimationFill::AUTO );
+            exportNode( rStrm, xRootNode, nullptr, DFF_msofbtAnimGroup, 1, 0, false, AnimationFill::AUTO );
         }
     }
 }
@@ -508,7 +509,7 @@ void AnimationExporter::exportNode( SvStream& rStrm, Reference< XAnimationNode >
             {
                 exportAnimNode( rStrm, xNode, pParent, nGroupLevel, nFillDefault );
                 exportAnimPropertySet( rStrm, xNode );
-                exportAnimEvent( rStrm, xNode, 0 );
+                exportAnimEvent( rStrm, xNode );
                 exportAnimValue( rStrm, xNode, false );
             }
             break;
@@ -530,7 +531,7 @@ void AnimationExporter::exportNode( SvStream& rStrm, Reference< XAnimationNode >
                 exportAnimNode( rStrm, xNode, pParent, nGroupLevel, nFillDefault );
                 sal_Int16 nNodeType = exportAnimPropertySet( rStrm, xNode );
                 sal_Int32 nFlags = 12;
-                if ( ( nGroupLevel == 1 ) && ( nNodeType == ::com::sun::star::presentation::EffectNodeType::INTERACTIVE_SEQUENCE ) )
+                if ( ( nGroupLevel == 1 ) && ( nNodeType == css::presentation::EffectNodeType::INTERACTIVE_SEQUENCE ) )
                 {
                     nFlags |= 0x20;
                     bTakeBackInteractiveSequenceTimingForChild = true;
@@ -572,7 +573,7 @@ void AnimationExporter::exportNode( SvStream& rStrm, Reference< XAnimationNode >
                 }
                 exportIterate( rStrm, xNode );
                 exportAnimPropertySet( rStrm, xNode );
-                exportAnimEvent( rStrm, xNode, 0 );
+                exportAnimEvent( rStrm, xNode );
                 exportAnimValue( rStrm, xNode, false );
             }
             break;
@@ -581,7 +582,7 @@ void AnimationExporter::exportNode( SvStream& rStrm, Reference< XAnimationNode >
             {
                 exportAnimNode( rStrm, xNode, pParent, nGroupLevel, nFillDefault );
                 exportAnimPropertySet( rStrm, xNode );
-                exportAnimEvent( rStrm, xNode, 0 );
+                exportAnimEvent( rStrm, xNode );
                 exportAnimValue( rStrm, xNode, false );
                 exportAnimate( rStrm, xNode );
             }
@@ -595,7 +596,7 @@ void AnimationExporter::exportNode( SvStream& rStrm, Reference< XAnimationNode >
                     exportAnimNode( rStrm, xNode, pParent, nGroupLevel, nFillDefault );
                     exportAnimPropertySet( rStrm, xNode );
                     exportAnimateSet( rStrm, xNode, bIsAfterEffectNode ? AFTEREFFECT_SET : AFTEREFFECT_NONE );
-                    exportAnimEvent( rStrm, xNode, 0 );
+                    exportAnimEvent( rStrm, xNode );
                     exportAnimValue( rStrm, xNode, false );
                 }
                 else
@@ -610,7 +611,7 @@ void AnimationExporter::exportNode( SvStream& rStrm, Reference< XAnimationNode >
                 exportAnimNode( rStrm, xNode, pParent, nGroupLevel, nFillDefault );
                 exportAnimPropertySet( rStrm, xNode );
                 exportAnimateMotion( rStrm, xNode );
-                exportAnimEvent( rStrm, xNode, 0 );
+                exportAnimEvent( rStrm, xNode );
                 exportAnimValue( rStrm, xNode, false );
             }
             break;
@@ -626,7 +627,7 @@ void AnimationExporter::exportNode( SvStream& rStrm, Reference< XAnimationNode >
                     exportAnimNode( rStrm, xNode, pParent, nGroupLevel, nFillDefault );
                     exportAnimPropertySet( rStrm, xNode );
                     exportAnimateColor( rStrm, xNode, bIsAfterEffectNode ? AFTEREFFECT_COLOR : AFTEREFFECT_NONE );
-                    exportAnimEvent( rStrm, xNode, 0 );
+                    exportAnimEvent( rStrm, xNode );
                     exportAnimValue( rStrm, xNode, false );
                 }
                 else
@@ -641,7 +642,7 @@ void AnimationExporter::exportNode( SvStream& rStrm, Reference< XAnimationNode >
                 exportAnimNode( rStrm, xNode, pParent, nGroupLevel, nFillDefault );
                 exportAnimPropertySet( rStrm, xNode );
                 exportAnimateTransform( rStrm, xNode );
-                exportAnimEvent( rStrm, xNode, 0 );
+                exportAnimEvent( rStrm, xNode );
                 exportAnimValue( rStrm, xNode, false );
             }
             break;
@@ -650,7 +651,7 @@ void AnimationExporter::exportNode( SvStream& rStrm, Reference< XAnimationNode >
             {
                 exportAnimNode( rStrm, xNode, pParent, nGroupLevel, nFillDefault );
                 exportAnimPropertySet( rStrm, xNode );
-                exportAnimEvent( rStrm, xNode, 0 );
+                exportAnimEvent( rStrm, xNode );
                 exportAnimValue( rStrm, xNode, false );
                 exportTransitionFilter( rStrm, xNode );
             }
@@ -747,11 +748,11 @@ void AnimationExporter::exportNode( SvStream& rStrm, Reference< XAnimationNode >
         aTarget = Any();
 }
 
-Reference< XAnimationNode > AnimationExporter::createAfterEffectNodeClone( const Reference< XAnimationNode >& xNode ) const
+Reference< XAnimationNode > AnimationExporter::createAfterEffectNodeClone( const Reference< XAnimationNode >& xNode )
 {
     try
     {
-        Reference< ::com::sun::star::util::XCloneable > xClonable( xNode, UNO_QUERY_THROW );
+        Reference< css::util::XCloneable > xClonable( xNode, UNO_QUERY_THROW );
         Reference< XAnimationNode > xCloneNode( xClonable->createClone(), UNO_QUERY_THROW );
 
         Any aEmpty;
@@ -788,7 +789,7 @@ bool AnimationExporter::GetNodeType( const Reference< XAnimationNode >& xNode, s
 }
 
 void AnimationExporter::exportAnimNode( SvStream& rStrm, const Reference< XAnimationNode >& xNode,
-        const ::com::sun::star::uno::Reference< ::com::sun::star::animations::XAnimationNode >*, const sal_Int32, const sal_Int16 nFillDefault )
+        const css::uno::Reference< css::animations::XAnimationNode >*, const sal_Int32, const sal_Int16 nFillDefault )
 {
     EscherExAtom    aAnimNodeExAtom( rStrm, DFF_msofbtAnimNode );
     AnimationNode   aAnim;
@@ -815,7 +816,7 @@ void AnimationExporter::exportAnimNode( SvStream& rStrm, const Reference< XAnima
     }
     // attribute Duration
     double fDuration = 0.0;
-    com::sun::star::animations::Timing eTiming;
+    css::animations::Timing eTiming;
     if ( xNode->getDuration() >>= eTiming )
     {
         if ( eTiming == Timing_INDEFINITE )
@@ -842,8 +843,8 @@ void AnimationExporter::exportAnimNode( SvStream& rStrm, const Reference< XAnima
             if( GetNodeType( xNode, nType ) )
             switch( nType )
             {
-                case ::com::sun::star::presentation::EffectNodeType::TIMING_ROOT : aAnim.mnNodeType = 0x12; break;
-                case ::com::sun::star::presentation::EffectNodeType::MAIN_SEQUENCE : aAnim.mnNodeType = 0x18; break;
+                case css::presentation::EffectNodeType::TIMING_ROOT : aAnim.mnNodeType = 0x12; break;
+                case css::presentation::EffectNodeType::MAIN_SEQUENCE : aAnim.mnNodeType = 0x18; break;
             }
         }
         break;
@@ -920,7 +921,7 @@ sal_uInt32 AnimationExporter::GetPresetID( const OUString& rPreset, sal_uInt32 n
     sal_uInt32 nPresetId = 0;
     bPresetId = false;
 
-    if ( rPreset.match( OUString( "ppt_" ), 0 ) )
+    if ( rPreset.match("ppt_", 0) )
     {
     sal_Int32 nLast = rPreset.lastIndexOf( '_' );
     if ( ( nLast != -1 ) && ( ( nLast + 1 ) < rPreset.getLength() ) )
@@ -932,7 +933,7 @@ sal_uInt32 AnimationExporter::GetPresetID( const OUString& rPreset, sal_uInt32 n
     }
     else
     {
-    const preset_maping* p = gPresetMaping;
+        const oox::ppt::preset_maping* p = oox::ppt::preset_maping::getList();
     while( p->mpStrPresetId && ((p->mnPresetClass != (sal_Int32)nAPIPresetClass) || !rPreset.equalsAscii( p->mpStrPresetId )) )
         p++;
 
@@ -948,7 +949,7 @@ sal_uInt32 AnimationExporter::GetPresetID( const OUString& rPreset, sal_uInt32 n
 
 sal_Int16 AnimationExporter::exportAnimPropertySet( SvStream& rStrm, const Reference< XAnimationNode >& xNode )
 {
-    sal_Int16 nNodeType = ::com::sun::star::presentation::EffectNodeType::DEFAULT;
+    sal_Int16 nNodeType = css::presentation::EffectNodeType::DEFAULT;
 
     EscherExContainer aAnimPropertySet( rStrm, DFF_msofbtAnimPropertySet );
 
@@ -958,7 +959,7 @@ sal_Int16 AnimationExporter::exportAnimPropertySet( SvStream& rStrm, const Refer
 
     // storing user data into pAny, to allow direct access later
     const Sequence< NamedValue > aUserData = xNode->getUserData();
-    const ::com::sun::star::uno::Any* pAny[ DFF_ANIM_PROPERTY_ID_COUNT ];
+    const css::uno::Any* pAny[ DFF_ANIM_PROPERTY_ID_COUNT ];
     GetUserData( aUserData, pAny, sizeof( pAny ) );
 
     if( pAny[ DFF_ANIM_AFTEREFFECT ] )
@@ -990,12 +991,12 @@ sal_Int16 AnimationExporter::exportAnimPropertySet( SvStream& rStrm, const Refer
             sal_uInt32 nPPTNodeType = DFF_ANIM_NODE_TYPE_ON_CLICK;
             switch( nNodeType )
             {
-                case ::com::sun::star::presentation::EffectNodeType::ON_CLICK : nPPTNodeType = DFF_ANIM_NODE_TYPE_ON_CLICK; break;
-                case ::com::sun::star::presentation::EffectNodeType::WITH_PREVIOUS : nPPTNodeType = DFF_ANIM_NODE_TYPE_WITH_PREVIOUS; break;
-                case ::com::sun::star::presentation::EffectNodeType::AFTER_PREVIOUS : nPPTNodeType = DFF_ANIM_NODE_TYPE_AFTER_PREVIOUS; break;
-                case ::com::sun::star::presentation::EffectNodeType::MAIN_SEQUENCE : nPPTNodeType = DFF_ANIM_NODE_TYPE_MAIN_SEQUENCE; break;
-                case ::com::sun::star::presentation::EffectNodeType::TIMING_ROOT : nPPTNodeType = DFF_ANIM_NODE_TYPE_TIMING_ROOT; break;
-                case ::com::sun::star::presentation::EffectNodeType::INTERACTIVE_SEQUENCE: nPPTNodeType = DFF_ANIM_NODE_TYPE_INTERACTIVE_SEQ; break;
+                case css::presentation::EffectNodeType::ON_CLICK : nPPTNodeType = DFF_ANIM_NODE_TYPE_ON_CLICK; break;
+                case css::presentation::EffectNodeType::WITH_PREVIOUS : nPPTNodeType = DFF_ANIM_NODE_TYPE_WITH_PREVIOUS; break;
+                case css::presentation::EffectNodeType::AFTER_PREVIOUS : nPPTNodeType = DFF_ANIM_NODE_TYPE_AFTER_PREVIOUS; break;
+                case css::presentation::EffectNodeType::MAIN_SEQUENCE : nPPTNodeType = DFF_ANIM_NODE_TYPE_MAIN_SEQUENCE; break;
+                case css::presentation::EffectNodeType::TIMING_ROOT : nPPTNodeType = DFF_ANIM_NODE_TYPE_TIMING_ROOT; break;
+                case css::presentation::EffectNodeType::INTERACTIVE_SEQUENCE: nPPTNodeType = DFF_ANIM_NODE_TYPE_INTERACTIVE_SEQ; break;
             }
             exportAnimPropertyuInt32( rStrm, DFF_ANIM_NODE_TYPE, nPPTNodeType, TRANSLATE_NONE );
         }
@@ -1059,7 +1060,7 @@ sal_Int16 AnimationExporter::exportAnimPropertySet( SvStream& rStrm, const Refer
     {
         bool bAfterEffect = false;
         if ( *pAny[ DFF_ANIM_AFTEREFFECT ] >>= bAfterEffect )
-            exportAnimPropertyByte( rStrm, DFF_ANIM_AFTEREFFECT, bAfterEffect, TRANSLATE_NONE );
+            exportAnimPropertyByte( rStrm, DFF_ANIM_AFTEREFFECT, int(bAfterEffect), TRANSLATE_NONE );
     }
 
     if ( pAny[ DFF_ANIM_RUNTIMECONTEXT ] )
@@ -1123,17 +1124,17 @@ sal_Int16 AnimationExporter::exportAnimPropertySet( SvStream& rStrm, const Refer
     return nNodeType;
 }
 
-bool AnimationExporter::exportAnimProperty( SvStream& rStrm, const sal_uInt16 nPropertyId, const ::com::sun::star::uno::Any& rAny, const TranslateMode eTranslateMode )
+bool AnimationExporter::exportAnimProperty( SvStream& rStrm, const sal_uInt16 nPropertyId, const css::uno::Any& rAny, const TranslateMode eTranslateMode )
 {
     bool bRet = false;
     if ( rAny.hasValue() )
     {
         switch( rAny.getValueType().getTypeClass() )
         {
-            case ::com::sun::star::uno::TypeClass_UNSIGNED_SHORT :
-            case ::com::sun::star::uno::TypeClass_SHORT :
-            case ::com::sun::star::uno::TypeClass_UNSIGNED_LONG :
-            case ::com::sun::star::uno::TypeClass_LONG :
+            case css::uno::TypeClass_UNSIGNED_SHORT :
+            case css::uno::TypeClass_SHORT :
+            case css::uno::TypeClass_UNSIGNED_LONG :
+            case css::uno::TypeClass_LONG :
             {
                 sal_Int32 nVal = 0;
                 if ( rAny >>= nVal )
@@ -1144,7 +1145,7 @@ bool AnimationExporter::exportAnimProperty( SvStream& rStrm, const sal_uInt16 nP
             }
             break;
 
-            case ::com::sun::star::uno::TypeClass_DOUBLE :
+            case css::uno::TypeClass_DOUBLE :
             {
                 double fVal = 0.0;
                 if ( rAny >>= fVal )
@@ -1154,7 +1155,7 @@ bool AnimationExporter::exportAnimProperty( SvStream& rStrm, const sal_uInt16 nP
                 }
             }
             break;
-            case ::com::sun::star::uno::TypeClass_FLOAT :
+            case css::uno::TypeClass_FLOAT :
             {
                 float fVal = 0.0;
                 if ( rAny >>= fVal )
@@ -1174,7 +1175,7 @@ bool AnimationExporter::exportAnimProperty( SvStream& rStrm, const sal_uInt16 nP
                 }
             }
             break;
-            case ::com::sun::star::uno::TypeClass_STRING :
+            case css::uno::TypeClass_STRING :
             {
                 OUString aStr;
                 if ( rAny >>= aStr )
@@ -1281,7 +1282,7 @@ void AnimationExporter::exportAnimEvent( SvStream& rStrm, const Reference< XAnim
             {
                 Any aAny;
                 Event aEvent;
-                com::sun::star::animations::Timing eTiming;
+                css::animations::Timing eTiming;
                 if ( i == 0 )
                 {
                     if ( nFlags & 0x20 )
@@ -1456,10 +1457,10 @@ Any AnimationExporter::convertAnimateValue( const Any& rSourceValue, const OUStr
     }
     else if ( rAttributeName == "FillStyle" )
     {
-        ::com::sun::star::drawing::FillStyle eFillStyle;
+        css::drawing::FillStyle eFillStyle;
         if ( rSourceValue >>= eFillStyle )
         {
-            if ( eFillStyle == ::com::sun::star::drawing::FillStyle_NONE )
+            if ( eFillStyle == css::drawing::FillStyle_NONE )
                 aDest += "none";    // ?
             else
                 aDest += "solid";
@@ -1467,10 +1468,10 @@ Any AnimationExporter::convertAnimateValue( const Any& rSourceValue, const OUStr
     }
     else if ( rAttributeName == "LineStyle" )
     {
-        ::com::sun::star::drawing::LineStyle eLineStyle;
+        css::drawing::LineStyle eLineStyle;
         if ( rSourceValue >>= eLineStyle )
         {
-            if ( eLineStyle == ::com::sun::star::drawing::LineStyle_NONE )
+            if ( eLineStyle == css::drawing::LineStyle_NONE )
                 aDest += "false";
             else
                 aDest += "true";
@@ -1481,7 +1482,7 @@ Any AnimationExporter::convertAnimateValue( const Any& rSourceValue, const OUStr
         float fFontWeight = 0.0;
         if ( rSourceValue >>= fFontWeight )
         {
-            if ( fFontWeight == com::sun::star::awt::FontWeight::BOLD )
+            if ( fFontWeight == css::awt::FontWeight::BOLD )
                 aDest += "bold";
             else
                 aDest += "normal";
@@ -1492,7 +1493,7 @@ Any AnimationExporter::convertAnimateValue( const Any& rSourceValue, const OUStr
         sal_Int16 nFontUnderline = 0;
         if ( rSourceValue >>= nFontUnderline )
         {
-            if ( nFontUnderline == com::sun::star::awt::FontUnderline::NONE )
+            if ( nFontUnderline == css::awt::FontUnderline::NONE )
                 aDest += "false";
             else
                 aDest += "true";
@@ -1500,10 +1501,10 @@ Any AnimationExporter::convertAnimateValue( const Any& rSourceValue, const OUStr
     }
     else if ( rAttributeName == "CharPosture" )
     {
-        ::com::sun::star::awt::FontSlant eFontSlant;
+        css::awt::FontSlant eFontSlant;
         if ( rSourceValue >>= eFontSlant )
         {
-            if ( eFontSlant == com::sun::star::awt::FontSlant_ITALIC )
+            if ( eFontSlant == css::awt::FontSlant_ITALIC )
                 aDest += "italic";
             else
                 aDest += "normal";  // ?
@@ -1582,7 +1583,7 @@ sal_uInt32 AnimationExporter::GetValueTypeForAttributeName( const OUString& rAtt
         { "width", 1 },
         { "x", 1 },
         { "y", 1 },
-        { NULL, 0 }
+        { nullptr, 0 }
     };
     const Entry* pPtr = &lcl_attributeMap[ 0 ];
     while( pPtr->pName )
@@ -1767,14 +1768,14 @@ Reference< XShape > AnimationExporter::getTargetElementShape( const Any& rAny, s
     return xShape;
 }
 
-void AnimationExporter::exportAnimateTargetElement( SvStream& rStrm, const Any aAny, const bool bCreate2b01Atom )
+void AnimationExporter::exportAnimateTargetElement( SvStream& rStrm, const Any& rAny, const bool bCreate2b01Atom )
 {
     sal_uInt32 nRefMode = 0;    // nRefMode == 2 -> Paragraph
     sal_Int32 begin = -1;
     sal_Int32 end = -1;
     bool bParagraphTarget;
 
-    Reference< XShape > xShape = getTargetElementShape( aAny, begin, end, bParagraphTarget );
+    Reference< XShape > xShape = getTargetElementShape(rAny, begin, end, bParagraphTarget);
 
     if( bParagraphTarget )
         nRefMode = 2;
@@ -1850,7 +1851,7 @@ void AnimationExporter::exportAnimValue( SvStream& rStrm, const Reference< XAnim
     // repeat count (0)
     double fRepeat = 0.0;
     float fRepeatCount = 0.0;
-    com::sun::star::animations::Timing eTiming;
+    css::animations::Timing eTiming;
     aAny = xNode->getRepeatCount();
     if ( aAny >>= eTiming )
     {
@@ -2045,7 +2046,7 @@ void AnimationExporter::exportAnimateTransform( SvStream& rStrm, const Reference
     }
 }
 
-bool AnimationExporter::getColorAny( const Any& rAny, const sal_Int16 nColorSpace, sal_Int32& rMode, sal_Int32& rA, sal_Int32& rB, sal_Int32& rC ) const
+bool AnimationExporter::getColorAny( const Any& rAny, const sal_Int16 nColorSpace, sal_Int32& rMode, sal_Int32& rA, sal_Int32& rB, sal_Int32& rC )
 {
     bool bIsColor = true;
 
