@@ -76,12 +76,12 @@
 #include "drawdoc.hxx"
 #include "app.hrc"
 
-#include <algorithm>
-
 #include <basegfx/polygon/b2dpolypolygontools.hxx>
 #include <basegfx/matrix/b2dhommatrix.hxx>
 #include <basegfx/range/b2drange.hxx>
-#include <boost/scoped_ptr.hpp>
+
+#include <algorithm>
+#include <memory>
 
 using namespace ::com::sun::star;
 using namespace ::com::sun::star::animations;
@@ -113,19 +113,19 @@ void fillDurationComboBox( ListBox* pBox )
     static const double gdVeryFast = 0.5;
 
     OUString aVerySlow( SD_RESSTR( STR_CUSTOMANIMATION_DURATION_VERY_SLOW ) );
-    pBox->SetEntryData( pBox->InsertEntry( aVerySlow ), (void*)&gdVerySlow );
+    pBox->SetEntryData( pBox->InsertEntry( aVerySlow ), const_cast<double *>(&gdVerySlow) );
 
     OUString aSlow( SD_RESSTR( STR_CUSTOMANIMATION_DURATION_SLOW ) );
-    pBox->SetEntryData( pBox->InsertEntry( aSlow ), (void*)&gdSlow );
+    pBox->SetEntryData( pBox->InsertEntry( aSlow ), const_cast<double *>(&gdSlow) );
 
     OUString aNormal( SD_RESSTR( STR_CUSTOMANIMATION_DURATION_NORMAL ) );
-    pBox->SetEntryData( pBox->InsertEntry( aNormal ), (void*)&gdNormal );
+    pBox->SetEntryData( pBox->InsertEntry( aNormal ), const_cast<double *>(&gdNormal) );
 
     OUString aFast( SD_RESSTR( STR_CUSTOMANIMATION_DURATION_FAST ) );
-    pBox->SetEntryData( pBox->InsertEntry( aFast ), (void*)&gdFast );
+    pBox->SetEntryData( pBox->InsertEntry( aFast ), const_cast<double *>(&gdFast) );
 
     OUString aVeryFast( SD_RESSTR( STR_CUSTOMANIMATION_DURATION_VERY_FAST ) );
-    pBox->SetEntryData( pBox->InsertEntry( aVeryFast ), (void*)&gdVeryFast );
+    pBox->SetEntryData( pBox->InsertEntry( aVeryFast ), const_cast<double *>(&gdVeryFast) );
 }
 
 void fillRepeatComboBox( ListBox* pBox )
@@ -150,7 +150,7 @@ CustomAnimationPane::CustomAnimationPane( Window* pParent, ViewShellBase& rBase,
                                           const Size& rMinSize )
 :   PanelLayout( pParent, "CustomAnimationsPanel", "modules/simpress/ui/customanimationspanel.ui", rxFrame ),
     mrBase( rBase ),
-    mpCustomAnimationPresets(NULL),
+    mpCustomAnimationPresets(nullptr),
     mnPropertyType( nPropertyTypeNone ),
     maMinSize( rMinSize ),
     mxModel( rBase.GetDocShell()->GetDoc()->getUnoModel(), UNO_QUERY ),
@@ -187,23 +187,23 @@ CustomAnimationPane::CustomAnimationPane( Window* pParent, ViewShellBase& rBase,
 
     fillDurationComboBox( mpCBSpeed );
 
-    mpPBAddEffect->SetClickHdl( LINK( this, CustomAnimationPane, implControlHdl ) );
-    mpPBChangeEffect->SetClickHdl( LINK( this, CustomAnimationPane, implControlHdl ) );
-    mpPBRemoveEffect->SetClickHdl( LINK( this, CustomAnimationPane, implControlHdl ) );
-    mpLBStart->SetSelectHdl( LINK( this, CustomAnimationPane, implControlHdl ) );
-    mpCBSpeed->SetSelectHdl( LINK( this, CustomAnimationPane, implControlHdl ) );
-    mpPBPropertyMore->SetClickHdl( LINK( this, CustomAnimationPane, implControlHdl ) );
-    mpPBMoveUp->SetClickHdl( LINK( this, CustomAnimationPane, implControlHdl ) );
-    mpPBMoveDown->SetClickHdl( LINK( this, CustomAnimationPane, implControlHdl ) );
-    mpPBPlay->SetClickHdl( LINK( this, CustomAnimationPane, implControlHdl ) );
-    mpCBAutoPreview->SetClickHdl( LINK( this, CustomAnimationPane, implControlHdl ) );
+    mpPBAddEffect->SetClickHdl( LINK( this, CustomAnimationPane, implClickHdl ) );
+    mpPBChangeEffect->SetClickHdl( LINK( this, CustomAnimationPane, implClickHdl ) );
+    mpPBRemoveEffect->SetClickHdl( LINK( this, CustomAnimationPane, implClickHdl ) );
+    mpLBStart->SetSelectHdl( LINK( this, CustomAnimationPane, implControlListBoxHdl ) );
+    mpCBSpeed->SetSelectHdl( LINK( this, CustomAnimationPane, implControlListBoxHdl ) );
+    mpPBPropertyMore->SetClickHdl( LINK( this, CustomAnimationPane, implClickHdl ) );
+    mpPBMoveUp->SetClickHdl( LINK( this, CustomAnimationPane, implClickHdl ) );
+    mpPBMoveDown->SetClickHdl( LINK( this, CustomAnimationPane, implClickHdl ) );
+    mpPBPlay->SetClickHdl( LINK( this, CustomAnimationPane, implClickHdl ) );
+    mpCBAutoPreview->SetClickHdl( LINK( this, CustomAnimationPane, implClickHdl ) );
 
     maStrModify = mpFTEffect->GetText();
 
     // get current controller and initialize listeners
     try
     {
-        mxView = Reference< XDrawView >::query(mrBase.GetController());
+        mxView.set(mrBase.GetController(), UNO_QUERY);
         addListener();
     }
     catch( Exception& )
@@ -287,7 +287,7 @@ void CustomAnimationPane::KeyInput( const KeyEvent& rKEvt )
 
 void CustomAnimationPane::addListener()
 {
-    Link<> aLink( LINK(this,CustomAnimationPane,EventMultiplexerListener) );
+    Link<tools::EventMultiplexerEvent&,void> aLink( LINK(this,CustomAnimationPane,EventMultiplexerListener) );
     mrBase.GetEventMultiplexer()->AddEventListener (
         aLink,
         tools::EventMultiplexerEvent::EID_EDIT_VIEW_SELECTION
@@ -300,14 +300,14 @@ void CustomAnimationPane::addListener()
 
 void CustomAnimationPane::removeListener()
 {
-    Link<> aLink( LINK(this,CustomAnimationPane,EventMultiplexerListener) );
+    Link<tools::EventMultiplexerEvent&,void> aLink( LINK(this,CustomAnimationPane,EventMultiplexerListener) );
     mrBase.GetEventMultiplexer()->RemoveEventListener( aLink );
 }
 
-IMPL_LINK(CustomAnimationPane,EventMultiplexerListener,
-    tools::EventMultiplexerEvent*,pEvent)
+IMPL_LINK_TYPED(CustomAnimationPane,EventMultiplexerListener,
+    tools::EventMultiplexerEvent&, rEvent, void)
 {
-    switch (pEvent->meEventId)
+    switch (rEvent.meEventId)
     {
         case tools::EventMultiplexerEvent::EID_EDIT_VIEW_SELECTION:
             onSelectionChanged();
@@ -321,11 +321,11 @@ IMPL_LINK(CustomAnimationPane,EventMultiplexerListener,
             // At this moment the controller may not yet been set at model
             // or ViewShellBase.  Take it from the view shell passed with
             // the event.
-            if (mrBase.GetMainViewShell() != 0)
+            if (mrBase.GetMainViewShell() != nullptr)
             {
                 if( mrBase.GetMainViewShell()->GetShellType() == ViewShell::ST_IMPRESS )
                 {
-                    mxView = Reference<XDrawView>::query(mrBase.GetDrawController());
+                    mxView.set(mrBase.GetDrawController(), UNO_QUERY);
                     onSelectionChanged();
                     onChangeCurrentPage();
                     break;
@@ -333,8 +333,8 @@ IMPL_LINK(CustomAnimationPane,EventMultiplexerListener,
             }
         // fall through intended
         case tools::EventMultiplexerEvent::EID_MAIN_VIEW_REMOVED:
-            mxView = 0;
-            mxCurrentPage = 0;
+            mxView = nullptr;
+            mxCurrentPage = nullptr;
             updateControls();
             break;
 
@@ -344,11 +344,10 @@ IMPL_LINK(CustomAnimationPane,EventMultiplexerListener,
             onChangeCurrentPage();
             break;
         case tools::EventMultiplexerEvent::EID_END_TEXT_EDIT:
-            if( mpMainSequence.get() && pEvent->mpUserData )
+            if( mpMainSequence.get() && rEvent.mpUserData )
                 mpCustomAnimationList->update( mpMainSequence );
             break;
     }
-    return 0;
 }
 
 static sal_Int32 getPropertyType( const OUString& rProperty )
@@ -520,15 +519,14 @@ void CustomAnimationPane::updateControls()
 
         if( !aUIName.isEmpty() )
         {
-            aTemp += OUString( (sal_Unicode)' ' );
-            aTemp += aUIName;
+            aTemp += " " + aUIName;
             mpFTEffect->SetText( aTemp );
         }
 
         CustomAnimationPresetPtr pDescriptor = getPresets().getEffectDescriptor( pEffect->getPresetId() );
         if( pDescriptor.get() )
         {
-            PropertySubControl* pSubControl = NULL;
+            PropertySubControl* pSubControl = nullptr;
 
             Any aValue;
 
@@ -557,16 +555,16 @@ void CustomAnimationPane::updateControls()
             }
             else
             {
-                mpLBProperty->setSubControl( 0 );
+                mpLBProperty->setSubControl( nullptr );
             }
 
-            bool bEnable = (pSubControl != 0) && (pSubControl->getControl()->IsEnabled());
+            bool bEnable = (pSubControl != nullptr) && (pSubControl->getControl()->IsEnabled());
             mpLBProperty->Enable( bEnable );
             mpFTProperty->Enable( bEnable );
         }
         else
         {
-            mpLBProperty->setSubControl( 0 );
+            mpLBProperty->setSubControl( nullptr );
             mpFTProperty->Enable( false );
             mpLBProperty->Enable( false );
             mpPBPropertyMore->Enable( false );
@@ -608,11 +606,11 @@ void CustomAnimationPane::updateControls()
             mpCBSpeed->SelectEntryPos( nPos );
         }
 
-        mpPBPropertyMore->Enable( true );
+        mpPBPropertyMore->Enable();
     }
     else
     {
-        mpLBProperty->setSubControl( 0 );
+        mpLBProperty->setSubControl( nullptr );
         mpFTProperty->Enable( false );
         mpLBProperty->Enable( false );
         mpPBPropertyMore->Enable( false );
@@ -656,7 +654,7 @@ void CustomAnimationPane::updateControls()
         {
             MainSequenceRebuildGuard aGuard( mpMainSequence );
 
-            EffectSequenceHelper* pSequence = 0;
+            EffectSequenceHelper* pSequence = nullptr;
             EffectSequence::iterator aRebuildIter( maListSelection.begin() );
             const EffectSequence::iterator aRebuildEnd( maListSelection.end() );
             while( aRebuildIter != aRebuildEnd )
@@ -665,7 +663,7 @@ void CustomAnimationPane::updateControls()
 
                 if( pEffect.get() )
                 {
-                    if( pSequence == 0 )
+                    if( pSequence == nullptr )
                     {
                         pSequence = pEffect->getEffectSequence();
                     }
@@ -698,7 +696,7 @@ static bool updateMotionPathImpl( CustomAnimationPane& rPane, ::sd::View& rView,
     while( aIter != aEnd )
     {
         CustomAnimationEffectPtr pEffect( (*aIter++) );
-        if( pEffect.get() && pEffect->getPresetClass() == ::com::sun::star::presentation::EffectPresetClass::MOTIONPATH )
+        if( pEffect.get() && pEffect->getPresetClass() == css::presentation::EffectPresetClass::MOTIONPATH )
         {
             rtl::Reference< MotionPathTag > xMotionPathTag;
             // first try to find if there is already a tag for this
@@ -739,11 +737,11 @@ void CustomAnimationPane::updateMotionPathTags()
     MotionPathTagVector aTags;
     aTags.swap( maMotionPathTags );
 
-    ::sd::View* pView = 0;
+    ::sd::View* pView = nullptr;
 
     if( mxView.is() )
     {
-        ::boost::shared_ptr<ViewShell> xViewShell( mrBase.GetMainViewShell() );
+        std::shared_ptr<ViewShell> xViewShell( mrBase.GetMainViewShell() );
         if( xViewShell.get() )
             pView = xViewShell->GetView();
     }
@@ -869,7 +867,6 @@ static sal_Int32 calcMaxParaDepth( Reference< XShape > xTargetShape )
         if( xText.is() )
         {
             Reference< XPropertySet > xParaSet;
-            const OUString strNumberingLevel( "NumberingLevel" );
 
             Reference< XEnumeration > xEnumeration( xText->createEnumeration(), UNO_QUERY_THROW );
             while( xEnumeration->hasMoreElements() )
@@ -878,7 +875,7 @@ static sal_Int32 calcMaxParaDepth( Reference< XShape > xTargetShape )
                 if( xParaSet.is() )
                 {
                     sal_Int32 nParaDepth = 0;
-                    xParaSet->getPropertyValue( strNumberingLevel ) >>= nParaDepth;
+                    xParaSet->getPropertyValue( "NumberingLevel" ) >>= nParaDepth;
 
                     if( nParaDepth > nMaxParaDepth )
                         nMaxParaDepth = nParaDepth;
@@ -1029,17 +1026,15 @@ static bool hasVisibleShape( const Reference< XShape >& xShape )
         if( sShapeType == "com.sun.star.presentation.TitleTextShape" || sShapeType == "com.sun.star.presentation.OutlinerShape" ||
             sShapeType == "com.sun.star.presentation.SubtitleShape" || sShapeType == "com.sun.star.drawing.TextShape" )
         {
-            const OUString sFillStyle( "FillStyle" );
-            const OUString sLineStyle( "LineStyle" );
             Reference< XPropertySet > xSet( xShape, UNO_QUERY_THROW );
 
             FillStyle eFillStyle;
-            xSet->getPropertyValue( sFillStyle ) >>= eFillStyle;
+            xSet->getPropertyValue( "FillStyle" ) >>= eFillStyle;
 
-            ::com::sun::star::drawing::LineStyle eLineStyle;
-            xSet->getPropertyValue( sLineStyle ) >>= eLineStyle;
+            css::drawing::LineStyle eLineStyle;
+            xSet->getPropertyValue( "LineStyle" ) >>= eLineStyle;
 
-            return eFillStyle != FillStyle_NONE || eLineStyle != ::com::sun::star::drawing::LineStyle_NONE;
+            return eFillStyle != FillStyle_NONE || eLineStyle != css::drawing::LineStyle_NONE;
         }
     }
     catch( Exception& )
@@ -1076,7 +1071,7 @@ STLPropertySet* CustomAnimationPane::createSelectionSet()
         }
 
         addValue( pSet, nHandleHasAfterEffect, makeAny( pEffect->hasAfterEffect() ) );
-        addValue( pSet, nHandleAfterEffectOnNextEffect, makeAny( pEffect->IsAfterEffectOnNext() ? sal_True : sal_False ) );
+        addValue( pSet, nHandleAfterEffectOnNextEffect, makeAny( pEffect->IsAfterEffectOnNext() ) );
         addValue( pSet, nHandleDimColor, pEffect->getDimColor() );
         addValue( pSet, nHandleIterateType, makeAny( pEffect->getIterateType() ) );
 
@@ -1898,8 +1893,7 @@ void CustomAnimationPane::onChangeStart()
     if( mpLBStart->GetSelectEntryCount() == 1 )
     {
         sal_Int16 nNodeType;
-        sal_uInt16 nPos= mpLBStart->GetSelectEntryPos();
-        switch( nPos )
+        switch( mpLBStart->GetSelectEntryPos() )
         {
         case 0: nNodeType = EffectNodeType::ON_CLICK; break;
         case 1: nNodeType = EffectNodeType::WITH_PREVIOUS; break;
@@ -1984,9 +1978,7 @@ void CustomAnimationPane::onChangeSpeed()
 
         double fDuration;
 
-        sal_uInt16 nPos= mpCBSpeed->GetSelectEntryPos();
-
-        switch( nPos )
+        switch( mpCBSpeed->GetSelectEntryPos() )
         {
         case 0: fDuration = 5.0; break;
         case 1: fDuration = 3.0; break;
@@ -2015,14 +2007,22 @@ void CustomAnimationPane::onChangeSpeed()
 }
 
 /// this link is called when the property box is modified by the user
-IMPL_LINK_NOARG(CustomAnimationPane, implPropertyHdl)
+IMPL_LINK_NOARG_TYPED(CustomAnimationPane, implPropertyHdl, LinkParamNone*, void)
 {
     onChangeProperty();
-    return 0;
+}
+
+IMPL_LINK_TYPED( CustomAnimationPane, implClickHdl, Button*, pBtn, void )
+{
+    implControlHdl(pBtn);
+}
+IMPL_LINK_TYPED( CustomAnimationPane, implControlListBoxHdl, ListBox&, rListBox, void )
+{
+    implControlHdl(&rListBox);
 }
 
 /// this link is called when one of the controls is modified
-IMPL_LINK( CustomAnimationPane, implControlHdl, Control*, pControl )
+void CustomAnimationPane::implControlHdl(Control* pControl )
 {
     if( pControl == mpPBAddEffect )
         onChange(true);
@@ -2049,8 +2049,6 @@ IMPL_LINK( CustomAnimationPane, implControlHdl, Control*, pControl )
     }
 
     updateControls();
-
-    return 0;
 }
 
 IMPL_LINK_NOARG_TYPED(CustomAnimationPane, lateInitCallback, Timer *, void)
@@ -2069,7 +2067,7 @@ void CustomAnimationPane::moveSelection( bool bUp )
         return;
 
     EffectSequenceHelper* pSequence = maListSelection.front()->getEffectSequence();
-    if( pSequence == 0 )
+    if( pSequence == nullptr )
         return;
 
     addUndo();
@@ -2201,9 +2199,8 @@ void CustomAnimationPane::onPreview( bool bForcePreview )
 void CustomAnimationPane::preview( const Reference< XAnimationNode >& xAnimationNode )
 {
     Reference< XParallelTimeContainer > xRoot = ParallelTimeContainer::create( ::comphelper::getProcessComponentContext() );
-    Sequence< ::com::sun::star::beans::NamedValue > aUserData( 1 );
-    aUserData[0].Name = "node-type";
-    aUserData[0].Value <<= ::com::sun::star::presentation::EffectNodeType::TIMING_ROOT;
+    Sequence< css::beans::NamedValue > aUserData
+        { { "node-type", css::uno::makeAny(css::presentation::EffectNodeType::TIMING_ROOT) } };
     xRoot->setUserData( aUserData );
     xRoot->appendChild( xAnimationNode );
 
@@ -2220,7 +2217,7 @@ void CustomAnimationPane::onSelect()
 
 const CustomAnimationPresets& CustomAnimationPane::getPresets()
 {
-    if (mpCustomAnimationPresets == NULL)
+    if (mpCustomAnimationPresets == nullptr)
         mpCustomAnimationPresets = &CustomAnimationPresets::getCustomAnimationPresets();
     return *mpCustomAnimationPresets;
 }
@@ -2232,7 +2229,7 @@ void CustomAnimationPane::markShapesFromSelectedEffects()
         ScopeLockGuard aGuard( maSelectionLock );
         DrawViewShell* pViewShell = dynamic_cast< DrawViewShell* >(
             FrameworkHelper::Instance(mrBase)->GetViewShell(FrameworkHelper::msCenterPaneURL).get());
-        DrawView* pView = pViewShell ? pViewShell->GetDrawView() : NULL;
+        DrawView* pView = pViewShell ? pViewShell->GetDrawView() : nullptr;
 
         if( pView )
         {
@@ -2246,7 +2243,7 @@ void CustomAnimationPane::markShapesFromSelectedEffects()
                 Reference< XShape > xShape( pEffect->getTargetShape() );
                 SdrObject* pObj = GetSdrObjectFromXShape( xShape );
                 if( pObj )
-                    pView->MarkObj(pObj, pView->GetSdrPageView(), false, false);
+                    pView->MarkObj(pObj, pView->GetSdrPageView());
             }
         }
     }
@@ -2259,7 +2256,7 @@ void CustomAnimationPane::updatePathFromMotionPathTag( const rtl::Reference< Mot
     {
         SdrPathObj* pPathObj = xTag->getPathObj();
         CustomAnimationEffectPtr pEffect = xTag->getEffect();
-        if( (pPathObj != 0) && pEffect.get() != 0 )
+        if( (pPathObj != nullptr) && pEffect.get() != nullptr )
         {
             ::svl::IUndoManager* pManager = mrBase.GetDocShell()->GetUndoManager();
             if( pManager )
@@ -2276,7 +2273,7 @@ void CustomAnimationPane::updatePathFromMotionPathTag( const rtl::Reference< Mot
 
 vcl::Window * createCustomAnimationPanel( vcl::Window* pParent, ViewShellBase& rBase, const css::uno::Reference<css::frame::XFrame>& rxFrame )
 {
-    vcl::Window* pWindow = 0;
+    vcl::Window* pWindow = nullptr;
 
     DrawDocShell* pDocSh = rBase.GetDocShell();
     if( pDocSh )
