@@ -21,6 +21,7 @@
 
 #include "SlideTransitionPane.hxx"
 #include "CustomAnimation.hrc"
+#include "createslidetransitionpanel.hxx"
 
 #include "TransitionPreset.hxx"
 #include "sdresid.hxx"
@@ -50,8 +51,6 @@
 #include <sfx2/sidebar/Theme.hxx>
 
 #include <algorithm>
-#include <memory>
-
 
 using namespace ::com::sun::star;
 
@@ -61,11 +60,6 @@ using ::com::sun::star::uno::RuntimeException;
 
 using ::sd::framework::FrameworkHelper;
 
-// ____________________________
-//
-// ::sd::impl::TransitionEffect
-// ____________________________
-
 namespace sd
 {
 namespace impl
@@ -75,7 +69,7 @@ struct TransitionEffect
     TransitionEffect() :
             mnType( 0 ),
             mnSubType( 0 ),
-            mbDirection( sal_True ),
+            mbDirection( true ),
             mnFadeColor( 0 )
     {
         init();
@@ -88,15 +82,6 @@ struct TransitionEffect
     {
         init();
     }
-    explicit TransitionEffect( sal_Int16 nType, sal_Int16 nSubType,
-                               sal_Bool  bDirection, sal_Int32 nFadeColor ) :
-            mnType( nType),
-            mnSubType( nSubType ),
-            mbDirection( bDirection ),
-            mnFadeColor( nFadeColor )
-    {
-        init();
-    }
     explicit TransitionEffect( const SdPage & rPage ) :
             mnType( rPage.getTransitionType() ),
             mnSubType( rPage.getTransitionSubtype() ),
@@ -119,9 +104,9 @@ struct TransitionEffect
         mfDuration = 2.0;
         mfTime = 0.0;
         mePresChange = PRESCHANGE_MANUAL;
-        mbSoundOn = sal_False;
-        mbLoopSound = sal_False;
-        mbStopSound = sal_False;
+        mbSoundOn = false;
+        mbLoopSound = false;
+        mbStopSound = false;
 
         mbEffectAmbiguous = false;
         mbDurationAmbiguous = false;
@@ -170,12 +155,12 @@ struct TransitionEffect
         {
             if( mbStopSound )
             {
-                rOutPage.SetStopSound( sal_True );
-                rOutPage.SetSound( sal_False );
+                rOutPage.SetStopSound( true );
+                rOutPage.SetSound( false );
             }
             else
             {
-                rOutPage.SetStopSound( sal_False );
+                rOutPage.SetStopSound( false );
                 rOutPage.SetSound( mbSoundOn );
                 rOutPage.SetSoundFile( maSound );
             }
@@ -210,14 +195,14 @@ struct TransitionEffect
     // effect
     sal_Int16 mnType;
     sal_Int16 mnSubType;
-    sal_Bool  mbDirection;
+    bool  mbDirection;
     sal_Int32 mnFadeColor;
 
     // other settings
     double      mfDuration;
     double       mfTime;
     PresChange  mePresChange;
-    sal_Bool        mbSoundOn;
+    bool        mbSoundOn;
     OUString    maSound;
     bool        mbLoopSound;
     bool        mbStopSound;
@@ -233,11 +218,7 @@ struct TransitionEffect
 } // namespace impl
 } // namespace sd
 
-// ______________________
-//
 // Local Helper Functions
-// ______________________
-
 namespace
 {
 
@@ -258,74 +239,29 @@ void lcl_CreateUndoForPages(
     ::sd::ViewShellBase& rBase )
 {
     ::sd::DrawDocShell* pDocSh      = rBase.GetDocShell();
+    if (!pDocSh)
+        return;
     ::svl::IUndoManager* pManager   = pDocSh->GetUndoManager();
+    if (!pManager)
+        return;
     SdDrawDocument* pDoc            = pDocSh->GetDoc();
-    if( pManager && pDocSh && pDoc )
+    if (!pDoc)
+        return;
+
+    OUString aComment( SdResId(STR_UNDO_SLIDE_PARAMS) );
+    pManager->EnterListAction(aComment, aComment);
+    SdUndoGroup* pUndoGroup = new SdUndoGroup( pDoc );
+    pUndoGroup->SetComment( aComment );
+
+    ::std::vector< SdPage * >::const_iterator aIt( rpPages->begin());
+    const ::std::vector< SdPage * >::const_iterator aEndIt( rpPages->end());
+    for( ; aIt != aEndIt; ++aIt )
     {
-        OUString aComment( SdResId(STR_UNDO_SLIDE_PARAMS) );
-        pManager->EnterListAction(aComment, aComment);
-        SdUndoGroup* pUndoGroup = new SdUndoGroup( pDoc );
-        pUndoGroup->SetComment( aComment );
-
-        ::std::vector< SdPage * >::const_iterator aIt( rpPages->begin());
-        const ::std::vector< SdPage * >::const_iterator aEndIt( rpPages->end());
-        for( ; aIt != aEndIt; ++aIt )
-        {
-            pUndoGroup->AddAction( new sd::UndoTransition( pDoc, (*aIt) ) );
-        }
-
-        pManager->AddUndoAction( pUndoGroup );
-        pManager->LeaveListAction();
-    }
-}
-
-sal_uInt16 lcl_getTransitionEffectIndex(
-    SdDrawDocument * pDoc,
-    const ::sd::impl::TransitionEffect & rTransition )
-{
-    // first entry: "<none>"
-    sal_uInt16 nResultIndex = LISTBOX_ENTRY_NOTFOUND;
-
-    if( pDoc )
-    {
-        sal_uInt16 nCurrentIndex = 0;
-        const ::sd::TransitionPresetList & rPresetList = ::sd::TransitionPreset::getTransitionPresetList();
-        ::sd::TransitionPresetList::const_iterator aIt( rPresetList.begin());
-        const ::sd::TransitionPresetList::const_iterator aEndIt( rPresetList.end());
-        for( ; aIt != aEndIt; ++aIt, ++nCurrentIndex )
-        {
-            if( rTransition.operator==( *(*aIt) ))
-            {
-                nResultIndex = nCurrentIndex;
-                break;
-            }
-        }
+        pUndoGroup->AddAction( new sd::UndoTransition( pDoc, (*aIt) ) );
     }
 
-    return nResultIndex;
-}
-
-::sd::TransitionPresetPtr lcl_getTransitionPresetByUIName(
-    SdDrawDocument * pDoc,
-    const OUString & rUIName )
-{
-    ::sd::TransitionPresetPtr pResult;
-    if( pDoc )
-    {
-        const ::sd::TransitionPresetList& rPresetList = ::sd::TransitionPreset::getTransitionPresetList();
-        ::sd::TransitionPresetList::const_iterator aIter( rPresetList.begin() );
-        const ::sd::TransitionPresetList::const_iterator aEnd( rPresetList.end() );
-        for( ; aIter != aEnd; ++aIter )
-        {
-            if( (*aIter)->getUIName().equals( rUIName ))
-            {
-                pResult = *aIter;
-                break;
-            }
-        }
-    }
-
-    return pResult;
+    pManager->AddUndoAction( pUndoGroup );
+    pManager->LeaveListAction();
 }
 
 struct lcl_EqualsSoundFileName : public ::std::unary_function< OUString, bool >
@@ -372,14 +308,14 @@ OUString lcl_getSoundFileURL(
 {
     if( rListBox->GetSelectEntryCount() > 0 )
     {
-        sal_uInt16 nPos = rListBox->GetSelectEntryPos();
+        sal_Int32 nPos = rListBox->GetSelectEntryPos();
         // the first three entries are no actual sounds
         if( nPos >= 3 )
         {
             DBG_ASSERT( (sal_uInt32)(rListBox->GetEntryCount() - 3) == rSoundList.size(),
                         "Sound list-box is not synchronized to sound list" );
             nPos -= 3;
-            if( rSoundList.size() > nPos )
+            if( rSoundList.size() > static_cast<size_t>(nPos) )
                 return rSoundList[ nPos ];
         }
     }
@@ -389,61 +325,93 @@ OUString lcl_getSoundFileURL(
 
 struct lcl_AppendSoundToListBox : public ::std::unary_function< OUString, void >
 {
-    lcl_AppendSoundToListBox( ListBox*  rListBox ) :
+    explicit lcl_AppendSoundToListBox( ListBox*  rListBox ) :
             mrListBox( rListBox )
     {}
 
     void operator() ( const OUString & rString ) const
     {
         INetURLObject aURL( rString );
-        mrListBox->InsertEntry( aURL.GetBase(), LISTBOX_APPEND );
+        mrListBox->InsertEntry( aURL.GetBase() );
     }
 
 private:
-    ListBox*  mrListBox;
+    VclPtr<ListBox>  mrListBox;
 };
 
 void lcl_FillSoundListBox(
     const ::std::vector< OUString > & rSoundList,
     ListBox*  rOutListBox )
 {
-    sal_uInt16 nCount = rOutListBox->GetEntryCount();
+    sal_Int32 nCount = rOutListBox->GetEntryCount();
 
     // keep first three entries
-    for( sal_uInt16 i=nCount - 1; i>=3; --i )
+    for( sal_Int32 i=nCount - 1; i>=3; --i )
         rOutListBox->RemoveEntry( i );
 
     ::std::for_each( rSoundList.begin(), rSoundList.end(),
                      lcl_AppendSoundToListBox( rOutListBox ));
 }
 
+/// Returns an offset into the list of transition presets
+size_t getPresetOffset( const sd::impl::TransitionEffect &rEffect )
+{
+    const sd::TransitionPresetList& rPresetList =
+        sd::TransitionPreset::getTransitionPresetList();
+    sd::TransitionPresetPtr pFound;
+
+    size_t nIdx = 0;
+    for( auto aIt: rPresetList )
+    {
+        if( rEffect.operator==( *aIt ))
+            break;
+        nIdx++;
+    }
+    return nIdx;
+}
+
 } // anonymous namespace
 
 namespace sd
 {
 
-// ___________________
-//
-// SlideTransitionPane
-// ___________________
+class TransitionPane : public ValueSet
+{
+public:
+    explicit TransitionPane( vcl::Window *pParent )
+        : ValueSet( pParent, WB_TABSTOP | WB_3DLOOK | WB_BORDER |
+                  WB_ITEMBORDER | WB_FLATVALUESET | WB_VSCROLL )
+    {
+        EnableFullItemMode( false );
+        set_hexpand( true );
+        set_vexpand( true );
+        SetExtraSpacing( 2 );
+    }
+    virtual ~TransitionPane() { disposeOnce(); }
 
+    virtual Size GetOptimalSize() const override
+    {
+        return LogicToPixel(Size(70, 88), MAP_APPFONT);
+    }
+};
+
+// SlideTransitionPane
 SlideTransitionPane::SlideTransitionPane(
-    ::Window * pParent,
+    Window * pParent,
     ViewShellBase & rBase,
-    const Size& rMinSize,
     SdDrawDocument* pDoc,
-    const cssu::Reference<css::frame::XFrame>& rxFrame ) :
+    const css::uno::Reference<css::frame::XFrame>& rxFrame ) :
         PanelLayout( pParent, "SlideTransitionsPanel", "modules/simpress/ui/slidetransitionspanel.ui", rxFrame ),
 
         mrBase( rBase ),
         mpDrawDoc( pDoc ),
-        maMinSize( rMinSize ),
         mbHasSelection( false ),
         mbUpdatingControls( false ),
         mbIsMainViewChangePending( false ),
         maLateInitTimer()
 {
-    get(mpLB_SLIDE_TRANSITIONS, "transitions_list");
+    get(mpFT_VARIANT, "variant_label");
+    get(mpLB_VARIANT, "variant_list");
     get(mpFT_SPEED, "speed_label");
     get(mpLB_SPEED, "speed_list");
     get(mpFT_SOUND, "sound_label");
@@ -454,11 +422,15 @@ SlideTransitionPane::SlideTransitionPane(
     get(mpMF_ADVANCE_AUTO_AFTER, "auto_after_value");
     get(mpPB_APPLY_TO_ALL, "apply_to_all");
     get(mpPB_PLAY, "play");
-    get(mpPB_SLIDE_SHOW, "slide_show");
     get(mpCB_AUTO_PREVIEW, "auto_preview");
 
-    mpLB_SLIDE_TRANSITIONS->set_width_request(mpLB_SLIDE_TRANSITIONS->approximate_char_width() * 16);
-    mpLB_SLIDE_TRANSITIONS->SetDropDownLineCount(4);
+    VclPtr<VclAlignment> xAlign;
+    get(xAlign, "transitions_icons");
+
+    mpVS_TRANSITION_ICONS = VclPtr<TransitionPane>::Create(xAlign);
+    mpVS_TRANSITION_ICONS->Show();
+
+    mpLB_VARIANT->SetDropDownLineCount(4);
 
     if( pDoc )
         mxModel.set( pDoc->getUnoModel(), uno::UNO_QUERY );
@@ -466,8 +438,12 @@ SlideTransitionPane::SlideTransitionPane(
     if( mxModel.is())
         mxView.set( mxModel->getCurrentController(), uno::UNO_QUERY );
 
-    // fill list box of slide transitions
-    mpLB_SLIDE_TRANSITIONS->InsertEntry( SD_RESSTR( STR_SLIDETRANSITION_NONE ) );
+    // dummy list box of slide transitions for startup.
+    mpVS_TRANSITION_ICONS->InsertItem(
+        0, Image( BitmapEx( "sd/cmd/transition-none.png" ) ),
+        SD_RESSTR( STR_SLIDETRANSITION_NONE ),
+        VALUESET_APPEND, /* show legend */ true );
+    mpVS_TRANSITION_ICONS->RecalculateItemSizes();
 
     // set defaults
     mpCB_AUTO_PREVIEW->Check();      // automatic preview on
@@ -478,10 +454,10 @@ SlideTransitionPane::SlideTransitionPane(
     // set handlers
     mpPB_APPLY_TO_ALL->SetClickHdl( LINK( this, SlideTransitionPane, ApplyToAllButtonClicked ));
     mpPB_PLAY->SetClickHdl( LINK( this, SlideTransitionPane, PlayButtonClicked ));
-    mpPB_SLIDE_SHOW->SetClickHdl( LINK( this, SlideTransitionPane, SlideShowButtonClicked ));
 
-    mpLB_SLIDE_TRANSITIONS->SetSelectHdl( LINK( this, SlideTransitionPane, TransitionSelected ));
+    mpVS_TRANSITION_ICONS->SetSelectHdl( LINK( this, SlideTransitionPane, TransitionSelected ));
 
+    mpLB_VARIANT->SetSelectHdl( LINK( this, SlideTransitionPane, VariantListBoxSelected ));
     mpLB_SPEED->SetSelectHdl( LINK( this, SlideTransitionPane, SpeedListBoxSelected ));
     mpLB_SOUND->SetSelectHdl( LINK( this, SlideTransitionPane, SoundListBoxSelected ));
     mpCB_LOOP_SOUND->SetClickHdl( LINK( this, SlideTransitionPane, LoopSoundBoxChecked ));
@@ -501,10 +477,29 @@ SlideTransitionPane::SlideTransitionPane(
 
 SlideTransitionPane::~SlideTransitionPane()
 {
-    maLateInitTimer.Stop();
-    removeListener();
+    disposeOnce();
 }
 
+void SlideTransitionPane::dispose()
+{
+    maLateInitTimer.Stop();
+    removeListener();
+    mpVS_TRANSITION_ICONS.disposeAndClear();
+    mpFT_VARIANT.clear();
+    mpLB_VARIANT.clear();
+    mpFT_SPEED.clear();
+    mpLB_SPEED.clear();
+    mpFT_SOUND.clear();
+    mpLB_SOUND.clear();
+    mpCB_LOOP_SOUND.clear();
+    mpRB_ADVANCE_ON_MOUSE.clear();
+    mpRB_ADVANCE_AUTO.clear();
+    mpMF_ADVANCE_AUTO_AFTER.clear();
+    mpPB_APPLY_TO_ALL.clear();
+    mpPB_PLAY.clear();
+    mpCB_AUTO_PREVIEW.clear();
+    PanelLayout::dispose();
+}
 
 void SlideTransitionPane::DataChanged (const DataChangedEvent& rEvent)
 {
@@ -512,19 +507,13 @@ void SlideTransitionPane::DataChanged (const DataChangedEvent& rEvent)
     UpdateLook();
 }
 
-
-
-
-void SlideTransitionPane::UpdateLook (void)
+void SlideTransitionPane::UpdateLook()
 {
     SetBackground(::sfx2::sidebar::Theme::GetWallpaper(::sfx2::sidebar::Theme::Paint_PanelBackground));
     mpFT_SPEED->SetBackground(Wallpaper());
     mpFT_SOUND->SetBackground(Wallpaper());
 }
 
-
-
-
 void SlideTransitionPane::onSelectionChanged()
 {
     updateControls();
@@ -535,11 +524,11 @@ void SlideTransitionPane::onChangeCurrentPage()
     updateControls();
 }
 
-::sd::slidesorter::SharedPageSelection SlideTransitionPane::getSelectedPages (void) const
+::sd::slidesorter::SharedPageSelection SlideTransitionPane::getSelectedPages() const
 {
     ::sd::slidesorter::SlideSorterViewShell * pSlideSorterViewShell
         = ::sd::slidesorter::SlideSorterViewShell::GetSlideSorter(mrBase);
-    ::boost::shared_ptr<sd::slidesorter::SlideSorterViewShell::PageSelection> pSelection;
+    std::shared_ptr<sd::slidesorter::SlideSorterViewShell::PageSelection> pSelection;
 
     if( pSlideSorterViewShell )
     {
@@ -579,41 +568,32 @@ void SlideTransitionPane::updateControls()
     impl::TransitionEffect aEffect( *pFirstPage );
 
     // merge with other pages
-    ::sd::slidesorter::SlideSorterViewShell::PageSelection::const_iterator aIt(
+    ::sd::slidesorter::SlideSorterViewShell::PageSelection::const_iterator aPageIt(
         pSelectedPages->begin());
-    ::sd::slidesorter::SlideSorterViewShell::PageSelection::const_iterator aEndIt(
+    ::sd::slidesorter::SlideSorterViewShell::PageSelection::const_iterator aPageEndIt(
         pSelectedPages->end());
 
     // start with second page (note aIt != aEndIt, because ! aSelectedPages.empty())
-    for( ++aIt ;aIt != aEndIt; ++aIt )
+    for( ++aPageIt; aPageIt != aPageEndIt; ++aPageIt )
     {
-        if( *aIt )
-            aEffect.compareWith( *(*aIt) );
+        if( *aPageIt )
+            aEffect.compareWith( *(*aPageIt) );
     }
 
     // detect current slide effect
     if( aEffect.mbEffectAmbiguous )
-        mpLB_SLIDE_TRANSITIONS->SetNoSelection();
+    {
+        SAL_WARN( "sd.transitions", "Unusual, ambiguous transition effect" );
+        mpVS_TRANSITION_ICONS->SetNoSelection();
+    }
     else
     {
         // ToDo: That 0 is "no transition" is documented nowhere except in the
         // CTOR of sdpage
         if( aEffect.mnType == 0 )
-            mpLB_SLIDE_TRANSITIONS->SelectEntryPos( 0 );
+            mpVS_TRANSITION_ICONS->SetNoSelection();
         else
-        {
-            sal_uInt16 nEntry = lcl_getTransitionEffectIndex( mpDrawDoc, aEffect );
-            if( nEntry == LISTBOX_ENTRY_NOTFOUND )
-                mpLB_SLIDE_TRANSITIONS->SetNoSelection();
-            else
-            {
-                // first entry in list is "none", so add 1 after translation
-                if( m_aPresetIndexes.find( nEntry ) != m_aPresetIndexes.end())
-                    mpLB_SLIDE_TRANSITIONS->SelectEntryPos( m_aPresetIndexes[ nEntry ] + 1 );
-                else
-                    mpLB_SLIDE_TRANSITIONS->SetNoSelection();
-            }
-        }
+            updateVariants( getPresetOffset( aEffect ) );
     }
 
     if( aEffect.mbDurationAmbiguous )
@@ -627,11 +607,11 @@ void SlideTransitionPane::updateControls()
     if( aEffect.mbSoundAmbiguous )
     {
         mpLB_SOUND->SetNoSelection();
-        maCurrentSoundFile = "";
+        maCurrentSoundFile.clear();
     }
     else
     {
-        maCurrentSoundFile = "";
+        maCurrentSoundFile.clear();
         if( aEffect.mbStopSound )
         {
             mpLB_SOUND->SelectEntryPos( 1 );
@@ -642,7 +622,7 @@ void SlideTransitionPane::updateControls()
             if( lcl_findSoundInList( maSoundList, aEffect.maSound, nPos ))
             {
                 // skip first three entries
-                mpLB_SOUND->SelectEntryPos( (sal_uInt16)nPos + 3 );
+                mpLB_SOUND->SelectEntryPos( nPos + 3 );
                 maCurrentSoundFile = aEffect.maSound;
             }
         }
@@ -654,7 +634,7 @@ void SlideTransitionPane::updateControls()
 
     if( aEffect.mbLoopSoundAmbiguous )
     {
-        mpCB_LOOP_SOUND->SetState( STATE_DONTKNOW );
+        mpCB_LOOP_SOUND->SetState( TRISTATE_INDET );
     }
     else
     {
@@ -663,8 +643,8 @@ void SlideTransitionPane::updateControls()
 
     if( aEffect.mbPresChangeAmbiguous )
     {
-        mpRB_ADVANCE_ON_MOUSE->Check( sal_False );
-        mpRB_ADVANCE_AUTO->Check( sal_False );
+        mpRB_ADVANCE_ON_MOUSE->Check( false );
+        mpRB_ADVANCE_AUTO->Check( false );
     }
     else
     {
@@ -674,7 +654,7 @@ void SlideTransitionPane::updateControls()
     }
 
     SdOptions* pOptions = SD_MOD()->GetSdOptions(DOCUMENT_TYPE_IMPRESS);
-    mpCB_AUTO_PREVIEW->Check( pOptions->IsPreviewTransitions() == sal_True );
+    mpCB_AUTO_PREVIEW->Check( pOptions->IsPreviewTransitions() );
 
     mbUpdatingControls = false;
 
@@ -683,7 +663,8 @@ void SlideTransitionPane::updateControls()
 
 void SlideTransitionPane::updateControlState()
 {
-    mpLB_SLIDE_TRANSITIONS->Enable( mbHasSelection );
+    mpVS_TRANSITION_ICONS->Enable( mbHasSelection );
+    mpLB_VARIANT->Enable( mbHasSelection && mpLB_VARIANT->GetEntryCount() > 0 );
     mpLB_SPEED->Enable( mbHasSelection );
     mpLB_SOUND->Enable( mbHasSelection );
     mpCB_LOOP_SOUND->Enable( mbHasSelection && (mpLB_SOUND->GetSelectEntryPos() > 2));
@@ -749,9 +730,9 @@ void SlideTransitionPane::openSoundFileDialog()
             {
                 OUString aStrWarning(SD_RESSTR(STR_WARNING_NOSOUNDFILE));
                 aStrWarning = aStrWarning.replaceFirst("%", aFile);
-                WarningBox aWarningBox( NULL, WB_3DLOOK | WB_RETRY_CANCEL, aStrWarning );
-                aWarningBox.SetModalInputMode (sal_True);
-                bQuitLoop = (aWarningBox.Execute() != RET_RETRY);
+                ScopedVclPtrInstance< WarningBox > aWarningBox( nullptr, WB_3DLOOK | WB_RETRY_CANCEL, aStrWarning );
+                aWarningBox->SetModalInputMode (true);
+                bQuitLoop = (aWarningBox->Execute() != RET_RETRY);
 
                 bValidSoundFile = false;
             }
@@ -759,7 +740,7 @@ void SlideTransitionPane::openSoundFileDialog()
 
         if( bValidSoundFile )
             // skip first three entries in list
-            mpLB_SOUND->SelectEntryPos( (sal_uInt16)nPos + 3 );
+            mpLB_SOUND->SelectEntryPos( nPos + 3 );
     }
 
     if( ! bValidSoundFile )
@@ -768,7 +749,7 @@ void SlideTransitionPane::openSoundFileDialog()
         {
             tSoundListType::size_type nPos = 0;
             if( lcl_findSoundInList( maSoundList, maCurrentSoundFile, nPos ))
-                mpLB_SOUND->SelectEntryPos( (sal_uInt16)nPos + 3 );
+                mpLB_SOUND->SelectEntryPos( nPos + 3 );
             else
                 mpLB_SOUND->SelectEntryPos( 0 );  // NONE
         }
@@ -783,29 +764,56 @@ impl::TransitionEffect SlideTransitionPane::getTransitionEffectFromControls() co
     aResult.setAllAmbiguous();
 
     // check first (aResult might be overwritten)
-    if( mpLB_SLIDE_TRANSITIONS->IsEnabled() &&
-        mpLB_SLIDE_TRANSITIONS->GetSelectEntryCount() > 0 )
+    if(  mpVS_TRANSITION_ICONS->IsEnabled() &&
+        !mpVS_TRANSITION_ICONS->IsNoSelection() &&
+         mpVS_TRANSITION_ICONS->GetSelectItemId() > 0 )
     {
-        TransitionPresetPtr pPreset = lcl_getTransitionPresetByUIName(
-            mpDrawDoc, OUString( mpLB_SLIDE_TRANSITIONS->GetSelectEntry()));
+        const sd::TransitionPresetList& rPresetList = sd::TransitionPreset::getTransitionPresetList();
+        auto aSelected = rPresetList.begin();
+        std::advance( aSelected, mpVS_TRANSITION_ICONS->GetSelectItemId() - 1);
 
-        if( pPreset.get())
+        if( mpLB_VARIANT->GetSelectEntryPos() == LISTBOX_ENTRY_NOTFOUND )
         {
-            aResult = impl::TransitionEffect( *pPreset );
+            // Transition with just one effect.
+            aResult = impl::TransitionEffect( **aSelected );
             aResult.setAllAmbiguous();
         }
         else
         {
-            aResult.mnType = 0;
+            int nVariant = 0;
+            bool bFound = false;
+            for( auto aIter: rPresetList )
+            {
+                if( aIter->getSetId() == (*aSelected)->getSetId() )
+                {
+                    if( mpLB_VARIANT->GetSelectEntryPos() == nVariant)
+                    {
+                        aResult = impl::TransitionEffect( *aIter );
+                        aResult.setAllAmbiguous();
+                        bFound = true;
+                        break;
+                    }
+                    else
+                    {
+                        nVariant++;
+                    }
+                }
+            }
+            if( !bFound )
+            {
+                aResult.mnType = 0;
+            }
         }
         aResult.mbEffectAmbiguous = false;
-    }
+
+    } else if (mpVS_TRANSITION_ICONS->IsNoSelection())
+        aResult.mbEffectAmbiguous = false;
 
     // speed
     if( mpLB_SPEED->IsEnabled() &&
         mpLB_SPEED->GetSelectEntryCount() > 0 )
     {
-        sal_uInt16 nPos = mpLB_SPEED->GetSelectEntryPos();
+        sal_Int32 nPos = mpLB_SPEED->GetSelectEntryPos();
         aResult.mfDuration = (nPos == 0)
             ? 3.0
             : (nPos == 1)
@@ -838,15 +846,15 @@ impl::TransitionEffect SlideTransitionPane::getTransitionEffectFromControls() co
     // sound
     if( mpLB_SOUND->IsEnabled())
     {
-        maCurrentSoundFile = "";
+        maCurrentSoundFile.clear();
         if( mpLB_SOUND->GetSelectEntryCount() > 0 )
         {
-            sal_uInt16 nPos = mpLB_SOUND->GetSelectEntryPos();
+            sal_Int32 nPos = mpLB_SOUND->GetSelectEntryPos();
             aResult.mbStopSound = nPos == 1;
             aResult.mbSoundOn = nPos > 1;
             if( aResult.mbStopSound )
             {
-                aResult.maSound = OUString();
+                aResult.maSound.clear();
                 aResult.mbSoundAmbiguous = false;
             }
             else
@@ -872,6 +880,8 @@ void SlideTransitionPane::applyToSelectedPages()
 {
     if( ! mbUpdatingControls )
     {
+        Window *pFocusWindow = Application::GetFocusWindow();
+
         ::sd::slidesorter::SharedPageSelection pSelectedPages( getSelectedPages());
         impl::TransitionEffect aEffect = getTransitionEffectFromControls();
         if( ! pSelectedPages->empty())
@@ -888,6 +898,9 @@ void SlideTransitionPane::applyToSelectedPages()
             else
                 stopEffects();
         }
+
+        if (pFocusWindow)
+            pFocusWindow->GrabFocus();
     }
 }
 
@@ -896,7 +909,7 @@ void SlideTransitionPane::playCurrentEffect()
     if( mxView.is() )
     {
 
-        Reference< ::com::sun::star::animations::XAnimationNode > xNode;
+        Reference< css::animations::XAnimationNode > xNode;
         SlideShow::StartPreview( mrBase, mxView->getCurrentPage(), xNode );
     }
 }
@@ -911,7 +924,7 @@ void SlideTransitionPane::stopEffects()
 
 void SlideTransitionPane::addListener()
 {
-    Link aLink( LINK(this,SlideTransitionPane,EventMultiplexerListener) );
+    Link<tools::EventMultiplexerEvent&,void> aLink( LINK(this,SlideTransitionPane,EventMultiplexerListener) );
     mrBase.GetEventMultiplexer()->AddEventListener (
         aLink,
         tools::EventMultiplexerEvent::EID_EDIT_VIEW_SELECTION
@@ -924,14 +937,14 @@ void SlideTransitionPane::addListener()
 
 void SlideTransitionPane::removeListener()
 {
-    Link aLink( LINK(this,SlideTransitionPane,EventMultiplexerListener) );
+    Link<tools::EventMultiplexerEvent&,void> aLink( LINK(this,SlideTransitionPane,EventMultiplexerListener) );
     mrBase.GetEventMultiplexer()->RemoveEventListener( aLink );
 }
 
-IMPL_LINK(SlideTransitionPane,EventMultiplexerListener,
-    tools::EventMultiplexerEvent*,pEvent)
+IMPL_LINK_TYPED(SlideTransitionPane,EventMultiplexerListener,
+    tools::EventMultiplexerEvent&, rEvent, void)
 {
-    switch (pEvent->meEventId)
+    switch (rEvent.meEventId)
     {
         case tools::EventMultiplexerEvent::EID_EDIT_VIEW_SELECTION:
             onSelectionChanged();
@@ -943,7 +956,7 @@ IMPL_LINK(SlideTransitionPane,EventMultiplexerListener,
             break;
 
         case tools::EventMultiplexerEvent::EID_MAIN_VIEW_REMOVED:
-            mxView = Reference<drawing::XDrawView>();
+            mxView.clear();
             onSelectionChanged();
             onChangeCurrentPage();
             break;
@@ -960,9 +973,9 @@ IMPL_LINK(SlideTransitionPane,EventMultiplexerListener,
                 // At this moment the controller may not yet been set at
                 // model or ViewShellBase.  Take it from the view shell
                 // passed with the event.
-                if (mrBase.GetMainViewShell() != 0)
+                if (mrBase.GetMainViewShell() != nullptr)
                 {
-                    mxView = Reference<drawing::XDrawView>::query(mrBase.GetController());
+                    mxView.set(mrBase.GetController(), css::uno::UNO_QUERY);
                     onSelectionChanged();
                     onChangeCurrentPage();
                 }
@@ -972,14 +985,13 @@ IMPL_LINK(SlideTransitionPane,EventMultiplexerListener,
         default:
             break;
     }
-    return 0;
 }
 
-IMPL_LINK_NOARG(SlideTransitionPane, ApplyToAllButtonClicked)
+IMPL_LINK_NOARG_TYPED(SlideTransitionPane, ApplyToAllButtonClicked, Button*, void)
 {
     DBG_ASSERT( mpDrawDoc, "Invalid Draw Document!" );
     if( !mpDrawDoc )
-        return 0;
+        return;
 
     ::sd::slidesorter::SharedPageSelection pPages (
         new ::sd::slidesorter::SlideSorterViewShell::PageSelection());
@@ -998,112 +1010,167 @@ IMPL_LINK_NOARG(SlideTransitionPane, ApplyToAllButtonClicked)
         lcl_CreateUndoForPages( pPages, mrBase );
         lcl_ApplyToPages( pPages, getTransitionEffectFromControls() );
     }
-
-    return 0;
 }
 
-
-IMPL_LINK_NOARG(SlideTransitionPane, PlayButtonClicked)
+IMPL_LINK_NOARG_TYPED(SlideTransitionPane, PlayButtonClicked, Button*, void)
 {
     playCurrentEffect();
-    return 0;
 }
 
-IMPL_LINK_NOARG(SlideTransitionPane, SlideShowButtonClicked)
-{
-    mrBase.StartPresentation();
-    return 0;
-}
-
-IMPL_LINK_NOARG(SlideTransitionPane, TransitionSelected)
+IMPL_LINK_NOARG_TYPED(SlideTransitionPane, TransitionSelected, ValueSet *, void)
 {
+    updateVariants( mpVS_TRANSITION_ICONS->GetSelectItemId() - 1 );
     applyToSelectedPages();
-    return 0;
 }
 
-IMPL_LINK_NOARG(SlideTransitionPane, AdvanceSlideRadioButtonToggled)
+/// we use an integer offset into the list of transition presets
+void SlideTransitionPane::updateVariants( size_t nPresetOffset )
+{
+    const sd::TransitionPresetList& rPresetList = sd::TransitionPreset::getTransitionPresetList();
+    mpLB_VARIANT->Clear();
+    mpVS_TRANSITION_ICONS->SetNoSelection();
+
+    if( nPresetOffset >= rPresetList.size() )
+    {
+        mpLB_VARIANT->Enable( false );
+    }
+    else
+    {
+        auto pFound = rPresetList.begin();
+        std::advance( pFound, nPresetOffset );
+
+        // Fill in the variant listbox
+        size_t nFirstItem = 0, nItem = 1;
+        for( auto aIt: rPresetList )
+        {
+            if( aIt->getSetId().equals( (*pFound)->getSetId() ) )
+            {
+                if (!nFirstItem)
+                    nFirstItem = nItem;
+                if( !aIt->getVariantLabel().isEmpty() )
+                {
+                    mpLB_VARIANT->InsertEntry( aIt->getVariantLabel() );
+                    if( *pFound == aIt )
+                        mpLB_VARIANT->SelectEntryPos( mpLB_VARIANT->GetEntryCount()-1 );
+                }
+            }
+            nItem++;
+        }
+
+        if( mpLB_VARIANT->GetEntryCount() == 0 )
+            mpLB_VARIANT->Enable( false );
+        else
+            mpLB_VARIANT->Enable();
+
+        // item has the id of the first transition from this set.
+        mpVS_TRANSITION_ICONS->SelectItem( nFirstItem );
+    }
+}
+
+IMPL_LINK_NOARG_TYPED(SlideTransitionPane, AdvanceSlideRadioButtonToggled, RadioButton&, void)
 {
     updateControlState();
     applyToSelectedPages();
-    return 0;
 }
 
-IMPL_LINK_NOARG(SlideTransitionPane, AdvanceTimeModified)
+IMPL_LINK_NOARG_TYPED(SlideTransitionPane, AdvanceTimeModified, Edit&, void)
 {
     applyToSelectedPages();
-    return 0;
 }
 
-IMPL_LINK_NOARG(SlideTransitionPane, SpeedListBoxSelected)
+IMPL_LINK_NOARG_TYPED(SlideTransitionPane, VariantListBoxSelected, ListBox&, void)
 {
     applyToSelectedPages();
-    return 0;
 }
 
-IMPL_LINK_NOARG(SlideTransitionPane, SoundListBoxSelected)
+IMPL_LINK_NOARG_TYPED(SlideTransitionPane, SpeedListBoxSelected, ListBox&, void)
+{
+    applyToSelectedPages();
+}
+
+IMPL_LINK_NOARG_TYPED(SlideTransitionPane, SoundListBoxSelected, ListBox&, void)
 {
     if( mpLB_SOUND->GetSelectEntryCount() )
     {
-        sal_uInt16 nPos = mpLB_SOUND->GetSelectEntryPos();
+        sal_Int32 nPos = mpLB_SOUND->GetSelectEntryPos();
         if( nPos == 2 )
         {
-            // other sound ...
+            // other sound...
             openSoundFileDialog();
         }
     }
     updateControlState();
     applyToSelectedPages();
-    return 0;
 }
 
-IMPL_LINK_NOARG(SlideTransitionPane, LoopSoundBoxChecked)
+IMPL_LINK_NOARG_TYPED(SlideTransitionPane, LoopSoundBoxChecked, Button*, void)
 {
     applyToSelectedPages();
-    return 0;
 }
 
-IMPL_LINK_NOARG(SlideTransitionPane, AutoPreviewClicked)
+IMPL_LINK_NOARG_TYPED(SlideTransitionPane, AutoPreviewClicked, Button*, void)
 {
     SdOptions* pOptions = SD_MOD()->GetSdOptions(DOCUMENT_TYPE_IMPRESS);
-    pOptions->SetPreviewTransitions( mpCB_AUTO_PREVIEW->IsChecked() ? sal_True : sal_False );
-    return 0;
+    pOptions->SetPreviewTransitions( mpCB_AUTO_PREVIEW->IsChecked() );
 }
 
-IMPL_LINK_NOARG(SlideTransitionPane, LateInitCallback)
+IMPL_LINK_NOARG_TYPED(SlideTransitionPane, LateInitCallback, Timer *, void)
 {
     const TransitionPresetList& rPresetList = TransitionPreset::getTransitionPresetList();
-    TransitionPresetList::const_iterator aIter( rPresetList.begin() );
-    const TransitionPresetList::const_iterator aEnd( rPresetList.end() );
-    sal_uInt16 nIndex = 0;
-    ::std::size_t nUIIndex = 0;
-    while( aIter != aEnd )
+
+    size_t nPresetOffset = 0;
+    for( auto aIter: rPresetList )
     {
-        TransitionPresetPtr pPreset = (*aIter++);
-        const OUString aUIName( pPreset->getUIName() );
-         if( !aUIName.isEmpty() )
+        TransitionPresetPtr pPreset = aIter;
+        const OUString sLabel( pPreset->getSetLabel() );
+        if( !sLabel.isEmpty() )
         {
-            mpLB_SLIDE_TRANSITIONS->InsertEntry( aUIName );
-            m_aPresetIndexes[ nIndex ] = (sal_uInt16)nUIIndex;
-            ++nUIIndex;
+            if( m_aNumVariants.find( pPreset->getSetId() ) == m_aNumVariants.end() )
+            {
+                OUString sImageName("sd/cmd/transition-" + pPreset->getSetId() + ".png");
+                BitmapEx aIcon( sImageName );
+                if ( aIcon.IsEmpty() ) // need a fallback
+                    aIcon = BitmapEx( "sd/cmd/transition-none.png" );
+
+                mpVS_TRANSITION_ICONS->InsertItem(
+                    nPresetOffset + 1, Image( aIcon ), sLabel,
+                    VALUESET_APPEND, /* show legend */ true );
+
+                m_aNumVariants[ pPreset->getSetId() ] = 1;
+            }
+            else
+            {
+                m_aNumVariants[ pPreset->getSetId() ]++;
+            }
         }
-        ++nIndex;
+        nPresetOffset++;
+    }
+    mpVS_TRANSITION_ICONS->RecalculateItemSizes();
+
+    SAL_INFO( "sd.transitions", "Item transition offsets in ValueSet:");
+    for( size_t i = 0; i < mpVS_TRANSITION_ICONS->GetItemCount(); ++i )
+        SAL_INFO( "sd.transitions", i << ":" << mpVS_TRANSITION_ICONS->GetItemId( i ) );
+
+    nPresetOffset = 0;
+    SAL_INFO( "sd.transitions", "Transition presets by offsets:");
+    for( auto aIter: rPresetList )
+    {
+        SAL_INFO( "sd.transitions", nPresetOffset++ << " " <<
+                  aIter->getPresetId() << ": " << aIter->getSetId() );
     }
 
     updateSoundList();
     updateControls();
-
-    return 0;
 }
 
-::Window * createSlideTransitionPanel( ::Window* pParent, ViewShellBase& rBase, const cssu::Reference<css::frame::XFrame>& rxFrame )
+vcl::Window * createSlideTransitionPanel( vcl::Window* pParent, ViewShellBase& rBase, const css::uno::Reference<css::frame::XFrame>& rxFrame )
 {
-    ::Window* pWindow = 0;
+    vcl::Window* pWindow = nullptr;
 
     DrawDocShell* pDocSh = rBase.GetDocShell();
     if( pDocSh )
     {
-        Size aMinSize( pParent->LogicToPixel( Size( 72, 216 ), MAP_APPFONT ) );
-        pWindow = new SlideTransitionPane( pParent, rBase, aMinSize, pDocSh->GetDoc(), rxFrame );
+        pWindow = VclPtr<SlideTransitionPane>::Create( pParent, rBase, pDocSh->GetDoc(), rxFrame );
     }
 
     return pWindow;
