@@ -31,68 +31,54 @@ namespace sd {
 
 //===== LeftImpressPaneShell ==================================================
 
-SFX_SLOTMAP(LeftImpressPaneShell)
+static SfxSlot aLeftImpressPaneShellSlots_Impl[] =
 {
-    { 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0 }
+    { 0, 0, SfxSlotMode::NONE, 0, 0, nullptr, nullptr, nullptr, nullptr, nullptr, nullptr, 0, 0, nullptr }
 };
 
-SFX_IMPL_INTERFACE(LeftImpressPaneShell, SfxShell, SdResId(STR_LEFT_IMPRESS_PANE_SHELL))
+SFX_IMPL_INTERFACE(LeftImpressPaneShell, SfxShell)
+
+void LeftImpressPaneShell::InitInterface_Impl()
 {
-    SFX_CHILDWINDOW_REGISTRATION(
-        ::sd::LeftPaneImpressChildWindow::GetChildWindowId());
+    GetStaticInterface()->RegisterChildWindow(::sd::LeftPaneImpressChildWindow::GetChildWindowId());
 }
 
-TYPEINIT1(LeftImpressPaneShell, SfxShell);
 
-
-
-LeftImpressPaneShell::LeftImpressPaneShell (void)
+LeftImpressPaneShell::LeftImpressPaneShell()
     : SfxShell()
 {
-    SetName(OUString("LeftImpressPane"));
+    SetName("LeftImpressPane");
 }
 
-
-
-
-LeftImpressPaneShell::~LeftImpressPaneShell (void)
+LeftImpressPaneShell::~LeftImpressPaneShell()
 {
 }
 
-
-
-
 //===== LeftDrawPaneShell =====================================================
 
-SFX_SLOTMAP(LeftDrawPaneShell)
+static SfxSlot aLeftDrawPaneShellSlots_Impl[] =
 {
-    { 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0 }
+    { 0, 0, SfxSlotMode::NONE, 0, 0, nullptr, nullptr, nullptr, nullptr, nullptr, nullptr, 0, 0, nullptr }
 };
 
-SFX_IMPL_INTERFACE(LeftDrawPaneShell, SfxShell, SdResId(STR_LEFT_DRAW_PANE_SHELL))
+SFX_IMPL_INTERFACE(LeftDrawPaneShell, SfxShell)
+
+void LeftDrawPaneShell::InitInterface_Impl()
 {
-    SFX_CHILDWINDOW_REGISTRATION(
-        ::sd::LeftPaneDrawChildWindow::GetChildWindowId());
+    GetStaticInterface()->RegisterChildWindow(::sd::LeftPaneDrawChildWindow::GetChildWindowId());
 }
 
-TYPEINIT1(LeftDrawPaneShell, SfxShell);
 
-
-
-LeftDrawPaneShell::LeftDrawPaneShell (void)
+LeftDrawPaneShell::LeftDrawPaneShell()
     : SfxShell()
 {
-    SetName(OUString("LeftDrawPane"));
+    SetName("LeftDrawPane");
 }
 
-
-
-
-LeftDrawPaneShell::~LeftDrawPaneShell (void)
+LeftDrawPaneShell::~LeftDrawPaneShell()
 {
 }
 
-
 } // end of namespace ::sd
 
 /* vim:set shiftwidth=4 softtabstop=4 expandtab: */
