@@ -17,7 +17,6 @@
  *   the License at http://www.apache.org/licenses/LICENSE-2.0 .
  */
 
-
 #include "BasicViewFactory.hxx"
 
 #include "framework/ViewShellWrapper.hxx"
@@ -36,6 +35,7 @@
 #include "PresentationViewShell.hxx"
 #include "SlideSorterViewShell.hxx"
 #include "FrameView.hxx"
+#include "facreg.hxx"
 
 #include <sfx2/viewfrm.hxx>
 #include <vcl/wrkwin.hxx>
@@ -50,75 +50,38 @@ using namespace ::com::sun::star::drawing::framework;
 
 using ::sd::framework::FrameworkHelper;
 
-
 namespace sd { namespace framework {
 
-
-Reference<XInterface> SAL_CALL BasicViewFactory_createInstance (
-    const Reference<XComponentContext>& rxContext)
-{
-    return Reference<XInterface>(static_cast<XWeak*>(new BasicViewFactory(rxContext)));
-}
-
-
-
-
-OUString BasicViewFactory_getImplementationName (void) throw(RuntimeException)
-{
-    return OUString("com.sun.star.comp.Draw.framework.BasicViewFactory");
-}
-
-
-
-
-Sequence<OUString> SAL_CALL BasicViewFactory_getSupportedServiceNames (void)
-    throw (RuntimeException)
-{
-    static const OUString sServiceName("com.sun.star.drawing.framework.BasicViewFactory");
-    return Sequence<OUString>(&sServiceName, 1);
-}
-
-
-
-
 //===== ViewDescriptor ========================================================
 
 class BasicViewFactory::ViewDescriptor
 {
 public:
     Reference<XResource> mxView;
-    ::boost::shared_ptr<sd::ViewShell> mpViewShell;
+    std::shared_ptr<sd::ViewShell> mpViewShell;
     ViewShellWrapper* mpWrapper;
     Reference<XResourceId> mxViewId;
-    static bool CompareView (const ::boost::shared_ptr<ViewDescriptor>& rpDescriptor,
+    static bool CompareView (const std::shared_ptr<ViewDescriptor>& rpDescriptor,
         const Reference<XResource>& rxView)
     { return rpDescriptor->mxView.get() == rxView.get(); }
 };
 
-
-
-
-
 //===== BasicViewFactory::ViewShellContainer ==================================
 
 class BasicViewFactory::ViewShellContainer
-    : public ::std::vector<boost::shared_ptr<ViewDescriptor> >
+    : public ::std::vector<std::shared_ptr<ViewDescriptor> >
 {
 public:
-    ViewShellContainer (void) {};
+    ViewShellContainer() {};
 };
 
-
 class BasicViewFactory::ViewCache
-    : public ::std::vector<boost::shared_ptr<ViewDescriptor> >
+    : public ::std::vector<std::shared_ptr<ViewDescriptor> >
 {
 public:
-    ViewCache (void) {};
+    ViewCache() {};
 };
 
-
-
-
 //===== ViewFactory ===========================================================
 
 BasicViewFactory::BasicViewFactory (
@@ -126,32 +89,26 @@ BasicViewFactory::BasicViewFactory (
     : BasicViewFactoryInterfaceBase(MutexOwner::maMutex),
       mxConfigurationController(),
       mpViewShellContainer(new ViewShellContainer()),
-      mpBase(NULL),
-      mpFrameView(NULL),
-      mpWindow(new WorkWindow(NULL,WB_STDWORK)),
+      mpBase(nullptr),
+      mpFrameView(nullptr),
+      mpWindow(VclPtr<WorkWindow>::Create(nullptr,WB_STDWORK)),
       mpViewCache(new ViewCache()),
       mxLocalPane(new Pane(Reference<XResourceId>(), mpWindow.get()))
 {
     (void)rxContext;
 }
 
-
-
-
-BasicViewFactory::~BasicViewFactory (void)
+BasicViewFactory::~BasicViewFactory()
 {
 }
 
-
-
-
-void SAL_CALL BasicViewFactory::disposing (void)
+void SAL_CALL BasicViewFactory::disposing()
 {
     // Disconnect from the frame view.
-    if (mpFrameView != NULL)
+    if (mpFrameView != nullptr)
     {
         mpFrameView->Disconnect();
-        mpFrameView = NULL;
+        mpFrameView = nullptr;
     }
 
     // Relase the view cache.
@@ -173,12 +130,9 @@ void SAL_CALL BasicViewFactory::disposing (void)
     mpViewShellContainer.reset();
 }
 
-
-
-
 Reference<XResource> SAL_CALL BasicViewFactory::createResource (
     const Reference<XResourceId>& rxViewId)
-    throw(RuntimeException, IllegalArgumentException, WrappedTargetException)
+    throw(RuntimeException, IllegalArgumentException, WrappedTargetException, std::exception)
 {
     Reference<XResource> xView;
     const bool bIsCenterPane (
@@ -187,38 +141,37 @@ Reference<XResource> SAL_CALL BasicViewFactory::createResource (
     // Get the pane for the anchor URL.
     Reference<XPane> xPane;
     if (mxConfigurationController.is())
-        xPane = Reference<XPane>(mxConfigurationController->getResource(rxViewId->getAnchor()),
-            UNO_QUERY);
+        xPane.set(mxConfigurationController->getResource(rxViewId->getAnchor()), UNO_QUERY);
 
     // For main views use the frame view of the last main view.
-    ::sd::FrameView* pFrameView = NULL;
+    ::sd::FrameView* pFrameView = nullptr;
     if (xPane.is() && bIsCenterPane)
     {
         pFrameView = mpFrameView;
     }
 
     // Get Window pointer for XWindow of the pane.
-    ::Window* pWindow = NULL;
+    vcl::Window* pWindow = nullptr;
     if (xPane.is())
         pWindow = VCLUnoHelper::GetWindow(xPane->getWindow());
 
     // Get the view frame.
-    SfxViewFrame* pFrame = NULL;
-    if (mpBase != NULL)
+    SfxViewFrame* pFrame = nullptr;
+    if (mpBase != nullptr)
         pFrame = mpBase->GetViewFrame();
 
-    if (pFrame != NULL && mpBase!=NULL && pWindow!=NULL)
+    if (pFrame != nullptr && mpBase!=nullptr && pWindow!=nullptr)
     {
         // Try to get the view from the cache.
-        ::boost::shared_ptr<ViewDescriptor> pDescriptor (GetViewFromCache(rxViewId, xPane));
+        std::shared_ptr<ViewDescriptor> pDescriptor (GetViewFromCache(rxViewId, xPane));
 
         // When the requested view is not in the cache then create a new view.
-        if (pDescriptor.get() == NULL)
+        if (pDescriptor.get() == nullptr)
         {
             pDescriptor = CreateView(rxViewId, *pFrame, *pWindow, xPane, pFrameView, bIsCenterPane);
         }
 
-        if (pDescriptor.get() != NULL)
+        if (pDescriptor.get() != nullptr)
             xView = pDescriptor->mxView;
 
         mpViewShellContainer->push_back(pDescriptor);
@@ -232,16 +185,13 @@ Reference<XResource> SAL_CALL BasicViewFactory::createResource (
     return xView;
 }
 
-
-
-
 void SAL_CALL BasicViewFactory::releaseResource (const Reference<XResource>& rxView)
-    throw(RuntimeException)
+    throw(RuntimeException, std::exception)
 {
     if ( ! rxView.is())
         throw lang::IllegalArgumentException();
 
-    if (rxView.is() && mpBase!=NULL)
+    if (rxView.is() && mpBase!=nullptr)
     {
         ViewShellContainer::iterator iViewShell (
             ::std::find_if(
@@ -250,7 +200,7 @@ void SAL_CALL BasicViewFactory::releaseResource (const Reference<XResource>& rxV
                 ::boost::bind(&ViewDescriptor::CompareView, _1, rxView)));
         if (iViewShell != mpViewShellContainer->end())
         {
-            ::boost::shared_ptr<ViewShell> pViewShell ((*iViewShell)->mpViewShell);
+            std::shared_ptr<ViewShell> pViewShell ((*iViewShell)->mpViewShell);
 
             if ((*iViewShell)->mxViewId->isBoundToURL(
                 FrameworkHelper::msCenterPaneURL, AnchorBindingMode_DIRECT))
@@ -258,7 +208,7 @@ void SAL_CALL BasicViewFactory::releaseResource (const Reference<XResource>& rxV
                 // Obtain a pointer to and connect to the frame view of the
                 // view.  The next view, that is created, will be
                 // initialized with this frame view.
-                if (mpFrameView == NULL)
+                if (mpFrameView == nullptr)
                 {
                     mpFrameView = pViewShell->GetFrameView();
                     if (mpFrameView)
@@ -271,7 +221,7 @@ void SAL_CALL BasicViewFactory::releaseResource (const Reference<XResource>& rxV
                     Reference<drawing::XDrawSubController>());
 
                 SfxViewShell* pSfxViewShell = pViewShell->GetViewShell();
-                if (pSfxViewShell != NULL)
+                if (pSfxViewShell != nullptr)
                     pSfxViewShell->DisconnectAllClients();
             }
 
@@ -286,11 +236,8 @@ void SAL_CALL BasicViewFactory::releaseResource (const Reference<XResource>& rxV
     }
 }
 
-
-
-
 void SAL_CALL BasicViewFactory::initialize (const Sequence<Any>& aArguments)
-    throw (Exception, RuntimeException)
+    throw (Exception, RuntimeException, std::exception)
 {
     if (aArguments.getLength() > 0)
     {
@@ -304,7 +251,7 @@ void SAL_CALL BasicViewFactory::initialize (const Sequence<Any>& aArguments)
             Reference<lang::XUnoTunnel> xTunnel (xController, UNO_QUERY_THROW);
             ::sd::DrawController* pController = reinterpret_cast<sd::DrawController*>(
                 xTunnel->getSomething(sd::DrawController::getUnoTunnelId()));
-            if (pController != NULL)
+            if (pController != nullptr)
                 mpBase = pController->GetViewShellBase();
 
             // Register the factory for its supported views.
@@ -322,7 +269,7 @@ void SAL_CALL BasicViewFactory::initialize (const Sequence<Any>& aArguments)
         }
         catch (RuntimeException&)
         {
-            mpBase = NULL;
+            mpBase = nullptr;
             if (mxConfigurationController.is())
                 mxConfigurationController->removeResourceFactoryForReference(this);
             throw;
@@ -330,18 +277,15 @@ void SAL_CALL BasicViewFactory::initialize (const Sequence<Any>& aArguments)
     }
 }
 
-
-
-
-::boost::shared_ptr<BasicViewFactory::ViewDescriptor> BasicViewFactory::CreateView (
+std::shared_ptr<BasicViewFactory::ViewDescriptor> BasicViewFactory::CreateView (
     const Reference<XResourceId>& rxViewId,
     SfxViewFrame& rFrame,
-    ::Window& rWindow,
+    vcl::Window& rWindow,
     const Reference<XPane>& rxPane,
     FrameView* pFrameView,
     const bool bIsCenterPane)
 {
-    ::boost::shared_ptr<ViewDescriptor> pDescriptor (new ViewDescriptor());
+    std::shared_ptr<ViewDescriptor> pDescriptor (new ViewDescriptor());
 
     pDescriptor->mpViewShell = CreateViewShell(
         rxViewId,
@@ -351,7 +295,7 @@ void SAL_CALL BasicViewFactory::initialize (const Sequence<Any>& aArguments)
         bIsCenterPane);
     pDescriptor->mxViewId = rxViewId;
 
-    if (pDescriptor->mpViewShell.get() != NULL)
+    if (pDescriptor->mpViewShell.get() != nullptr)
     {
         pDescriptor->mpViewShell->Init(bIsCenterPane);
         mpBase->GetViewShellManager()->ActivateViewShell(pDescriptor->mpViewShell.get());
@@ -366,29 +310,26 @@ void SAL_CALL BasicViewFactory::initialize (const Sequence<Any>& aArguments)
         if (xWindow.is())
         {
             xWindow->addWindowListener(pDescriptor->mpWrapper);
-            if (pDescriptor->mpViewShell != 0)
+            if (pDescriptor->mpViewShell != nullptr)
             {
                 pDescriptor->mpViewShell->Resize();
             }
         }
 
-        pDescriptor->mxView.set( pDescriptor->mpWrapper->queryInterface( XResource::static_type() ), UNO_QUERY_THROW );
+        pDescriptor->mxView.set( pDescriptor->mpWrapper->queryInterface( cppu::UnoType<XResource>::get() ), UNO_QUERY_THROW );
     }
 
     return pDescriptor;
 }
 
-
-
-
-::boost::shared_ptr<ViewShell> BasicViewFactory::CreateViewShell (
+std::shared_ptr<ViewShell> BasicViewFactory::CreateViewShell (
     const Reference<XResourceId>& rxViewId,
     SfxViewFrame& rFrame,
-    ::Window& rWindow,
+    vcl::Window& rWindow,
     FrameView* pFrameView,
     const bool bIsCenterPane)
 {
-    ::boost::shared_ptr<ViewShell> pViewShell;
+    std::shared_ptr<ViewShell> pViewShell;
     const OUString& rsViewURL (rxViewId->getResourceURL());
     if (rsViewURL.equals(FrameworkHelper::msImpressViewURL))
     {
@@ -460,11 +401,8 @@ void SAL_CALL BasicViewFactory::initialize (const Sequence<Any>& aArguments)
     return pViewShell;
 }
 
-
-
-
 void BasicViewFactory::ReleaseView (
-    const ::boost::shared_ptr<ViewDescriptor>& rpDescriptor,
+    const std::shared_ptr<ViewDescriptor>& rpDescriptor,
     bool bDoNotCache)
 {
     bool bIsCacheable (!bDoNotCache && IsCacheable(rpDescriptor));
@@ -502,10 +440,7 @@ void BasicViewFactory::ReleaseView (
     }
 }
 
-
-
-
-bool BasicViewFactory::IsCacheable (const ::boost::shared_ptr<ViewDescriptor>& rpDescriptor)
+bool BasicViewFactory::IsCacheable (const std::shared_ptr<ViewDescriptor>& rpDescriptor)
 {
     bool bIsCacheable (false);
 
@@ -515,12 +450,12 @@ bool BasicViewFactory::IsCacheable (const ::boost::shared_ptr<ViewDescriptor>& r
         static ::std::vector<Reference<XResourceId> > maCacheableResources;
         if (maCacheableResources.empty() )
         {
-            ::boost::shared_ptr<FrameworkHelper> pHelper (FrameworkHelper::Instance(*mpBase));
+            std::shared_ptr<FrameworkHelper> pHelper (FrameworkHelper::Instance(*mpBase));
 
             // The slide sorter and the task panel are cacheable and relocatable.
-            maCacheableResources.push_back(pHelper->CreateResourceId(
+            maCacheableResources.push_back(FrameworkHelper::CreateResourceId(
                 FrameworkHelper::msSlideSorterURL, FrameworkHelper::msLeftDrawPaneURL));
-            maCacheableResources.push_back(pHelper->CreateResourceId(
+            maCacheableResources.push_back(FrameworkHelper::CreateResourceId(
                 FrameworkHelper::msSlideSorterURL, FrameworkHelper::msLeftImpressPaneURL));
         }
 
@@ -538,14 +473,11 @@ bool BasicViewFactory::IsCacheable (const ::boost::shared_ptr<ViewDescriptor>& r
     return bIsCacheable;
 }
 
-
-
-
-::boost::shared_ptr<BasicViewFactory::ViewDescriptor> BasicViewFactory::GetViewFromCache (
+std::shared_ptr<BasicViewFactory::ViewDescriptor> BasicViewFactory::GetViewFromCache (
     const Reference<XResourceId>& rxViewId,
     const Reference<XPane>& rxPane)
 {
-    ::boost::shared_ptr<ViewDescriptor> pDescriptor;
+    std::shared_ptr<ViewDescriptor> pDescriptor;
 
     // Search for the requested view in the cache.
     ViewCache::iterator iEntry;
@@ -561,7 +493,7 @@ bool BasicViewFactory::IsCacheable (const ::boost::shared_ptr<ViewDescriptor>& r
 
     // When the view has been found then relocate it to the given pane and
     // remove it from the cache.
-    if (pDescriptor.get() != NULL)
+    if (pDescriptor.get() != nullptr)
     {
         bool bRelocationSuccessfull (false);
         Reference<XRelocatableResource> xResource (pDescriptor->mxView, UNO_QUERY);
@@ -581,11 +513,8 @@ bool BasicViewFactory::IsCacheable (const ::boost::shared_ptr<ViewDescriptor>& r
     return pDescriptor;
 }
 
-
-
-
 void BasicViewFactory::ActivateCenterView (
-    const ::boost::shared_ptr<ViewDescriptor>& rpDescriptor)
+    const std::shared_ptr<ViewDescriptor>& rpDescriptor)
 {
     mpBase->GetDocShell()->Connect(rpDescriptor->mpViewShell.get());
 
@@ -594,7 +523,7 @@ void BasicViewFactory::ActivateCenterView (
     // have to request a resize now.
     rpDescriptor->mpViewShell->UIFeatureChanged();
     if (mpBase->GetDocShell()->IsInPlaceActive())
-        mpBase->GetViewFrame()->Resize(sal_True);
+        mpBase->GetViewFrame()->Resize(true);
 
     mpBase->GetDrawController().SetSubController(
         rpDescriptor->mpViewShell->CreateSubController());
@@ -602,4 +531,14 @@ void BasicViewFactory::ActivateCenterView (
 
 } } // end of namespace sd::framework
 
+
+extern "C" SAL_DLLPUBLIC_EXPORT css::uno::XInterface* SAL_CALL
+com_sun_star_comp_Draw_framework_BasicViewFactory_get_implementation(css::uno::XComponentContext* context,
+                                                                     css::uno::Sequence<css::uno::Any> const &)
+{
+    return cppu::acquire(new sd::framework::BasicViewFactory(context));
+}
+
+
+
 /* vim:set shiftwidth=4 softtabstop=4 expandtab: */
