@@ -17,13 +17,13 @@
  *   the License at http://www.apache.org/licenses/LICENSE-2.0 .
  */
 
-
 #include <sot/object.hxx>
 #include <editeng/eeitem.hxx>
 #include <vcl/waitobj.hxx>
 
 #include <editeng/flditem.hxx>
 #include <svx/svdogrp.hxx>
+#include <svx/svdoole2.hxx>
 #include <tools/urlobj.hxx>
 #include <vcl/help.hxx>
 #include <svx/bmpmask.hxx>
@@ -68,45 +68,118 @@ using namespace ::com::sun::star;
 
 namespace sd {
 
-TYPEINIT1( FuDraw, FuPoor );
 
 /**
  * Base-class for all drawmodul-specific functions
  */
 FuDraw::FuDraw(ViewShell* pViewSh, ::sd::Window* pWin, ::sd::View* pView,
-               SdDrawDocument* pDoc, SfxRequest& rReq) :
-    FuPoor(pViewSh, pWin, pView, pDoc, rReq),
-    bMBDown(sal_False),
-    bDragHelpLine(sal_False),
-    bPermanent(sal_False)
+               SdDrawDocument* pDoc, SfxRequest& rReq)
+    : FuPoor(pViewSh, pWin, pView, pDoc, rReq)
+    , bMBDown(false)
+    , bDragHelpLine(false)
+    , nHelpLine(0)
+    , bPermanent(false)
+    , bIsImageSelected(false)
 {
 }
 
-
 FuDraw::~FuDraw()
 {
     mpView->BrkAction();
 }
 
 
-sal_Bool FuDraw::MouseButtonDown(const MouseEvent& rMEvt)
+/**
+ * Code shared by MouseButtonDown and MouseMove
+ */
+void FuDraw::DoModifiers(const MouseEvent& rMEvt, bool bSnapModPressed)
+{
+    FrameView* pFrameView = mpViewShell->GetFrameView();
+    bool bGridSnap = pFrameView->IsGridSnap();
+    bGridSnap = (bSnapModPressed != bGridSnap);
+
+    if (mpView->IsGridSnap() != bGridSnap)
+        mpView->SetGridSnap(bGridSnap);
+
+    bool bBordSnap = pFrameView->IsBordSnap();
+    bBordSnap = (bSnapModPressed != bBordSnap);
+
+    if (mpView->IsBordSnap() != bBordSnap)
+        mpView->SetBordSnap(bBordSnap);
+
+    bool bHlplSnap = pFrameView->IsHlplSnap();
+    bHlplSnap = (bSnapModPressed != bHlplSnap);
+
+    if (mpView->IsHlplSnap() != bHlplSnap)
+        mpView->SetHlplSnap(bHlplSnap);
+
+    bool bOFrmSnap = pFrameView->IsOFrmSnap();
+    bOFrmSnap = (bSnapModPressed != bOFrmSnap);
+
+    if (mpView->IsOFrmSnap() != bOFrmSnap)
+        mpView->SetOFrmSnap(bOFrmSnap);
+
+    bool bOPntSnap = pFrameView->IsOPntSnap();
+    bOPntSnap = (bSnapModPressed != bOPntSnap);
+
+    if (mpView->IsOPntSnap() != bOPntSnap)
+        mpView->SetOPntSnap(bOPntSnap);
+
+    bool bOConSnap = pFrameView->IsOConSnap();
+    bOConSnap = (bSnapModPressed != bOConSnap);
+
+    if (mpView->IsOConSnap() != bOConSnap)
+        mpView->SetOConSnap(bOConSnap);
+
+    bool bAngleSnap = rMEvt.IsShift() == !pFrameView->IsAngleSnapEnabled();
+
+    if (mpView->IsAngleSnapEnabled() != bAngleSnap)
+        mpView->SetAngleSnapEnabled(bAngleSnap);
+
+    bool bCenter = rMEvt.IsMod2();
+
+    if ( mpView->IsCreate1stPointAsCenter() != bCenter ||
+         mpView->IsResizeAtCenter() != bCenter )
+    {
+        mpView->SetCreate1stPointAsCenter(bCenter);
+        mpView->SetResizeAtCenter(bCenter);
+    }
+}
+
+
+bool FuDraw::MouseButtonDown(const MouseEvent& rMEvt)
 {
     // remember button state for creation of own MouseEvents
     SetMouseButtonCode(rMEvt.GetButtons());
 
-    sal_Bool bReturn = sal_False;
-
-    bDragHelpLine = sal_False;
-
+    bool bReturn = false;
+    bDragHelpLine = false;
     aMDPos = mpWindow->PixelToLogic( rMEvt.GetPosPixel() );
 
+    // Check whether an image is selected
+    bIsImageSelected = false;
+    if (mpView->AreObjectsMarked())
+    {
+        const SdrMarkList& rMarkList = mpView->GetMarkedObjectList();
+        if (rMarkList.GetMarkCount() == 1)
+        {
+            SdrMark* pMark = rMarkList.GetMark(0);
+            // tdf#89758 Extra check to avoid interactive crop preview from being
+            // proportionally scaled by default.
+            if (mpView->GetDragMode() != SDRDRAG_CROP)
+            {
+                bIsImageSelected = pMark->GetMarkedSdrObj()->GetObjIdentifier() == OBJ_GRAF;
+            }
+        }
+    }
+
     if ( rMEvt.IsLeft() )
     {
         FrameView* pFrameView = mpViewShell->GetFrameView();
 
-        bool bOrtho = sal_False;
+        bool bOrtho = false;
 
-        sal_Bool bRestricted = sal_True;
+        bool bRestricted = true;
 
         if (mpView->IsDragObj())
         {
@@ -116,7 +189,7 @@ sal_Bool FuDraw::MouseButtonDown(const MouseEvent& rMEvt)
             if (!pHdl || (!pHdl->IsCornerHdl() && !pHdl->IsVertexHdl()))
             {
                 // Move
-                bRestricted = sal_False;
+                bRestricted = false;
             }
         }
 
@@ -131,72 +204,23 @@ sal_Bool FuDraw::MouseButtonDown(const MouseEvent& rMEvt)
         {
             bOrtho = rMEvt.IsShift() != pFrameView->IsOrtho();
         }
-
         if (!mpView->IsSnapEnabled())
-            mpView->SetSnapEnabled(sal_True);
-        sal_Bool bSnapModPressed = rMEvt.IsMod1();
-
-        sal_Bool bGridSnap = pFrameView->IsGridSnap();
-        bGridSnap = (bSnapModPressed != bGridSnap);
-
-        if (mpView->IsGridSnap() != bGridSnap)
-            mpView->SetGridSnap(bGridSnap);
-
-        sal_Bool bBordSnap = pFrameView->IsBordSnap();
-        bBordSnap = (bSnapModPressed != bBordSnap);
-
-        if (mpView->IsBordSnap() != bBordSnap)
-            mpView->SetBordSnap(bBordSnap);
-
-        sal_Bool bHlplSnap = pFrameView->IsHlplSnap();
-        bHlplSnap = (bSnapModPressed != bHlplSnap);
-
-        if (mpView->IsHlplSnap() != bHlplSnap)
-            mpView->SetHlplSnap(bHlplSnap);
-
-        sal_Bool bOFrmSnap = pFrameView->IsOFrmSnap();
-        bOFrmSnap = (bSnapModPressed != bOFrmSnap);
-
-        if (mpView->IsOFrmSnap() != bOFrmSnap)
-            mpView->SetOFrmSnap(bOFrmSnap);
-
-        sal_Bool bOPntSnap = pFrameView->IsOPntSnap();
-        bOPntSnap = (bSnapModPressed != bOPntSnap);
-
-        if (mpView->IsOPntSnap() != bOPntSnap)
-            mpView->SetOPntSnap(bOPntSnap);
-
-        sal_Bool bOConSnap = pFrameView->IsOConSnap();
-        bOConSnap = (bSnapModPressed != bOConSnap);
-
-        if (mpView->IsOConSnap() != bOConSnap)
-            mpView->SetOConSnap(bOConSnap);
-
-        sal_Bool bAngleSnap = rMEvt.IsShift() == !pFrameView->IsAngleSnapEnabled();
-
-        if (mpView->IsAngleSnapEnabled() != bAngleSnap)
-            mpView->SetAngleSnapEnabled(bAngleSnap);
+            mpView->SetSnapEnabled(true);
 
+        bool bSnapModPressed = rMEvt.IsMod1();
         if (mpView->IsOrtho() != bOrtho)
             mpView->SetOrtho(bOrtho);
 
-        sal_Bool bCenter = rMEvt.IsMod2();
+        DoModifiers(rMEvt, bSnapModPressed);
 
-        if ( mpView->IsCreate1stPointAsCenter() != bCenter ||
-             mpView->IsResizeAtCenter() != bCenter )
-        {
-            mpView->SetCreate1stPointAsCenter(bCenter);
-            mpView->SetResizeAtCenter(bCenter);
-        }
-
-        SdrPageView* pPV = 0;
+        SdrPageView* pPV = nullptr;
         sal_uInt16 nHitLog = sal_uInt16 ( mpWindow->PixelToLogic(Size(HITPIX,0)).Width() );
 
         // look only for HelpLines when they are visible (!)
-        sal_Bool bHelpLine(sal_False);
+        bool bHelpLine(false);
         if(mpView->IsHlplVisible())
             bHelpLine = mpView->PickHelpLine(aMDPos, nHitLog, *mpWindow, nHelpLine, pPV);
-        sal_Bool bHitHdl = (mpView->PickHandle(aMDPos) != NULL);
+        bool bHitHdl = (mpView->PickHandle(aMDPos) != nullptr);
 
         if ( bHelpLine
             && !mpView->IsCreateObj()
@@ -205,7 +229,7 @@ sal_Bool FuDraw::MouseButtonDown(const MouseEvent& rMEvt)
             mpWindow->CaptureMouse();
             mpView->BegDragHelpLine(nHelpLine, pPV);
             bDragHelpLine = mpView->IsDragHelpLine();
-            bReturn = sal_True;
+            bReturn = true;
         }
     }
     ForcePointer(&rMEvt);
@@ -213,15 +237,13 @@ sal_Bool FuDraw::MouseButtonDown(const MouseEvent& rMEvt)
     return bReturn;
 }
 
-
-sal_Bool FuDraw::MouseMove(const MouseEvent& rMEvt)
+bool FuDraw::MouseMove(const MouseEvent& rMEvt)
 {
     FrameView* pFrameView = mpViewShell->GetFrameView();
     Point aPos = mpWindow->PixelToLogic( rMEvt.GetPosPixel() );
 
-    bool bOrtho = sal_False;
-
-    sal_Bool bRestricted = sal_True;
+    bool bOrtho = false;
+    bool bRestricted = true;
 
     if (mpView->IsDragObj())
     {
@@ -231,17 +253,17 @@ sal_Bool FuDraw::MouseMove(const MouseEvent& rMEvt)
         if (!pHdl || (!pHdl->IsCornerHdl() && !pHdl->IsVertexHdl()))
         {
             // Move
-            bRestricted = sal_False;
+            bRestricted = false;
         }
     }
 
     if (mpView->IsAction())
     {
-        // #i33136#
-        if(bRestricted && doConstructOrthogonal())
+        // #i33136# and fdo#88339
+        if(bRestricted && (bIsImageSelected || doConstructOrthogonal()))
         {
-            // Restrict movement:
-            // rectangle->quadrat, ellipse->circle etc.
+            // Scale proportionally by default:
+            // rectangle->quadrat, ellipse->circle, Images etc.
             bOrtho = !rMEvt.IsShift();
         }
         else
@@ -249,67 +271,19 @@ sal_Bool FuDraw::MouseMove(const MouseEvent& rMEvt)
             bOrtho = rMEvt.IsShift() != pFrameView->IsOrtho();
         }
 
-        sal_Bool bSnapModPressed = rMEvt.IsMod2();
+        bool bSnapModPressed = rMEvt.IsMod2();
         mpView->SetDragWithCopy(rMEvt.IsMod1() && pFrameView->IsDragWithCopy());
 
-        sal_Bool bGridSnap = pFrameView->IsGridSnap();
-        bGridSnap = (bSnapModPressed != bGridSnap);
-
-        if (mpView->IsGridSnap() != bGridSnap)
-            mpView->SetGridSnap(bGridSnap);
-
-        sal_Bool bBordSnap = pFrameView->IsBordSnap();
-        bBordSnap = (bSnapModPressed != bBordSnap);
-
-        if (mpView->IsBordSnap() != bBordSnap)
-            mpView->SetBordSnap(bBordSnap);
-
-        sal_Bool bHlplSnap = pFrameView->IsHlplSnap();
-        bHlplSnap = (bSnapModPressed != bHlplSnap);
-
-        if (mpView->IsHlplSnap() != bHlplSnap)
-            mpView->SetHlplSnap(bHlplSnap);
-
-        sal_Bool bOFrmSnap = pFrameView->IsOFrmSnap();
-        bOFrmSnap = (bSnapModPressed != bOFrmSnap);
-
-        if (mpView->IsOFrmSnap() != bOFrmSnap)
-            mpView->SetOFrmSnap(bOFrmSnap);
-
-        sal_Bool bOPntSnap = pFrameView->IsOPntSnap();
-        bOPntSnap = (bSnapModPressed != bOPntSnap);
-
-        if (mpView->IsOPntSnap() != bOPntSnap)
-            mpView->SetOPntSnap(bOPntSnap);
-
-        sal_Bool bOConSnap = pFrameView->IsOConSnap();
-        bOConSnap = (bSnapModPressed != bOConSnap);
-
-        if (mpView->IsOConSnap() != bOConSnap)
-            mpView->SetOConSnap(bOConSnap);
-
-        sal_Bool bAngleSnap = rMEvt.IsShift() == !pFrameView->IsAngleSnapEnabled();
-
-        if (mpView->IsAngleSnapEnabled() != bAngleSnap)
-            mpView->SetAngleSnapEnabled(bAngleSnap);
-
         if (mpView->IsOrtho() != bOrtho)
             mpView->SetOrtho(bOrtho);
+        DoModifiers(rMEvt, bSnapModPressed);
 
-        sal_Bool bCenter = rMEvt.IsMod2();
-
-        if ( mpView->IsCreate1stPointAsCenter() != bCenter ||
-             mpView->IsResizeAtCenter() != bCenter )
-        {
-            mpView->SetCreate1stPointAsCenter(bCenter);
-            mpView->SetResizeAtCenter(bCenter);
-        }
 
         if ( mpView->IsDragHelpLine() )
             mpView->MovDragHelpLine(aPos);
     }
 
-    sal_Bool bReturn = mpView->MouseMove(rMEvt, mpWindow);
+    bool bReturn = mpView->MouseMove(rMEvt, mpWindow);
 
     if (mpView->IsAction())
     {
@@ -323,50 +297,52 @@ sal_Bool FuDraw::MouseMove(const MouseEvent& rMEvt)
     return bReturn;
 }
 
-
-sal_Bool FuDraw::MouseButtonUp(const MouseEvent& rMEvt)
+bool FuDraw::MouseButtonUp(const MouseEvent& rMEvt)
 {
-    if ( mpView->IsDragHelpLine() )
+    if (mpView && mpView->IsDragHelpLine())
         mpView->EndDragHelpLine();
 
     if ( bDragHelpLine )
     {
         Rectangle aOutputArea(Point(0,0), mpWindow->GetOutputSizePixel());
 
-        if ( !aOutputArea.IsInside(rMEvt.GetPosPixel()) )
+        if (mpView && !aOutputArea.IsInside(rMEvt.GetPosPixel()))
             mpView->GetSdrPageView()->DeleteHelpLine(nHelpLine);
 
         mpWindow->ReleaseMouse();
     }
 
-    FrameView* pFrameView = mpViewShell->GetFrameView();
-    mpView->SetOrtho( pFrameView->IsOrtho() );
-    mpView->SetAngleSnapEnabled( pFrameView->IsAngleSnapEnabled() );
-    mpView->SetSnapEnabled(sal_True);
-    mpView->SetCreate1stPointAsCenter(sal_False);
-    mpView->SetResizeAtCenter(sal_False);
-    mpView->SetDragWithCopy(pFrameView->IsDragWithCopy());
-    mpView->SetGridSnap(pFrameView->IsGridSnap());
-    mpView->SetBordSnap(pFrameView->IsBordSnap());
-    mpView->SetHlplSnap(pFrameView->IsHlplSnap());
-    mpView->SetOFrmSnap(pFrameView->IsOFrmSnap());
-    mpView->SetOPntSnap(pFrameView->IsOPntSnap());
-    mpView->SetOConSnap(pFrameView->IsOConSnap());
+    if (mpView)
+    {
+        FrameView* pFrameView = mpViewShell->GetFrameView();
+        mpView->SetOrtho( pFrameView->IsOrtho() );
+        mpView->SetAngleSnapEnabled( pFrameView->IsAngleSnapEnabled() );
+        mpView->SetSnapEnabled(true);
+        mpView->SetCreate1stPointAsCenter(false);
+        mpView->SetResizeAtCenter(false);
+        mpView->SetDragWithCopy(pFrameView->IsDragWithCopy());
+        mpView->SetGridSnap(pFrameView->IsGridSnap());
+        mpView->SetBordSnap(pFrameView->IsBordSnap());
+        mpView->SetHlplSnap(pFrameView->IsHlplSnap());
+        mpView->SetOFrmSnap(pFrameView->IsOFrmSnap());
+        mpView->SetOPntSnap(pFrameView->IsOPntSnap());
+        mpView->SetOConSnap(pFrameView->IsOConSnap());
+    }
 
-    bIsInDragMode = sal_False;
+    bIsInDragMode = false;
     ForcePointer(&rMEvt);
     FuPoor::MouseButtonUp(rMEvt);
 
-    return sal_False;
+    return false;
 }
 
 /**
  * Process keyboard input
  * @returns sal_True if a KeyEvent is being processed, sal_False otherwise
  */
-sal_Bool FuDraw::KeyInput(const KeyEvent& rKEvt)
+bool FuDraw::KeyInput(const KeyEvent& rKEvt)
 {
-    sal_Bool bReturn = sal_False;
+    bool bReturn = false;
 
     switch ( rKEvt.GetKeyCode().GetCode() )
     {
@@ -381,9 +357,9 @@ sal_Bool FuDraw::KeyInput(const KeyEvent& rKEvt)
         {
             if (!mpDocSh->IsReadOnly())
             {
-                if ( mpView && mpView->IsPresObjSelected(sal_False, sal_True, sal_False, sal_True) )
+                if (mpView->IsPresObjSelected(false, true, false, true))
                 {
-                    InfoBox(mpWindow, SD_RESSTR(STR_ACTION_NOTPOSSIBLE) ).Execute();
+                    ScopedVclPtr<InfoBox>::Create(mpWindow, SD_RESSTR(STR_ACTION_NOTPOSSIBLE) )->Execute();
                 }
                 else
                 {
@@ -392,25 +368,25 @@ sal_Bool FuDraw::KeyInput(const KeyEvent& rKEvt)
                        avoid the restoration of an no more existing object in
                        ::SelectionHasChanged after deletion. All other OLE
                        objects are not affected. */
-                    OSL_ASSERT (mpViewShell->GetViewShell()!=NULL);
+                    OSL_ASSERT (mpViewShell->GetViewShell()!=nullptr);
                     Client* pIPClient = static_cast<Client*>(
                         mpViewShell->GetViewShell()->GetIPClient());
                     if (pIPClient && pIPClient->IsObjectInPlaceActive())
-                        pIPClient->SetSdrGrafObj(NULL);
+                        pIPClient->SetSdrGrafObj(nullptr);
 
                     // wait-mousepointer while deleting object
-                    WaitObject aWait( (Window*)mpViewShell->GetActiveWindow() );
+                    WaitObject aWait( static_cast<vcl::Window*>(mpViewShell->GetActiveWindow()) );
                     // delete object
                     mpView->DeleteMarked();
                 }
             }
-            bReturn = sal_True;
+            bReturn = true;
         }
         break;
 
         case KEY_TAB:
         {
-            KeyCode aCode = rKEvt.GetKeyCode();
+            vcl::KeyCode aCode = rKEvt.GetKeyCode();
 
             if ( !aCode.IsMod1() && !aCode.IsMod2() )
             {
@@ -421,57 +397,61 @@ sal_Bool FuDraw::KeyInput(const KeyEvent& rKEvt)
                 // Switch to FuSelect.
                 mpViewShell->GetViewFrame()->GetDispatcher()->Execute(
                     SID_OBJECT_SELECT,
-                    SFX_CALLMODE_ASYNCHRON | SFX_CALLMODE_RECORD);
+                    SfxCallMode::ASYNCHRON | SfxCallMode::RECORD);
 
                 // changeover to the next object
                 if(!mpView->MarkNextObj( !aCode.IsShift() ))
                 {
-                    // No next object: go over open end and
-                    // get first from the other side
-                    mpView->UnmarkAllObj();
-                    mpView->MarkNextObj(!aCode.IsShift());
+                    //If there is only one object, don't do the UnmarkAllObj() & MarkNextObj().
+                    if ( mpView->GetMarkableObjCount() > 1 && mpView->AreObjectsMarked() )
+                    {
+                        // No next object: go over open end and get first from
+                        // the other side
+                        mpView->UnmarkAllObj();
+                        mpView->MarkNextObj(!aCode.IsShift());
+                    }
                 }
 
                 if(mpView->AreObjectsMarked())
                     mpView->MakeVisible(mpView->GetAllMarkedRect(), *mpWindow);
 
-                bReturn = sal_True;
+                bReturn = true;
             }
         }
         break;
 
         case KEY_END:
         {
-            KeyCode aCode = rKEvt.GetKeyCode();
+            vcl::KeyCode aCode = rKEvt.GetKeyCode();
 
             if ( aCode.IsMod1() )
             {
                 // mark last object
                 mpView->UnmarkAllObj();
-                mpView->MarkNextObj(sal_False);
+                mpView->MarkNextObj();
 
                 if(mpView->AreObjectsMarked())
                     mpView->MakeVisible(mpView->GetAllMarkedRect(), *mpWindow);
 
-                bReturn = sal_True;
+                bReturn = true;
             }
         }
         break;
 
         case KEY_HOME:
         {
-            KeyCode aCode = rKEvt.GetKeyCode();
+            vcl::KeyCode aCode = rKEvt.GetKeyCode();
 
             if ( aCode.IsMod1() )
             {
                 // mark first object
                 mpView->UnmarkAllObj();
-                mpView->MarkNextObj(sal_True);
+                mpView->MarkNextObj(true);
 
                 if(mpView->AreObjectsMarked())
                     mpView->MakeVisible(mpView->GetAllMarkedRect(), *mpWindow);
 
-                bReturn = sal_True;
+                bReturn = true;
             }
         }
         break;
@@ -489,23 +469,20 @@ sal_Bool FuDraw::KeyInput(const KeyEvent& rKEvt)
         mpWindow->ReleaseMouse();
     }
 
-    return (bReturn);
+    return bReturn;
 }
 
-
 void FuDraw::Activate()
 {
     FuPoor::Activate();
     ForcePointer();
 }
 
-
 void FuDraw::Deactivate()
 {
     FuPoor::Deactivate();
 }
 
-
 /**
  * Toggle mouse-pointer
  */
@@ -513,8 +490,8 @@ void FuDraw::ForcePointer(const MouseEvent* pMEvt)
 {
     Point aPnt;
     sal_uInt16 nModifier = 0;
-    sal_Bool bLeftDown = sal_False;
-    sal_Bool bDefPointer = sal_True;
+    bool bLeftDown = false;
+    bool bDefPointer = true;
 
     if (pMEvt)
     {
@@ -532,8 +509,8 @@ void FuDraw::ForcePointer(const MouseEvent* pMEvt)
         if (SD_MOD()->GetWaterCan() && !mpView->PickHandle(aPnt))
         {
             // water can mode
-            bDefPointer = sal_False;
-            mpWindow->SetPointer(Pointer(POINTER_FILL));
+            bDefPointer = false;
+            mpWindow->SetPointer(Pointer(PointerStyle::Fill));
         }
     }
     else
@@ -543,59 +520,59 @@ void FuDraw::ForcePointer(const MouseEvent* pMEvt)
         if (SD_MOD()->GetWaterCan() && !pHdl)
         {
             // water can mode
-            bDefPointer = sal_False;
-            mpWindow->SetPointer(Pointer(POINTER_FILL));
+            bDefPointer = false;
+            mpWindow->SetPointer(Pointer(PointerStyle::Fill));
         }
         else if (!pHdl &&
                  mpViewShell->GetViewFrame()->HasChildWindow(SvxBmpMaskChildWindow::GetChildWindowId()))
         {
             // pipette mode
-            SvxBmpMask* pMask = (SvxBmpMask*) mpViewShell->GetViewFrame()->GetChildWindow(SvxBmpMaskChildWindow::GetChildWindowId())->GetWindow();
-
+            SfxChildWindow* pWnd = mpViewShell->GetViewFrame()->GetChildWindow(SvxBmpMaskChildWindow::GetChildWindowId());
+            SvxBmpMask* pMask = pWnd ? static_cast<SvxBmpMask*>(pWnd->GetWindow()) : nullptr;
             if (pMask && pMask->IsEyedropping())
             {
-                bDefPointer = sal_False;
-                mpWindow->SetPointer(Pointer(POINTER_REFHAND));
+                bDefPointer = false;
+                mpWindow->SetPointer(Pointer(PointerStyle::RefHand));
             }
         }
         else if (!mpView->IsAction())
         {
-            SdrObject* pObj = NULL;
-            SdrPageView* pPV = NULL;
+            SdrObject* pObj = nullptr;
+            SdrPageView* pPV = nullptr;
             SdrViewEvent aVEvt;
             SdrHitKind eHit = SDRHIT_NONE;
             SdrDragMode eDragMode = mpView->GetDragMode();
 
             if (pMEvt)
             {
-                eHit = mpView->PickAnything(*pMEvt, SDRMOUSEMOVE, aVEvt);
+                eHit = mpView->PickAnything(*pMEvt, SdrMouseEventKind::MOVE, aVEvt);
             }
 
             if ((eDragMode == SDRDRAG_ROTATE) && (eHit == SDRHIT_MARKEDOBJECT))
             {
                 // The goal of this request is show always the rotation-arrow for 3D-objects at rotation-modus
                 // Independent of the settings at Extras->Optionen->Grafik "Objekte immer verschieben"
-                // 2D-objects acquit in an other way. Otherwise, the rotation of 3d-objects around any axises
+                // 2D-objects acquit in an other way. Otherwise, the rotation of 3d-objects around any axes
                 // wouldn't be possible per default.
                 const SdrMarkList& rMarkList = mpView->GetMarkedObjectList();
                 SdrObject* pObject = rMarkList.GetMark(0)->GetMarkedSdrObj();
-                if ((pObject->ISA(E3dObject)) && (rMarkList.GetMarkCount() == 1))
+                if ((dynamic_cast<const E3dObject* >(pObject) !=  nullptr) && (rMarkList.GetMarkCount() == 1))
                 {
-                    mpWindow->SetPointer(Pointer(POINTER_ROTATE));
-                    bDefPointer = sal_False;     // Otherwise it'll be calles Joes routine and the mousepointer will reconfigurate again
+                    mpWindow->SetPointer(Pointer(PointerStyle::Rotate));
+                    bDefPointer = false;     // Otherwise it'll be calles Joes routine and the mousepointer will reconfigurate again
                 }
             }
 
             if (eHit == SDRHIT_NONE)
             {
                 // found nothing -> look after at the masterpage
-                mpView->PickObj(aPnt, mpView->getHitTolLog(), pObj, pPV, SDRSEARCH_ALSOONMASTER);
+                mpView->PickObj(aPnt, mpView->getHitTolLog(), pObj, pPV, SdrSearchOptions::ALSOONMASTER);
             }
             else if (eHit == SDRHIT_UNMARKEDOBJECT)
             {
                 pObj = aVEvt.pObj;
             }
-            else if (eHit == SDRHIT_TEXTEDITOBJ && this->ISA(FuSelection))
+            else if (eHit == SDRHIT_TEXTEDITOBJ && dynamic_cast< const FuSelection *>( this ) !=  nullptr)
             {
                 sal_uInt16 nSdrObjKind = aVEvt.pObj->GetObjIdentifier();
 
@@ -604,21 +581,21 @@ void FuDraw::ForcePointer(const MouseEvent* pMEvt)
                      nSdrObjKind != OBJ_OUTLINETEXT &&
                      aVEvt.pObj->IsEmptyPresObj() )
                 {
-                    pObj = NULL;
-                    bDefPointer = sal_False;
-                    mpWindow->SetPointer(Pointer(POINTER_ARROW));
+                    pObj = nullptr;
+                    bDefPointer = false;
+                    mpWindow->SetPointer(Pointer(PointerStyle::Arrow));
                 }
             }
 
-            if (pObj && pMEvt && !pMEvt->IsMod2() && this->ISA(FuSelection))
+            if (pObj && pMEvt && !pMEvt->IsMod2() && dynamic_cast< const   FuSelection *>( this ) !=  nullptr)
             {
                 // test for animation or ImageMap
                 bDefPointer = !SetPointer(pObj, aPnt);
 
-                if (bDefPointer && (pObj->ISA(SdrObjGroup) || pObj->ISA(E3dPolyScene)))
+                if (bDefPointer && (dynamic_cast< const SdrObjGroup *>( pObj ) != nullptr || dynamic_cast< const E3dPolyScene* >(pObj) !=  nullptr))
                 {
                     // take a glance into the group
-                    if (mpView->PickObj(aPnt, mpView->getHitTolLog(), pObj, pPV, SDRSEARCH_ALSOONMASTER | SDRSEARCH_DEEP))
+                    if (mpView->PickObj(aPnt, mpView->getHitTolLog(), pObj, pPV, SdrSearchOptions::ALSOONMASTER | SdrSearchOptions::DEEP))
                         bDefPointer = !SetPointer(pObj, aPnt);
                 }
             }
@@ -627,25 +604,25 @@ void FuDraw::ForcePointer(const MouseEvent* pMEvt)
 
     if (bDefPointer)
     {
-        mpWindow->SetPointer(mpView->GetPreferedPointer(
+        mpWindow->SetPointer(mpView->GetPreferredPointer(
                             aPnt, mpWindow, nModifier, bLeftDown));
     }
 }
 
 /**
- * Set cursor for animaton or imagemap
+ * Set cursor for animation or imagemap
  */
-sal_Bool FuDraw::SetPointer(SdrObject* pObj, const Point& rPos)
+bool FuDraw::SetPointer(SdrObject* pObj, const Point& rPos)
 {
-    sal_Bool bSet = sal_False;
+    bool bSet = false;
 
-    sal_Bool bAnimationInfo = (!mpDocSh->ISA(GraphicDocShell) &&
-                          mpDoc->GetAnimationInfo(pObj)) ? sal_True:sal_False;
+    bool bAnimationInfo = dynamic_cast< const GraphicDocShell *>( mpDocSh ) ==  nullptr &&
+                          mpDoc->GetAnimationInfo(pObj);
 
-    sal_Bool bImageMapInfo = sal_False;
+    bool bImageMapInfo = false;
 
     if (!bAnimationInfo)
-        bImageMapInfo = mpDoc->GetIMapInfo(pObj) ? sal_True:sal_False;
+        bImageMapInfo = mpDoc->GetIMapInfo(pObj) != nullptr;
 
     if (bAnimationInfo || bImageMapInfo)
     {
@@ -679,7 +656,7 @@ sal_Bool FuDraw::SetPointer(SdrObject* pObj, const Point& rPos)
                 ******************************************************/
                 SdAnimationInfo* pInfo = mpDoc->GetAnimationInfo(pObj);
 
-                if ((mpView->ISA(DrawView) &&
+                if(( dynamic_cast< const DrawView *>( mpView ) !=  nullptr &&
                       (pInfo->meClickAction == presentation::ClickAction_BOOKMARK  ||
                        pInfo->meClickAction == presentation::ClickAction_DOCUMENT  ||
                        pInfo->meClickAction == presentation::ClickAction_PREVPAGE  ||
@@ -691,7 +668,7 @@ sal_Bool FuDraw::SetPointer(SdrObject* pObj, const Point& rPos)
                        pInfo->meClickAction == presentation::ClickAction_MACRO     ||
                        pInfo->meClickAction == presentation::ClickAction_SOUND))
                                                                     ||
-                    (mpView->ISA(DrawView) &&
+                    ( dynamic_cast< const DrawView *>( mpView ) !=  nullptr &&
                         SlideShow::IsRunning( mpViewShell->GetViewShellBase() )   &&
                          (pInfo->meClickAction == presentation::ClickAction_VANISH            ||
                           pInfo->meClickAction == presentation::ClickAction_INVISIBLE         ||
@@ -701,8 +678,8 @@ sal_Bool FuDraw::SetPointer(SdrObject* pObj, const Point& rPos)
                             pInfo->meTextEffect != presentation::AnimationEffect_NONE )))))
                     {
                         // Animation object
-                        bSet = sal_True;
-                        mpWindow->SetPointer(Pointer(POINTER_REFHAND));
+                        bSet = true;
+                        mpWindow->SetPointer(Pointer(PointerStyle::RefHand));
                     }
             }
             else if (bImageMapInfo &&
@@ -711,8 +688,8 @@ sal_Bool FuDraw::SetPointer(SdrObject* pObj, const Point& rPos)
                 /******************************************************
                 * ImageMap
                 ******************************************************/
-                bSet = sal_True;
-                mpWindow->SetPointer(Pointer(POINTER_REFHAND));
+                bSet = true;
+                mpWindow->SetPointer(Pointer(PointerStyle::RefHand));
             }
         }
     }
@@ -720,8 +697,6 @@ sal_Bool FuDraw::SetPointer(SdrObject* pObj, const Point& rPos)
     return bSet;
 }
 
-
-
 /**
  * Response of doubleclick
  */
@@ -750,66 +725,65 @@ void FuDraw::DoubleClick(const MouseEvent& rMEvt)
                     /**********************************************************
                     * activate OLE-object
                     **********************************************************/
-                    mpViewShell->ActivateObject( (SdrOle2Obj*) pObj, 0);
+                    mpViewShell->ActivateObject( static_cast<SdrOle2Obj*>(pObj), 0);
                 }
             }
             else if (nInv == SdrInventor &&  nSdrObjKind == OBJ_GRAF && pObj->IsEmptyPresObj() )
             {
                 mpViewShell->GetViewFrame()->
                     GetDispatcher()->Execute( SID_INSERT_GRAPHIC,
-                                              SFX_CALLMODE_ASYNCHRON | SFX_CALLMODE_RECORD );
+                                              SfxCallMode::ASYNCHRON | SfxCallMode::RECORD );
             }
-            else if ( ( pObj->ISA(SdrTextObj) || pObj->ISA(SdrObjGroup) ) &&
+            else if ( ( dynamic_cast< const SdrTextObj *>( pObj ) != nullptr || dynamic_cast< const SdrObjGroup *>( pObj ) !=  nullptr ) &&
                       !SD_MOD()->GetWaterCan()                            &&
                       mpViewShell->GetFrameView()->IsDoubleClickTextEdit() &&
                       !mpDocSh->IsReadOnly())
             {
                 SfxUInt16Item aItem(SID_TEXTEDIT, 2);
                 mpViewShell->GetViewFrame()->GetDispatcher()->
-                                 Execute(SID_TEXTEDIT, SFX_CALLMODE_ASYNCHRON |
-                                         SFX_CALLMODE_RECORD, &aItem, 0L);
+                                 Execute(SID_TEXTEDIT, SfxCallMode::ASYNCHRON |
+                                         SfxCallMode::RECORD, &aItem, 0L);
             }
             else if (nInv == SdrInventor &&  nSdrObjKind == OBJ_GRUP)
             {
                 // hit group -> select subobject
                 mpView->UnMarkAll();
-                mpView->MarkObj(aMDPos, nHitLog, rMEvt.IsShift(), sal_True);
+                mpView->MarkObj(aMDPos, nHitLog, rMEvt.IsShift(), true);
             }
         }
     }
     else
-        mpViewShell->GetViewFrame()->GetDispatcher()->Execute(SID_OBJECT_SELECT, SFX_CALLMODE_ASYNCHRON | SFX_CALLMODE_RECORD);
+        mpViewShell->GetViewFrame()->GetDispatcher()->Execute(SID_OBJECT_SELECT, SfxCallMode::ASYNCHRON | SfxCallMode::RECORD);
 }
 
-
-sal_Bool FuDraw::RequestHelp(const HelpEvent& rHEvt)
+bool FuDraw::RequestHelp(const HelpEvent& rHEvt)
 {
-    sal_Bool bReturn = sal_False;
+    bool bReturn = false;
 
     if (Help::IsBalloonHelpEnabled() || Help::IsQuickHelpEnabled())
     {
         SdrViewEvent aVEvt;
 
-        MouseEvent aMEvt(mpWindow->GetPointerPosPixel(), 1, 0, MOUSE_LEFT);
+        MouseEvent aMEvt(mpWindow->GetPointerPosPixel(), 1, MouseEventModifiers::NONE, MOUSE_LEFT);
 
-        SdrHitKind eHit = mpView->PickAnything(aMEvt, SDRMOUSEBUTTONDOWN, aVEvt);
+        SdrHitKind eHit = mpView->PickAnything(aMEvt, SdrMouseEventKind::BUTTONDOWN, aVEvt);
 
         SdrObject* pObj = aVEvt.pObj;
 
-        if (eHit != SDRHIT_NONE && pObj != NULL)
+        if (eHit != SDRHIT_NONE && pObj != nullptr)
         {
             Point aPosPixel = rHEvt.GetMousePosPixel();
 
             bReturn = SetHelpText(pObj, aPosPixel, aVEvt);
 
-            if (!bReturn && (pObj->ISA(SdrObjGroup) || pObj->ISA(E3dPolyScene)))
+            if (!bReturn && (dynamic_cast< const SdrObjGroup *>( pObj ) != nullptr || dynamic_cast< const E3dPolyScene* >(pObj) !=  nullptr))
             {
                 // take a glance into the group
-                SdrPageView* pPV = NULL;
+                SdrPageView* pPV = nullptr;
 
                 Point aPos(mpWindow->PixelToLogic(mpWindow->ScreenToOutputPixel(aPosPixel)));
 
-                if (mpView->PickObj(aPos, mpView->getHitTolLog(), pObj, pPV, SDRSEARCH_ALSOONMASTER | SDRSEARCH_DEEP))
+                if (mpView->PickObj(aPos, mpView->getHitTolLog(), pObj, pPV, SdrSearchOptions::ALSOONMASTER | SdrSearchOptions::DEEP))
                     bReturn = SetHelpText(pObj, aPosPixel, aVEvt);
             }
         }
@@ -820,14 +794,12 @@ sal_Bool FuDraw::RequestHelp(const HelpEvent& rHEvt)
         bReturn = FuPoor::RequestHelp(rHEvt);
     }
 
-    return(bReturn);
+    return bReturn;
 }
 
-
-
-sal_Bool FuDraw::SetHelpText(SdrObject* pObj, const Point& rPosPixel, const SdrViewEvent& rVEvt)
+bool FuDraw::SetHelpText(SdrObject* pObj, const Point& rPosPixel, const SdrViewEvent& rVEvt)
 {
-    sal_Bool bSet = sal_False;
+    bool bSet = false;
     OUString aHelpText;
     Point aPos(mpWindow->PixelToLogic(mpWindow->ScreenToOutputPixel(rPosPixel)));
 
@@ -844,11 +816,11 @@ sal_Bool FuDraw::SetHelpText(SdrObject* pObj, const Point& rPosPixel, const SdrV
             if (aHelpText.isEmpty())
             {
                 // show url if no name is available
-                aHelpText = INetURLObject::decode( pIMapObj->GetURL(), '%', INetURLObject::DECODE_WITH_CHARSET );
+                aHelpText = INetURLObject::decode( pIMapObj->GetURL(), INetURLObject::DECODE_WITH_CHARSET );
             }
         }
     }
-    else if (!mpDocSh->ISA(GraphicDocShell) && mpDoc->GetAnimationInfo(pObj))
+    else if (dynamic_cast< GraphicDocShell *>( mpDocSh ) ==  nullptr && mpDoc->GetAnimationInfo(pObj))
     {
         SdAnimationInfo* pInfo = mpDoc->GetAnimationInfo(pObj);
 
@@ -887,7 +859,7 @@ sal_Bool FuDraw::SetHelpText(SdrObject* pObj, const Point& rPosPixel, const SdrV
                 // jump to object/page
                 aHelpText = SD_RESSTR(STR_CLICK_ACTION_BOOKMARK);
                 aHelpText += ": ";
-                aHelpText += INetURLObject::decode( pInfo->GetBookmark(), '%', INetURLObject::DECODE_WITH_CHARSET );
+                aHelpText += INetURLObject::decode( pInfo->GetBookmark(), INetURLObject::DECODE_WITH_CHARSET );
             }
             break;
 
@@ -896,7 +868,7 @@ sal_Bool FuDraw::SetHelpText(SdrObject* pObj, const Point& rPosPixel, const SdrV
                 // jump to document (object/page)
                 aHelpText = SD_RESSTR(STR_CLICK_ACTION_DOCUMENT);
                 aHelpText += ": ";
-                aHelpText += INetURLObject::decode( pInfo->GetBookmark(), '%', INetURLObject::DECODE_WITH_CHARSET );
+                aHelpText += INetURLObject::decode( pInfo->GetBookmark(), INetURLObject::DECODE_WITH_CHARSET );
             }
             break;
 
@@ -905,7 +877,7 @@ sal_Bool FuDraw::SetHelpText(SdrObject* pObj, const Point& rPosPixel, const SdrV
                 // execute program
                 aHelpText = SD_RESSTR(STR_CLICK_ACTION_PROGRAM);
                 aHelpText += ": ";
-                aHelpText += INetURLObject::decode( pInfo->GetBookmark(), '%', INetURLObject::DECODE_WITH_CHARSET );
+                aHelpText += INetURLObject::decode( pInfo->GetBookmark(), INetURLObject::DECODE_WITH_CHARSET );
             }
             break;
 
@@ -960,27 +932,26 @@ sal_Bool FuDraw::SetHelpText(SdrObject* pObj, const Point& rPosPixel, const SdrV
         /**************************************************************
         * URL-Field
         **************************************************************/
-        aHelpText = INetURLObject::decode( rVEvt.pURLField->GetURL(), '%', INetURLObject::DECODE_WITH_CHARSET );
+        aHelpText = INetURLObject::decode( rVEvt.pURLField->GetURL(), INetURLObject::DECODE_WITH_CHARSET );
     }
 
     if (!aHelpText.isEmpty())
     {
-        bSet = sal_True;
+        bSet = true;
         Rectangle aLogicPix = mpWindow->LogicToPixel(pObj->GetLogicRect());
         Rectangle aScreenRect(mpWindow->OutputToScreenPixel(aLogicPix.TopLeft()),
                               mpWindow->OutputToScreenPixel(aLogicPix.BottomRight()));
 
         if (Help::IsBalloonHelpEnabled())
-            Help::ShowBalloon( (Window*)mpWindow, rPosPixel, aScreenRect, aHelpText);
+            Help::ShowBalloon( static_cast<vcl::Window*>(mpWindow), rPosPixel, aScreenRect, aHelpText);
         else if (Help::IsQuickHelpEnabled())
-            Help::ShowQuickHelp( (Window*)mpWindow, aScreenRect, aHelpText);
+            Help::ShowQuickHelp( static_cast<vcl::Window*>(mpWindow), aScreenRect, aHelpText);
     }
 
     return bSet;
 }
 
-
-/** is called when the currenct function should be aborted. <p>
+/** is called when the current function should be aborted. <p>
     This is used when a function gets a KEY_ESCAPE but can also
     be called directly.
 
@@ -1021,7 +992,7 @@ bool FuDraw::cancel()
         // Switch to FuSelect.
         mpViewShell->GetViewFrame()->GetDispatcher()->Execute(
             SID_OBJECT_SELECT,
-            SFX_CALLMODE_ASYNCHRON | SFX_CALLMODE_RECORD);
+            SfxCallMode::ASYNCHRON | SfxCallMode::RECORD);
 
         bReturn = true;
     }
