@@ -85,12 +85,13 @@ static sal_uInt16 SidArray[] = {
     SID_ATTR_CHAR_FONT,               //   10007
     SID_ATTR_CHAR_POSTURE,            //   10008
     SID_ATTR_CHAR_WEIGHT,             //   10009
-    SID_ATTR_CHAR_SHADOWED,     //10010
-    SID_ATTR_CHAR_STRIKEOUT,        //10013
+    SID_ATTR_CHAR_SHADOWED,           //   10010
+    SID_ATTR_CHAR_STRIKEOUT,          //   10013
     SID_ATTR_CHAR_UNDERLINE,          //   10014
     SID_ATTR_CHAR_FONTHEIGHT,         //   10015
     SID_ATTR_CHAR_COLOR,              //   10017
-    SID_ATTR_CHAR_KERNING,          //10018
+    SID_ATTR_CHAR_KERNING,            //   10018
+    SID_ATTR_CHAR_CASEMAP,            //   10019
     SID_ATTR_PARA_ADJUST_LEFT,        //   10028
     SID_ATTR_PARA_ADJUST_RIGHT,       //   10029
     SID_ATTR_PARA_ADJUST_CENTER,      //   10030
@@ -124,12 +125,11 @@ static sal_uInt16 SidArray[] = {
     SID_TEXTDIRECTION_TOP_TO_BOTTOM,  //   10908
     SID_ATTR_PARA_LEFT_TO_RIGHT,      //   10950
     SID_ATTR_PARA_RIGHT_TO_LEFT,      //   10951
+    SID_PARASPACE_INCREASE,           //   11145
+    SID_PARASPACE_DECREASE,           //   11146
     FN_NUM_BULLET_ON,                 //   20138
-    SID_PARASPACE_INCREASE,           //   27346
-    SID_PARASPACE_DECREASE,           //   27347
                             0 };
 
-TYPEINIT1( FuText, FuConstruct );
 
 static bool bTestText = false;
 
@@ -155,8 +155,8 @@ void FuText::disposing()
 {
     if(mpView)
     {
-        if(mpView->SdrEndTextEdit(false) == SDRENDTEXTEDIT_DELETED)
-            mxTextObj.reset( 0 );
+        if(mpView->SdrEndTextEdit() == SDRENDTEXTEDIT_DELETED)
+            mxTextObj.reset( nullptr );
 
         // reset the RequestHandler of the used Outliner to the handler of the document
         ::Outliner* pOutliner = mpView->GetTextEditOutliner();
@@ -196,7 +196,7 @@ void FuText::DoExecute( SfxRequest& )
         // Try to select an object
         SdrPageView* pPV = mpView->GetSdrPageView();
         SdrViewEvent aVEvt;
-        mpView->PickAnything(aMEvt, SDRMOUSEBUTTONDOWN, aVEvt);
+        mpView->PickAnything(aMEvt, SdrMouseEventKind::BUTTONDOWN, aVEvt);
         mpView->MarkObj(aVEvt.pRootObj, pPV);
 
         mxTextObj.reset( dynamic_cast< SdrTextObj* >( aVEvt.pObj ) );
@@ -255,7 +255,7 @@ bool FuText::MouseButtonDown(const MouseEvent& rMEvt)
 
     mpView->SetMarkHdlWhenTextEdit(true);
     SdrViewEvent aVEvt;
-    SdrHitKind eHit = mpView->PickAnything(rMEvt, SDRMOUSEBUTTONDOWN, aVEvt);
+    SdrHitKind eHit = mpView->PickAnything(rMEvt, SdrMouseEventKind::BUTTONDOWN, aVEvt);
 
     if (eHit == SDRHIT_TEXTEDIT)
     {
@@ -279,8 +279,8 @@ bool FuText::MouseButtonDown(const MouseEvent& rMEvt)
                    list. The call MarkObj further below accesses then the dead
                    object. As a simple fix, we determine eHit after
                    SdrEndTextEdit again, this returns then SDRHIT_NONE. */
-                mxTextObj.reset( NULL );
-                eHit = mpView->PickAnything(rMEvt, SDRMOUSEBUTTONDOWN, aVEvt);
+                mxTextObj.reset( nullptr );
+                eHit = mpView->PickAnything(rMEvt, SdrMouseEventKind::BUTTONDOWN, aVEvt);
             }
 
             mpView->SetCurrentObj(OBJ_TEXT);
@@ -322,7 +322,7 @@ bool FuText::MouseButtonDown(const MouseEvent& rMEvt)
                            select object and set to EditMode */
                         mpView->MarkObj(aVEvt.pRootObj, pPV);
 
-                        if (aVEvt.pObj && aVEvt.pObj->ISA(SdrTextObj))
+                        if (aVEvt.pObj && dynamic_cast< const SdrTextObj *>( aVEvt.pObj ) !=  nullptr)
                         {
                             mxTextObj.reset( static_cast<SdrTextObj*>(aVEvt.pObj) );
                         }
@@ -376,8 +376,8 @@ bool FuText::MouseButtonDown(const MouseEvent& rMEvt)
                             {
                                 // force new handle identification, the pointer will be dead here
                                 // since SdrEndTextEdit has resetted (deleted) the handles.
-                                aVEvt.pHdl = 0;
-                                mpView->PickAnything(rMEvt, SDRMOUSEBUTTONDOWN, aVEvt);
+                                aVEvt.pHdl = nullptr;
+                                mpView->PickAnything(rMEvt, SdrMouseEventKind::BUTTONDOWN, aVEvt);
                             }
                         }
 
@@ -399,11 +399,11 @@ bool FuText::MouseButtonDown(const MouseEvent& rMEvt)
                         if ( ! rMEvt.IsRight())
                         {
                             // we need to pick again since SdrEndTextEdit can rebuild the handles list
-                            eHit = mpView->PickAnything(rMEvt, SDRMOUSEBUTTONDOWN, aVEvt);
+                            eHit = mpView->PickAnything(rMEvt, SdrMouseEventKind::BUTTONDOWN, aVEvt);
                             if( (eHit == SDRHIT_HANDLE) || (eHit == SDRHIT_MARKEDOBJECT) )
                             {
                                 sal_uInt16 nDrgLog = sal_uInt16 ( mpWindow->PixelToLogic(Size(DRGPIX,0)).Width() );
-                                mpView->BegDragObj(aMDPos, (OutputDevice*) NULL, aVEvt.pHdl, nDrgLog);
+                                mpView->BegDragObj(aMDPos, nullptr, aVEvt.pHdl, nDrgLog);
                             }
                         }
                         bReturn = true;
@@ -416,7 +416,7 @@ bool FuText::MouseButtonDown(const MouseEvent& rMEvt)
                     mpView->SetCurrentObj(OBJ_TEXT);
                     mpView->SetEditMode(SDREDITMODE_CREATE);
                     sal_uInt16 nDrgLog = sal_uInt16 ( mpWindow->PixelToLogic(Size(DRGPIX,0)).Width() );
-                    mpView->BegCreateObj(aMDPos, (OutputDevice*) NULL, nDrgLog);
+                    mpView->BegCreateObj(aMDPos, nullptr, nDrgLog);
                 }
                 else
                 {
@@ -441,7 +441,7 @@ bool FuText::MouseButtonDown(const MouseEvent& rMEvt)
         mpViewShell->GetViewFrame()->GetBindings().Invalidate(SidArray);
     }
 
-    return (bReturn);
+    return bReturn;
 }
 
 bool FuText::MouseMove(const MouseEvent& rMEvt)
@@ -467,7 +467,7 @@ bool FuText::MouseMove(const MouseEvent& rMEvt)
 
     ForcePointer(&rMEvt);
 
-    return (bReturn);
+    return bReturn;
 }
 
 void FuText::ImpSetAttributesForNewTextObject(SdrTextObj* pTxtObj)
@@ -513,7 +513,7 @@ void FuText::ImpSetAttributesForNewTextObject(SdrTextObj* pTxtObj)
             aSet.Put(makeSdrTextAutoGrowWidthItem(true));
             aSet.Put(makeSdrTextAutoGrowHeightItem(false));
 
-            // Set defaults for vertical klick-n'drag text object, pool defaults are:
+            // Set defaults for vertical click-n'drag text object, pool defaults are:
             // SdrTextVertAdjustItem: SDRTEXTVERTADJUST_TOP
             // SdrTextHorzAdjustItem: SDRTEXTHORZADJUST_BLOCK
             // Analog to that:
@@ -581,8 +581,6 @@ void FuText::ImpSetAttributesFitCommon(SdrTextObj* pTxtObj)
 bool FuText::MouseButtonUp(const MouseEvent& rMEvt)
 {
     bool bReturn = false;
-    SdrObject* pObj;
-    SdrPageView* pPV;
     if (aDragTimer.IsActive())
     {
         aDragTimer.Stop();
@@ -619,7 +617,7 @@ bool FuText::MouseButtonUp(const MouseEvent& rMEvt)
 
         if (bReset)
         {
-            mxTextObj.reset( 0 );
+            mxTextObj.reset( nullptr );
         }
     }
 
@@ -631,7 +629,7 @@ bool FuText::MouseButtonUp(const MouseEvent& rMEvt)
 
         if (bDragWithCopy)
         {
-            bDragWithCopy = !mpView->IsPresObjSelected(false, true);
+            bDragWithCopy = !mpView->IsPresObjSelected(false);
         }
 
         mpView->SetDragWithCopy(bDragWithCopy);
@@ -654,11 +652,16 @@ bool FuText::MouseButtonUp(const MouseEvent& rMEvt)
             /*************************************************************
             * From text mode, you don't want to rotate immediately.
             **************************************************************/
-            if (mpView->PickObj(aMDPos, mpView->getHitTolLog(), pObj, pPV, SDRSEARCH_ALSOONMASTER | SDRSEARCH_BEFOREMARK))
+            SdrObject* pObj;
+            SdrPageView* pPV;
+            if (mpView->PickObj(aMDPos, mpView->getHitTolLog(), pObj, pPV, SdrSearchOptions::ALSOONMASTER | SdrSearchOptions::BEFOREMARK))
             {
-                mpView->UnmarkAllObj();
-                mpView->MarkObj(pObj,pPV,false,false);
-                return (bReturn);
+                if (pPV->IsObjSelectable(pObj))
+                {
+                    mpView->UnmarkAllObj();
+                    mpView->MarkObj(pObj,pPV);
+                    return bReturn;
+                }
             }
         }
     }
@@ -703,7 +706,7 @@ bool FuText::MouseButtonUp(const MouseEvent& rMEvt)
         if (!mpView->EndCreateObj(SDRCREATE_FORCEEND))
         {
             // it was not possible to create text object
-            mxTextObj.reset(0);
+            mxTextObj.reset(nullptr);
         }
         else if (nSlotId == SID_TEXT_FITTOSIZE)
         {
@@ -743,7 +746,7 @@ bool FuText::MouseButtonUp(const MouseEvent& rMEvt)
     {
         SdrPageView* pPV2 = mpView->GetSdrPageView();
         SdrViewEvent aVEvt;
-        mpView->PickAnything(rMEvt, SDRMOUSEBUTTONDOWN, aVEvt);
+        mpView->PickAnything(rMEvt, SdrMouseEventKind::BUTTONDOWN, aVEvt);
         mpView->MarkObj(aVEvt.pRootObj, pPV2);
     }
 
@@ -758,7 +761,7 @@ bool FuText::MouseButtonUp(const MouseEvent& rMEvt)
             mpView->SetCurrentObj(OBJ_TEXT);
             mpView->SetEditMode(SDREDITMODE_CREATE);
             sal_uInt16 nDrgLog = sal_uInt16 ( mpWindow->PixelToLogic(Size(DRGPIX,0)).Width() );
-            mpView->BegCreateObj(aMDPos, (OutputDevice*) NULL, nDrgLog);
+            mpView->BegCreateObj(aMDPos, nullptr, nDrgLog);
 
             bool bSnapEnabled = mpView->IsSnapEnabled();
 
@@ -778,7 +781,7 @@ bool FuText::MouseButtonUp(const MouseEvent& rMEvt)
 
             if(!mpView->EndCreateObj(SDRCREATE_FORCEEND))
             {
-                mxTextObj.reset(0);
+                mxTextObj.reset(nullptr);
             }
 
             if(bSnapEnabled)
@@ -796,10 +799,10 @@ bool FuText::MouseButtonUp(const MouseEvent& rMEvt)
                 {
                     // Here, all items which need to be different from pool default need to be set
                     // again on the newly created text object.
-                    // Since this is a simple klick text object, it is first created, then SetVertical()
+                    // Since this is a simple click text object, it is first created, then SetVertical()
                     // is used, then ImpSetAttributesForNewTextObject is called and then the object is
                     // deleted again since not the minimum drag distance was travelled. Then, a new
-                    // klick text object is created and thus all that stuff needs to be set again here.
+                    // click text object is created and thus all that stuff needs to be set again here.
 
                     // Before using the new object the vertical writing mode
                     // needs to be set. This is done here at the OutlinerParaObject
@@ -869,7 +872,7 @@ bool FuText::MouseButtonUp(const MouseEvent& rMEvt)
             // switch to selection
             if (mpView->SdrEndTextEdit() == SDRENDTEXTEDIT_DELETED)
             {
-                mxTextObj.reset(0);
+                mxTextObj.reset(nullptr);
             }
 
             mpViewShell->GetViewFrame()->GetDispatcher()->Execute( SID_OBJECT_SELECT,
@@ -883,7 +886,7 @@ bool FuText::MouseButtonUp(const MouseEvent& rMEvt)
     }
     bMBDown = false;
     FuConstruct::MouseButtonUp(rMEvt);
-    return (bReturn);
+    return bReturn;
 }
 
 /**
@@ -902,7 +905,7 @@ bool FuText::KeyInput(const KeyEvent& rKEvt)
     {
         // maybe object is deleted, test if it's equal to the selected object
         const SdrMarkList& rMarkList = mpView->GetMarkedObjectList();
-        SdrObject* pSelectedObj = 0L;
+        SdrObject* pSelectedObj = nullptr;
 
         if(1 == rMarkList.GetMarkCount())
         {
@@ -912,7 +915,7 @@ bool FuText::KeyInput(const KeyEvent& rKEvt)
 
         if(mxTextObj.get() != pSelectedObj)
         {
-            mxTextObj.reset(0);
+            mxTextObj.reset(nullptr);
         }
     }
 
@@ -960,7 +963,7 @@ bool FuText::KeyInput(const KeyEvent& rKEvt)
         bReturn = FuDraw::KeyInput(aKEvt);
     }
 
-    return (bReturn);
+    return bReturn;
 }
 
 void FuText::Activate()
@@ -1067,7 +1070,7 @@ void FuText::SetInEditMode(const MouseEvent& rMEvt, bool bQuickDrag)
                         nSdrObjKind = mxTextObj->GetObjIdentifier();
 
                         SdrViewEvent aVEvt;
-                        SdrHitKind eHit = mpView->PickAnything(rMEvt, SDRMOUSEBUTTONDOWN, aVEvt);
+                        SdrHitKind eHit = mpView->PickAnything(rMEvt, SdrMouseEventKind::BUTTONDOWN, aVEvt);
 
                         if (eHit == SDRHIT_TEXTEDIT)
                         {
@@ -1093,7 +1096,7 @@ void FuText::SetInEditMode(const MouseEvent& rMEvt, bool bQuickDrag)
                         {
                             // Move cursor to end of text
                             ESelection aNewSelection(EE_PARA_NOT_FOUND, EE_INDEX_NOT_FOUND, EE_PARA_NOT_FOUND, EE_INDEX_NOT_FOUND);
-                            if (pOLV != NULL)
+                            if (pOLV != nullptr)
                                 pOLV->SetSelection(aNewSelection);
                         }
                     }
@@ -1107,7 +1110,7 @@ void FuText::SetInEditMode(const MouseEvent& rMEvt, bool bQuickDrag)
     }
     else
     {
-        mxTextObj.reset(0);
+        mxTextObj.reset(nullptr);
     }
 }
 
@@ -1153,7 +1156,7 @@ bool FuText::DeleteDefaultText()
         }
     }
 
-    return(bDeleted);
+    return bDeleted;
 }
 
 bool FuText::Command(const CommandEvent& rCEvt)
@@ -1174,10 +1177,10 @@ bool FuText::RequestHelp(const HelpEvent& rHEvt)
         const SvxFieldItem* pFieldItem = pOLV->GetFieldUnderMousePointer();
         const SvxFieldData* pField = pFieldItem->GetField();
 
-        if (pField && pField->ISA(SvxURLField))
+        if (pField && dynamic_cast< const SvxURLField *>( pField ) !=  nullptr)
         {
             // URL-Field
-            aHelpText = INetURLObject::decode( static_cast<const SvxURLField*>(pField)->GetURL(), '%', INetURLObject::DECODE_WITH_CHARSET );
+            aHelpText = INetURLObject::decode( static_cast<const SvxURLField*>(pField)->GetURL(), INetURLObject::DECODE_WITH_CHARSET );
         }
         if (!aHelpText.isEmpty())
         {
@@ -1187,11 +1190,11 @@ bool FuText::RequestHelp(const HelpEvent& rHEvt)
 
             if (Help::IsBalloonHelpEnabled())
             {
-                bReturn = Help::ShowBalloon( (vcl::Window*)mpWindow, rHEvt.GetMousePosPixel(), aScreenRect, aHelpText);
+                bReturn = Help::ShowBalloon( static_cast<vcl::Window*>(mpWindow), rHEvt.GetMousePosPixel(), aScreenRect, aHelpText);
             }
             else if (Help::IsQuickHelpEnabled())
             {
-                bReturn = Help::ShowQuickHelp( (vcl::Window*)mpWindow, aScreenRect, aHelpText);
+                bReturn = Help::ShowQuickHelp( static_cast<vcl::Window*>(mpWindow), aScreenRect, aHelpText);
             }
         }
     }
@@ -1201,7 +1204,7 @@ bool FuText::RequestHelp(const HelpEvent& rHEvt)
         bReturn = FuConstruct::RequestHelp(rHEvt);
     }
 
-    return(bReturn);
+    return bReturn;
 }
 
 void FuText::ReceiveRequest(SfxRequest& rReq)
@@ -1215,7 +1218,7 @@ void FuText::ReceiveRequest(SfxRequest& rReq)
     {
         MouseEvent aMEvt(mpWindow->GetPointerPosPixel());
 
-        mxTextObj.reset(0);
+        mxTextObj.reset(nullptr);
 
         if (nSlotId == SID_TEXTEDIT)
         {
@@ -1228,10 +1231,10 @@ void FuText::ReceiveRequest(SfxRequest& rReq)
                 // Try to select an object
                 SdrPageView* pPV = mpView->GetSdrPageView();
                 SdrViewEvent aVEvt;
-                mpView->PickAnything(aMEvt, SDRMOUSEBUTTONDOWN, aVEvt);
+                mpView->PickAnything(aMEvt, SdrMouseEventKind::BUTTONDOWN, aVEvt);
                 mpView->MarkObj(aVEvt.pRootObj, pPV);
 
-                if (aVEvt.pObj && aVEvt.pObj->ISA(SdrTextObj))
+                if (aVEvt.pObj && dynamic_cast< SdrTextObj *>( aVEvt.pObj ) !=  nullptr)
                 {
                     mxTextObj.reset( static_cast< SdrTextObj* >( aVEvt.pObj ) );
                 }
@@ -1245,7 +1248,7 @@ void FuText::ReceiveRequest(SfxRequest& rReq)
             {
                 SdrObject* pObj = rMarkList.GetMark(0)->GetMarkedSdrObj();
 
-                if (pObj->ISA(SdrTextObj))
+                if( dynamic_cast< const SdrTextObj *>( pObj ) !=  nullptr)
                 {
                     mxTextObj.reset( static_cast< SdrTextObj* >( pObj ) );
                 }
@@ -1285,11 +1288,11 @@ SdrObject* FuText::CreateDefaultObject(const sal_uInt16 nID, const Rectangle& rR
 
     SdrObject* pObj = SdrObjFactory::MakeNewObject(
         mpView->GetCurrentObjInventor(), mpView->GetCurrentObjIdentifier(),
-        0L, mpDoc);
+        nullptr, mpDoc);
 
     if(pObj)
     {
-        if(pObj->ISA(SdrTextObj))
+        if( dynamic_cast< SdrTextObj *>( pObj ) !=  nullptr)
         {
             SdrTextObj* pText = static_cast<SdrTextObj*>(pObj);
             pText->SetLogicRect(rRectangle);
@@ -1336,7 +1339,7 @@ bool FuText::cancel()
     if ( mpView->IsTextEdit() )
     {
         if(mpView->SdrEndTextEdit() == SDRENDTEXTEDIT_DELETED)
-            mxTextObj.reset(0);
+            mxTextObj.reset(nullptr);
 
         mpView->SetCurrentObj(OBJ_TEXT);
         mpView->SetEditMode(SDREDITMODE_EDIT);
