@@ -38,7 +38,7 @@ public:
 
 CanvasUpdateRequester::RequesterMap CanvasUpdateRequester::maRequesterMap;
 
-::boost::shared_ptr<CanvasUpdateRequester> CanvasUpdateRequester::Instance (
+std::shared_ptr<CanvasUpdateRequester> CanvasUpdateRequester::Instance (
     const Reference<rendering::XSpriteCanvas>& rxSharedCanvas)
 {
     RequesterMap::const_iterator iRequester;
@@ -49,7 +49,7 @@ CanvasUpdateRequester::RequesterMap CanvasUpdateRequester::maRequesterMap;
     }
 
     // No requester for the given canvas found.  Create a new one.
-    ::boost::shared_ptr<CanvasUpdateRequester> pRequester (
+    std::shared_ptr<CanvasUpdateRequester> pRequester (
         new CanvasUpdateRequester(rxSharedCanvas), Deleter());
     maRequesterMap.push_back(RequesterMap::value_type(rxSharedCanvas,pRequester));
     return pRequester;
@@ -58,7 +58,7 @@ CanvasUpdateRequester::RequesterMap CanvasUpdateRequester::maRequesterMap;
 CanvasUpdateRequester::CanvasUpdateRequester (
     const Reference<rendering::XSpriteCanvas>& rxCanvas)
     : mxCanvas(rxCanvas),
-      mnUserEventId(0),
+      mnUserEventId(nullptr),
       mbUpdateFlag(false)
 {
     Reference<lang::XComponent> xComponent (mxCanvas, UNO_QUERY);
@@ -68,15 +68,15 @@ CanvasUpdateRequester::CanvasUpdateRequester (
     }
 }
 
-CanvasUpdateRequester::~CanvasUpdateRequester (void)
+CanvasUpdateRequester::~CanvasUpdateRequester()
 {
-    if (mnUserEventId != 0)
+    if (mnUserEventId != nullptr)
         Application::RemoveUserEvent(mnUserEventId);
 }
 
 void CanvasUpdateRequester::RequestUpdate (const bool bUpdateAll)
 {
-    if (mnUserEventId == 0)
+    if (mnUserEventId == nullptr)
     {
         mbUpdateFlag = bUpdateAll;
         mnUserEventId = Application::PostUserEvent(LINK(this, CanvasUpdateRequester, Callback));
@@ -87,15 +87,14 @@ void CanvasUpdateRequester::RequestUpdate (const bool bUpdateAll)
     }
 }
 
-IMPL_LINK_NOARG(CanvasUpdateRequester, Callback)
+IMPL_LINK_NOARG_TYPED(CanvasUpdateRequester, Callback, void*, void)
 {
-    mnUserEventId = 0;
+    mnUserEventId = nullptr;
     if (mxCanvas.is())
     {
         mxCanvas->updateScreen(mbUpdateFlag);
         mbUpdateFlag = false;
     }
-    return 0;
 }
 
 } } // end of namespace ::sd::presenter
