@@ -52,10 +52,12 @@ namespace sd {
         BufferedStreamSocket *mpStreamSocket;
         OUString mPin;
 
-        ClientInfoInternal( const OUString rName,
-                            const OUString rAddress,
-                            BufferedStreamSocket *pSocket, OUString rPin ):
-                ClientInfo( rName, rAddress ),
+        ClientInfoInternal( const OUString& rName,
+                            const OUString& rAddress,
+                            const bool bIsAlreadyAuthorised,
+                            BufferedStreamSocket *pSocket,
+                            const OUString& rPin ):
+                ClientInfo( rName, rAddress, bIsAlreadyAuthorised ),
                 mpStreamSocket( pSocket ),
                 mPin( rPin ) {}
     };
@@ -80,21 +82,21 @@ void RemoteServer::execute()
     if (!xContext.is()/* || !officecfg::Office::Common::Misc::ExperimentalMode::get(xContext)*/)
     {
         // SAL_INFO("sdremote", "not in experimental mode, disabling TCP server");
-        spServer = NULL;
+        spServer = nullptr;
         return;
     }
     osl::SocketAddr aAddr( "0", PORT );
     if ( !mSocket.bind( aAddr ) )
     {
         SAL_WARN( "sdremote", "bind failed" << mSocket.getErrorAsString() );
-        spServer = NULL;
+        spServer = nullptr;
         return;
     }
 
     if ( !mSocket.listen(3) )
     {
         SAL_WARN( "sdremote", "listen failed" << mSocket.getErrorAsString() );
-        spServer = NULL;
+        spServer = nullptr;
         return;
     }
     while ( true )
@@ -104,7 +106,7 @@ void RemoteServer::execute()
         if ( mSocket.acceptConnection( aSocket ) == osl_Socket_Error )
         {
             SAL_WARN( "sdremote", "accept failed" << mSocket.getErrorAsString() );
-            spServer = NULL;
+            spServer = nullptr;
             return; // Closed, or other issue.
         }
         BufferedStreamSocket *pSocket = new BufferedStreamSocket( aSocket);
@@ -127,10 +129,11 @@ void RemoteServer::execute()
             OUString aAddress = aClientAddr.getHostname();
 
             MutexGuard aGuard( sDataMutex );
-            ClientInfoInternal* pClient = new ClientInfoInternal(
+            std::shared_ptr< ClientInfoInternal > pClient(
+                new ClientInfoInternal(
                     OStringToOUString( aName, RTL_TEXTENCODING_UTF8 ),
-                    aAddress, pSocket, OStringToOUString( aPin,
-                    RTL_TEXTENCODING_UTF8 ) );
+                    aAddress, false, pSocket, OStringToOUString( aPin,
+                                                                 RTL_TEXTENCODING_UTF8 ) ) );
             mAvailableClients.push_back( pClient );
 
             // Read off any additional non-empty lines
@@ -176,10 +179,10 @@ void RemoteServer::execute()
         }
     }
     SAL_INFO( "sdremote", "shutting down RemoteServer" );
-    spServer = NULL; // Object is destroyed when Thread::execute() ends.
+    spServer = nullptr; // Object is destroyed when Thread::execute() ends.
 }
 
-RemoteServer *sd::RemoteServer::spServer = NULL;
+RemoteServer *sd::RemoteServer::spServer = nullptr;
 ::osl::Mutex sd::RemoteServer::sDataMutex;
 ::std::vector<Communicator*> sd::RemoteServer::sCommunicators;
 
@@ -196,7 +199,6 @@ void RemoteServer::setup()
 #endif
 }
 
-
 void RemoteServer::presentationStarted( const css::uno::Reference<
                 css::presentation::XSlideShowController > &rController )
 {
@@ -237,33 +239,56 @@ void RemoteServer::removeCommunicator( Communicator* mCommunicator )
     }
 }
 
-std::vector<ClientInfo*> RemoteServer::getClients()
+std::vector< std::shared_ptr< ClientInfo > > RemoteServer::getClients()
 {
     SAL_INFO( "sdremote", "RemoteServer::getClients() called" );
-    std::vector<ClientInfo*> aClients;
-    if ( !spServer )
+    std::vector< std::shared_ptr< ClientInfo > > aClients;
+    if ( spServer )
     {
-        SAL_INFO( "sdremote", "No remote server instance => no clients" );
-        return aClients;
+        MutexGuard aGuard( sDataMutex );
+        aClients.assign( spServer->mAvailableClients.begin(),
+                         spServer->mAvailableClients.end() );
+    }
+    else
+    {
+        SAL_INFO( "sdremote", "No remote server instance => no remote clients" );
+    }
+    // We also need to provide authorised clients (no matter whether or not
+    // they are actually available), so that they can be de-authorised if
+    // necessary. We specifically want these to be at the end of the list
+    // since the user is more likely to be trying to connect a new remote
+    // than removing an existing remote.
+    // We can also be sure that pre-authorised clients will not be on the
+    // available clients list, as they get automatically connected if seen.
+    // TODO: we should probably add some sort of extra labelling to mark
+    // authorised AND connected client.
+    Reference< XNameAccess > const xConfig = officecfg::Office::Impress::Misc::AuthorisedRemotes::get();
+    Sequence< OUString > aNames = xConfig->getElementNames();
+    for ( int i = 0; i < aNames.getLength(); i++ )
+    {
+        aClients.push_back( std::shared_ptr< ClientInfo > ( new ClientInfo( aNames[i], "", true ) ) );
     }
 
-    MutexGuard aGuard( sDataMutex );
-    aClients.assign( spServer->mAvailableClients.begin(),
-                     spServer->mAvailableClients.end() );
     return aClients;
 }
 
-sal_Bool RemoteServer::connectClient( ClientInfo* pClient, OUString aPin )
+bool RemoteServer::connectClient( std::shared_ptr< ClientInfo > pClient, const OUString& aPin )
 {
     SAL_INFO( "sdremote", "RemoteServer::connectClient called" );
     if ( !spServer )
         return false;
 
-    ClientInfoInternal *apClient = (ClientInfoInternal*) pClient;
+    ClientInfoInternal* apClient = dynamic_cast< ClientInfoInternal* >( pClient.get() );
+    if ( !apClient )
+    // could happen if we try to "connect" an already authorised client
+    {
+        return false;
+    }
+
     if ( apClient->mPin.equals( aPin ) )
     {
         // Save in settings first
-        boost::shared_ptr< ConfigurationChanges > aChanges = ConfigurationChanges::create();
+        std::shared_ptr< ConfigurationChanges > aChanges = ConfigurationChanges::create();
         Reference< XNameContainer > const xConfig = officecfg::Office::Impress::Misc::AuthorisedRemotes::get( aChanges );
 
         Reference<XSingleServiceFactory> xChildFactory (
@@ -296,13 +321,13 @@ sal_Bool RemoteServer::connectClient( ClientInfo* pClient, OUString aPin )
 
         sCommunicators.push_back( pCommunicator );
 
-        for ( vector<ClientInfoInternal*>::iterator aIt = spServer->mAvailableClients.begin();
+        for ( vector< std::shared_ptr< ClientInfoInternal > >::iterator aIt = spServer->mAvailableClients.begin();
             aIt != spServer->mAvailableClients.end(); ++aIt )
         {
             if ( pClient == *aIt )
             {
                 spServer->mAvailableClients.erase( aIt );
-            break;
+                break;
             }
         }
         pCommunicator->launch();
@@ -314,9 +339,46 @@ sal_Bool RemoteServer::connectClient( ClientInfo* pClient, OUString aPin )
     }
 }
 
+void RemoteServer::deauthoriseClient( std::shared_ptr< ClientInfo > pClient )
+{
+    // TODO: we probably want to forcefully disconnect at this point too?
+    // But possibly via a separate function to allow just disconnecting from
+    // the UI.
+
+    SAL_INFO( "sdremote", "RemoteServer::deauthoriseClient called" );
+
+    if ( !pClient->mbIsAlreadyAuthorised )
+    // We can't remove unauthorised clients from the authorised list...
+    {
+        return;
+    }
+
+    std::shared_ptr< ConfigurationChanges > aChanges = ConfigurationChanges::create();
+    Reference< XNameContainer > const xConfig =
+        officecfg::Office::Impress::Misc::AuthorisedRemotes::get( aChanges );
+
+    xConfig->removeByName( pClient->mName );
+    aChanges->commit();
+}
+
 void SdDLL::RegisterRemotes()
 {
     SAL_INFO( "sdremote", "SdDLL::RegisterRemotes called" );
+
+    // The remote server is likely of no use in headless mode. And as only
+    // one instance of the server can actually own the appropriate ports its
+    // probably best to not even try to do so from our headless instance
+    // (i.e. as to avoid blocking expected usage).
+    // It could perhaps be argued that we would still need the remote
+    // server for tiled rendering of presentations, but even then this
+    // implementation would not be of much use, i.e. would be controlling
+    // the purely imaginary headless presentation -- instead we'd need
+    // to have some sort of mechanism of plugging in our tiled rendering
+    // client to be controlled by the remote server, or provide an
+    // alternative implementation.
+    if ( Application::IsHeadlessModeEnabled() )
+        return;
+
     uno::Reference< uno::XComponentContext > xContext = comphelper::getProcessComponentContext();
     if ( xContext.is()  && !officecfg::Office::Impress::Misc::Start::EnableSdremote::get( xContext ) )
         return;
