@@ -17,7 +17,6 @@
  *   the License at http://www.apache.org/licenses/LICENSE-2.0 .
  */
 
-
 #include "controller/SlsClipboard.hxx"
 
 #include "SlideSorterViewShell.hxx"
@@ -74,8 +73,6 @@
 #include <rtl/ustring.hxx>
 #include <osl/mutex.hxx>
 #include <vcl/svapp.hxx>
-#include <boost/bind.hpp>
-
 
 namespace sd { namespace slidesorter { namespace controller {
 
@@ -89,7 +86,7 @@ namespace {
 class TemporarySlideTrackingDeactivator
 {
 public:
-    TemporarySlideTrackingDeactivator (SlideSorterController& rController)
+    explicit TemporarySlideTrackingDeactivator (SlideSorterController& rController)
         : mrController(rController),
           mbIsCurrentSlideTrackingActive (
               mrController.GetVisibleAreaManager().IsCurrentSlideTrackingActive())
@@ -97,7 +94,7 @@ public:
         if (mbIsCurrentSlideTrackingActive)
             mrController.GetVisibleAreaManager().DeactivateCurrentSlideTracking();
     }
-    ~TemporarySlideTrackingDeactivator (void)
+    ~TemporarySlideTrackingDeactivator()
     {
         if (mbIsCurrentSlideTrackingActive)
             mrController.GetVisibleAreaManager().ActivateCurrentSlideTracking();
@@ -114,11 +111,11 @@ class Clipboard::UndoContext
 public:
     UndoContext (
         SdDrawDocument* pDocument,
-        const ::boost::shared_ptr<ViewShell>& rpMainViewShell)
+        const std::shared_ptr<ViewShell>& rpMainViewShell)
         : mpDocument(pDocument),
           mpMainViewShell(rpMainViewShell)
     {
-        if (mpDocument!=NULL && mpDocument->IsUndoEnabled())
+        if (mpDocument!=nullptr && mpDocument->IsUndoEnabled())
         {
             if (mpMainViewShell && mpMainViewShell->GetShellType() == ViewShell::ST_DRAW)
                 mpDocument->BegUndo(SD_RESSTR(STRING_DRAG_AND_DROP_PAGES));
@@ -127,11 +124,11 @@ public:
         }
     }
 
-    ~UndoContext (void)
+    ~UndoContext()
     {
-        if (mpDocument!=NULL && mpDocument->IsUndoEnabled())
+        if (mpDocument!=nullptr && mpDocument->IsUndoEnabled())
             mpDocument->EndUndo();
-        if (mpMainViewShell && mpMainViewShell->GetViewFrame()!=NULL)
+        if (mpMainViewShell && mpMainViewShell->GetViewFrame()!=nullptr)
         {
             SfxBindings& rBindings = mpMainViewShell->GetViewFrame()->GetBindings();
             rBindings.Invalidate(SID_UNDO);
@@ -140,12 +137,9 @@ public:
     }
 private:
     SdDrawDocument* mpDocument;
-    ::boost::shared_ptr<ViewShell> mpMainViewShell;
+    std::shared_ptr<ViewShell> mpMainViewShell;
 };
 
-
-
-
 Clipboard::Clipboard (SlideSorter& rSlideSorter)
     : ViewClipboard(rSlideSorter.GetView()),
       mrSlideSorter(rSlideSorter),
@@ -153,24 +147,18 @@ Clipboard::Clipboard (SlideSorter& rSlideSorter)
       maPagesToRemove(),
       maPagesToSelect(),
       mbUpdateSelectionPending(false),
-      mpUndoContext(),
-      mpSelectionObserverContext(),
-      mnDragFinishedUserEventId(0)
+      mxUndoContext(),
+      mxSelectionObserverContext(),
+      mnDragFinishedUserEventId(nullptr)
 {
 }
 
-
-
-
-Clipboard::~Clipboard (void)
+Clipboard::~Clipboard()
 {
-    if (mnDragFinishedUserEventId != 0)
+    if (mnDragFinishedUserEventId != nullptr)
         Application::RemoveUserEvent(mnDragFinishedUserEventId);
 }
 
-
-
-
 /** With the current implementation the forwarded calls to the current
     function will come back eventually to call the local Do(Cut|Copy|Paste)
     methods.  A shortcut is possible but would be an unclean hack.
@@ -179,7 +167,7 @@ void Clipboard::HandleSlotCall (SfxRequest& rRequest)
 {
     ViewShell* pViewShell = mrSlideSorter.GetViewShell();
     rtl::Reference<FuPoor> xFunc;
-    if (pViewShell != NULL)
+    if (pViewShell != nullptr)
         xFunc = pViewShell->GetCurrentFunction();
     switch (rRequest.GetSlot())
     {
@@ -228,10 +216,7 @@ void Clipboard::HandleSlotCall (SfxRequest& rRequest)
     }
 }
 
-
-
-
-void Clipboard::DoCut (::Window* pWindow)
+void Clipboard::DoCut (vcl::Window* pWindow)
 {
     if (mrSlideSorter.GetModel().GetPageCount() > 1)
     {
@@ -240,10 +225,7 @@ void Clipboard::DoCut (::Window* pWindow)
     }
 }
 
-
-
-
-void Clipboard::DoDelete (::Window* )
+void Clipboard::DoDelete (vcl::Window* )
 {
     if (mrSlideSorter.GetModel().GetPageCount() > 1)
     {
@@ -251,22 +233,16 @@ void Clipboard::DoDelete (::Window* )
     }
 }
 
-
-
-
-void Clipboard::DoCopy (::Window* pWindow )
+void Clipboard::DoCopy (vcl::Window* pWindow )
 {
-    CreateSlideTransferable( pWindow, sal_False );
+    CreateSlideTransferable( pWindow, false );
 }
 
-
-
-
-void Clipboard::DoPaste (::Window* pWindow)
+void Clipboard::DoPaste (vcl::Window* pWindow)
 {
     SdTransferable* pClipTransferable = SD_MOD()->pTransferClip;
 
-    if (pClipTransferable!=NULL && pClipTransferable->IsPageTransferable())
+    if (pClipTransferable!=nullptr && pClipTransferable->IsPageTransferable())
     {
         sal_Int32 nInsertPosition = GetInsertionPosition(pWindow);
 
@@ -282,10 +258,7 @@ void Clipboard::DoPaste (::Window* pWindow)
     }
 }
 
-
-
-
-sal_Int32 Clipboard::GetInsertionPosition (::Window* pWindow)
+sal_Int32 Clipboard::GetInsertionPosition (vcl::Window* pWindow)
 {
     sal_Int32 nInsertPosition = -1;
 
@@ -297,7 +270,7 @@ sal_Int32 Clipboard::GetInsertionPosition (::Window* pWindow)
     // selection.
     // d) After the last page when there is no selection and no focus.
 
-    ::boost::shared_ptr<controller::InsertionIndicatorHandler> pInsertionIndicatorHandler (
+    std::shared_ptr<controller::InsertionIndicatorHandler> pInsertionIndicatorHandler (
         mrController.GetInsertionIndicatorHandler());
     if (pInsertionIndicatorHandler->IsActive())
     {
@@ -313,11 +286,11 @@ sal_Int32 Clipboard::GetInsertionPosition (::Window* pWindow)
     else if (mrController.GetFocusManager().IsFocusShowing())
     {
         // Use the focus to determine the insertion position.
-        SdInsertPasteDlg aDialog (pWindow);
-        if (aDialog.Execute() == RET_OK)
+        ScopedVclPtrInstance< SdInsertPasteDlg > aDialog(pWindow);
+        if (aDialog->Execute() == RET_OK)
         {
             nInsertPosition = mrController.GetFocusManager().GetFocusedPageIndex();
-            if ( ! aDialog.IsInsertBefore())
+            if ( ! aDialog->IsInsertBefore())
                 nInsertPosition ++;
         }
     }
@@ -325,9 +298,6 @@ sal_Int32 Clipboard::GetInsertionPosition (::Window* pWindow)
     return nInsertPosition;
 }
 
-
-
-
 sal_Int32 Clipboard::PasteTransferable (sal_Int32 nInsertPosition)
 {
     SdTransferable* pClipTransferable = SD_MOD()->pTransferClip;
@@ -343,23 +313,23 @@ sal_Int32 Clipboard::PasteTransferable (sal_Int32 nInsertPosition)
         nInsertPageCount = (sal_uInt16) rBookmarkList.size();
         rModel.GetDocument()->InsertBookmarkAsPage(
             rBookmarkList,
-            NULL,
-            sal_False,
-            sal_False,
+            nullptr,
+            false,
+            false,
             nInsertIndex,
-            sal_False,
+            false,
             pClipTransferable->GetPageDocShell(),
-            sal_True,
+            true,
             bMergeMasterPages,
-            sal_False);
+            false);
     }
     else
     {
         SfxObjectShell* pShell = pClipTransferable->GetDocShell();
-        DrawDocShell* pDataDocSh = (DrawDocShell*)pShell;
+        DrawDocShell* pDataDocSh = static_cast<DrawDocShell*>(pShell);
         SdDrawDocument* pDataDoc = pDataDocSh->GetDoc();
 
-        if (pDataDoc!=NULL
+        if (pDataDoc!=nullptr
             && pDataDoc->GetSdPageCount(PK_STANDARD))
         {
             const SolarMutexGuard aGuard;
@@ -368,35 +338,32 @@ sal_Int32 Clipboard::PasteTransferable (sal_Int32 nInsertPosition)
             nInsertPageCount = pDataDoc->GetSdPageCount( PK_STANDARD );
             rModel.GetDocument()->InsertBookmarkAsPage(
                 std::vector<OUString>(),
-                NULL,
-                sal_False,
-                sal_False,
+                nullptr,
+                false,
+                false,
                 nInsertIndex,
-                sal_False,
+                false,
                 pDataDocSh,
-                sal_True,
+                true,
                 bMergeMasterPages,
-                sal_False);
+                false);
         }
     }
     mrController.HandleModelChange();
     return nInsertPageCount;
 }
 
-
-
-
 void Clipboard::SelectPageRange (sal_Int32 nFirstIndex, sal_Int32 nPageCount)
 {
     // Select the newly inserted pages.  That are the nInsertPageCount pages
     // after the nInsertIndex position.
     PageSelector& rSelector (mrController.GetPageSelector());
     rSelector.DeselectAllPages();
-    for (sal_uInt16 i=0; i<nPageCount; i++)
+    for (sal_Int32 i=0; i<nPageCount; i++)
     {
         model::SharedPageDescriptor pDescriptor (
             mrSlideSorter.GetModel().GetPageDescriptor(nFirstIndex + i));
-        if (pDescriptor.get() != NULL)
+        if (pDescriptor.get() != nullptr)
         {
             rSelector.SelectPage(pDescriptor);
             // The first page of the new selection is made the current page.
@@ -408,11 +375,8 @@ void Clipboard::SelectPageRange (sal_Int32 nFirstIndex, sal_Int32 nPageCount)
     }
 }
 
-
-
-
 void Clipboard::CreateSlideTransferable (
-    ::Window* pWindow,
+    vcl::Window* pWindow,
     bool bDrag)
 {
     std::vector<OUString> aBookmarkList;
@@ -435,12 +399,12 @@ void Clipboard::CreateSlideTransferable (
     aSelectedPages.Rewind();
     ::std::vector<TransferableData::Representative> aRepresentatives;
     aRepresentatives.reserve(3);
-    ::boost::shared_ptr<cache::PageCache> pPreviewCache (
+    std::shared_ptr<cache::PageCache> pPreviewCache (
         mrSlideSorter.GetView().GetPreviewCache());
     while (aSelectedPages.HasMoreElements())
     {
         model::SharedPageDescriptor pDescriptor (aSelectedPages.GetNextElement());
-        if ( ! pDescriptor || pDescriptor->GetPage()==NULL)
+        if ( ! pDescriptor || pDescriptor->GetPage()==nullptr)
             continue;
         Bitmap aPreview (pPreviewCache->GetPreviewBitmap(pDescriptor->GetPage(), false));
         aRepresentatives.push_back(TransferableData::Representative(
@@ -456,8 +420,8 @@ void Clipboard::CreateSlideTransferable (
         SdDrawDocument* pDocument = mrSlideSorter.GetModel().GetDocument();
         SdTransferable* pTransferable = TransferableData::CreateTransferable (
             pDocument,
-            NULL,
-            sal_False,
+            nullptr,
+            false,
             dynamic_cast<SlideSorterViewShell*>(mrSlideSorter.GetViewShell()),
             aRepresentatives);
 
@@ -467,21 +431,20 @@ void Clipboard::CreateSlideTransferable (
             SD_MOD()->pTransferClip = pTransferable;
 
         pDocument->CreatingDataObj (pTransferable);
-        pTransferable->SetWorkDocument( dynamic_cast<SdDrawDocument*>(pDocument->AllocModel()) );
-        pDocument->CreatingDataObj (NULL);
+        pTransferable->SetWorkDocument(pDocument->AllocSdDrawDocument());
         TransferableObjectDescriptor aObjDesc;
         pTransferable->GetWorkDocument()->GetDocSh()
             ->FillTransferableObjectDescriptor (aObjDesc);
 
-        if (pDocument->GetDocSh() != NULL)
+        if (pDocument->GetDocSh() != nullptr)
             aObjDesc.maDisplayName = pDocument->GetDocSh()
                 ->GetMedium()->GetURLObject().GetURLNoPass();
 
-        ::Window* pActionWindow = pWindow;
-        if (pActionWindow == NULL)
+        vcl::Window* pActionWindow = pWindow;
+        if (pActionWindow == nullptr)
         {
             ViewShell* pViewShell = mrSlideSorter.GetViewShell();
-            if (pViewShell != NULL)
+            if (pViewShell != nullptr)
                 pActionWindow = pViewShell->GetActiveWindow();
         }
 
@@ -501,38 +464,37 @@ void Clipboard::CreateSlideTransferable (
         }
         else
             pTransferable->CopyToClipboard (pActionWindow);
+
+        pDocument->CreatingDataObj(nullptr);
     }
 }
 
-
-
-
-::boost::shared_ptr<SdTransferable::UserData> Clipboard::CreateTransferableUserData (SdTransferable* pTransferable)
+std::shared_ptr<SdTransferable::UserData> Clipboard::CreateTransferableUserData (SdTransferable* pTransferable)
 {
     do
     {
         SdPageObjsTLB::SdPageObjsTransferable* pTreeListBoxTransferable
             = dynamic_cast<SdPageObjsTLB::SdPageObjsTransferable*>(pTransferable);
-        if (pTreeListBoxTransferable == NULL)
+        if (pTreeListBoxTransferable == nullptr)
             break;
 
         // Find view shell for the document of the transferable.
         ::sd::ViewShell* pViewShell
               = SdPageObjsTLB::GetViewShellForDocShell(pTreeListBoxTransferable->GetDocShell());
-        if (pViewShell == NULL)
+        if (pViewShell == nullptr)
             break;
 
         // Find slide sorter for the document of the transferable.
         SlideSorterViewShell* pSlideSorterViewShell
             = SlideSorterViewShell::GetSlideSorter(pViewShell->GetViewShellBase());
-        if (pSlideSorterViewShell == NULL)
+        if (pSlideSorterViewShell == nullptr)
             break;
         SlideSorter& rSlideSorter (pSlideSorterViewShell->GetSlideSorter());
 
         // Get bookmark from transferable.
         TransferableDataHelper  aDataHelper (pTransferable);
         INetBookmark aINetBookmark;
-        if ( ! aDataHelper.GetINetBookmark(SOT_FORMATSTR_ID_NETSCAPE_BOOKMARK, aINetBookmark))
+        if ( ! aDataHelper.GetINetBookmark(SotClipboardFormatId::NETSCAPE_BOOKMARK, aINetBookmark))
             break;
         const OUString sURL (aINetBookmark.GetURL());
         const sal_Int32 nIndex (sURL.indexOf((sal_Unicode)'#'));
@@ -542,9 +504,9 @@ void Clipboard::CreateSlideTransferable (
 
         // Make sure that the bookmark points to a page.
         SdDrawDocument* pTransferableDocument = rSlideSorter.GetModel().GetDocument();
-        if (pTransferableDocument == NULL)
+        if (pTransferableDocument == nullptr)
             break;
-        sal_Bool bIsMasterPage = sal_False;
+        bool bIsMasterPage = false;
         const sal_uInt16 nPageIndex (pTransferableDocument->GetPageByName(sBookmark, bIsMasterPage));
         if (nPageIndex == SDRPAGE_NOTFOUND)
             break;
@@ -552,10 +514,10 @@ void Clipboard::CreateSlideTransferable (
         // Create preview.
         ::std::vector<TransferableData::Representative> aRepresentatives;
         aRepresentatives.reserve(1);
-        ::boost::shared_ptr<cache::PageCache> pPreviewCache (
+        std::shared_ptr<cache::PageCache> pPreviewCache (
             rSlideSorter.GetView().GetPreviewCache());
         model::SharedPageDescriptor pDescriptor (rSlideSorter.GetModel().GetPageDescriptor((nPageIndex-1)/2));
-        if ( ! pDescriptor || pDescriptor->GetPage()==NULL)
+        if ( ! pDescriptor || pDescriptor->GetPage()==nullptr)
             break;
         Bitmap aPreview (pPreviewCache->GetPreviewBitmap(pDescriptor->GetPage(), false));
         aRepresentatives.push_back(TransferableData::Representative(
@@ -569,12 +531,11 @@ void Clipboard::CreateSlideTransferable (
         rOtherClipboard.maPagesToRemove.push_back(pDescriptor->GetPage());
 
         // Create the new transferable.
-        ::boost::shared_ptr<SdTransferable::UserData> pNewTransferable (
+        std::shared_ptr<SdTransferable::UserData> pNewTransferable (
             new TransferableData(
                 pSlideSorterViewShell,
                 aRepresentatives));
-        pTransferable->SetWorkDocument( dynamic_cast<SdDrawDocument*>(
-                pTreeListBoxTransferable->GetSourceDoc()->AllocModel()));
+        pTransferable->SetWorkDocument(pTreeListBoxTransferable->GetSourceDoc()->AllocSdDrawDocument());
         //        pTransferable->SetView(&mrSlideSorter.GetView());
 
         // Set page bookmark list.
@@ -590,51 +551,38 @@ void Clipboard::CreateSlideTransferable (
     }
     while (false);
 
-    return ::boost::shared_ptr<SdTransferable::UserData>();
+    return std::shared_ptr<SdTransferable::UserData>();
 }
 
-
-
-
 void Clipboard::StartDrag (
     const Point& rPosition,
-    ::Window* pWindow)
+    vcl::Window* pWindow)
 {
     maPagesToRemove.clear();
     maPagesToSelect.clear();
     mbUpdateSelectionPending = false;
-    CreateSlideTransferable(pWindow, sal_True);
+    CreateSlideTransferable(pWindow, true);
 
     mrController.GetInsertionIndicatorHandler()->UpdatePosition(
         rPosition,
         InsertionIndicatorHandler::UnknownMode);
 }
 
-
-
-
 void Clipboard::DragFinished (sal_Int8 nDropAction)
 {
-    if (mnDragFinishedUserEventId == 0)
+    if (mnDragFinishedUserEventId == nullptr)
     {
-        if ( ! Application::PostUserEvent(
-            mnDragFinishedUserEventId,
+        mnDragFinishedUserEventId = Application::PostUserEvent(
             LINK(this, Clipboard, ProcessDragFinished),
-            reinterpret_cast<void*>(nDropAction)))
-        {
-            mnDragFinishedUserEventId = 0;
-        }
+            reinterpret_cast<void*>(nDropAction));
     }
 }
 
-
-
-
-IMPL_LINK(Clipboard, ProcessDragFinished, void*, pUserData)
+IMPL_LINK_TYPED(Clipboard, ProcessDragFinished, void*, pUserData, void)
 {
     const sal_Int8 nDropAction (static_cast<sal_Int8>(reinterpret_cast<sal_IntPtr>(pUserData)));
 
-    mnDragFinishedUserEventId = 0;
+    mnDragFinishedUserEventId = nullptr;
 
     // Hide the substitution display and insertion indicator.
     ::rtl::Reference<SelectionFunction> pFunction (mrController.GetCurrentSelectionFunction());
@@ -657,15 +605,10 @@ IMPL_LINK(Clipboard, ProcessDragFinished, void*, pUserData)
         }
         mrController.GetSelectionManager()->DeleteSelectedPages();
     }
-    mpUndoContext.reset();
-    mpSelectionObserverContext.reset();
-
-    return 1;
+    mxUndoContext.reset();
+    mxSelectionObserverContext.reset();
 }
 
-
-
-
 sal_Int8 Clipboard::AcceptDrop (
     const AcceptDropEvent& rEvent,
     DropTargetHelper& rTargetHelper,
@@ -689,10 +632,10 @@ sal_Int8 Clipboard::AcceptDrop (
             // explicitly set to move or link, and when the source and
             // target models are not the same.
             SdTransferable* pDragTransferable = SD_MOD()->pTransferDrag;
-            if (pDragTransferable != NULL
+            if (pDragTransferable != nullptr
                 && pDragTransferable->IsPageTransferable()
                 && ((rEvent.maDragEvent.DropAction
-                        & ::com::sun::star::datatransfer::dnd::DNDConstants::ACTION_DEFAULT) != 0)
+                        & css::datatransfer::dnd::DNDConstants::ACTION_DEFAULT) != 0)
                 && (mrSlideSorter.GetModel().GetDocument()->GetDocSh()
                     != pDragTransferable->GetPageDocShell()))
             {
@@ -706,7 +649,7 @@ sal_Int8 Clipboard::AcceptDrop (
             // Show the insertion marker and the substitution for a drop.
             SelectionFunction* pSelectionFunction = dynamic_cast<SelectionFunction*>(
                 mrSlideSorter.GetViewShell()->GetCurrentFunction().get());
-            if (pSelectionFunction != NULL)
+            if (pSelectionFunction != nullptr)
                 pSelectionFunction->MouseDragged(rEvent, nAction);
 
             // Scroll the window when the mouse reaches the window border.
@@ -734,9 +677,6 @@ sal_Int8 Clipboard::AcceptDrop (
     return nAction;
 }
 
-
-
-
 sal_Int8 Clipboard::ExecuteDrop (
     const ExecuteDropEvent& rEvent,
     DropTargetHelper& rTargetHelper,
@@ -745,7 +685,7 @@ sal_Int8 Clipboard::ExecuteDrop (
     sal_uInt16 nLayer)
 {
     sal_Int8 nResult = DND_ACTION_NONE;
-    mpUndoContext.reset();
+    mxUndoContext.reset();
     const Clipboard::DropType eDropType (IsDropAccepted(rTargetHelper));
 
     switch (eDropType)
@@ -764,7 +704,7 @@ sal_Int8 Clipboard::ExecuteDrop (
                 ( pDragTransferable->GetView() != &mrSlideSorter.GetView() )
                 || ( nXOffset >= 2 && nYOffset >= 2 );
 
-            ::boost::shared_ptr<InsertionIndicatorHandler> pInsertionIndicatorHandler(
+            std::shared_ptr<InsertionIndicatorHandler> pInsertionIndicatorHandler(
                         mrController.GetInsertionIndicatorHandler());
             // Get insertion position and then turn off the insertion indicator.
             pInsertionIndicatorHandler->UpdatePosition(aEventModelPosition, rEvent.mnAction);
@@ -786,10 +726,10 @@ sal_Int8 Clipboard::ExecuteDrop (
                 SlideSorterController::ModelChangeLock aModelChangeLock (mrController);
 
                 // Handle a general drop operation.
-                mpUndoContext.reset(new UndoContext (
+                mxUndoContext.reset(new UndoContext (
                     mrSlideSorter.GetModel().GetDocument(),
                     mrSlideSorter.GetViewShell()->GetViewShellBase().GetMainViewShell()));
-                mpSelectionObserverContext.reset(new SelectionObserver::Context(mrSlideSorter));
+                mxSelectionObserverContext.reset(new SelectionObserver::Context(mrSlideSorter));
 
                 HandlePageDrop(*pDragTransferable);
                 nResult = rEvent.mnAction;
@@ -804,7 +744,7 @@ sal_Int8 Clipboard::ExecuteDrop (
             // only that is notified automatically about the drag
             // operation being finished.  Because the target slide sorter
             // has be notified, too, add a callback for that.
-            ::boost::shared_ptr<TransferableData> pSlideSorterTransferable (
+            std::shared_ptr<TransferableData> pSlideSorterTransferable (
                 TransferableData::GetFromTransferable(pDragTransferable));
             BOOST_ASSERT(pSlideSorterTransferable);
             if (pSlideSorterTransferable
@@ -841,14 +781,11 @@ sal_Int8 Clipboard::ExecuteDrop (
     return nResult;
 }
 
-
-
-
 bool Clipboard::IsInsertionTrivial (
     SdTransferable* pTransferable,
     const sal_Int8 nDndAction) const
 {
-    ::boost::shared_ptr<TransferableData> pSlideSorterTransferable (
+    std::shared_ptr<TransferableData> pSlideSorterTransferable (
         TransferableData::GetFromTransferable(pTransferable));
     if (pSlideSorterTransferable
         && pSlideSorterTransferable->GetSourceViewShell() != mrSlideSorter.GetViewShell())
@@ -856,21 +793,15 @@ bool Clipboard::IsInsertionTrivial (
     return mrController.GetInsertionIndicatorHandler()->IsInsertionTrivial(nDndAction);
 }
 
-
-
-
-void Clipboard::Abort (void)
+void Clipboard::Abort()
 {
-    if (mpSelectionObserverContext)
+    if (mxSelectionObserverContext)
     {
-        mpSelectionObserverContext->Abort();
-        mpSelectionObserverContext.reset();
+        mxSelectionObserverContext->Abort();
+        mxSelectionObserverContext.reset();
     }
 }
 
-
-
-
 sal_uInt16 Clipboard::DetermineInsertPosition (const SdTransferable& )
 {
     // Tell the model to move the dragged pages behind the one with the
@@ -886,9 +817,6 @@ sal_uInt16 Clipboard::DetermineInsertPosition (const SdTransferable& )
         return 0;
 }
 
-
-
-
 sal_uInt16 Clipboard::InsertSlides (
     const SdTransferable& rTransferable,
     sal_uInt16 nInsertPosition)
@@ -901,7 +829,7 @@ sal_uInt16 Clipboard::InsertSlides (
     // operation is finished.
     maPagesToSelect.clear();
     SdDrawDocument* pDocument = mrSlideSorter.GetModel().GetDocument();
-    if (pDocument != NULL)
+    if (pDocument != nullptr)
         for (sal_Int32 i=0; i<=nInsertedPageCount; i+=2)
             maPagesToSelect.push_back(
                 dynamic_cast<SdPage*>(pDocument->GetPage(nInsertPosition+i)));
@@ -911,13 +839,10 @@ sal_uInt16 Clipboard::InsertSlides (
     return nInsertedPageCount;
 }
 
-
-
-
 Clipboard::DropType Clipboard::IsDropAccepted (DropTargetHelper&) const
 {
     const SdTransferable* pDragTransferable = SD_MOD()->pTransferDrag;
-    if (pDragTransferable == NULL)
+    if (pDragTransferable == nullptr)
         return DT_NONE;
 
     if (pDragTransferable->IsPageTransferable())
@@ -930,15 +855,12 @@ Clipboard::DropType Clipboard::IsDropAccepted (DropTargetHelper&) const
 
     const SdPageObjsTLB::SdPageObjsTransferable* pPageObjsTransferable
         = dynamic_cast<const SdPageObjsTLB::SdPageObjsTransferable*>(pDragTransferable);
-    if (pPageObjsTransferable != NULL)
+    if (pPageObjsTransferable != nullptr)
         return DT_PAGE_FROM_NAVIGATOR;
 
     return DT_SHAPE;
 }
 
-
-
-
 sal_Int8 Clipboard::ExecuteOrAcceptShapeDrop (
     DropCommand eCommand,
     const Point& rPosition,
@@ -955,11 +877,11 @@ sal_Int8 Clipboard::ExecuteOrAcceptShapeDrop (
     // technical reasons:  The actual code to accept or execute a shape drop
     // is implemented in the ViewShell class and uses the page view of the
     // main edit view.  This is not possible without a DrawViewShell.
-    ::boost::shared_ptr<DrawViewShell> pDrawViewShell;
-    if (mrSlideSorter.GetViewShell() != NULL)
-        pDrawViewShell = ::boost::dynamic_pointer_cast<DrawViewShell>(
+    std::shared_ptr<DrawViewShell> pDrawViewShell;
+    if (mrSlideSorter.GetViewShell() != nullptr)
+        pDrawViewShell = std::dynamic_pointer_cast<DrawViewShell>(
             mrSlideSorter.GetViewShell()->GetViewShellBase().GetMainViewShell());
-    if (pDrawViewShell.get() != NULL
+    if (pDrawViewShell.get() != nullptr
         && (pDrawViewShell->GetShellType() == ViewShell::ST_IMPRESS
             || pDrawViewShell->GetShellType() == ViewShell::ST_DRAW))
     {
@@ -983,7 +905,7 @@ sal_Int8 Clipboard::ExecuteOrAcceptShapeDrop (
             {
                 case DC_ACCEPT:
                     nResult = pDrawViewShell->AcceptDrop(
-                        *reinterpret_cast<const AcceptDropEvent*>(pDropEvent),
+                        *static_cast<const AcceptDropEvent*>(pDropEvent),
                         rTargetHelper,
                         pTargetWindow,
                         nPage,
@@ -992,7 +914,7 @@ sal_Int8 Clipboard::ExecuteOrAcceptShapeDrop (
 
                 case DC_EXECUTE:
                     nResult = pDrawViewShell->ExecuteDrop(
-                        *reinterpret_cast<const ExecuteDropEvent*>(pDropEvent),
+                        *static_cast<const ExecuteDropEvent*>(pDropEvent),
                         rTargetHelper,
                         pTargetWindow,
                         nPage,
@@ -1004,8 +926,6 @@ sal_Int8 Clipboard::ExecuteOrAcceptShapeDrop (
     return nResult;
 }
 
-
-
 } } } // end of namespace ::sd::slidesorter::controller
 
 /* vim:set shiftwidth=4 softtabstop=4 expandtab: */
