@@ -28,7 +28,6 @@
 #include "controller/SlsCurrentSlideManager.hxx"
 #include "controller/SlsSlotManager.hxx"
 #include "view/SlideSorterView.hxx"
-#include "taskpane/SlideSorterCacheDisplay.hxx"
 #include <com/sun/star/drawing/XDrawPagesSupplier.hpp>
 #include <com/sun/star/drawing/XMasterPagesSupplier.hpp>
 #include <com/sun/star/beans/XPropertySet.hpp>
@@ -56,16 +55,16 @@ namespace {
             SharedPageDescriptor pDescriptor (rModel.GetPageDescriptor(nIndex));
             if (pDescriptor)
             {
-                OSL_TRACE("%d %d %d %d %p",
-                    nIndex,
-                    pDescriptor->GetPageIndex(),
-                    pDescriptor->GetVisualState().mnPageId,
-                    FromCoreIndex(pDescriptor->GetPage()->GetPageNum()),
-                    pDescriptor->GetPage());
+                SAL_INFO(
+                    "sd.sls",
+                    nIndex << " " << pDescriptor->GetPageIndex() << " "
+                        << pDescriptor->GetVisualState().mnPageId << " "
+                        << FromCoreIndex(pDescriptor->GetPage()->GetPageNum())
+                        << " " << pDescriptor->GetPage());
             }
             else
             {
-                OSL_TRACE("%d", nIndex);
+                SAL_INFO("sd.sls", nIndex);
             }
         }
 
@@ -110,26 +109,22 @@ SlideSorterModel::SlideSorterModel (SlideSorter& rSlideSorter)
 {
 }
 
-SlideSorterModel::~SlideSorterModel (void)
+SlideSorterModel::~SlideSorterModel()
 {
     ClearDescriptorList ();
 }
 
-void SlideSorterModel::Init (void)
-{
-}
-
-void SlideSorterModel::Dispose (void)
+void SlideSorterModel::Dispose()
 {
     ClearDescriptorList ();
 }
 
-SdDrawDocument* SlideSorterModel::GetDocument (void)
+SdDrawDocument* SlideSorterModel::GetDocument()
 {
-    if (mrSlideSorter.GetViewShellBase() != NULL)
+    if (mrSlideSorter.GetViewShellBase() != nullptr)
         return mrSlideSorter.GetViewShellBase()->GetDocument();
     else
-         return NULL;
+         return nullptr;
 }
 
 bool SlideSorterModel::SetEditMode (EditMode eEditMode)
@@ -144,7 +139,7 @@ bool SlideSorterModel::SetEditMode (EditMode eEditMode)
     return bEditModeChanged;
 }
 
-sal_Int32 SlideSorterModel::GetPageCount (void) const
+sal_Int32 SlideSorterModel::GetPageCount() const
 {
     return maPageDescriptors.size();
 }
@@ -160,7 +155,7 @@ SharedPageDescriptor SlideSorterModel::GetPageDescriptor (
     if (nPageIndex>=0 && nPageIndex<GetPageCount())
     {
         pDescriptor = maPageDescriptors[nPageIndex];
-        if (pDescriptor == 0 && bCreate && mxSlides.is())
+        if (pDescriptor == nullptr && bCreate && mxSlides.is())
         {
             SdPage* pPage = GetPage(nPageIndex);
             pDescriptor.reset(new PageDescriptor (
@@ -189,7 +184,7 @@ sal_Int32 SlideSorterModel::GetIndex (const Reference<drawing::XDrawPage>& rxSli
             aNumber >>= nNumber;
             nNumber -= 1;
             SharedPageDescriptor pDescriptor (GetPageDescriptor(nNumber, false));
-            if (pDescriptor.get() != NULL
+            if (pDescriptor.get() != nullptr
                 && pDescriptor->GetXDrawPage() == rxSlide)
             {
                 return nNumber;
@@ -210,10 +205,10 @@ sal_Int32 SlideSorterModel::GetIndex (const Reference<drawing::XDrawPage>& rxSli
 
         // Make sure that the descriptor exists.  Without it the given slide
         // can not be found.
-        if (pDescriptor.get() == NULL)
+        if (pDescriptor.get() == nullptr)
         {
             // Call GetPageDescriptor() to create the missing descriptor.
-            pDescriptor = GetPageDescriptor(nIndex,true);
+            pDescriptor = GetPageDescriptor(nIndex);
         }
 
         if (pDescriptor->GetXDrawPage() == rxSlide)
@@ -225,7 +220,7 @@ sal_Int32 SlideSorterModel::GetIndex (const Reference<drawing::XDrawPage>& rxSli
 
 sal_Int32 SlideSorterModel::GetIndex (const SdrPage* pPage) const
 {
-    if (pPage == NULL)
+    if (pPage == nullptr)
         return -1;
 
     ::osl::MutexGuard aGuard (maMutex);
@@ -233,7 +228,7 @@ sal_Int32 SlideSorterModel::GetIndex (const SdrPage* pPage) const
     // First try to guess the right index.
     sal_Int16 nNumber ((pPage->GetPageNum()-1)/2);
     SharedPageDescriptor pDescriptor (GetPageDescriptor(nNumber, false));
-    if (pDescriptor.get() != NULL
+    if (pDescriptor.get() != nullptr
         && pDescriptor->GetPage() == pPage)
     {
         return nNumber;
@@ -248,10 +243,10 @@ sal_Int32 SlideSorterModel::GetIndex (const SdrPage* pPage) const
 
         // Make sure that the descriptor exists.  Without it the given slide
         // can not be found.
-        if (pDescriptor.get() == NULL)
+        if (pDescriptor.get() == nullptr)
         {
             // Call GetPageDescriptor() to create the missing descriptor.
-            pDescriptor = GetPageDescriptor(nIndex, true);
+            pDescriptor = GetPageDescriptor(nIndex);
         }
 
         if (pDescriptor->GetPage() == pPage)
@@ -277,14 +272,14 @@ sal_uInt16 SlideSorterModel::GetCoreIndex (const sal_Int32 nIndex) const
     document: pages may have been deleted and others may have been created
     at the exact same memory locations.
 */
-void SlideSorterModel::Resync (void)
+void SlideSorterModel::Resync()
 {
     ::osl::MutexGuard aGuard (maMutex);
 
     // Check if document and this model really differ.
     bool bIsUpToDate (true);
     SdDrawDocument* pDocument = GetDocument();
-    if (pDocument!=NULL && maPageDescriptors.size()==pDocument->GetSdPageCount(mePageKind))
+    if (pDocument!=nullptr && maPageDescriptors.size()==pDocument->GetSdPageCount(mePageKind))
     {
         for (sal_Int32 nIndex=0,nCount=maPageDescriptors.size(); nIndex<nCount; ++nIndex)
         {
@@ -292,7 +287,7 @@ void SlideSorterModel::Resync (void)
                 && maPageDescriptors[nIndex]->GetPage()
                 != GetPage(nIndex))
             {
-                OSL_TRACE("page %d differs", nIndex);
+                SAL_INFO("sd.sls", "page " << nIndex << " differs");
                 bIsUpToDate = false;
                 break;
             }
@@ -315,7 +310,7 @@ void SlideSorterModel::Resync (void)
     CheckModel(*this);
 }
 
-void SlideSorterModel::ClearDescriptorList (void)
+void SlideSorterModel::ClearDescriptorList()
 {
     DescriptorContainer aDescriptors;
 
@@ -328,11 +323,14 @@ void SlideSorterModel::ClearDescriptorList (void)
          iDescriptor!=iEnd;
          ++iDescriptor)
     {
-        if (iDescriptor->get() != NULL)
+        if (iDescriptor->get() != nullptr)
         {
             if ( ! iDescriptor->unique())
             {
-                OSL_TRACE("SlideSorterModel::ClearDescriptorList: trying to delete page descriptor  that is still used with count %zu", iDescriptor->use_count());
+                SAL_INFO(
+                    "sd.sls",
+                    "trying to delete page descriptor that is still used with"
+                        " count " << iDescriptor->use_count());
                 // No assertion here because that can hang the office when
                 // opening a dialog from here.
             }
@@ -341,7 +339,7 @@ void SlideSorterModel::ClearDescriptorList (void)
     }
 }
 
-void SlideSorterModel::SynchronizeDocumentSelection (void)
+void SlideSorterModel::SynchronizeDocumentSelection()
 {
     ::osl::MutexGuard aGuard (maMutex);
 
@@ -354,7 +352,7 @@ void SlideSorterModel::SynchronizeDocumentSelection (void)
     }
 }
 
-void SlideSorterModel::SynchronizeModelSelection (void)
+void SlideSorterModel::SynchronizeModelSelection()
 {
     ::osl::MutexGuard aGuard (maMutex);
 
@@ -375,7 +373,7 @@ void SlideSorterModel::SetDocumentSlides (
     // Make the current selection persistent and then release the
     // current set of pages.
     SynchronizeDocumentSelection();
-    mxSlides = NULL;
+    mxSlides = nullptr;
     ClearDescriptorList ();
 
     // Reset the current page to cause everbody to release references to it.
@@ -397,10 +395,10 @@ void SlideSorterModel::SetDocumentSlides (
     }
 
     ViewShell* pViewShell = mrSlideSorter.GetViewShell();
-    if (pViewShell != NULL)
+    if (pViewShell != nullptr)
     {
         SdPage* pPage = pViewShell->getCurrentPage();
-        if (pPage != NULL)
+        if (pPage != nullptr)
             mrSlideSorter.GetController().GetCurrentSlideManager()->NotifyCurrentSlideChange(
                 pPage);
         else
@@ -408,7 +406,7 @@ void SlideSorterModel::SetDocumentSlides (
             // No current page.  This can only be when the slide sorter is
             // the main view shell.  Get current slide form frame view.
             const FrameView* pFrameView = pViewShell->GetFrameView();
-            if (pFrameView != NULL)
+            if (pFrameView != nullptr)
                 mrSlideSorter.GetController().GetCurrentSlideManager()->NotifyCurrentSlideChange(
                     pFrameView->GetSelectedPage());
             else
@@ -424,13 +422,13 @@ void SlideSorterModel::SetDocumentSlides (
     mrSlideSorter.GetController().GetSlotManager()->NotifyEditModeChange();
 }
 
-Reference<container::XIndexAccess> SlideSorterModel::GetDocumentSlides (void) const
+Reference<container::XIndexAccess> SlideSorterModel::GetDocumentSlides() const
 {
     ::osl::MutexGuard aGuard (maMutex);
     return mxSlides;
 }
 
-void SlideSorterModel::UpdatePageList (void)
+void SlideSorterModel::UpdatePageList()
 {
     ::osl::MutexGuard aGuard (maMutex);
 
@@ -448,8 +446,7 @@ void SlideSorterModel::UpdatePageList (void)
                     xController->getModel(), UNO_QUERY);
                 if (xSupplier.is())
                 {
-                    xPages = Reference<container::XIndexAccess>(
-                        xSupplier->getMasterPages(), UNO_QUERY);
+                    xPages.set( xSupplier->getMasterPages(), UNO_QUERY);
                 }
             }
             break;
@@ -460,8 +457,7 @@ void SlideSorterModel::UpdatePageList (void)
                     xController->getModel(), UNO_QUERY);
                 if (xSupplier.is())
                 {
-                    xPages = Reference<container::XIndexAccess>(
-                        xSupplier->getDrawPages(), UNO_QUERY);
+                    xPages.set( xSupplier->getDrawPages(), UNO_QUERY);
                 }
             }
             break;
@@ -476,7 +472,7 @@ void SlideSorterModel::UpdatePageList (void)
     mrSlideSorter.GetController().SetDocumentSlides(xPages);
 }
 
-void SlideSorterModel::AdaptSize (void)
+void SlideSorterModel::AdaptSize()
 {
     if (mxSlides.is())
         maPageDescriptors.resize(mxSlides->getCount());
@@ -484,16 +480,16 @@ void SlideSorterModel::AdaptSize (void)
         maPageDescriptors.resize(0);
 }
 
-bool SlideSorterModel::IsReadOnly (void) const
+bool SlideSorterModel::IsReadOnly() const
 {
-    if (mrSlideSorter.GetViewShellBase() != NULL
+    if (mrSlideSorter.GetViewShellBase() != nullptr
         && mrSlideSorter.GetViewShellBase()->GetDocShell())
         return mrSlideSorter.GetViewShellBase()->GetDocShell()->IsReadOnly();
     else
         return true;
 }
 
-void SlideSorterModel::SaveCurrentSelection (void)
+void SlideSorterModel::SaveCurrentSelection()
 {
     PageEnumeration aPages (PageEnumerationProvider::CreateAllPagesEnumeration(*this));
     while (aPages.HasMoreElements())
@@ -505,7 +501,7 @@ void SlideSorterModel::SaveCurrentSelection (void)
     }
 }
 
-vcl::Region SlideSorterModel::RestoreSelection (void)
+vcl::Region SlideSorterModel::RestoreSelection()
 {
     vcl::Region aRepaintRegion;
     PageEnumeration aPages (PageEnumerationProvider::CreateAllPagesEnumeration(*this));
@@ -527,7 +523,7 @@ bool SlideSorterModel::NotifyPageEvent (const SdrPage* pSdrPage)
     ::osl::MutexGuard aGuard (maMutex);
 
     SdPage* pPage = const_cast<SdPage*>(dynamic_cast<const SdPage*>(pSdrPage));
-    if (pPage == NULL)
+    if (pPage == nullptr)
         return false;
 
     // We are only interested in pages that are currently served by this
@@ -537,10 +533,12 @@ bool SlideSorterModel::NotifyPageEvent (const SdrPage* pSdrPage)
     if (pPage->IsMasterPage() != (meEditMode==EM_MASTERPAGE))
         return false;
 
+    //NotifyPageEvent is called for add, remove, *and* change position so for
+    //the change position case we must ensure we don't end up with the slide
+    //duplicated in our list
+    DeleteSlide(pPage);
     if (pPage->IsInserted())
         InsertSlide(pPage);
-    else
-        DeleteSlide(pPage);
     CheckModel(*this);
 
     return true;
@@ -559,7 +557,7 @@ void SlideSorterModel::InsertSlide (SdPage* pPage)
     if (nIndex>0)
         if (GetPage(nIndex-1) != GetPageDescriptor(nIndex-1)->GetPage())
             return;
-    if (size_t(nIndex)<maPageDescriptors.size()-1)
+    if (nIndex < static_cast<sal_Int32>(maPageDescriptors.size()) -1)
         if (GetPage(nIndex+1) != GetPageDescriptor(nIndex)->GetPage())
             return;
 
@@ -637,7 +635,7 @@ void SlideSorterModel::UpdateIndices (const sal_Int32 nFirstIndex)
 SdPage* SlideSorterModel::GetPage (const sal_Int32 nSdIndex) const
 {
     SdDrawDocument* pModel = const_cast<SlideSorterModel*>(this)->GetDocument();
-    if (pModel != NULL)
+    if (pModel != nullptr)
     {
         if (meEditMode == EM_PAGE)
             return pModel->GetSdPage ((sal_uInt16)nSdIndex, mePageKind);
@@ -645,7 +643,7 @@ SdPage* SlideSorterModel::GetPage (const sal_Int32 nSdIndex) const
             return pModel->GetMasterSdPage ((sal_uInt16)nSdIndex, mePageKind);
     }
     else
-        return NULL;
+        return nullptr;
 }
 
 } } } // end of namespace ::sd::slidesorter::model
