@@ -39,7 +39,6 @@
 #include "cache/SlsPageCache.hxx"
 #include "cache/SlsPageCacheManager.hxx"
 #include "cache/SlsCacheContext.hxx"
-#include "taskpane/SlideSorterCacheDisplay.hxx"
 #include "DrawDocShell.hxx"
 #include "PaneDockingWindow.hxx"
 
@@ -67,12 +66,12 @@
 #include <basegfx/polygon/b2dpolygon.hxx>
 #include <drawinglayer/geometry/viewinformation2d.hxx>
 #include <canvas/elapsedtime.hxx>
+#include <boost/noncopyable.hpp>
 
 //#define DEBUG_TIMING
 #ifdef DEBUG_TIMING
 #include <vector>
 #endif
-#include <boost/foreach.hpp>
 
 using namespace std;
 using namespace ::sd::slidesorter::model;
@@ -83,21 +82,21 @@ namespace sd { namespace slidesorter { namespace view {
 namespace {
     /** Wrapper around the SlideSorterView that supports the IPainter
         interface and that allows the LayeredDevice to hold the
-        SlideSorterView (held as scoped_ptr by the SlideSorter) as
+        SlideSorterView (held as unique_ptr by the SlideSorter) as
         shared_ptr.
     */
     class Painter : public ILayerPainter
     {
     public:
-        Painter (SlideSorterView& rView) : mrView(rView) {}
-        virtual ~Painter (void) {}
+        explicit Painter (SlideSorterView& rView) : mrView(rView) {}
+        virtual ~Painter() {}
 
-        virtual void Paint (OutputDevice& rDevice, const Rectangle& rRepaintArea) SAL_OVERRIDE
+        virtual void Paint (OutputDevice& rDevice, const Rectangle& rRepaintArea) override
         {
             mrView.Paint(rDevice,rRepaintArea);
         }
 
-        virtual void SetLayerInvalidator (const SharedILayerInvalidator&) SAL_OVERRIDE {}
+        virtual void SetLayerInvalidator (const SharedILayerInvalidator&) override {}
 
     private:
         SlideSorterView& mrView;
@@ -109,30 +108,29 @@ class BackgroundPainter
       public ::boost::noncopyable
 {
 public:
-    BackgroundPainter (const Color aBackgroundColor) : maBackgroundColor(aBackgroundColor) {}
-    virtual ~BackgroundPainter (void) {}
+    explicit BackgroundPainter (const Color& rBackgroundColor) : maBackgroundColor(rBackgroundColor) {}
+    virtual ~BackgroundPainter() {}
 
-    virtual void Paint (OutputDevice& rDevice, const Rectangle& rRepaintArea) SAL_OVERRIDE
+    virtual void Paint (OutputDevice& rDevice, const Rectangle& rRepaintArea) override
     {
         rDevice.SetFillColor(maBackgroundColor);
         rDevice.SetLineColor();
         rDevice.DrawRect(rRepaintArea);
     }
 
-    virtual void SetLayerInvalidator (const SharedILayerInvalidator&) SAL_OVERRIDE {}
+    virtual void SetLayerInvalidator (const SharedILayerInvalidator&) override {}
 
-    void SetColor (const Color aColor) { maBackgroundColor = aColor; }
+    void SetColor (const Color& rColor) { maBackgroundColor = rColor; }
 
 private:
     Color maBackgroundColor;
 };
 
-TYPEINIT1(SlideSorterView, ::sd::View);
 
 SlideSorterView::SlideSorterView (SlideSorter& rSlideSorter)
     : ::sd::View (
           *rSlideSorter.GetModel().GetDocument(),
-          rSlideSorter.GetContentWindow().get(),
+          rSlideSorter.GetContentWindow(),
           rSlideSorter.GetViewShell()),
       mrSlideSorter(rSlideSorter),
       mrModel(rSlideSorter.GetModel()),
@@ -148,7 +146,6 @@ SlideSorterView::SlideSorterView (SlideSorter& rSlideSorter)
       meOrientation(Layouter::GRID),
       mpProperties(rSlideSorter.GetProperties()),
       mpPageUnderMouse(),
-      mnButtonUnderMouse(-1),
       mpPageObjectPainter(),
       mpSelectionPainter(),
       mpBackgroundPainter(
@@ -177,7 +174,7 @@ SlideSorterView::SlideSorterView (SlideSorter& rSlideSorter)
     mpLayeredDevice->RegisterPainter(pPainter, 1);
 }
 
-SlideSorterView::~SlideSorterView (void)
+SlideSorterView::~SlideSorterView()
 {
     if ( ! mbIsDisposed)
     {
@@ -186,12 +183,12 @@ SlideSorterView::~SlideSorterView (void)
     }
 }
 
-void SlideSorterView::Init (void)
+void SlideSorterView::Init()
 {
     HandleModelChange();
 }
 
-void SlideSorterView::Dispose (void)
+void SlideSorterView::Dispose()
 {
     mpSelectionPainter.reset();
 
@@ -217,7 +214,7 @@ sal_Int32 SlideSorterView::GetPageIndexAtPoint (const Point& rWindowPosition) co
 {
     sal_Int32 nIndex (-1);
 
-    SharedSdWindow pWindow (mrSlideSorter.GetContentWindow());
+    sd::Window *pWindow (mrSlideSorter.GetContentWindow());
     if (pWindow)
     {
         nIndex = mpLayouter->GetIndexAtPoint(pWindow->PixelToLogic(rWindowPosition), false, false);
@@ -230,24 +227,24 @@ sal_Int32 SlideSorterView::GetPageIndexAtPoint (const Point& rWindowPosition) co
     return nIndex;
 }
 
-Layouter& SlideSorterView::GetLayouter (void)
+Layouter& SlideSorterView::GetLayouter()
 {
     return *mpLayouter.get();
 }
 
-void SlideSorterView::ModelHasChanged (void)
+void SlideSorterView::ModelHasChanged()
 {
     // Ignore this call.  Rely on hints sent by the model to get informed of
     // model changes.
 }
 
-void SlideSorterView::PreModelChange (void)
+void SlideSorterView::PreModelChange()
 {
     // Reset the slide under the mouse.  It will be re-set in PostModelChange().
     SetPageUnderMouse(SharedPageDescriptor());
 }
 
-void SlideSorterView::PostModelChange (void)
+void SlideSorterView::PostModelChange()
 {
     // In PreModelChange() the page objects have been released.  Here we
     // create new ones.
@@ -266,37 +263,37 @@ void SlideSorterView::PostModelChange (void)
     describe the type of change so that existing page objects can be
     reused.
 */
-void SlideSorterView::HandleModelChange (void)
+void SlideSorterView::HandleModelChange()
 {
     PreModelChange ();
     PostModelChange();
 }
 
-void SlideSorterView::HandleDrawModeChange (void)
+void SlideSorterView::HandleDrawModeChange()
 {
     // Replace the preview cache with a new and empty one.  The
     // PreviewRenderer that is used by the cache is replaced by this as
     // well.
     mpPreviewCache.reset();
-    GetPreviewCache()->InvalidateCache(true);
+    GetPreviewCache()->InvalidateCache();
 
     RequestRepaint();
 }
 
-void SlideSorterView::HandleDataChangeEvent (void)
+void SlideSorterView::HandleDataChangeEvent()
 {
     GetPageObjectPainter()->SetTheme(mrSlideSorter.GetTheme());
 
     // Update the color used by the background painter.
-    ::boost::shared_ptr<BackgroundPainter> pPainter (
-        ::boost::dynamic_pointer_cast<BackgroundPainter>(mpBackgroundPainter));
+    std::shared_ptr<BackgroundPainter> pPainter (
+        std::dynamic_pointer_cast<BackgroundPainter>(mpBackgroundPainter));
     if (pPainter)
         pPainter->SetColor(mrSlideSorter.GetTheme()->GetColor(Theme::Color_Background));
 
     RequestRepaint();
 }
 
-void SlideSorterView::Resize (void)
+void SlideSorterView::Resize()
 {
     UpdateOrientation();
 
@@ -304,20 +301,20 @@ void SlideSorterView::Resize (void)
     RequestRearrange();
 }
 
-void SlideSorterView::RequestRearrange (void)
+void SlideSorterView::RequestRearrange()
 {
     mbIsRearrangePending = true;
     Rearrange();
 }
 
-void SlideSorterView::Rearrange (void)
+void SlideSorterView::Rearrange()
 {
     if ( ! mbIsRearrangePending)
         return;
     if (mrModel.GetPageCount() <= 0)
         return;
 
-    SharedSdWindow pWindow (mrSlideSorter.GetContentWindow());
+    sd::Window *pWindow (mrSlideSorter.GetContentWindow());
     if ( ! pWindow)
         return;
     const Size aWindowSize (pWindow->GetSizePixel());
@@ -339,7 +336,7 @@ void SlideSorterView::Rearrange (void)
     }
 }
 
-void SlideSorterView::UpdateOrientation (void)
+void SlideSorterView::UpdateOrientation()
 {
     // The layout of slides depends on whether the slide sorter is
     // displayed in the center or the side pane.
@@ -348,15 +345,15 @@ void SlideSorterView::UpdateOrientation (void)
     else
     {
         // Get access to the docking window.
-        vcl::Window* pWindow = mrSlideSorter.GetContentWindow().get();
-        PaneDockingWindow* pDockingWindow = NULL;
-        while (pWindow!=NULL && pDockingWindow==NULL)
+        vcl::Window* pWindow = mrSlideSorter.GetContentWindow();
+        PaneDockingWindow* pDockingWindow = nullptr;
+        while (pWindow!=nullptr && pDockingWindow==nullptr)
         {
             pDockingWindow = dynamic_cast<PaneDockingWindow*>(pWindow);
             pWindow = pWindow->GetParent();
         }
 
-        if (pDockingWindow != NULL)
+        if (pDockingWindow != nullptr)
         {
             const long nScrollBarSize (
                 Application::GetSettings().GetStyleSettings().GetScrollBarSize());
@@ -409,7 +406,7 @@ void SlideSorterView::UpdateOrientation (void)
 
 void SlideSorterView::Layout ()
 {
-    SharedSdWindow pWindow (mrSlideSorter.GetContentWindow());
+    sd::Window *pWindow (mrSlideSorter.GetContentWindow());
     if (pWindow)
     {
         // Set the model area, i.e. the smallest rectangle that includes all
@@ -418,7 +415,7 @@ void SlideSorterView::Layout ()
         pWindow->SetViewOrigin (aViewBox.TopLeft());
         pWindow->SetViewSize (aViewBox.GetSize());
 
-        ::boost::shared_ptr<PageObjectLayouter> pPageObjectLayouter(
+        std::shared_ptr<PageObjectLayouter> pPageObjectLayouter(
             mpLayouter->GetPageObjectLayouter());
         if (pPageObjectLayouter)
         {
@@ -444,14 +441,14 @@ void SlideSorterView::Layout ()
     InvalidatePageObjectVisibilities ();
 }
 
-void SlideSorterView::InvalidatePageObjectVisibilities (void)
+void SlideSorterView::InvalidatePageObjectVisibilities()
 {
     mbPageObjectVisibilitiesValid = false;
 }
 
-void SlideSorterView::DeterminePageObjectVisibilities (void)
+void SlideSorterView::DeterminePageObjectVisibilities()
 {
-    SharedSdWindow pWindow (mrSlideSorter.GetContentWindow());
+    sd::Window *pWindow (mrSlideSorter.GetContentWindow());
     if (pWindow)
     {
         // Set this flag to true here so that an invalidate during the
@@ -470,10 +467,10 @@ void SlideSorterView::DeterminePageObjectVisibilities (void)
             mbPreciousFlagUpdatePending |= true;
 
         model::SharedPageDescriptor pDescriptor;
-        for (int nIndex=aUnion.Min(); nIndex<=aUnion.Max(); nIndex++)
+        for (long nIndex=aUnion.Min(); nIndex<=aUnion.Max(); nIndex++)
         {
             pDescriptor = mrModel.GetPageDescriptor(nIndex);
-            if (pDescriptor.get() != NULL)
+            if (pDescriptor.get() != nullptr)
                 SetState(
                     pDescriptor,
                     PageDescriptor::ST_Visible,
@@ -487,14 +484,14 @@ void SlideSorterView::DeterminePageObjectVisibilities (void)
 
             // Tell the listeners that the visibility of some objects has
             // changed.
-            ::std::vector<Link>& aChangeListeners (maVisibilityChangeListeners);
-            for (::std::vector<Link>::const_iterator
+            ::std::vector<Link<LinkParamNone*,void>>& aChangeListeners (maVisibilityChangeListeners);
+            for (::std::vector<Link<LinkParamNone*,void>>::const_iterator
                      iLink(aChangeListeners.begin()),
                      iEnd(aChangeListeners.end());
                  iLink!=iEnd;
                  ++iLink)
             {
-                iLink->Call(NULL);
+                iLink->Call(nullptr);
             }
         }
 
@@ -503,26 +500,24 @@ void SlideSorterView::DeterminePageObjectVisibilities (void)
     }
 }
 
-void SlideSorterView::UpdatePreciousFlags (void)
+void SlideSorterView::UpdatePreciousFlags()
 {
     if (mbPreciousFlagUpdatePending)
     {
         mbPreciousFlagUpdatePending = false;
 
         model::SharedPageDescriptor pDescriptor;
-        ::boost::shared_ptr<cache::PageCache> pCache = GetPreviewCache();
+        std::shared_ptr<cache::PageCache> pCache = GetPreviewCache();
         sal_Int32 nPageCount (mrModel.GetPageCount());
 
         for (int nIndex=0; nIndex<=nPageCount; ++nIndex)
         {
             pDescriptor = mrModel.GetPageDescriptor(nIndex);
-            if (pDescriptor.get() != NULL)
+            if (pDescriptor.get() != nullptr)
             {
                 pCache->SetPreciousFlag(
                     pDescriptor->GetPage(),
                     maVisiblePageRange.IsInside(nIndex));
-                SSCD_SET_VISIBILITY(mrModel.GetDocument(), nIndex,
-                    maVisiblePageRange.IsInside(nIndex));
             }
             else
             {
@@ -546,9 +541,9 @@ bool SlideSorterView::SetOrientation (const Layouter::Orientation eOrientation)
         return false;
 }
 
-void SlideSorterView::RequestRepaint (void)
+void SlideSorterView::RequestRepaint()
 {
-    SharedSdWindow pWindow (mrSlideSorter.GetContentWindow());
+    sd::Window *pWindow (mrSlideSorter.GetContentWindow());
     if (pWindow)
     {
         mpLayeredDevice->InvalidateAllLayers(
@@ -567,7 +562,7 @@ void SlideSorterView::RequestRepaint (const model::SharedPageDescriptor& rpDescr
 
 void SlideSorterView::RequestRepaint (const Rectangle& rRepaintBox)
 {
-    SharedSdWindow pWindow (mrSlideSorter.GetContentWindow());
+    sd::Window *pWindow (mrSlideSorter.GetContentWindow());
     if (pWindow)
     {
         mpLayeredDevice->InvalidateAllLayers(rRepaintBox);
@@ -577,7 +572,7 @@ void SlideSorterView::RequestRepaint (const Rectangle& rRepaintBox)
 
 void SlideSorterView::RequestRepaint (const vcl::Region& rRepaintRegion)
 {
-    SharedSdWindow pWindow (mrSlideSorter.GetContentWindow());
+    sd::Window *pWindow (mrSlideSorter.GetContentWindow());
     if (pWindow)
     {
         mpLayeredDevice->InvalidateAllLayers(rRepaintRegion);
@@ -585,7 +580,7 @@ void SlideSorterView::RequestRepaint (const vcl::Region& rRepaintRegion)
     }
 }
 
-Rectangle SlideSorterView::GetModelArea (void)
+Rectangle SlideSorterView::GetModelArea()
 {
     return mpLayouter->GetTotalBoundingBox();
 }
@@ -613,7 +608,7 @@ void SlideSorterView::CompleteRedraw (
         mnLockRedrawSmph ? "locked" : "");
 #endif
 
-    if (pDevice == NULL || pDevice!=mrSlideSorter.GetContentWindow().get())
+    if (pDevice == nullptr || pDevice!=mrSlideSorter.GetContentWindow())
         return;
 
     // The parent implementation of CompleteRedraw is called only when
@@ -650,7 +645,7 @@ void SlideSorterView::CompleteRedraw (
     mrSlideSorter.GetContentWindow()->DrawText(
         gFrameTimeBox,
         OUString::number(1 / (gFrameTimeSum / gFrameTimeCount)),
-        TEXT_DRAW_RIGHT | TEXT_DRAW_VCENTER);
+        DrawTextFlags::Right | DrawTextFlags::VCenter);
     //    mrSlideSorter.GetContentWindow()->Invalidate(gFrameTimeBox);
 #endif
 }
@@ -676,7 +671,7 @@ void SlideSorterView::Paint (
     // Paint all page objects that are fully or partially inside the
     // repaint region.
     const Range aRange (mpLayouter->GetRangeOfVisiblePageObjects(rRepaintArea));
-    for (sal_Int32 nIndex=aRange.Min(); nIndex<=aRange.Max(); ++nIndex)
+    for (long nIndex=aRange.Min(); nIndex<=aRange.Max(); ++nIndex)
     {
         model::SharedPageDescriptor pDescriptor (mrModel.GetPageDescriptor(nIndex));
         if (!pDescriptor || ! pDescriptor->HasState(PageDescriptor::ST_Visible))
@@ -699,10 +694,10 @@ void SlideSorterView::ConfigurationChanged (
 
 }
 
-::boost::shared_ptr<cache::PageCache> SlideSorterView::GetPreviewCache (void)
+std::shared_ptr<cache::PageCache> SlideSorterView::GetPreviewCache()
 {
-    SharedSdWindow pWindow (mrSlideSorter.GetContentWindow());
-    if (pWindow && mpPreviewCache.get() == NULL)
+    sd::Window *pWindow (mrSlideSorter.GetContentWindow());
+    if (pWindow && mpPreviewCache.get() == nullptr)
     {
         mpPreviewCache.reset(
             new cache::PageCache(
@@ -714,14 +709,14 @@ void SlideSorterView::ConfigurationChanged (
     return mpPreviewCache;
 }
 
-Pair SlideSorterView::GetVisiblePageRange (void)
+Pair SlideSorterView::GetVisiblePageRange()
 {
     if ( ! mbPageObjectVisibilitiesValid)
         DeterminePageObjectVisibilities();
     return maVisiblePageRange;
 }
 
-void SlideSorterView::AddVisibilityChangeListener (const Link& rListener)
+void SlideSorterView::AddVisibilityChangeListener (const Link<LinkParamNone*,void>& rListener)
 {
     if (::std::find (
         maVisibilityChangeListeners.begin(),
@@ -732,7 +727,7 @@ void SlideSorterView::AddVisibilityChangeListener (const Link& rListener)
     }
 }
 
-void SlideSorterView::RemoveVisibilityChangeListener(const Link&rListener)
+void SlideSorterView::RemoveVisibilityChangeListener(const Link<LinkParamNone*,void>&rListener)
 {
     maVisibilityChangeListeners.erase (
         ::std::find (
@@ -741,7 +736,7 @@ void SlideSorterView::RemoveVisibilityChangeListener(const Link&rListener)
             rListener));
 }
 
-ToolTip& SlideSorterView::GetToolTip (void) const
+ToolTip& SlideSorterView::GetToolTip() const
 {
     OSL_ASSERT(mpToolTip);
     return *mpToolTip;
@@ -757,7 +752,7 @@ void SlideSorterView::DragFinished (sal_Int8 nDropAction)
 void SlideSorterView::Notify (SfxBroadcaster& rBroadcaster, const SfxHint& rHint)
 {
     ::sd::DrawDocShell* pDocShell = mrModel.GetDocument()->GetDocSh();
-    if (pDocShell!=NULL && pDocShell->IsEnableSetModified())
+    if (pDocShell!=nullptr && pDocShell->IsEnableSetModified())
         mbModelChangedWhileModifyEnabled = true;
 
     ::sd::View::Notify(rBroadcaster, rHint);
@@ -765,8 +760,8 @@ void SlideSorterView::Notify (SfxBroadcaster& rBroadcaster, const SfxHint& rHint
 
 void SlideSorterView::UpdatePageUnderMouse ()
 {
-    ::boost::shared_ptr<ScrollBar> pVScrollBar (mrSlideSorter.GetVerticalScrollBar());
-    ::boost::shared_ptr<ScrollBar> pHScrollBar (mrSlideSorter.GetHorizontalScrollBar());
+    VclPtr<ScrollBar> pVScrollBar (mrSlideSorter.GetVerticalScrollBar());
+    VclPtr<ScrollBar> pHScrollBar (mrSlideSorter.GetHorizontalScrollBar());
     if ((pVScrollBar && pVScrollBar->IsVisible() && pVScrollBar->IsTracking())
         || (pHScrollBar && pHScrollBar->IsVisible() && pHScrollBar->IsTracking()))
     {
@@ -776,7 +771,7 @@ void SlideSorterView::UpdatePageUnderMouse ()
         return;
     }
 
-    SharedSdWindow pWindow (mrSlideSorter.GetContentWindow());
+    sd::Window *pWindow (mrSlideSorter.GetContentWindow());
     if (pWindow && pWindow->IsVisible() && ! pWindow->IsMouseCaptured())
     {
         const Window::PointerState aPointerState (pWindow->GetPointerState());
@@ -842,7 +837,7 @@ bool SlideSorterView::SetState (
     return bModified;
 }
 
-::boost::shared_ptr<PageObjectPainter> SlideSorterView::GetPageObjectPainter (void)
+std::shared_ptr<PageObjectPainter> SlideSorterView::GetPageObjectPainter()
 {
     if ( ! mpPageObjectPainter)
         mpPageObjectPainter.reset(new PageObjectPainter(mrSlideSorter));
@@ -860,7 +855,7 @@ SlideSorterView::DrawLock::DrawLock (SlideSorter& rSlideSorter)
     ++mrView.mnLockRedrawSmph;
 }
 
-SlideSorterView::DrawLock::~DrawLock (void)
+SlideSorterView::DrawLock::~DrawLock()
 {
     OSL_ASSERT(mrView.mnLockRedrawSmph>0);
     --mrView.mnLockRedrawSmph;
@@ -872,7 +867,7 @@ SlideSorterView::DrawLock::~DrawLock (void)
         }
 }
 
-void SlideSorterView::DrawLock::Dispose (void)
+void SlideSorterView::DrawLock::Dispose()
 {
     mpWindow.reset();
 }
