@@ -17,7 +17,6 @@
  *   the License at http://www.apache.org/licenses/LICENSE-2.0 .
  */
 
-
 #include "view/SlsPageObjectPainter.hxx"
 
 #include "model/SlsPageDescriptor.hxx"
@@ -34,12 +33,11 @@
 #include <vcl/svapp.hxx>
 #include <vcl/vclenum.hxx>
 #include <vcl/virdev.hxx>
-#include <boost/scoped_ptr.hpp>
 #include "CustomAnimationEffect.hxx"
+#include <memory>
 
 using namespace ::drawinglayer::primitive2d;
 
-
 namespace sd { namespace slidesorter { namespace view {
 
 //===== PageObjectPainter =====================================================
@@ -47,19 +45,12 @@ namespace sd { namespace slidesorter { namespace view {
 PageObjectPainter::PageObjectPainter (
     const SlideSorter& rSlideSorter)
     : mrLayouter(rSlideSorter.GetView().GetLayouter()),
-      mpPageObjectLayouter(),
       mpCache(rSlideSorter.GetView().GetPreviewCache()),
       mpProperties(rSlideSorter.GetProperties()),
       mpTheme(rSlideSorter.GetTheme()),
       mpPageNumberFont(Theme::GetFont(Theme::Font_PageNumber, *rSlideSorter.GetContentWindow())),
       mpShadowPainter(new FramePainter(mpTheme->GetIcon(Theme::Icon_RawShadow))),
-      mpFocusBorderPainter(new FramePainter(mpTheme->GetIcon(Theme::Icon_FocusBorder))),
-      maNormalBackground(),
-      maSelectionBackground(),
-      maFocusedSelectionBackground(),
-      maMouseOverBackground(),
-      maMouseOverFocusedBackground(),
-      maSize()
+      mpFocusBorderPainter(new FramePainter(mpTheme->GetIcon(Theme::Icon_FocusBorder)))
 {
     // Replace the color (not the alpha values) in the focus border with a
     // color derived from the current selection color.
@@ -70,120 +61,66 @@ PageObjectPainter::PageObjectPainter (
     mpFocusBorderPainter->AdaptColor(aColor, true);
 }
 
-
-
-PageObjectPainter::~PageObjectPainter (void)
+PageObjectPainter::~PageObjectPainter()
 {
 }
 
-
-
-
 void PageObjectPainter::PaintPageObject (
     OutputDevice& rDevice,
     const model::SharedPageDescriptor& rpDescriptor)
 {
     if (UpdatePageObjectLayouter())
     {
+        PageObjectLayouter *pPageObjectLayouter = mrLayouter.GetPageObjectLayouter().get();
         // Turn off antialiasing to avoid the bitmaps from being
         // shifted by fractions of a pixel and thus show blurry edges.
-        const sal_uInt16 nSavedAntialiasingMode (rDevice.GetAntialiasing());
-        rDevice.SetAntialiasing(nSavedAntialiasingMode & ~ANTIALIASING_ENABLE_B2DDRAW);
+        const AntialiasingFlags nSavedAntialiasingMode (rDevice.GetAntialiasing());
+        rDevice.SetAntialiasing(nSavedAntialiasingMode & ~AntialiasingFlags::EnableB2dDraw);
 
-        PaintBackground(rDevice, rpDescriptor);
-        PaintPreview(rDevice, rpDescriptor);
-        PaintPageNumber(rDevice, rpDescriptor);
-        PaintTransitionEffect(rDevice, rpDescriptor);
+        PaintBackground(pPageObjectLayouter, rDevice, rpDescriptor);
+        PaintPreview(pPageObjectLayouter, rDevice, rpDescriptor);
+        PaintPageNumber(pPageObjectLayouter, rDevice, rpDescriptor);
+        PaintTransitionEffect(pPageObjectLayouter, rDevice, rpDescriptor);
         if (rpDescriptor->GetPage()->hasAnimationNode())
-            PaintCustomAnimationEffect(rDevice, rpDescriptor);
+            PaintCustomAnimationEffect(pPageObjectLayouter, rDevice, rpDescriptor);
         rDevice.SetAntialiasing(nSavedAntialiasingMode);
     }
 }
 
-
-
-
-bool PageObjectPainter::UpdatePageObjectLayouter (void)
+bool PageObjectPainter::UpdatePageObjectLayouter()
 {
     // The page object layouter is quite volatile. It may have been replaced
     // since the last call.  Update it now.
-    mpPageObjectLayouter = mrLayouter.GetPageObjectLayouter();
-    if ( ! mpPageObjectLayouter)
+    PageObjectLayouter *pPageObjectLayouter = mrLayouter.GetPageObjectLayouter().get();
+    if ( ! pPageObjectLayouter)
     {
-        OSL_ASSERT(mpPageObjectLayouter);
+        OSL_FAIL("no page object layouter");
         return false;
     }
-    else
-        return true;
+
+    return true;
 }
 
-
-
-
-void PageObjectPainter::NotifyResize (const bool bForce)
-{
-    mpPageObjectLayouter = mrLayouter.GetPageObjectLayouter();
-    if (bForce || ! mpPageObjectLayouter)
-        InvalidateBitmaps();
-    else if (UpdatePageObjectLayouter())
-    {
-        const Size aSize (mpPageObjectLayouter->GetSize(
-                PageObjectLayouter::FocusIndicator,
-                PageObjectLayouter::WindowCoordinateSystem));
-        if ( maSize!=aSize)
-        {
-            maSize = aSize;
-            InvalidateBitmaps();
-        }
-    }
-}
-
-
-
-
-void PageObjectPainter::InvalidateBitmaps (void)
-{
-    maNormalBackground.SetEmpty();
-    maSelectionBackground.SetEmpty();
-    maFocusedSelectionBackground.SetEmpty();
-    maFocusedBackground.SetEmpty();
-    maMouseOverBackground.SetEmpty();
-    maMouseOverFocusedBackground.SetEmpty();
-    maMouseOverSelectedAndFocusedBackground.SetEmpty();
-}
-
-
-
-
-void PageObjectPainter::SetTheme (const ::boost::shared_ptr<view::Theme>& rpTheme)
+void PageObjectPainter::SetTheme (const std::shared_ptr<view::Theme>& rpTheme)
 {
     mpTheme = rpTheme;
-    NotifyResize(true);
 }
 
-
-
-
 void PageObjectPainter::PaintBackground (
+    PageObjectLayouter *pPageObjectLayouter,
     OutputDevice& rDevice,
-    const model::SharedPageDescriptor& rpDescriptor)
+    const model::SharedPageDescriptor& rpDescriptor) const
 {
-    const Rectangle aBox (mpPageObjectLayouter->GetBoundingBox(
-        rpDescriptor,
-        PageObjectLayouter::FocusIndicator,
-        PageObjectLayouter::ModelCoordinateSystem));
-
-    const Bitmap& rBackground (GetBackgroundForState(rpDescriptor, rDevice));
-    rDevice.DrawBitmap(aBox.TopLeft(), rBackground);
+    PaintBackgroundDetail(pPageObjectLayouter, rDevice, rpDescriptor);
 
     // Fill the interior of the preview area with the default background
     // color of the page.
     SdPage* pPage = rpDescriptor->GetPage();
-    if (pPage != NULL)
+    if (pPage != nullptr)
     {
-        rDevice.SetFillColor(pPage->GetPageBackgroundColor(NULL));
-        rDevice.SetLineColor(pPage->GetPageBackgroundColor(NULL));
-        const Rectangle aPreviewBox (mpPageObjectLayouter->GetBoundingBox(
+        rDevice.SetFillColor(pPage->GetPageBackgroundColor(nullptr));
+        rDevice.SetLineColor(pPage->GetPageBackgroundColor(nullptr));
+        const Rectangle aPreviewBox (pPageObjectLayouter->GetBoundingBox(
             rpDescriptor,
             PageObjectLayouter::Preview,
             PageObjectLayouter::ModelCoordinateSystem));
@@ -191,19 +128,17 @@ void PageObjectPainter::PaintBackground (
     }
 }
 
-
-
-
 void PageObjectPainter::PaintPreview (
+    PageObjectLayouter *pPageObjectLayouter,
     OutputDevice& rDevice,
     const model::SharedPageDescriptor& rpDescriptor) const
 {
-    const Rectangle aBox (mpPageObjectLayouter->GetBoundingBox(
+    const Rectangle aBox (pPageObjectLayouter->GetBoundingBox(
         rpDescriptor,
         PageObjectLayouter::Preview,
         PageObjectLayouter::ModelCoordinateSystem));
 
-    if (mpCache != 0)
+    if (mpCache != nullptr)
     {
         const SdrPage* pPage = rpDescriptor->GetPage();
         mpCache->SetPreciousFlag(pPage, true);
@@ -219,20 +154,17 @@ void PageObjectPainter::PaintPreview (
     }
 }
 
-
-
-
 Bitmap PageObjectPainter::CreateMarkedPreview (
     const Size& rSize,
     const Bitmap& rPreview,
     const BitmapEx& rOverlay,
-    const OutputDevice* pReferenceDevice) const
+    const OutputDevice* pReferenceDevice)
 {
-    ::boost::scoped_ptr<VirtualDevice> pDevice;
-    if (pReferenceDevice != NULL)
-        pDevice.reset(new VirtualDevice(*pReferenceDevice));
+    ScopedVclPtr<VirtualDevice> pDevice;
+    if (pReferenceDevice != nullptr)
+        pDevice.disposeAndReset(VclPtr<VirtualDevice>::Create(*pReferenceDevice));
     else
-        pDevice.reset(new VirtualDevice());
+        pDevice.disposeAndReset(VclPtr<VirtualDevice>::Create());
     pDevice->SetOutputSizePixel(rSize);
 
     pDevice->DrawBitmap(Point(0,0), rSize, rPreview);
@@ -242,16 +174,13 @@ Bitmap PageObjectPainter::CreateMarkedPreview (
     const sal_Int32 nIconHeight (rOverlay.GetSizePixel().Height());
     if (nIconWidth>0 && nIconHeight>0)
     {
-        for (sal_Int32 nX=0; nX<rSize.Width(); nX+=nIconWidth)
-            for (sal_Int32 nY=0; nY<rSize.Height(); nY+=nIconHeight)
+        for (long nX=0; nX<rSize.Width(); nX+=nIconWidth)
+            for (long nY=0; nY<rSize.Height(); nY+=nIconHeight)
                 pDevice->DrawBitmapEx(Point(nX,nY), rOverlay);
     }
     return pDevice->GetBitmap(Point(0,0), rSize);
 }
 
-
-
-
 Bitmap PageObjectPainter::GetPreviewBitmap (
     const model::SharedPageDescriptor& rpDescriptor,
     const OutputDevice* pReferenceDevice) const
@@ -261,8 +190,10 @@ Bitmap PageObjectPainter::GetPreviewBitmap (
 
     if (bIsExcluded)
     {
+        PageObjectLayouter *pPageObjectLayouter = mrLayouter.GetPageObjectLayouter().get();
+
         Bitmap aMarkedPreview (mpCache->GetMarkedPreviewBitmap(pPage,false));
-        const Rectangle aPreviewBox (mpPageObjectLayouter->GetBoundingBox(
+        const Rectangle aPreviewBox (pPageObjectLayouter->GetBoundingBox(
             rpDescriptor,
             PageObjectLayouter::Preview,
             PageObjectLayouter::ModelCoordinateSystem));
@@ -283,14 +214,12 @@ Bitmap PageObjectPainter::GetPreviewBitmap (
     }
 }
 
-
-
-
 void PageObjectPainter::PaintPageNumber (
+    PageObjectLayouter *pPageObjectLayouter,
     OutputDevice& rDevice,
     const model::SharedPageDescriptor& rpDescriptor) const
 {
-    const Rectangle aBox (mpPageObjectLayouter->GetBoundingBox(
+    const Rectangle aBox (pPageObjectLayouter->GetBoundingBox(
         rpDescriptor,
         PageObjectLayouter::PageNumber,
         PageObjectLayouter::ModelCoordinateSystem));
@@ -330,58 +259,58 @@ void PageObjectPainter::PaintPageNumber (
     }
 
     // Paint the page number.
-    OSL_ASSERT(rpDescriptor->GetPage()!=NULL);
+    OSL_ASSERT(rpDescriptor->GetPage()!=nullptr);
     const sal_Int32 nPageNumber ((rpDescriptor->GetPage()->GetPageNum() - 1) / 2 + 1);
     const OUString sPageNumber(OUString::number(nPageNumber));
     rDevice.SetFont(*mpPageNumberFont);
     rDevice.SetTextColor(aPageNumberColor);
-    rDevice.DrawText(aBox, sPageNumber, TEXT_DRAW_RIGHT | TEXT_DRAW_VCENTER);
+    rDevice.DrawText(aBox, sPageNumber, DrawTextFlags::Right | DrawTextFlags::VCenter);
 }
 
-
-
-
 void PageObjectPainter::PaintTransitionEffect (
+    PageObjectLayouter *pPageObjectLayouter,
     OutputDevice& rDevice,
-    const model::SharedPageDescriptor& rpDescriptor) const
+    const model::SharedPageDescriptor& rpDescriptor)
 {
     const SdPage* pPage = rpDescriptor->GetPage();
-    if (pPage!=NULL && pPage->getTransitionType() > 0)
+    if (pPage!=nullptr && pPage->getTransitionType() > 0)
     {
-        const Rectangle aBox (mpPageObjectLayouter->GetBoundingBox(
+        const Rectangle aBox (pPageObjectLayouter->GetBoundingBox(
             rpDescriptor,
             PageObjectLayouter::TransitionEffectIndicator,
             PageObjectLayouter::ModelCoordinateSystem));
 
         rDevice.DrawBitmapEx(
             aBox.TopCenter(),
-            mpPageObjectLayouter->GetTransitionEffectIcon().GetBitmapEx());
+            pPageObjectLayouter->GetTransitionEffectIcon().GetBitmapEx());
     }
 }
 
 void PageObjectPainter::PaintCustomAnimationEffect (
+    PageObjectLayouter *pPageObjectLayouter,
     OutputDevice& rDevice,
-    const model::SharedPageDescriptor& rpDescriptor) const
+    const model::SharedPageDescriptor& rpDescriptor)
 {
     SdPage* pPage = rpDescriptor->GetPage();
-    boost::shared_ptr< MainSequence > aMainSequence = pPage->getMainSequence();
+    std::shared_ptr< MainSequence > aMainSequence = pPage->getMainSequence();
     EffectSequence::iterator aIter = aMainSequence->getBegin();
     EffectSequence::iterator aEnd = aMainSequence->getEnd();
     if ( aIter != aEnd )
     {
-        const Rectangle aBox (mpPageObjectLayouter->GetBoundingBox(
+        const Rectangle aBox (pPageObjectLayouter->GetBoundingBox(
             rpDescriptor,
             PageObjectLayouter::CustomAnimationEffectIndicator,
             PageObjectLayouter::ModelCoordinateSystem));
         rDevice.DrawBitmapEx(
             aBox.TopCenter(),
-            mpPageObjectLayouter->GetCustomAnimationEffectIcon().GetBitmapEx());
+            pPageObjectLayouter->GetCustomAnimationEffectIcon().GetBitmapEx());
     }
 }
 
-Bitmap& PageObjectPainter::GetBackgroundForState (
-    const model::SharedPageDescriptor& rpDescriptor,
-    const OutputDevice& rReferenceDevice)
+void PageObjectPainter::PaintBackgroundDetail (
+    PageObjectLayouter *pPageObjectLayouter,
+    OutputDevice& rDevice,
+    const model::SharedPageDescriptor& rpDescriptor) const
 {
     enum State { None = 0x00, Selected = 0x01, MouseOver = 0x02, Focused = 0x04 };
     const int eState =
@@ -389,98 +318,68 @@ Bitmap& PageObjectPainter::GetBackgroundForState (
         | (rpDescriptor->HasState(model::PageDescriptor::ST_MouseOver) ? MouseOver : None)
         | (rpDescriptor->HasState(model::PageDescriptor::ST_Focused) ? Focused : None);
 
+    bool bHasFocusBorder;
+    Theme::GradientColorType eColorType;
+
     switch (eState)
     {
         case MouseOver | Selected | Focused:
-            return GetBackground(
-                maMouseOverSelectedAndFocusedBackground,
-                Theme::Gradient_MouseOverSelectedAndFocusedPage,
-                rReferenceDevice,
-                true);
+            eColorType = Theme::Gradient_MouseOverSelectedAndFocusedPage;
+            bHasFocusBorder = true;
+            break;
 
         case MouseOver | Selected:
+            eColorType = Theme::Gradient_MouseOverSelected;
+            bHasFocusBorder = false;
+            break;
+
         case MouseOver:
-            return GetBackground(
-                maMouseOverBackground,
-                Theme::Gradient_MouseOverPage,
-                rReferenceDevice,
-                false);
+            eColorType = Theme::Gradient_MouseOverPage;
+            bHasFocusBorder = false;
+            break;
 
         case MouseOver | Focused:
-            return GetBackground(
-                maMouseOverFocusedBackground,
-                Theme::Gradient_MouseOverPage,
-                rReferenceDevice,
-                true);
+            eColorType = Theme::Gradient_MouseOverPage;
+            bHasFocusBorder = true;
+            break;
 
         case Selected | Focused:
-            return GetBackground(
-                maFocusedSelectionBackground,
-                Theme::Gradient_SelectedAndFocusedPage,
-                rReferenceDevice,
-                true);
+            eColorType = Theme::Gradient_SelectedAndFocusedPage;
+            bHasFocusBorder = true;
+            break;
 
         case Selected:
-            return GetBackground(
-                maSelectionBackground,
-                Theme::Gradient_SelectedPage,
-                rReferenceDevice,
-                false);
+            eColorType = Theme::Gradient_SelectedPage;
+            bHasFocusBorder = false;
+            break;
 
         case Focused:
-            return GetBackground(
-                maFocusedBackground,
-                Theme::Gradient_FocusedPage,
-                rReferenceDevice,
-                true);
+            eColorType = Theme::Gradient_FocusedPage;
+            bHasFocusBorder = true;
+            break;
 
         case None:
         default:
-            return GetBackground(
-                maNormalBackground,
-                Theme::Gradient_NormalPage,
-                rReferenceDevice,
-                false);
+            eColorType = Theme::Gradient_NormalPage;
+            bHasFocusBorder = false;
+            break;
     }
-}
 
+    const Rectangle aFocusSize (pPageObjectLayouter->GetBoundingBox(
+                                        rpDescriptor,
+                                        PageObjectLayouter::FocusIndicator,
+                                        PageObjectLayouter::ModelCoordinateSystem));
 
-
-
-Bitmap& PageObjectPainter::GetBackground(
-    Bitmap& rBackground,
-    Theme::GradientColorType eType,
-    const OutputDevice& rReferenceDevice,
-    const bool bHasFocusBorder)
-{
-    if (rBackground.IsEmpty())
-        rBackground = CreateBackgroundBitmap(rReferenceDevice, eType, bHasFocusBorder);
-    return rBackground;
-}
-
-
-
-
-Bitmap PageObjectPainter::CreateBackgroundBitmap(
-    const OutputDevice& rReferenceDevice,
-    const Theme::GradientColorType eColorType,
-    const bool bHasFocusBorder) const
-{
-    const Size aSize (mpPageObjectLayouter->GetSize(
-        PageObjectLayouter::FocusIndicator,
-        PageObjectLayouter::WindowCoordinateSystem));
-    const Rectangle aPageObjectBox (mpPageObjectLayouter->GetBoundingBox(
-        Point(0,0),
-        PageObjectLayouter::PageObject,
-        PageObjectLayouter::ModelCoordinateSystem));
-    VirtualDevice aBitmapDevice (rReferenceDevice);
-    aBitmapDevice.SetOutputSizePixel(aSize);
+    const Rectangle aPageObjectBox (pPageObjectLayouter->GetBoundingBox(
+                                        rpDescriptor,
+                                        PageObjectLayouter::PageObject,
+                                        PageObjectLayouter::ModelCoordinateSystem));
 
     // Fill the background with the background color of the slide sorter.
     const Color aBackgroundColor (mpTheme->GetColor(Theme::Color_Background));
-    aBitmapDevice.SetFillColor(aBackgroundColor);
-    aBitmapDevice.SetLineColor(aBackgroundColor);
-    aBitmapDevice.DrawRect(Rectangle(Point(0,0), aSize));
+    rDevice.SetFillColor(aBackgroundColor);
+    rDevice.SetLineColor(aBackgroundColor);
+    rDevice.DrawRect(aFocusSize);
 
     // Paint the slide area with a linear gradient that starts some pixels
     // below the top and ends some pixels above the bottom.
@@ -502,47 +401,42 @@ Bitmap PageObjectPainter::CreateBackgroundBitmap(
         for (sal_Int32 nY=0; nY<nHeight; ++nY)
         {
             if (nY<=nY1)
-                aBitmapDevice.SetLineColor(aTopColor);
+                rDevice.SetLineColor(aTopColor);
             else if (nY>=nY2)
-                aBitmapDevice.SetLineColor(aBottomColor);
+                rDevice.SetLineColor(aBottomColor);
             else
             {
                 Color aColor (aTopColor);
                 aColor.Merge(aBottomColor, 255 * (nY2-nY) / (nY2-nY1));
-                aBitmapDevice.SetLineColor(aColor);
+                rDevice.SetLineColor(aColor);
             }
-            aBitmapDevice.DrawLine(
+            rDevice.DrawLine(
                 Point(aPageObjectBox.Left(), nY+nTop),
                 Point(aPageObjectBox.Right(), nY+nTop));
         }
     }
     else
     {
-        aBitmapDevice.SetFillColor(aTopColor);
-        aBitmapDevice.DrawRect(aPageObjectBox);
+        rDevice.SetFillColor(aTopColor);
+        rDevice.DrawRect(aPageObjectBox);
     }
 
     // Paint the simple border and, for some backgrounds, the focus border.
     if (bHasFocusBorder)
-        mpFocusBorderPainter->PaintFrame(aBitmapDevice, aPageObjectBox);
+        mpFocusBorderPainter->PaintFrame(rDevice, aPageObjectBox);
     else
-        PaintBorder(aBitmapDevice, eColorType, aPageObjectBox);
+        PaintBorder(rDevice, eColorType, aPageObjectBox);
 
     // Get bounding box of the preview around which a shadow is painted.
     // Compensate for the border around the preview.
-    const Rectangle aBox (mpPageObjectLayouter->GetBoundingBox(
-        Point(0,0),
-        PageObjectLayouter::Preview,
-        PageObjectLayouter::ModelCoordinateSystem));
+    const Rectangle aBox (pPageObjectLayouter->GetBoundingBox(
+                                rpDescriptor,
+                                PageObjectLayouter::Preview,
+                                PageObjectLayouter::ModelCoordinateSystem));
     Rectangle aFrameBox (aBox.Left()-1,aBox.Top()-1,aBox.Right()+1,aBox.Bottom()+1);
-    mpShadowPainter->PaintFrame(aBitmapDevice, aFrameBox);
-
-    return aBitmapDevice.GetBitmap (Point(0,0),aSize);
+    mpShadowPainter->PaintFrame(rDevice, aFrameBox);
 }
 
-
-
-
 void PageObjectPainter::PaintBorder (
     OutputDevice& rDevice,
     const Theme::GradientColorType eColorType,
@@ -571,8 +465,6 @@ void PageObjectPainter::PaintBorder (
     }
 }
 
-
-
 } } } // end of namespace sd::slidesorter::view
 
 /* vim:set shiftwidth=4 softtabstop=4 expandtab: */
