@@ -27,7 +27,6 @@
 #include <com/sun/star/frame/XLayoutManager.hpp>
 #include <com/sun/star/ui/UIElementType.hpp>
 
-#include <cppuhelper/implbase1.hxx>
 #include <osl/mutex.hxx>
 #include <rtl/ref.hxx>
 #include <sfx2/app.hxx>
@@ -60,8 +59,8 @@ class ToolBarRules;
 class LayouterLock
 {
 public:
-    LayouterLock (const Reference<frame::XLayoutManager>& rxLayouter);
-    ~LayouterLock (void);
+    explicit LayouterLock (const Reference<frame::XLayoutManager>& rxLayouter);
+    ~LayouterLock();
 private:
     Reference<frame::XLayoutManager> mxLayouter;
 };
@@ -74,7 +73,7 @@ typedef ::std::vector<OUString> NameList;
 class ToolBarList
 {
 public:
-    ToolBarList (void);
+    ToolBarList();
 
     void ClearGroup (sd::ToolBarManager::ToolBarGroup eGroup);
     void AddToolBar (sd::ToolBarManager::ToolBarGroup eGroup, const OUString& rsName);
@@ -85,7 +84,7 @@ public:
 
     void MarkToolBarAsActive (const OUString& rsName);
     void MarkToolBarAsNotActive (const OUString& rsName);
-    void MarkAllToolBarsAsNotActive (void);
+    void MarkAllToolBarsAsNotActive();
 
 private:
     typedef ::std::map<sd::ToolBarManager::ToolBarGroup,NameList> Groups;
@@ -116,7 +115,7 @@ public:
     /** Create a new object with an empty current list and an empty
         requested list.
     */
-    ToolBarShellList (void);
+    ToolBarShellList();
 
     /** Remove all shells from a group.  Calling this method should normally
         not be necessary because after the construction or after a call to
@@ -126,7 +125,7 @@ public:
     */
     void ClearGroup (sd::ToolBarManager::ToolBarGroup eGroup);
 
-    /** Add a shell.  When the specified shell has alreadt been requested
+    /** Add a shell. When the specified shell has already been requested
         for another group then it is moved to this group.
         @param eGroup
             The group to which to add the shell.
@@ -136,7 +135,7 @@ public:
     void AddShellId (sd::ToolBarManager::ToolBarGroup eGroup, sd::ShellId nId);
 
     /** Releasing all shells means that the given ToolBarRules object is
-        informed that every shell mananged by the called ToolBarShellList is
+        informed that every shell managed by the called ToolBarShellList is
         about to be removed and that the associated framework tool bars can
         be removed as well.  The caller still has to call UpdateShells().
     */
@@ -152,8 +151,8 @@ public:
             This ViewShellManager is used to activate or deactivate shells.
     */
     void UpdateShells (
-        const ::boost::shared_ptr<ViewShell>& rpMainViewShell,
-        const ::boost::shared_ptr<ViewShellManager>& rpManager);
+        const std::shared_ptr<ViewShell>& rpMainViewShell,
+        const std::shared_ptr<ViewShellManager>& rpManager);
 
 private:
     class ShellDescriptor
@@ -185,8 +184,8 @@ class ToolBarRules
 {
 public:
     ToolBarRules (
-        const ::boost::shared_ptr<ToolBarManager>& rpToolBarManager,
-        const ::boost::shared_ptr<ViewShellManager>& rpViewShellManager);
+        const std::shared_ptr<ToolBarManager>& rpToolBarManager,
+        const std::shared_ptr<ViewShellManager>& rpViewShellManager);
 
     /** This method calls MainViewShellChanged() and SelectionHasChanged()
         for the current main view shell and its view.
@@ -223,8 +222,8 @@ public:
         sd::ShellId nShellId);
 
 private:
-    ::boost::shared_ptr<ToolBarManager> mpToolBarManager;
-    ::boost::shared_ptr<ViewShellManager> mpViewShellManager;
+    std::shared_ptr<ToolBarManager> mpToolBarManager;
+    std::shared_ptr<ViewShellManager> mpViewShellManager;
 };
 
 } // end of anonymous namespace
@@ -244,15 +243,15 @@ public:
     */
     Implementation (
         ViewShellBase& rBase,
-        const ::boost::shared_ptr<sd::tools::EventMultiplexer>& rpMultiplexer,
-        const ::boost::shared_ptr<ViewShellManager>& rpViewShellManager,
-        const ::boost::shared_ptr<ToolBarManager>& rpToolBarManager);
-    ~Implementation (void);
+        const std::shared_ptr<sd::tools::EventMultiplexer>& rpMultiplexer,
+        const std::shared_ptr<ViewShellManager>& rpViewShellManager,
+        const std::shared_ptr<ToolBarManager>& rpToolBarManager);
+    ~Implementation();
 
     void SetValid (bool bValid);
 
     void ResetToolBars (ToolBarGroup eGroup);
-    void ResetAllToolBars (void);
+    void ResetAllToolBars();
     void AddToolBar (ToolBarGroup eGroup, const OUString& rsToolBarName);
     void AddToolBarShell (ToolBarGroup eGroup, ShellId nToolBarId);
     void RemoveToolBar (ToolBarGroup eGroup, const OUString& rsToolBarName);
@@ -263,14 +262,14 @@ public:
         shells are destroyed anyway and without calling this method they
         would still be referenced.
     */
-    void ReleaseAllToolBarShells (void);
+    void ReleaseAllToolBarShells();
 
-    void ToolBarsDestroyed(void);
+    void ToolBarsDestroyed();
 
-    void RequestUpdate (void);
+    void RequestUpdate();
 
-    void PreUpdate (void);
-    void PostUpdate (void);
+    void PreUpdate();
+    void PostUpdate();
     /** Tell the XLayoutManager about the tool bars that we would like to be
         shown.
         @param rpLayouterLock
@@ -283,25 +282,25 @@ public:
     class UpdateLockImplementation
     {
     public:
-        UpdateLockImplementation (Implementation& rImplementation)
+        explicit UpdateLockImplementation (Implementation& rImplementation)
             : mrImplementation(rImplementation) { mrImplementation.LockUpdate();  }
-        ~UpdateLockImplementation (void) { mrImplementation.UnlockUpdate(); }
+        ~UpdateLockImplementation() { mrImplementation.UnlockUpdate(); }
     private:
         Implementation& mrImplementation;
     };
 
-    void LockViewShellManager (void);
-    void LockUpdate (void);
-    void UnlockUpdate (void);
+    void LockViewShellManager();
+    void LockUpdate();
+    void UnlockUpdate();
 
-    ToolBarRules& GetToolBarRules (void) { return maToolBarRules;}
+    ToolBarRules& GetToolBarRules() { return maToolBarRules;}
 
 private:
     const static OUString msToolBarResourcePrefix;
 
     mutable ::osl::Mutex maMutex;
     ViewShellBase& mrBase;
-    ::boost::shared_ptr<sd::tools::EventMultiplexer> mpEventMultiplexer;
+    std::shared_ptr<sd::tools::EventMultiplexer> mpEventMultiplexer;
     bool mbIsValid;
     ToolBarList maToolBarList;
     ToolBarShellList maToolBarShellList;
@@ -321,12 +320,12 @@ private:
     ImplSVEvent * mnPendingSetValidCall;
     ToolBarRules maToolBarRules;
 
-    OUString GetToolBarResourceName (const OUString& rsBaseName) const;
+    static OUString GetToolBarResourceName (const OUString& rsBaseName);
     bool CheckPlugInMode (const OUString& rsName) const;
 
-    DECL_LINK(UpdateCallback, void *);
-    DECL_LINK(EventMultiplexerCallback, sd::tools::EventMultiplexerEvent*);
-    DECL_LINK(SetValidCallback,void*);
+    DECL_LINK_TYPED(UpdateCallback, void *, void);
+    DECL_LINK_TYPED(EventMultiplexerCallback, sd::tools::EventMultiplexerEvent&, void);
+    DECL_LINK_TYPED(SetValidCallback, void*, void);
 };
 
 //===== ToolBarManager ========================================================
@@ -347,44 +346,44 @@ const OUString ToolBarManager::msGraphicObjectBar("graphicobjectbar");
 const OUString ToolBarManager::msMediaObjectBar("mediaobjectbar");
 const OUString ToolBarManager::msTableObjectBar("tableobjectbar");
 
-::boost::shared_ptr<ToolBarManager> ToolBarManager::Create (
+std::shared_ptr<ToolBarManager> ToolBarManager::Create (
     ViewShellBase& rBase,
-    const ::boost::shared_ptr<sd::tools::EventMultiplexer>& rpMultiplexer,
-    const ::boost::shared_ptr<ViewShellManager>& rpViewShellManager)
+    const std::shared_ptr<sd::tools::EventMultiplexer>& rpMultiplexer,
+    const std::shared_ptr<ViewShellManager>& rpViewShellManager)
 {
-    ::boost::shared_ptr<ToolBarManager> pManager (new ToolBarManager());
+    std::shared_ptr<ToolBarManager> pManager (new ToolBarManager());
     pManager->mpImpl.reset(
         new Implementation(rBase,rpMultiplexer,rpViewShellManager,pManager));
     return pManager;
 }
 
-ToolBarManager::ToolBarManager (void)
+ToolBarManager::ToolBarManager()
         : mpImpl()
 {
 }
 
-ToolBarManager::~ToolBarManager (void)
+ToolBarManager::~ToolBarManager()
 {
 }
 
-void ToolBarManager::Shutdown (void)
+void ToolBarManager::Shutdown()
 {
-    if (mpImpl.get() != NULL)
+    if (mpImpl.get() != nullptr)
         mpImpl.reset();
 }
 
 void ToolBarManager::ResetToolBars (ToolBarGroup eGroup)
 {
-    if (mpImpl.get() != NULL)
+    if (mpImpl.get() != nullptr)
     {
         UpdateLock aLock (shared_from_this());
         mpImpl->ResetToolBars(eGroup);
     }
 }
 
-void ToolBarManager::ResetAllToolBars (void)
+void ToolBarManager::ResetAllToolBars()
 {
-    if (mpImpl.get() != NULL)
+    if (mpImpl.get() != nullptr)
     {
         UpdateLock aLock (shared_from_this());
         mpImpl->ResetAllToolBars();
@@ -395,7 +394,7 @@ void ToolBarManager::AddToolBar (
     ToolBarGroup eGroup,
     const OUString& rsToolBarName)
 {
-    if (mpImpl.get() != NULL)
+    if (mpImpl.get() != nullptr)
     {
         UpdateLock aLock (shared_from_this());
         mpImpl->AddToolBar(eGroup,rsToolBarName);
@@ -406,7 +405,7 @@ void ToolBarManager::AddToolBarShell (
     ToolBarGroup eGroup,
     ShellId nToolBarId)
 {
-    if (mpImpl.get() != NULL)
+    if (mpImpl.get() != nullptr)
     {
         UpdateLock aLock (shared_from_this());
         mpImpl->AddToolBarShell(eGroup,nToolBarId);
@@ -417,7 +416,7 @@ void ToolBarManager::RemoveToolBar (
     ToolBarGroup eGroup,
     const OUString& rsToolBarName)
 {
-    if (mpImpl.get() != NULL)
+    if (mpImpl.get() != nullptr)
     {
         UpdateLock aLock (shared_from_this());
         mpImpl->RemoveToolBar(eGroup,rsToolBarName);
@@ -428,7 +427,7 @@ void ToolBarManager::SetToolBar (
     ToolBarGroup eGroup,
     const OUString& rsToolBarName)
 {
-    if (mpImpl.get() != NULL)
+    if (mpImpl.get() != nullptr)
     {
         UpdateLock aLock (shared_from_this());
         mpImpl->ResetToolBars(eGroup);
@@ -440,7 +439,7 @@ void ToolBarManager::SetToolBarShell (
     ToolBarGroup eGroup,
     ShellId nToolBarId)
 {
-    if (mpImpl.get() != NULL)
+    if (mpImpl.get() != nullptr)
     {
         UpdateLock aLock (shared_from_this());
         mpImpl->ResetToolBars(eGroup);
@@ -448,39 +447,39 @@ void ToolBarManager::SetToolBarShell (
     }
 }
 
-void ToolBarManager::PreUpdate (void)
+void ToolBarManager::PreUpdate()
 {
-    if (mpImpl.get()!=NULL)
+    if (mpImpl.get()!=nullptr)
         mpImpl->PreUpdate();
 }
 
-void ToolBarManager::RequestUpdate (void)
+void ToolBarManager::RequestUpdate()
 {
-    if (mpImpl.get()!=NULL)
+    if (mpImpl.get()!=nullptr)
         mpImpl->RequestUpdate();
 }
 
-void ToolBarManager::LockViewShellManager (void)
+void ToolBarManager::LockViewShellManager()
 {
-    if (mpImpl.get() != NULL)
+    if (mpImpl.get() != nullptr)
         mpImpl->LockViewShellManager();
 }
 
-void ToolBarManager::LockUpdate (void)
+void ToolBarManager::LockUpdate()
 {
-    if (mpImpl.get()!=NULL)
+    if (mpImpl.get()!=nullptr)
         mpImpl->LockUpdate();
 }
 
-void ToolBarManager::UnlockUpdate (void)
+void ToolBarManager::UnlockUpdate()
 {
-    if (mpImpl.get()!=NULL)
+    if (mpImpl.get()!=nullptr)
         mpImpl->UnlockUpdate();
 }
 
 void ToolBarManager::MainViewShellChanged (ViewShell::ShellType nShellType)
 {
-    if (mpImpl.get() != NULL)
+    if (mpImpl.get() != nullptr)
     {
         mpImpl->ReleaseAllToolBarShells();
         mpImpl->GetToolBarRules().MainViewShellChanged(nShellType);
@@ -489,7 +488,7 @@ void ToolBarManager::MainViewShellChanged (ViewShell::ShellType nShellType)
 
 void ToolBarManager::MainViewShellChanged (const ViewShell& rMainViewShell)
 {
-    if (mpImpl.get() != NULL)
+    if (mpImpl.get() != nullptr)
     {
         mpImpl->ReleaseAllToolBarShells();
         mpImpl->GetToolBarRules().MainViewShellChanged(rMainViewShell);
@@ -500,13 +499,13 @@ void ToolBarManager::SelectionHasChanged (
     const ViewShell& rViewShell,
     const SdrView& rView)
 {
-    if (mpImpl.get() != NULL)
+    if (mpImpl.get() != nullptr)
         mpImpl->GetToolBarRules().SelectionHasChanged(rViewShell,rView);
 }
 
-void ToolBarManager::ToolBarsDestroyed(void)
+void ToolBarManager::ToolBarsDestroyed()
 {
-    if (mpImpl.get() != NULL)
+    if (mpImpl.get() != nullptr)
         mpImpl->ToolBarsDestroyed();
 }
 
@@ -516,27 +515,27 @@ const OUString ToolBarManager::Implementation::msToolBarResourcePrefix("private:
 
 ToolBarManager::Implementation::Implementation (
     ViewShellBase& rBase,
-    const ::boost::shared_ptr<sd::tools::EventMultiplexer>& rpMultiplexer,
-    const ::boost::shared_ptr<ViewShellManager>& rpViewShellManager,
-    const ::boost::shared_ptr<ToolBarManager>& rpToolBarManager)
+    const std::shared_ptr<sd::tools::EventMultiplexer>& rpMultiplexer,
+    const std::shared_ptr<ViewShellManager>& rpViewShellManager,
+    const std::shared_ptr<ToolBarManager>& rpToolBarManager)
     : maMutex(),
       mrBase(rBase),
       mpEventMultiplexer(rpMultiplexer),
       mbIsValid(false),
       maToolBarList(),
       maToolBarShellList(),
-      mxLayouter(NULL),
+      mxLayouter(nullptr),
       mnLockCount(0),
       mbPreUpdatePending(false),
       mbPostUpdatePending(false),
       mpSynchronousLayouterLock(),
       mpAsynchronousLayouterLock(),
       mpViewShellManagerLock(),
-      mnPendingUpdateCall(0),
-      mnPendingSetValidCall(0),
+      mnPendingUpdateCall(nullptr),
+      mnPendingSetValidCall(nullptr),
       maToolBarRules(rpToolBarManager,rpViewShellManager)
 {
-    Link aLink (LINK(this,ToolBarManager::Implementation,EventMultiplexerCallback));
+    Link<tools::EventMultiplexerEvent&,void> aLink (LINK(this,ToolBarManager::Implementation,EventMultiplexerCallback));
     mpEventMultiplexer->AddEventListener(
         aLink,
         tools::EventMultiplexerEvent::EID_CONTROLLER_ATTACHED
@@ -548,20 +547,20 @@ ToolBarManager::Implementation::Implementation (
     First unregister listeners, which may post user events.
     Then remove pending user events.
 */
-ToolBarManager::Implementation::~Implementation (void)
+ToolBarManager::Implementation::~Implementation()
 {
     // Unregister at broadcasters.
-    Link aLink (LINK(this,ToolBarManager::Implementation,EventMultiplexerCallback));
+    Link<tools::EventMultiplexerEvent&,void> aLink (LINK(this,ToolBarManager::Implementation,EventMultiplexerCallback));
     mpEventMultiplexer->RemoveEventListener(aLink);
 
     // Abort pending user calls.
-    if (mnPendingUpdateCall != 0)
+    if (mnPendingUpdateCall != nullptr)
         Application::RemoveUserEvent(mnPendingUpdateCall);
-    if (mnPendingSetValidCall != 0)
+    if (mnPendingSetValidCall != nullptr)
         Application::RemoveUserEvent(mnPendingSetValidCall);
 }
 
-void ToolBarManager::Implementation::ToolBarsDestroyed(void)
+void ToolBarManager::Implementation::ToolBarsDestroyed()
 {
     maToolBarList.MarkAllToolBarsAsNotActive();
 }
@@ -578,7 +577,7 @@ void ToolBarManager::Implementation::SetValid (bool bValid)
         if (mbIsValid)
         {
             Reference<frame::XFrame> xFrame;
-            if (mrBase.GetViewFrame() != NULL)
+            if (mrBase.GetViewFrame() != nullptr)
                 xFrame = mrBase.GetViewFrame()->GetFrame().GetFrameInterface();
             try
             {
@@ -595,7 +594,7 @@ void ToolBarManager::Implementation::SetValid (bool bValid)
         else
         {
             ResetAllToolBars();
-            mxLayouter = NULL;
+            mxLayouter = nullptr;
         }
     }
 }
@@ -610,7 +609,7 @@ void ToolBarManager::Implementation::ResetToolBars (ToolBarGroup eGroup)
     mbPreUpdatePending = true;
 }
 
-void ToolBarManager::Implementation::ResetAllToolBars (void)
+void ToolBarManager::Implementation::ResetAllToolBars()
 {
     SAL_INFO("sd.view", OSL_THIS_FUNC << ": resetting all tool bars");
     for (int i=TBG__FIRST; i<=TBG__LAST; ++i)
@@ -652,29 +651,29 @@ void ToolBarManager::Implementation::AddToolBarShell (
     ShellId nToolBarId)
 {
     ViewShell* pMainViewShell = mrBase.GetMainViewShell().get();
-    if (pMainViewShell != NULL)
+    if (pMainViewShell != nullptr)
     {
         maToolBarShellList.AddShellId(eGroup,nToolBarId);
         GetToolBarRules().SubShellAdded(eGroup, nToolBarId);
     }
 }
 
-void ToolBarManager::Implementation::ReleaseAllToolBarShells (void)
+void ToolBarManager::Implementation::ReleaseAllToolBarShells()
 {
     maToolBarShellList.ReleaseAllShells(GetToolBarRules());
     maToolBarShellList.UpdateShells(mrBase.GetMainViewShell(), mrBase.GetViewShellManager());
 }
 
-void ToolBarManager::Implementation::RequestUpdate (void)
+void ToolBarManager::Implementation::RequestUpdate()
 {
-    if (mnPendingUpdateCall == 0)
+    if (mnPendingUpdateCall == nullptr)
     {
         mnPendingUpdateCall = Application::PostUserEvent(
             LINK(this,ToolBarManager::Implementation,UpdateCallback));
     }
 }
 
-void ToolBarManager::Implementation::PreUpdate (void)
+void ToolBarManager::Implementation::PreUpdate()
 {
     ::osl::MutexGuard aGuard(maMutex);
 
@@ -706,7 +705,7 @@ void ToolBarManager::Implementation::PreUpdate (void)
     }
 }
 
-void ToolBarManager::Implementation::PostUpdate (void)
+void ToolBarManager::Implementation::PostUpdate()
 {
     ::osl::MutexGuard aGuard(maMutex);
 
@@ -737,14 +736,14 @@ void ToolBarManager::Implementation::PostUpdate (void)
     }
 }
 
-void ToolBarManager::Implementation::LockViewShellManager (void)
+void ToolBarManager::Implementation::LockViewShellManager()
 {
-    if (mpViewShellManagerLock.get() == NULL)
+    if (mpViewShellManagerLock.get() == nullptr)
         mpViewShellManagerLock.reset(
             new ViewShellManager::UpdateLock(mrBase.GetViewShellManager()));
 }
 
-void ToolBarManager::Implementation::LockUpdate (void)
+void ToolBarManager::Implementation::LockUpdate()
 {
     SAL_INFO("sd.view", OSL_THIS_FUNC << ": LockUpdate " << mnLockCount);
     ::osl::MutexGuard aGuard(maMutex);
@@ -752,14 +751,14 @@ void ToolBarManager::Implementation::LockUpdate (void)
     DBG_ASSERT(mnLockCount<100, "ToolBarManager lock count unusually high");
     if (mnLockCount == 0)
     {
-        OSL_ASSERT(mpSynchronousLayouterLock.get()==NULL);
+        OSL_ASSERT(mpSynchronousLayouterLock.get()==nullptr);
 
         mpSynchronousLayouterLock.reset(new LayouterLock(mxLayouter));
     }
     ++mnLockCount;
 }
 
-void ToolBarManager::Implementation::UnlockUpdate (void)
+void ToolBarManager::Implementation::UnlockUpdate()
 {
     SAL_INFO("sd.view", OSL_THIS_FUNC << ": UnlockUpdate " << mnLockCount);
     ::osl::MutexGuard aGuard(maMutex);
@@ -779,16 +778,16 @@ void ToolBarManager::Implementation::Update (
     // tool bars then update this set now.
     if (mnLockCount == 0)
     {
-        // During ceation of ViewShellBase we may have the situation that
+        // During creation of ViewShellBase we may have the situation that
         // the controller has already been created and attached to the frame
         // but that the ToolBarManager has not yet completed its
         // initialization (by initializing the mxLayouter member.)  We do
         // this here so that we do not have to wait for the next Update()
         // call to show the tool bars.
-        if (mnPendingSetValidCall != 0)
+        if (mnPendingSetValidCall != nullptr)
         {
             Application::RemoveUserEvent(mnPendingSetValidCall);
-            mnPendingSetValidCall = 0;
+            mnPendingSetValidCall = nullptr;
             SetValid(true);
         }
 
@@ -804,7 +803,7 @@ void ToolBarManager::Implementation::Update (
             // functionality. Those that are not used anymore are
             // deactivated now.  Those that are missing are activated in the
             // next step together with the view shells.
-            if (mpViewShellManagerLock.get() == NULL)
+            if (mpViewShellManagerLock.get() == nullptr)
                 mpViewShellManagerLock.reset(
                     new ViewShellManager::UpdateLock(mrBase.GetViewShellManager()));
             maToolBarShellList.UpdateShells(
@@ -812,7 +811,7 @@ void ToolBarManager::Implementation::Update (
                 mrBase.GetViewShellManager());
 
             // 3) Unlock the ViewShellManager::UpdateLock.  This updates the
-            // shell stack.  We have to be carfull here.  The deletion of
+            // shell stack.  We have to be carefully here.  The deletion of
             // the lock may end in a synchronous call to LockUpdate(). When
             // at this time the lock has been deleted but the unique_ptr has
             // not yet been reset then the lock is deleted a second time.
@@ -829,7 +828,7 @@ void ToolBarManager::Implementation::Update (
             // Note that the lock count may have been increased since
             // entering this method.  In that case one of the next
             // UnlockUpdate() calls will post the UpdateCallback.
-            if (mnPendingUpdateCall==0 && mnLockCount==0)
+            if (mnPendingUpdateCall==nullptr && mnLockCount==0)
             {
                 mpAsynchronousLayouterLock = std::move(pLocalLayouterLock);
                 mnPendingUpdateCall = Application::PostUserEvent(
@@ -848,9 +847,9 @@ void ToolBarManager::Implementation::Update (
     }
 }
 
-IMPL_LINK_NOARG(ToolBarManager::Implementation, UpdateCallback)
+IMPL_LINK_NOARG_TYPED(ToolBarManager::Implementation, UpdateCallback, void*, void)
 {
-    mnPendingUpdateCall = 0;
+    mnPendingUpdateCall = nullptr;
     if (mnLockCount == 0)
     {
         if (mbPreUpdatePending)
@@ -860,43 +859,37 @@ IMPL_LINK_NOARG(ToolBarManager::Implementation, UpdateCallback)
         if (mbIsValid && mxLayouter.is())
             mpAsynchronousLayouterLock.reset();
     }
-    return 0;
 }
 
-IMPL_LINK(ToolBarManager::Implementation,EventMultiplexerCallback,
-    sd::tools::EventMultiplexerEvent*,pEvent)
+IMPL_LINK_TYPED(ToolBarManager::Implementation,EventMultiplexerCallback,
+    sd::tools::EventMultiplexerEvent&, rEvent, void)
 {
-    if (pEvent != NULL)
+    switch (rEvent.meEventId)
     {
-        switch (pEvent->meEventId)
-        {
-            case tools::EventMultiplexerEvent::EID_CONTROLLER_ATTACHED:
-                if (mnPendingSetValidCall == 0)
-                    mnPendingSetValidCall
-                        = Application::PostUserEvent(LINK(this,Implementation,SetValidCallback));
-                break;
+        case tools::EventMultiplexerEvent::EID_CONTROLLER_ATTACHED:
+            if (mnPendingSetValidCall == nullptr)
+                mnPendingSetValidCall
+                    = Application::PostUserEvent(LINK(this,Implementation,SetValidCallback));
+            break;
 
-            case tools::EventMultiplexerEvent::EID_CONTROLLER_DETACHED:
-                SetValid(false);
-                break;
+        case tools::EventMultiplexerEvent::EID_CONTROLLER_DETACHED:
+            SetValid(false);
+            break;
 
-            case tools::EventMultiplexerEvent::EID_PANE_MANAGER_DYING:
-                SetValid(false);
-                break;
-        }
+        case tools::EventMultiplexerEvent::EID_PANE_MANAGER_DYING:
+            SetValid(false);
+            break;
     }
-    return 0;
 }
 
-IMPL_LINK_NOARG(ToolBarManager::Implementation, SetValidCallback)
+IMPL_LINK_NOARG_TYPED(ToolBarManager::Implementation, SetValidCallback, void*, void)
 {
-    mnPendingSetValidCall = 0;
+    mnPendingSetValidCall = nullptr;
     SetValid(true);
-    return 0;
 }
 
 OUString ToolBarManager::Implementation::GetToolBarResourceName (
-    const OUString& rsBaseName) const
+    const OUString& rsBaseName)
 {
     OUString sToolBarName (msToolBarResourcePrefix);
     sToolBarName += rsBaseName;
@@ -912,15 +905,15 @@ bool ToolBarManager::Implementation::CheckPlugInMode (const OUString& rsName) co
     do
     {
         SfxObjectShell* pObjectShell = mrBase.GetObjectShell();
-        if (pObjectShell == NULL)
+        if (pObjectShell == nullptr)
             break;
 
         SfxMedium* pMedium = pObjectShell->GetMedium();
-        if (pMedium == NULL)
+        if (pMedium == nullptr)
             break;
 
-        SFX_ITEMSET_ARG(pMedium->GetItemSet(),pViewOnlyItem,SfxBoolItem,SID_VIEWONLY,false);
-        if (pViewOnlyItem == NULL)
+        const SfxBoolItem* pViewOnlyItem = SfxItemSet::GetItem<SfxBoolItem>(pMedium->GetItemSet(), SID_VIEWONLY, false);
+        if (pViewOnlyItem == nullptr)
             break;
 
         bIsPlugInMode = pViewOnlyItem->GetValue();
@@ -951,7 +944,7 @@ LayouterLock::LayouterLock (const Reference<frame::XLayoutManager>& rxLayouter)
         mxLayouter->lock();
 }
 
-LayouterLock::~LayouterLock (void)
+LayouterLock::~LayouterLock()
 {
     SAL_INFO("sd.view", OSL_THIS_FUNC << ": ~LayouterLock " << (mxLayouter.is() ? 1 :0));
     if (mxLayouter.is())
@@ -961,8 +954,8 @@ LayouterLock::~LayouterLock (void)
 //===== ToolBarRules ==========================================================
 
 ToolBarRules::ToolBarRules (
-    const ::boost::shared_ptr<sd::ToolBarManager>& rpToolBarManager,
-    const ::boost::shared_ptr<sd::ViewShellManager>& rpViewShellManager)
+    const std::shared_ptr<sd::ToolBarManager>& rpToolBarManager,
+    const std::shared_ptr<sd::ViewShellManager>& rpViewShellManager)
     : mpToolBarManager(rpToolBarManager),
       mpViewShellManager(rpViewShellManager)
 {
@@ -971,7 +964,7 @@ ToolBarRules::ToolBarRules (
 void ToolBarRules::Update (ViewShellBase& rBase)
 {
     ViewShell* pMainViewShell = rBase.GetMainViewShell().get();
-    if (pMainViewShell != NULL)
+    if (pMainViewShell != nullptr)
     {
         MainViewShellChanged(pMainViewShell->GetShellType());
         if (pMainViewShell->GetView())
@@ -999,9 +992,6 @@ void ToolBarRules::MainViewShellChanged (ViewShell::ShellType nShellType)
             mpToolBarManager->AddToolBar(
                 ToolBarManager::TBG_PERMANENT,
                 ToolBarManager::msOptionsToolBar);
-            mpToolBarManager->AddToolBar(
-                ToolBarManager::TBG_PERMANENT,
-                ToolBarManager::msCommonTaskToolBar);
             mpToolBarManager->AddToolBar(
                 ToolBarManager::TBG_PERMANENT,
                 ToolBarManager::msViewerToolBar);
@@ -1064,11 +1054,17 @@ void ToolBarRules::MainViewShellChanged (const ViewShell& rMainViewShell)
         {
             const DrawViewShell* pDrawViewShell
                 = dynamic_cast<const DrawViewShell*>(&rMainViewShell);
-            if (pDrawViewShell != NULL)
+            if (pDrawViewShell != nullptr)
+            {
                 if (pDrawViewShell->GetEditMode() == EM_MASTERPAGE)
                     mpToolBarManager->AddToolBar(
                         ToolBarManager::TBG_MASTER_MODE,
                         ToolBarManager::msMasterViewToolBar);
+                else if ( rMainViewShell.GetShellType() != ::sd::ViewShell::ST_DRAW )
+                    mpToolBarManager->AddToolBar(
+                        ToolBarManager::TBG_COMMON_TASK,
+                        ToolBarManager::msCommonTaskToolBar);
+            }
             break;
         }
 
@@ -1204,7 +1200,7 @@ void ToolBarRules::SubShellRemoved (
 
 //===== ToolBarList ===========================================================
 
-ToolBarList::ToolBarList (void)
+ToolBarList::ToolBarList()
     : maGroups(),
       maActiveToolBars()
 {
@@ -1316,7 +1312,7 @@ void ToolBarList::MarkToolBarAsNotActive (const OUString& rsName)
         ::std::find(maActiveToolBars.begin(),maActiveToolBars.end(), rsName));
 }
 
-void ToolBarList::MarkAllToolBarsAsNotActive (void)
+void ToolBarList::MarkAllToolBarsAsNotActive()
 {
     maActiveToolBars.clear();
 }
@@ -1331,7 +1327,7 @@ ToolBarShellList::ShellDescriptor::ShellDescriptor (
 {
 }
 
-ToolBarShellList::ToolBarShellList (void)
+ToolBarShellList::ToolBarShellList()
 : maNewList()
 , maCurrentList()
 {
@@ -1401,10 +1397,10 @@ void ToolBarShellList::ReleaseAllShells (ToolBarRules& rRules)
 }
 
 void ToolBarShellList::UpdateShells (
-    const ::boost::shared_ptr<ViewShell>& rpMainViewShell,
-    const ::boost::shared_ptr<ViewShellManager>& rpManager)
+    const std::shared_ptr<ViewShell>& rpMainViewShell,
+    const std::shared_ptr<ViewShellManager>& rpManager)
 {
-    if (rpMainViewShell.get() != NULL)
+    if (rpMainViewShell.get() != nullptr)
     {
         GroupedShellList aList;
 
