@@ -72,7 +72,6 @@ using namespace ::com::sun::star;
 
 namespace sd {
 
-TYPEINIT1(DrawView, View);
 
 /**
  * Shows the first page of document at position 0,0. In the case
@@ -83,15 +82,15 @@ DrawView::DrawView( DrawDocShell* pDocSh, OutputDevice* pOutDev, DrawViewShell*
 : ::sd::View(*pDocSh->GetDoc(), pOutDev, pShell)
 , mpDocShell(pDocSh)
 , mpDrawViewShell(pShell)
-, mpVDev(NULL)
+, mpVDev(nullptr)
 , mnPOCHSmph(0)
 {
-    SetCurrentObj(OBJ_RECT, SdrInventor);
+    SetCurrentObj(OBJ_RECT);
 }
 
 DrawView::~DrawView()
 {
-    delete mpVDev;
+    mpVDev.disposeAndClear();
 }
 
 /**
@@ -116,7 +115,7 @@ void DrawView::ModelHasChanged()
 
     // force framer to rerender
     SfxStyleSheetBasePool* pSSPool = mrDoc.GetStyleSheetPool();
-    pSSPool->Broadcast(SfxStyleSheetPoolHint(SFX_STYLESHEETPOOL_CHANGES));
+    pSSPool->Broadcast(SfxStyleSheetPoolHint(SfxStyleSheetHintId::CREATED));
 
     if( mpDrawViewShell )
         mpDrawViewShell->ModelHasChanged();
@@ -128,10 +127,10 @@ void DrawView::ModelHasChanged()
  * rectangle of a masterpage into templates, otherwise pass on baseclass.
  */
 
-sal_Bool DrawView::SetAttributes(const SfxItemSet& rSet,
-                                            sal_Bool bReplaceAll)
+bool DrawView::SetAttributes(const SfxItemSet& rSet,
+                             bool bReplaceAll)
 {
-    sal_Bool bOk = sal_False;
+    bool bOk = false;
 
     // is there a masterpage edit?
     if ( mpDrawViewShell && mpDrawViewShell->GetEditMode() == EM_MASTERPAGE )
@@ -168,7 +167,7 @@ sal_Bool DrawView::SetAttributes(const SfxItemSet& rSet,
 
                     pSheet->GetItemSet().Put(aTempSet);
                     pSheet->Broadcast(SfxSimpleHint(SFX_HINT_DATACHANGED));
-                    bOk = sal_True;
+                    bOk = true;
                 }
                 else if (eObjKind == OBJ_OUTLINETEXT)
                 {
@@ -176,8 +175,8 @@ sal_Bool DrawView::SetAttributes(const SfxItemSet& rSet,
                     OutlinerView* pOV   = GetTextEditOutlinerView();
                     ::Outliner* pOutliner = pOV->GetOutliner();
 
-                    pOutliner->SetUpdateMode(sal_False);
-                    mpDocSh->SetWaitCursor( sal_True );
+                    pOutliner->SetUpdateMode(false);
+                    mpDocSh->SetWaitCursor( true );
 
                     // replace placeholder by template name
                     OUString aComment(SD_RESSTR(STR_UNDO_CHANGE_PRES_OBJECT));
@@ -188,7 +187,7 @@ sal_Bool DrawView::SetAttributes(const SfxItemSet& rSet,
                     pOV->CreateSelectionList(aSelList);
 
                     std::vector<Paragraph*>::reverse_iterator iter = aSelList.rbegin();
-                    Paragraph* pPara = iter != aSelList.rend() ? *iter : NULL;
+                    Paragraph* pPara = iter != aSelList.rend() ? *iter : nullptr;
 
                     while (pPara)
                     {
@@ -196,52 +195,66 @@ sal_Bool DrawView::SetAttributes(const SfxItemSet& rSet,
                         sal_Int16 nDepth = pOutliner->GetDepth( nParaPos );
                         OUString aName = rPage.GetLayoutName() + " " +
                             OUString::number((nDepth <= 0) ? 1 : nDepth + 1);
-                        SfxStyleSheet* pSheet = (SfxStyleSheet*)pStShPool->Find(aName, SD_STYLE_FAMILY_MASTERPAGE);
-                        DBG_ASSERT(pSheet, "StyleSheet not found");
-
-                        SfxItemSet aTempSet( pSheet->GetItemSet() );
-                        aTempSet.Put( rSet );
-                        aTempSet.ClearInvalidItems();
-
-                        if( nDepth > 0 && aTempSet.GetItemState( EE_PARA_NUMBULLET ) == SFX_ITEM_ON )
+                        SfxStyleSheet* pSheet = static_cast<SfxStyleSheet*>(pStShPool->Find(aName, SD_STYLE_FAMILY_MASTERPAGE));
+                        //We have no stylesheet if we access outline level 10
+                        //in the master preview, there is no true style backing
+                        //that entry
+                        SAL_WARN_IF(!pSheet, "sd", "StyleSheet " << aName << " not found");
+                        if (pSheet)
                         {
-                            // no SvxNumBulletItem in outline level 1 to 8!
-                            aTempSet.ClearItem( EE_PARA_NUMBULLET );
-                        }
+                            SfxItemSet aTempSet( pSheet->GetItemSet() );
+                            aTempSet.Put( rSet );
+                            aTempSet.ClearInvalidItems();
 
-                        // Undo-Action
-                        StyleSheetUndoAction* pAction = new StyleSheetUndoAction(&mrDoc, pSheet, &aTempSet);
-                        mpDocSh->GetUndoManager()->AddUndoAction(pAction);
+                            if( nDepth > 0 && aTempSet.GetItemState( EE_PARA_NUMBULLET ) == SfxItemState::SET )
+                            {
+                                // no SvxNumBulletItem in outline level 1 to 8!
+                                aTempSet.ClearItem( EE_PARA_NUMBULLET );
+                            }
 
-                        pSheet->GetItemSet().Put(aTempSet);
-                        pSheet->Broadcast(SfxSimpleHint(SFX_HINT_DATACHANGED));
+                            // Undo-Action
+                            StyleSheetUndoAction* pAction = new StyleSheetUndoAction(&mrDoc, pSheet, &aTempSet);
+                            mpDocSh->GetUndoManager()->AddUndoAction(pAction);
 
-                        // now also broadcast any child sheets
-                        sal_Int16 nChild;
-                        for( nChild = nDepth + 1; nChild < 9; nChild++ )
-                        {
-                            OUString aSheetName = rPage.GetLayoutName() + " " +
-                                OUString::number((nChild <= 0) ? 1 : nChild + 1);
-                            SfxStyleSheet* pOutlSheet = static_cast< SfxStyleSheet* >(pStShPool->Find(aSheetName, SD_STYLE_FAMILY_MASTERPAGE));
+                            pSheet->GetItemSet().Put(aTempSet);
+                            pSheet->Broadcast(SfxSimpleHint(SFX_HINT_DATACHANGED));
 
-                            if( pOutlSheet )
-                                pOutlSheet->Broadcast(SfxSimpleHint(SFX_HINT_DATACHANGED));
+                            // now also broadcast any child sheets
+                            sal_Int16 nChild;
+                            for( nChild = nDepth + 1; nChild < 9; nChild++ )
+                            {
+                                OUString aSheetName = rPage.GetLayoutName() + " " +
+                                    OUString::number((nChild <= 0) ? 1 : nChild + 1);
+                                SfxStyleSheet* pOutlSheet = static_cast< SfxStyleSheet* >(pStShPool->Find(aSheetName, SD_STYLE_FAMILY_MASTERPAGE));
+
+                                if( pOutlSheet )
+                                    pOutlSheet->Broadcast(SfxSimpleHint(SFX_HINT_DATACHANGED));
+                            }
                         }
 
                         ++iter;
-                        pPara = iter != aSelList.rend() ? *iter : NULL;
+                        pPara = iter != aSelList.rend() ? *iter : nullptr;
 
-                        if( !pPara && nDepth > 0 &&  rSet.GetItemState( EE_PARA_NUMBULLET ) == SFX_ITEM_ON &&
-                            pOutliner->GetDepth( pOutliner->GetAbsPos(*(aSelList.begin())) ) > 0 )
-                            pPara = pOutliner->GetParagraph( 0 );  // Put NumBulletItem in outline level 1
+                        bool bJumpToLevel1 = false;
+                        if( !pPara && nDepth > 0 && rSet.GetItemState( EE_PARA_NUMBULLET ) == SfxItemState::SET )
+                            bJumpToLevel1 = true;
+
+                        if (bJumpToLevel1)
+                        {
+                            iter = aSelList.rend();
+                            --iter;
+
+                            if (pOutliner->GetDepth(pOutliner->GetAbsPos(*iter)) > 0)
+                                pPara = pOutliner->GetParagraph( 0 );  // Put NumBulletItem in outline level 1
+                        }
                     }
 
-                    mpDocSh->SetWaitCursor( sal_False );
-                    pOV->GetOutliner()->SetUpdateMode(sal_True);
+                    mpDocSh->SetWaitCursor( false );
+                    pOV->GetOutliner()->SetUpdateMode(true);
 
                     mpDocSh->GetUndoManager()->LeaveListAction();
 
-                    bOk = sal_True;
+                    bOk = true;
                 }
                 else
                 {
@@ -253,8 +266,8 @@ sal_Bool DrawView::SetAttributes(const SfxItemSet& rSet,
         {
             // Selection
             const SdrMarkList& rList = GetMarkedObjectList();
-            sal_uLong nMarkCount         = rList.GetMarkCount();
-            for (sal_uLong nMark = 0; nMark < nMarkCount; nMark++)
+            const size_t nMarkCount = rList.GetMarkCount();
+            for (size_t nMark = 0; nMark < nMarkCount; ++nMark)
             {
                 SdrObject* pObject = rList.GetMark(nMark)->GetMarkedSdrObj();
                 sal_uInt32 nInv = pObject->GetObjInventor();
@@ -281,7 +294,7 @@ sal_Bool DrawView::SetAttributes(const SfxItemSet& rSet,
 
                         pSheet->GetItemSet().Put(aTempSet,false);
                         pSheet->Broadcast(SfxSimpleHint(SFX_HINT_DATACHANGED));
-                        bOk = sal_True;
+                        bOk = true;
                     }
                     else if (eObjKind == OBJ_OUTLINETEXT)
                     {
@@ -290,8 +303,8 @@ sal_Bool DrawView::SetAttributes(const SfxItemSet& rSet,
                         {
                             OUString aName = rPage.GetLayoutName() + " " +
                                 OUString::number(nLevel);
-                            SfxStyleSheet* pSheet = (SfxStyleSheet*)pStShPool->
-                                                Find(aName, SD_STYLE_FAMILY_MASTERPAGE);
+                            SfxStyleSheet* pSheet = static_cast<SfxStyleSheet*>(pStShPool->
+                                                Find(aName, SD_STYLE_FAMILY_MASTERPAGE));
                             DBG_ASSERT(pSheet, "StyleSheet not found");
 
                             SfxItemSet aTempSet( pSheet->GetItemSet() );
@@ -304,7 +317,7 @@ sal_Bool DrawView::SetAttributes(const SfxItemSet& rSet,
                                 sal_uInt16 nWhich(aWhichIter.FirstWhich());
                                 while( nWhich )
                                 {
-                                    if( SFX_ITEM_ON == rSet.GetItemState( nWhich ) )
+                                    if( SfxItemState::SET == rSet.GetItemState( nWhich ) )
                                         aTempSet.ClearItem( nWhich );
                                     nWhich = aWhichIter.NextWhich();
                                 }
@@ -331,12 +344,12 @@ sal_Bool DrawView::SetAttributes(const SfxItemSet& rSet,
                         sal_uInt16 nWhich(aWhichIter.FirstWhich());
                         while( nWhich )
                         {
-                            if( SFX_ITEM_ON == rSet.GetItemState( nWhich ) )
+                            if( SfxItemState::SET == rSet.GetItemState( nWhich ) )
                                 pObject->ClearMergedItem( nWhich );
                             nWhich = aWhichIter.NextWhich();
                         }
 
-                        bOk = sal_True;
+                        bOk = true;
                     }
                 }
             }
@@ -350,18 +363,18 @@ sal_Bool DrawView::SetAttributes(const SfxItemSet& rSet,
         bOk = ::sd::View::SetAttributes(rSet, bReplaceAll);
     }
 
-    return (bOk);
+    return bOk;
 }
 
 /**
- * Notify for change of site arragement
+ * Notify for change of site arrangement
  */
 
 void DrawView::Notify(SfxBroadcaster& rBC, const SfxHint& rHint)
 {
-    if ( mpDrawViewShell && rHint.ISA(SdrHint) )
+    if ( mpDrawViewShell && dynamic_cast<const SdrHint*>(&rHint) )
     {
-        SdrHintKind eHintKind = ( (SdrHint&) rHint).GetKind();
+        SdrHintKind eHintKind = static_cast<const SdrHint&>(rHint).GetKind();
 
         if ( mnPOCHSmph == 0 && eHintKind == HINT_PAGEORDERCHG )
         {
@@ -375,7 +388,7 @@ void DrawView::Notify(SfxBroadcaster& rBC, const SfxHint& rHint)
         // switch to that page when it's not a master page
         if(HINT_SWITCHTOPAGE == eHintKind)
         {
-            const SdrPage* pPage = ((const SdrHint&)rHint).GetPage();
+            const SdrPage* pPage = static_cast<const SdrHint&>(rHint).GetPage();
 
             if(pPage && !pPage->IsMasterPage())
             {
@@ -395,7 +408,7 @@ void DrawView::Notify(SfxBroadcaster& rBC, const SfxHint& rHint)
  * Lock/Unlock PageOrderChangedHint
  */
 
-void DrawView::BlockPageOrderChangedHint(sal_Bool bBlock)
+void DrawView::BlockPageOrderChangedHint(bool bBlock)
 {
     if (bBlock)
         mnPOCHSmph++;
@@ -411,19 +424,18 @@ void DrawView::BlockPageOrderChangedHint(sal_Bool bBlock)
  * masterpage.
  */
 
-sal_Bool DrawView::SetStyleSheet(SfxStyleSheet* pStyleSheet, sal_Bool bDontRemoveHardAttr)
+bool DrawView::SetStyleSheet(SfxStyleSheet* pStyleSheet, bool bDontRemoveHardAttr)
 {
-    sal_Bool bResult = sal_True;
+    bool bResult = true;
 
     // is there a masterpage edit?
     if (mpDrawViewShell && mpDrawViewShell->GetEditMode() == EM_MASTERPAGE)
     {
-        if (IsPresObjSelected(sal_False, sal_True))
+        if (IsPresObjSelected(false))
         {
-
-            InfoBox(mpDrawViewShell->GetActiveWindow(),
-                    SD_RESSTR(STR_ACTION_NOTPOSSIBLE)).Execute();
-            bResult = sal_False;
+            ScopedVclPtr<InfoBox>::Create(mpDrawViewShell->GetActiveWindow(),
+                    SD_RESSTR(STR_ACTION_NOTPOSSIBLE))->Execute();
+            bResult = false;
         }
         else
         {
@@ -441,15 +453,14 @@ sal_Bool DrawView::SetStyleSheet(SfxStyleSheet* pStyleSheet, sal_Bool bDontRemov
  * Paint-method: Redirect event to the view
  */
 
-void DrawView::CompleteRedraw(OutputDevice* pOutDev, const Region& rReg, sdr::contact::ViewObjectContactRedirector* pRedirector /*=0L*/)
+void DrawView::CompleteRedraw(OutputDevice* pOutDev, const vcl::Region& rReg, sdr::contact::ViewObjectContactRedirector* pRedirector /*=0L*/)
 {
     if( mpVDev )
     {
-        delete mpVDev;
-        mpVDev = NULL;
+        mpVDev.disposeAndClear();
     }
 
-    sal_Bool bStandardPaint = sal_True;
+    bool bStandardPaint = true;
 
     SdDrawDocument* pDoc = mpDocShell->GetDoc();
     if( pDoc && pDoc->GetDocumentType() == DOCUMENT_TYPE_IMPRESS)
@@ -457,12 +468,12 @@ void DrawView::CompleteRedraw(OutputDevice* pOutDev, const Region& rReg, sdr::co
         rtl::Reference< sd::SlideShow > xSlideshow( SlideShow::GetSlideShow( pDoc ) );
         if(xSlideshow.is() && xSlideshow->isRunning())
         {
-            OutputDevice* pShowWindow = ( OutputDevice* )xSlideshow->getShowWindow();
+            OutputDevice* pShowWindow = xSlideshow->getShowWindow();
             if( (pShowWindow == pOutDev) || (xSlideshow->getAnimationMode() == ANIMATIONMODE_PREVIEW) )
             {
                 if( pShowWindow == pOutDev )
                     PresPaint(rReg);
-                bStandardPaint = sal_False;
+                bStandardPaint = false;
             }
         }
     }
@@ -477,7 +488,7 @@ void DrawView::CompleteRedraw(OutputDevice* pOutDev, const Region& rReg, sdr::co
  * Paint-Event during running slide show
  */
 
-void DrawView::PresPaint(const Region& rRegion)
+void DrawView::PresPaint(const vcl::Region& rRegion)
 {
     if(mpViewSh)
     {
@@ -492,7 +503,7 @@ void DrawView::PresPaint(const Region& rRegion)
  * in slide show).
  */
 
-sal_Bool DrawView::IsObjMarkable(SdrObject* pObj, SdrPageView* pPV) const
+bool DrawView::IsObjMarkable(SdrObject* pObj, SdrPageView* pPV) const
 {
     return FmFormView::IsObjMarkable(pObj, pPV);
 }
@@ -501,7 +512,7 @@ sal_Bool DrawView::IsObjMarkable(SdrObject* pObj, SdrPageView* pPV) const
  * Make passed region visible (scrolling if necessary)
  */
 
-void DrawView::MakeVisible(const Rectangle& rRect, ::Window& rWin)
+void DrawView::MakeVisible(const Rectangle& rRect, vcl::Window& rWin)
 {
     if (!rRect.IsEmpty() && mpDrawViewShell)
     {
@@ -537,14 +548,14 @@ void DrawView::DeleteMarked()
         pUndoManager->EnterListAction(aUndo, aUndo);
     }
 
-    SdPage* pPage = 0;
+    SdPage* pPage = nullptr;
     bool bResetLayout = false;
 
-    const sal_uLong nMarkCount = GetMarkedObjectList().GetMarkCount();
+    const size_t nMarkCount = GetMarkedObjectList().GetMarkCount();
     if( nMarkCount )
     {
         SdrMarkList aList( GetMarkedObjectList() );
-        for (sal_uLong nMark = 0; nMark < nMarkCount; nMark++)
+        for (size_t nMark = 0; nMark < nMarkCount; ++nMark)
         {
             SdrObject* pObj = aList.GetMark(nMark)->GetMarkedSdrObj();
             if( pObj && !pObj->IsEmptyPresObj() && pObj->GetUserCall() )
@@ -571,12 +582,12 @@ void DrawView::DeleteMarked()
                     SdrTextObj* pTextObj = dynamic_cast< SdrTextObj* >( pObj );
                     bool bVertical = pTextObj && pTextObj->IsVerticalWriting();
                     Rectangle aRect( pObj->GetLogicRect() );
-                    SdrObject* pNewObj = pPage->InsertAutoLayoutShape( 0, ePresObjKind, bVertical, aRect, true );
+                    SdrObject* pNewObj = pPage->InsertAutoLayoutShape( nullptr, ePresObjKind, bVertical, aRect, true );
 
                     // pUndoManager should not be NULL (see assert above)
                     // but since we have defensive code
                     // for it earlier and later in the function
-                    // we might as well be consistant
+                    // we might as well be consistent
                     if(pUndoManager)
                     {
                         // Move the new PresObj to the position before the
