@@ -63,7 +63,7 @@
 #include <editeng/adjustitem.hxx>
 #include <svx/nbdtmgfact.hxx>
 #include <svx/nbdtmg.hxx>
-#include <boost/scoped_ptr.hpp>
+#include <memory>
 
 using namespace svx::sidebar;
 using namespace ::com::sun::star;
@@ -78,7 +78,7 @@ void DrawViewShell::GetCtrlState(SfxItemSet &rSet)
     if (rSet.GetItemState(SID_RELOAD) != SfxItemState::UNKNOWN)
     {
         // let "last version" of SFx en/disable
-        GetViewFrame()->GetSlotState (SID_RELOAD, NULL, &rSet);
+        GetViewFrame()->GetSlotState (SID_RELOAD, nullptr, &rSet);
     }
 
     if (SfxItemState::DEFAULT == rSet.GetItemState(SID_HYPERLINK_GETLINK))
@@ -97,7 +97,7 @@ void DrawViewShell::GetCtrlState(SfxItemSet &rSet)
                 if ( abs( aSel.nEndPos - aSel.nStartPos ) == 1 )
                 {
                     const SvxFieldData* pField = pFieldItem->GetField();
-                    if (pField->ISA(SvxURLField))
+                    if( dynamic_cast< const SvxURLField *>( pField ) !=  nullptr)
                     {
                         aHLinkItem.SetName(static_cast<const SvxURLField*>(pField)->GetRepresentation());
                         aHLinkItem.SetURL(static_cast<const SvxURLField*>(pField)->GetURL());
@@ -207,7 +207,7 @@ void DrawViewShell::GetCtrlState(SfxItemSet &rSet)
     if ( SfxItemState::DEFAULT == rSet.GetItemState(SID_ATTR_YEAR2000) )
     {
         FmFormShell* pFormShell = GetViewShellBase().GetFormShellManager()->GetFormShell();
-        if (pFormShell != NULL)
+        if (pFormShell != nullptr)
         {
             sal_uInt16 nState = 0;
             if (pFormShell->GetY2KState(nState))
@@ -390,6 +390,10 @@ void DrawViewShell::GetAttrState( SfxItemSet& rSet )
             case SID_ATTR_FILL_HATCH:
             case SID_ATTR_FILL_BITMAP:
             case SID_ATTR_FILL_SHADOW:
+            case SID_ATTR_SHADOW_COLOR:
+            case SID_ATTR_SHADOW_TRANSPARENCE:
+            case SID_ATTR_SHADOW_XDISTANCE:
+            case SID_ATTR_SHADOW_YDISTANCE:
             case SID_ATTR_FILL_TRANSPARENCE:
             case SID_ATTR_FILL_FLOATTRANSPARENCE:
             case SID_ATTR_LINE_STYLE:
@@ -409,6 +413,7 @@ void DrawViewShell::GetAttrState( SfxItemSet& rSet )
             case SID_ATTR_CHAR_WEIGHT:
             case SID_ATTR_CHAR_COLOR:
             case SID_ATTR_CHAR_KERNING:
+            case SID_ATTR_CHAR_CASEMAP:
             case SID_SET_SUB_SCRIPT:
             case SID_SET_SUPER_SCRIPT:
             {
@@ -483,7 +488,7 @@ void DrawViewShell::GetAttrState( SfxItemSet& rSet )
 
             case SID_STYLE_WATERCAN:
             {
-                SfxPoolItem* pItem = NULL;
+                SfxPoolItem* pItem = nullptr;
                 GetViewFrame()->GetBindings().QueryState(SID_STYLE_FAMILY, pItem);
                 SfxUInt16Item* pFamilyItem = dynamic_cast<SfxUInt16Item*>(pItem);
                 if (pFamilyItem && SfxTemplate::NIdToSfxFamilyId(pFamilyItem->GetValue()) == SD_STYLE_FAMILY_PSEUDO)
@@ -499,7 +504,7 @@ void DrawViewShell::GetAttrState( SfxItemSet& rSet )
 
             case SID_STYLE_NEW:
             {
-                SfxPoolItem* pItem = NULL;
+                SfxPoolItem* pItem = nullptr;
                 GetViewFrame()->GetBindings().QueryState(SID_STYLE_FAMILY, pItem);
                 SfxUInt16Item* pFamilyItem = dynamic_cast<SfxUInt16Item*>(pItem);
                 if (pFamilyItem && SfxTemplate::NIdToSfxFamilyId(pFamilyItem->GetValue()) == SD_STYLE_FAMILY_PSEUDO)
@@ -512,7 +517,7 @@ void DrawViewShell::GetAttrState( SfxItemSet& rSet )
 
             case SID_STYLE_DRAGHIERARCHIE:
             {
-                SfxPoolItem* pItem = NULL;
+                SfxPoolItem* pItem = nullptr;
                 GetViewFrame()->GetBindings().QueryState(SID_STYLE_FAMILY, pItem);
                 SfxUInt16Item* pFamilyItem = dynamic_cast<SfxUInt16Item*>(pItem);
                 if (pFamilyItem && SfxTemplate::NIdToSfxFamilyId(pFamilyItem->GetValue()) == SD_STYLE_FAMILY_PSEUDO)
@@ -526,7 +531,7 @@ void DrawViewShell::GetAttrState( SfxItemSet& rSet )
                 // It is not possible to create PseudoStyleSheets 'by Example';
                 // normal style sheets need a selected object for that
 
-                SfxPoolItem* pItem = NULL;
+                SfxPoolItem* pItem = nullptr;
                 GetViewFrame()->GetBindings().QueryState(SID_STYLE_FAMILY, pItem);
                 SfxUInt16Item* pFamilyItem = dynamic_cast<SfxUInt16Item*>(pItem);
                 if (pFamilyItem)
@@ -573,12 +578,9 @@ void DrawViewShell::GetAttrState( SfxItemSet& rSet )
                 SfxItemSet aNewAttr( GetPool(), EE_ITEMS_START, EE_ITEMS_END );
                 aNewAttr.Put( aEditAttr, false );
 
-                boost::scoped_ptr<SvxNumRule> pNumRule;
-                const SfxPoolItem* pTmpItem=NULL;
+                std::unique_ptr<SvxNumRule> pNumRule;
+                const SfxPoolItem* pTmpItem=nullptr;
                 sal_uInt16 nNumItemId = SID_ATTR_NUMBERING_RULE;
-
-                rSet.Put(SfxUInt16Item(FN_NUM_NUM_RULE_INDEX,DEFAULT_NONE));
-                rSet.Put(SfxUInt16Item(FN_BUL_NUM_RULE_INDEX,DEFAULT_NONE));
                 sal_uInt16 nActNumLvl = mpDrawView->GetSelectionLevel();
                 pTmpItem=GetNumBulletItem(aNewAttr, nNumItemId);
 
@@ -601,10 +603,10 @@ void DrawViewShell::GetAttrState( SfxItemSet& rSet )
                     }
                     if ( nCount == 1 )
                     {
-                        bool bBullets = false;
                         const SvxNumberFormat* pNumFmt = pNumRule->Get(nCurLevel);
                         if ( pNumFmt )
                         {
+                            bool bBullets = false;
                             switch(pNumFmt->GetNumberingType())
                             {
                                 case SVX_NUM_CHAR_SPECIAL:
@@ -640,8 +642,6 @@ void DrawViewShell::GetAttrState( SfxItemSet& rSet )
                 }
             }
             break;
-            //End
-            // Added by Li Hui for story 179.
             case FN_NUM_BULLET_ON:
             case FN_NUM_NUMBERING_ON:
             {
@@ -676,7 +676,7 @@ void DrawViewShell::GetAttrState( SfxItemSet& rSet )
         nWhich = aIter.NextWhich();
     }
 
-    boost::scoped_ptr<SfxItemSet> pSet;
+    std::unique_ptr<SfxItemSet> pSet;
 
     if( bAttr )
     {
@@ -737,7 +737,7 @@ void DrawViewShell::GetAttrState( SfxItemSet& rSet )
             rSet.Put( SfxBoolItem( SID_SET_SUB_SCRIPT, true ) );
         }
 
-        eState = pSet->GetItemState( EE_CHAR_KERNING, true );
+        eState = pSet->GetItemState( EE_CHAR_KERNING );
         if ( eState == SfxItemState::DONTCARE )
         {
             rSet.InvalidateItem(EE_CHAR_KERNING);
@@ -769,7 +769,7 @@ OUString DrawViewShell::GetSelectionText(bool bCompleteWords)
         }
     }
 
-    return (aStrSelection);
+    return aStrSelection;
 }
 
 bool DrawViewShell::HasSelection(bool bText) const
