@@ -37,7 +37,6 @@
 #include <sfx2/docfile.hxx>
 #include <rtl/ustrbuf.hxx>
 
-
 #include "app.hrc"
 
 #include "Outliner.hxx"
@@ -62,54 +61,54 @@ void DrawViewShell::GetMenuStateSel( SfxItemSet &rSet )
 
     // Single selection
     const SdrMarkList& rMarkList = mpDrawView->GetMarkedObjectList();
-    sal_uLong nMarkCount = rMarkList.GetMarkCount();
+    const size_t nMarkCount = rMarkList.GetMarkCount();
 
     if ( nMarkCount == 1 )
     {
-        if( SFX_ITEM_AVAILABLE == rSet.GetItemState( SID_BEZIER_EDIT ) ||
-            SFX_ITEM_AVAILABLE == rSet.GetItemState( SID_UNGROUP ) ||
-            SFX_ITEM_AVAILABLE == rSet.GetItemState( SID_ENTER_GROUP ) ||
-            SFX_ITEM_AVAILABLE == rSet.GetItemState( SID_NAME_GROUP ) ||
+        if( SfxItemState::DEFAULT == rSet.GetItemState( SID_BEZIER_EDIT ) ||
+            SfxItemState::DEFAULT == rSet.GetItemState( SID_UNGROUP ) ||
+            SfxItemState::DEFAULT == rSet.GetItemState( SID_ENTER_GROUP ) ||
+            SfxItemState::DEFAULT == rSet.GetItemState( SID_NAME_GROUP ) ||
 
             // #i68101#
-            SFX_ITEM_AVAILABLE == rSet.GetItemState( SID_OBJECT_TITLE_DESCRIPTION ) ||
+            SfxItemState::DEFAULT == rSet.GetItemState( SID_OBJECT_TITLE_DESCRIPTION ) ||
 
-            SFX_ITEM_AVAILABLE == rSet.GetItemState( SID_ATTR_FILL_STYLE ) ||
-            SFX_ITEM_AVAILABLE == rSet.GetItemState( SID_ATTR_FILL_TRANSPARENCE ) ||
-            SFX_ITEM_AVAILABLE == rSet.GetItemState( SID_ATTR_FILL_FLOATTRANSPARENCE ) ||
-            SFX_ITEM_AVAILABLE == rSet.GetItemState( SID_CHANGEBEZIER ) ||
-            SFX_ITEM_AVAILABLE == rSet.GetItemState( SID_CHANGEPOLYGON ) ||
-            SFX_ITEM_AVAILABLE == rSet.GetItemState( SID_LINEEND_POLYGON ) ||
-            SFX_ITEM_AVAILABLE == rSet.GetItemState( OBJ_TITLETEXT ) ||
-            SFX_ITEM_AVAILABLE == rSet.GetItemState( OBJ_OUTLINETEXT ) ||
-            SFX_ITEM_AVAILABLE == rSet.GetItemState( SID_MEASURE_DLG ) ||
-            SFX_ITEM_AVAILABLE == rSet.GetItemState( SID_CONNECTION_DLG ) ||
-            SFX_ITEM_AVAILABLE == rSet.GetItemState( SID_CONNECTION_NEW_ROUTING ) ||
-            SFX_ITEM_AVAILABLE == rSet.GetItemState( SID_OBJECT_SHEAR ) ||
-            SFX_ITEM_AVAILABLE == rSet.GetItemState( SID_CONVERT_TO_1BIT_THRESHOLD ) ||
-            SFX_ITEM_AVAILABLE == rSet.GetItemState( SID_CONVERT_TO_1BIT_MATRIX ) ||
-            SFX_ITEM_AVAILABLE == rSet.GetItemState( SID_CONVERT_TO_4BIT_GRAYS ) ||
-            SFX_ITEM_AVAILABLE == rSet.GetItemState( SID_CONVERT_TO_4BIT_COLORS ) ||
-            SFX_ITEM_AVAILABLE == rSet.GetItemState( SID_CONVERT_TO_8BIT_GRAYS ) ||
-            SFX_ITEM_AVAILABLE == rSet.GetItemState( SID_CONVERT_TO_8BIT_COLORS ) ||
-            SFX_ITEM_AVAILABLE == rSet.GetItemState( SID_CONVERT_TO_24BIT ) ||
-            SFX_ITEM_AVAILABLE == rSet.GetItemState( SID_OBJECT_ALIGN_LEFT ) ||
-            SFX_ITEM_AVAILABLE == rSet.GetItemState( SID_OBJECT_ALIGN_CENTER ) ||
-            SFX_ITEM_AVAILABLE == rSet.GetItemState( SID_OBJECT_ALIGN_RIGHT ) ||
-            SFX_ITEM_AVAILABLE == rSet.GetItemState( SID_OBJECT_ALIGN_UP ) ||
-            SFX_ITEM_AVAILABLE == rSet.GetItemState( SID_OBJECT_ALIGN_MIDDLE ) ||
-            SFX_ITEM_AVAILABLE == rSet.GetItemState( SID_OBJECT_ALIGN_DOWN ) ||
-            SFX_ITEM_AVAILABLE == rSet.GetItemState( SID_FRAME_TO_TOP ) ||
-            SFX_ITEM_AVAILABLE == rSet.GetItemState( SID_MOREFRONT ) ||
-            SFX_ITEM_AVAILABLE == rSet.GetItemState( SID_MOREBACK ) ||
-            SFX_ITEM_AVAILABLE == rSet.GetItemState( SID_FRAME_TO_BOTTOM ) ||
-            SFX_ITEM_AVAILABLE == rSet.GetItemState( SID_BEFORE_OBJ ) ||
-            SFX_ITEM_AVAILABLE == rSet.GetItemState( SID_BEHIND_OBJ ) ||
-            SFX_ITEM_AVAILABLE == rSet.GetItemState( SID_REVERSE_ORDER ) ||
-            SFX_ITEM_AVAILABLE == rSet.GetItemState( SID_ORIGINAL_SIZE ) ||
-            SFX_ITEM_AVAILABLE == rSet.GetItemState( SID_SAVE_GRAPHIC ) ||
-            SFX_ITEM_AVAILABLE == rSet.GetItemState( SID_COMPRESS_GRAPHIC ) ||
-            SFX_ITEM_AVAILABLE == rSet.GetItemState( SID_TEXTATTR_DLG ) )
+            SfxItemState::DEFAULT == rSet.GetItemState( SID_ATTR_FILL_STYLE ) ||
+            SfxItemState::DEFAULT == rSet.GetItemState( SID_ATTR_FILL_TRANSPARENCE ) ||
+            SfxItemState::DEFAULT == rSet.GetItemState( SID_ATTR_FILL_FLOATTRANSPARENCE ) ||
+            SfxItemState::DEFAULT == rSet.GetItemState( SID_CHANGEBEZIER ) ||
+            SfxItemState::DEFAULT == rSet.GetItemState( SID_CHANGEPOLYGON ) ||
+            SfxItemState::DEFAULT == rSet.GetItemState( SID_LINEEND_POLYGON ) ||
+            SfxItemState::DEFAULT == rSet.GetItemState( OBJ_TITLETEXT ) ||
+            SfxItemState::DEFAULT == rSet.GetItemState( OBJ_OUTLINETEXT ) ||
+            SfxItemState::DEFAULT == rSet.GetItemState( SID_MEASURE_DLG ) ||
+            SfxItemState::DEFAULT == rSet.GetItemState( SID_CONNECTION_DLG ) ||
+            SfxItemState::DEFAULT == rSet.GetItemState( SID_CONNECTION_NEW_ROUTING ) ||
+            SfxItemState::DEFAULT == rSet.GetItemState( SID_OBJECT_SHEAR ) ||
+            SfxItemState::DEFAULT == rSet.GetItemState( SID_CONVERT_TO_1BIT_THRESHOLD ) ||
+            SfxItemState::DEFAULT == rSet.GetItemState( SID_CONVERT_TO_1BIT_MATRIX ) ||
+            SfxItemState::DEFAULT == rSet.GetItemState( SID_CONVERT_TO_4BIT_GRAYS ) ||
+            SfxItemState::DEFAULT == rSet.GetItemState( SID_CONVERT_TO_4BIT_COLORS ) ||
+            SfxItemState::DEFAULT == rSet.GetItemState( SID_CONVERT_TO_8BIT_GRAYS ) ||
+            SfxItemState::DEFAULT == rSet.GetItemState( SID_CONVERT_TO_8BIT_COLORS ) ||
+            SfxItemState::DEFAULT == rSet.GetItemState( SID_CONVERT_TO_24BIT ) ||
+            SfxItemState::DEFAULT == rSet.GetItemState( SID_OBJECT_ALIGN_LEFT ) ||
+            SfxItemState::DEFAULT == rSet.GetItemState( SID_OBJECT_ALIGN_CENTER ) ||
+            SfxItemState::DEFAULT == rSet.GetItemState( SID_OBJECT_ALIGN_RIGHT ) ||
+            SfxItemState::DEFAULT == rSet.GetItemState( SID_OBJECT_ALIGN_UP ) ||
+            SfxItemState::DEFAULT == rSet.GetItemState( SID_OBJECT_ALIGN_MIDDLE ) ||
+            SfxItemState::DEFAULT == rSet.GetItemState( SID_OBJECT_ALIGN_DOWN ) ||
+            SfxItemState::DEFAULT == rSet.GetItemState( SID_FRAME_TO_TOP ) ||
+            SfxItemState::DEFAULT == rSet.GetItemState( SID_MOREFRONT ) ||
+            SfxItemState::DEFAULT == rSet.GetItemState( SID_MOREBACK ) ||
+            SfxItemState::DEFAULT == rSet.GetItemState( SID_FRAME_TO_BOTTOM ) ||
+            SfxItemState::DEFAULT == rSet.GetItemState( SID_BEFORE_OBJ ) ||
+            SfxItemState::DEFAULT == rSet.GetItemState( SID_BEHIND_OBJ ) ||
+            SfxItemState::DEFAULT == rSet.GetItemState( SID_REVERSE_ORDER ) ||
+            SfxItemState::DEFAULT == rSet.GetItemState( SID_ORIGINAL_SIZE ) ||
+            SfxItemState::DEFAULT == rSet.GetItemState( SID_SAVE_GRAPHIC ) ||
+            SfxItemState::DEFAULT == rSet.GetItemState( SID_COMPRESS_GRAPHIC ) ||
+            SfxItemState::DEFAULT == rSet.GetItemState( SID_TEXTATTR_DLG ) )
         {
             const SdrObject* pObj = rMarkList.GetMark(0)->GetMarkedSdrObj();
             const SdrGrafObj* pSdrGrafObj = dynamic_cast< const SdrGrafObj* >(pObj);
@@ -135,14 +134,14 @@ void DrawViewShell::GetMenuStateSel( SfxItemSet &rSet )
 
             /* If it is not a group object or 3D object, we disable "enter
                group". */
-            if( !( ( pObj->ISA( SdrObjGroup ) && nInv == SdrInventor ) ||
-                (pObj->ISA (E3dPolyScene) || pObj->ISA (E3dScene) /*|| pObj->ISA (E3dCompoundObject) */) ) )
+            if( !( ( dynamic_cast< const SdrObjGroup *>( pObj ) !=  nullptr && nInv == SdrInventor ) ||
+                (dynamic_cast< const E3dPolyScene* >(pObj) !=  nullptr|| dynamic_cast< const E3dScene* >(pObj) !=  nullptr /*|| pObj->ISA (E3dCompoundObject) */) ) )
             {
                 rSet.DisableItem( SID_ENTER_GROUP );
             }
 
             // If it is not a group object, we disable "ungroup"
-            if (!(pObj->ISA(SdrObjGroup) && nInv == SdrInventor))
+            if(!(dynamic_cast< const SdrObjGroup *>( pObj ) !=  nullptr && nInv == SdrInventor))
             {
                 rSet.DisableItem(SID_UNGROUP);
             }
@@ -171,7 +170,7 @@ void DrawViewShell::GetMenuStateSel( SfxItemSet &rSet )
                 rSet.DisableItem( SID_ATTR_FILL_TRANSPARENCE );
                 rSet.DisableItem( SID_ATTR_FILL_FLOATTRANSPARENCE );
             }
-            if( (!pObj->ISA( SdrPathObj ) && !aInfoRec.bCanConvToPath) || pObj->ISA( SdrObjGroup ) ) // As long as JOE handles it incorrectly!
+            if( (dynamic_cast< const SdrPathObj *>( pObj ) ==  nullptr&& !aInfoRec.bCanConvToPath) || dynamic_cast< const SdrObjGroup *>( pObj ) !=  nullptr ) // As long as JOE handles it incorrectly!
             { // JOE: a group object may can be converted into a PathObj
                 rSet.DisableItem( SID_LINEEND_POLYGON );
             }
@@ -198,20 +197,20 @@ void DrawViewShell::GetMenuStateSel( SfxItemSet &rSet )
                 rSet.DisableItem( SID_CONNECTION_DLG );
             else
             {
-                sal_Bool bDisable = sal_True;
+                bool bDisable = true;
                 SfxItemSet aAttrSet( GetDoc()->GetPool() );
                 GetView()->GetAttributes( aAttrSet );
 
-                if( aAttrSet.GetItemState( SDRATTR_EDGELINE1DELTA ) >= SFX_ITEM_AVAILABLE &&
-                    aAttrSet.GetItemState( SDRATTR_EDGELINE2DELTA ) >= SFX_ITEM_AVAILABLE &&
-                    aAttrSet.GetItemState( SDRATTR_EDGELINE3DELTA ) >= SFX_ITEM_AVAILABLE )
+                if( aAttrSet.GetItemState( SDRATTR_EDGELINE1DELTA ) >= SfxItemState::DEFAULT &&
+                    aAttrSet.GetItemState( SDRATTR_EDGELINE2DELTA ) >= SfxItemState::DEFAULT &&
+                    aAttrSet.GetItemState( SDRATTR_EDGELINE3DELTA ) >= SfxItemState::DEFAULT )
                 {
-                    long nVal1 = ( ( const SdrEdgeLine1DeltaItem& ) aAttrSet.Get( SDRATTR_EDGELINE1DELTA ) ).GetValue();
-                    long nVal2 = ( ( const SdrEdgeLine2DeltaItem& ) aAttrSet.Get( SDRATTR_EDGELINE2DELTA ) ).GetValue();
-                    long nVal3 = ( ( const SdrEdgeLine3DeltaItem& ) aAttrSet.Get( SDRATTR_EDGELINE3DELTA ) ).GetValue();
+                    long nVal1 = static_cast<const SdrMetricItem&>( aAttrSet.Get( SDRATTR_EDGELINE1DELTA ) ).GetValue();
+                    long nVal2 = static_cast<const SdrMetricItem&>( aAttrSet.Get( SDRATTR_EDGELINE2DELTA ) ).GetValue();
+                    long nVal3 = static_cast<const SdrMetricItem&>( aAttrSet.Get( SDRATTR_EDGELINE3DELTA ) ).GetValue();
                     {
                         if( nVal1 != 0 || nVal2 != 0 || nVal3 != 0 )
-                            bDisable = sal_False;
+                            bDisable = false;
                     }
                 }
                 if( bDisable )
@@ -219,15 +218,16 @@ void DrawViewShell::GetMenuStateSel( SfxItemSet &rSet )
             }
 
             if ( nInv == E3dInventor                          ||
-                 (!mpDrawView->IsConvertToPathObjPossible(sal_False) &&
+                 (!mpDrawView->IsConvertToPathObjPossible(false) &&
                   !mpDrawView->IsShearAllowed()                  &&
                   !mpDrawView->IsDistortAllowed()) )
             {
                 rSet.DisableItem( SID_OBJECT_SHEAR );
             }
 
-            if(pObj->ISA(E3dCompoundObject))
+            if(dynamic_cast< const E3dCompoundObject *>( pObj ) !=  nullptr)
             {
+                rSet.DisableItem( SID_OBJECT_ALIGN );
                 rSet.DisableItem( SID_OBJECT_ALIGN_LEFT );
                 rSet.DisableItem( SID_OBJECT_ALIGN_CENTER );
                 rSet.DisableItem( SID_OBJECT_ALIGN_RIGHT );
@@ -241,25 +241,26 @@ void DrawViewShell::GetMenuStateSel( SfxItemSet &rSet )
                 rSet.DisableItem( SID_BEFORE_OBJ );
                 rSet.DisableItem( SID_BEHIND_OBJ );
                 rSet.DisableItem( SID_REVERSE_ORDER );
+                rSet.DisableItem( SID_POSITION );
             }
         }
 
-        if( SFX_ITEM_AVAILABLE == rSet.GetItemState( SID_DISMANTLE ) ||
-            SFX_ITEM_AVAILABLE == rSet.GetItemState( SID_BREAK ) )
+        if( SfxItemState::DEFAULT == rSet.GetItemState( SID_DISMANTLE ) ||
+            SfxItemState::DEFAULT == rSet.GetItemState( SID_BREAK ) )
         {
-            if ( !mpDrawView->IsDismantlePossible(sal_False) )
+            if ( !mpDrawView->IsDismantlePossible() )
             {
                 rSet.DisableItem( SID_DISMANTLE );
             }
 
-            if ( !mpDrawView->IsDismantlePossible(sal_True) &&
+            if ( !mpDrawView->IsDismantlePossible(true) &&
                  !mpDrawView->IsImportMtfPossible()     &&
                  !mpDrawView->IsBreak3DObjPossible() )
             {
                 rSet.DisableItem( SID_BREAK );
             }
         }
-        if( SFX_ITEM_AVAILABLE == rSet.GetItemState( SID_MODIFY_FIELD ) )
+        if( SfxItemState::DEFAULT == rSet.GetItemState( SID_MODIFY_FIELD ) )
         {
             OutlinerView* pOLV = mpDrawView->GetTextEditOutlinerView();
 
@@ -267,10 +268,10 @@ void DrawViewShell::GetMenuStateSel( SfxItemSet &rSet )
             {
                 const SvxFieldItem* pFldItem = pOLV->GetFieldAtSelection();
 
-                if( !( pFldItem && (pFldItem->GetField()->ISA( SvxDateField ) ||
-                                 pFldItem->GetField()->ISA( SvxAuthorField ) ||
-                                 pFldItem->GetField()->ISA( SvxExtFileField ) ||
-                                 pFldItem->GetField()->ISA( SvxExtTimeField ) ) ) )
+                if( !( pFldItem && (nullptr != dynamic_cast< const SvxDateField *>( pFldItem->GetField() ) ||
+                                 nullptr != dynamic_cast< const SvxAuthorField *>( pFldItem->GetField() ) ||
+                                 nullptr != dynamic_cast< const SvxExtFileField *>( pFldItem->GetField() ) ||
+                                 nullptr != dynamic_cast< const SvxExtTimeField *>( pFldItem->GetField() ) ) ) )
                 {
                     rSet.DisableItem( SID_MODIFY_FIELD );
                 }
@@ -278,20 +279,22 @@ void DrawViewShell::GetMenuStateSel( SfxItemSet &rSet )
             else
                 rSet.DisableItem( SID_MODIFY_FIELD );
         }
-        if( SFX_ITEM_AVAILABLE == rSet.GetItemState( SID_OUTLINE_TEXT_AUTOFIT ) )
+        if( SfxItemState::DEFAULT == rSet.GetItemState( SID_OUTLINE_TEXT_AUTOFIT ) )
         {
             const SdrObject* pObj = rMarkList.GetMark(0)->GetMarkedSdrObj();
-            const bool bSet = ((const SdrTextFitToSizeTypeItem*)pObj->GetMergedItemSet().GetItem(SDRATTR_TEXT_FITTOSIZE))->GetValue() != SDRTEXTFIT_NONE;
+            const bool bSet = static_cast<const SdrTextFitToSizeTypeItem*>(pObj->GetMergedItemSet().GetItem(SDRATTR_TEXT_FITTOSIZE))->GetValue() != SDRTEXTFIT_NONE;
             rSet.Put(SfxBoolItem(SID_OUTLINE_TEXT_AUTOFIT, bSet));
         }
 
-        rSet.DisableItem( SID_GROUP );
-        rSet.DisableItem( SID_COMBINE );
+        rSet.DisableItem(SID_GROUP);
+        rSet.DisableItem(SID_COMBINE);
         rSet.DisableItem(SID_DISTRIBUTE_DLG);
         rSet.DisableItem(SID_POLY_MERGE);
         rSet.DisableItem(SID_POLY_SUBSTRACT);
         rSet.DisableItem(SID_POLY_INTERSECT);
-        rSet.DisableItem( SID_CONNECT );
+        rSet.DisableItem(SID_EQUALIZEWIDTH);
+        rSet.DisableItem(SID_EQUALIZEHEIGHT);
+        rSet.DisableItem(SID_CONNECT);
     }
     // multi-selection
     else if( nMarkCount > 1 )
@@ -309,20 +312,18 @@ void DrawViewShell::GetMenuStateSel( SfxItemSet &rSet )
         rSet.DisableItem( SID_MODIFY_FIELD );
 
         {
-            sal_Bool bText = sal_False;
-            sal_Bool bLine = sal_False;
-            sal_Bool bGroup = sal_False;
-            sal_Bool bGraf = sal_False;
-            sal_Bool bDrawObj = sal_False;
-            sal_Bool b3dObj = sal_False;
+            bool bText = false;
+            bool bLine = false;
+            bool bGroup = false;
+            bool bGraf = false;
+            bool bDrawObj = false;
+            bool b3dObj = false;
             bool bTable = false;
-            sal_Bool bMeasureObj = sal_False;
-            sal_Bool bEdgeObj = sal_False; // Connector
-            sal_Bool bE3dCompoundObject = sal_False;
+            bool bMeasureObj = false;
+            bool bEdgeObj = false; // Connector
+            bool bE3dCompoundObject = false;
 
-            for( sal_uLong i = 0;
-                 i < nMarkCount && !bText && i < 50;
-                 i++ )
+            for( size_t i = 0; i < nMarkCount && !bText && i < 50; ++i )
             {
                 SdrObject* pObj = rMarkList.GetMark(i)->GetMarkedSdrObj();
                 sal_uInt32 nInv = pObj->GetObjInventor();
@@ -332,13 +333,13 @@ void DrawViewShell::GetMenuStateSel( SfxItemSet &rSet )
                 {
                     switch (nId)
                     {
-                        case OBJ_TEXT: bText = sal_True; break;
+                        case OBJ_TEXT: bText = true; break;
 
-                        case OBJ_LINE: bLine = sal_True; break;
+                        case OBJ_LINE: bLine = true; break;
 
-                        case OBJ_EDGE: bEdgeObj = sal_True; break;
+                        case OBJ_EDGE: bEdgeObj = true; break;
 
-                        case OBJ_MEASURE: bMeasureObj = sal_True; break;
+                        case OBJ_MEASURE: bMeasureObj = true; break;
 
                         case OBJ_RECT:
                         case OBJ_CIRC:
@@ -348,21 +349,21 @@ void DrawViewShell::GetMenuStateSel( SfxItemSet &rSet )
                         case OBJ_PATHLINE:
                         case OBJ_SECT:
                         case OBJ_CARC:
-                        case OBJ_CCUT: bDrawObj = sal_True; break;
+                        case OBJ_CCUT: bDrawObj = true; break;
 
-                        case OBJ_GRUP: bGroup = sal_True; break;
+                        case OBJ_GRUP: bGroup = true; break;
 
-                        case OBJ_GRAF: bGraf = sal_True; break;
+                        case OBJ_GRAF: bGraf = true; break;
 
                         case OBJ_TABLE: bTable = true; break;
                     }
                 }
                 else if (nInv == E3dInventor)
                 {
-                    if(pObj->ISA(E3dScene))
-                        b3dObj = sal_True;
-                    else if(pObj->ISA(E3dCompoundObject))
-                        bE3dCompoundObject = sal_True;
+                    if(dynamic_cast< const E3dScene *>( pObj ) !=  nullptr)
+                        b3dObj = true;
+                    else if(dynamic_cast< const E3dCompoundObject* >(pObj) !=  nullptr)
+                        bE3dCompoundObject = true;
                 }
             }
             if( bLine && !bText && !bDrawObj &&!b3dObj)
@@ -380,10 +381,12 @@ void DrawViewShell::GetMenuStateSel( SfxItemSet &rSet )
                 rSet.DisableItem(SID_POLY_MERGE);
                 rSet.DisableItem(SID_POLY_SUBSTRACT);
                 rSet.DisableItem(SID_POLY_INTERSECT);
+                rSet.DisableItem(SID_EQUALIZEWIDTH);
+                rSet.DisableItem(SID_EQUALIZEHEIGHT);
             }
 
             if (b3dObj                                        ||
-                 (!mpDrawView->IsConvertToPathObjPossible(sal_False) &&
+                 (!mpDrawView->IsConvertToPathObjPossible(false) &&
                   !mpDrawView->IsShearAllowed()                  &&
                   !mpDrawView->IsDistortAllowed()) )
             {
@@ -413,6 +416,7 @@ void DrawViewShell::GetMenuStateSel( SfxItemSet &rSet )
 
             if(bE3dCompoundObject)
             {
+                rSet.DisableItem( SID_OBJECT_ALIGN );
                 rSet.DisableItem( SID_OBJECT_ALIGN_LEFT );
                 rSet.DisableItem( SID_OBJECT_ALIGN_CENTER );
                 rSet.DisableItem( SID_OBJECT_ALIGN_RIGHT );
@@ -426,27 +430,30 @@ void DrawViewShell::GetMenuStateSel( SfxItemSet &rSet )
                 rSet.DisableItem( SID_BEFORE_OBJ );
                 rSet.DisableItem( SID_BEHIND_OBJ );
                 rSet.DisableItem( SID_REVERSE_ORDER );
+                rSet.DisableItem( SID_POSITION );
             }
         }
 
-        if ( !mpDrawView->IsDismantlePossible(sal_False) )
+        if ( !mpDrawView->IsDismantlePossible() )
         {
             rSet.DisableItem( SID_DISMANTLE );
         }
-        if ( !mpDrawView->IsDismantlePossible(sal_True) &&
+        if ( !mpDrawView->IsDismantlePossible(true) &&
              !mpDrawView->IsImportMtfPossible()     &&
              !mpDrawView->IsBreak3DObjPossible() )
         {
             rSet.DisableItem( SID_BREAK );
         }
-        if ( !mpDrawView->IsCombinePossible(sal_False) )
+        if ( !mpDrawView->IsCombinePossible() )
         {
-            rSet.DisableItem( SID_COMBINE );
+            rSet.DisableItem(SID_COMBINE);
             rSet.DisableItem(SID_POLY_MERGE);
             rSet.DisableItem(SID_POLY_SUBSTRACT);
             rSet.DisableItem(SID_POLY_INTERSECT);
+            rSet.DisableItem(SID_EQUALIZEWIDTH);
+            rSet.DisableItem(SID_EQUALIZEHEIGHT);
         }
-        if ( !mpDrawView->IsCombinePossible(sal_True) )
+        if ( !mpDrawView->IsCombinePossible(true) )
         {
             rSet.DisableItem( SID_CONNECT );
         }
@@ -468,6 +475,7 @@ void DrawViewShell::GetMenuStateSel( SfxItemSet &rSet )
         rSet.DisableItem( SID_DELETE );
         rSet.DisableItem( SID_ATTR_TRANSFORM );
 
+        rSet.DisableItem( SID_OBJECT_ALIGN );
         rSet.DisableItem( SID_OBJECT_ALIGN_LEFT );
         rSet.DisableItem( SID_OBJECT_ALIGN_CENTER );
         rSet.DisableItem( SID_OBJECT_ALIGN_RIGHT );
@@ -482,6 +490,7 @@ void DrawViewShell::GetMenuStateSel( SfxItemSet &rSet )
         rSet.DisableItem( SID_BEFORE_OBJ );
         rSet.DisableItem( SID_BEHIND_OBJ );
         rSet.DisableItem( SID_CONVERT );
+        rSet.DisableItem( SID_POSITION );
 
         rSet.DisableItem( SID_SIZE_OPTIMAL );
         rSet.DisableItem( SID_LINEEND_POLYGON );
@@ -504,6 +513,8 @@ void DrawViewShell::GetMenuStateSel( SfxItemSet &rSet )
         rSet.DisableItem(SID_POLY_MERGE);
         rSet.DisableItem(SID_POLY_SUBSTRACT);
         rSet.DisableItem(SID_POLY_INTERSECT);
+        rSet.DisableItem(SID_EQUALIZEWIDTH);
+        rSet.DisableItem(SID_EQUALIZEHEIGHT);
         rSet.DisableItem( SID_CONNECT );
         rSet.DisableItem( SID_ANIMATION_EFFECTS );
         rSet.DisableItem( SID_MODIFY_FIELD );
@@ -512,7 +523,6 @@ void DrawViewShell::GetMenuStateSel( SfxItemSet &rSet )
 
 }
 
-
 } // end of namespace sd
 
 /* vim:set shiftwidth=4 softtabstop=4 expandtab: */
