@@ -75,14 +75,12 @@ using namespace com::sun::star;
 
 namespace sd {
 
-const OUString aEmptyStr;
-
 /**
  * adjust Thumbpos and VisibleSize
  */
 void ViewShell::UpdateScrollBars()
 {
-    if (mpHorizontalScrollBar.get() != NULL)
+    if (mpHorizontalScrollBar.get() != nullptr)
     {
         long nW = (long)(mpContentWindow->GetVisibleWidth() * 32000);
         long nX = (long)(mpContentWindow->GetVisibleX() * 32000);
@@ -95,7 +93,7 @@ void ViewShell::UpdateScrollBars()
         mpHorizontalScrollBar->SetPageSize(nPage);
     }
 
-    if (mpVerticalScrollBar.get() != NULL)
+    if (mpVerticalScrollBar.get() != nullptr)
     {
         long nH = (long)(mpContentWindow->GetVisibleHeight() * 32000);
         long nY = (long)(mpContentWindow->GetVisibleY() * 32000);
@@ -134,11 +132,10 @@ void ViewShell::UpdateScrollBars()
 /**
  * Handling for horizontal Scrollbars
  */
-IMPL_LINK_INLINE_START(ViewShell, HScrollHdl, ScrollBar *, pHScroll )
+IMPL_LINK_TYPED(ViewShell, HScrollHdl, ScrollBar *, pHScroll, void )
 {
-    return VirtHScrollHdl(pHScroll);
+    VirtHScrollHdl(pHScroll);
 }
-IMPL_LINK_INLINE_END(ViewShell, HScrollHdl, ScrollBar *, pHScroll )
 
 /**
  * virtual scroll handler for horizontal Scrollbars
@@ -153,7 +150,7 @@ long ViewShell::VirtHScrollHdl(ScrollBar* pHScroll)
 
         // scroll all windows of the column
         ::sd::View* pView = GetView();
-        OutlinerView* pOLV = NULL;
+        OutlinerView* pOLV = nullptr;
 
         if (pView)
             pOLV = pView->GetTextEditOutlinerView();
@@ -191,11 +188,10 @@ long ViewShell::VirtHScrollHdl(ScrollBar* pHScroll)
 /**
  * handling for vertical Scrollbars
  */
-IMPL_LINK_INLINE_START(ViewShell, VScrollHdl, ScrollBar *, pVScroll )
+IMPL_LINK_TYPED(ViewShell, VScrollHdl, ScrollBar *, pVScroll, void )
 {
-    return VirtVScrollHdl(pVScroll);
+    VirtVScrollHdl(pVScroll);
 }
-IMPL_LINK_INLINE_END(ViewShell, VScrollHdl, ScrollBar *, pVScroll )
 
 /**
  * handling for vertical Scrollbars
@@ -215,7 +211,7 @@ long ViewShell::VirtVScrollHdl(ScrollBar* pVScroll)
         double fY = (double) pVScroll->GetThumbPos() / pVScroll->GetRange().Len();
 
         ::sd::View* pView = GetView();
-        OutlinerView* pOLV = NULL;
+        OutlinerView* pOLV = nullptr;
 
         if (pView)
             pOLV = pView->GetTextEditOutlinerView();
@@ -250,14 +246,14 @@ long ViewShell::VirtVScrollHdl(ScrollBar* pVScroll)
     return 0;
 }
 
-SvxRuler* ViewShell::CreateHRuler(::sd::Window* , sal_Bool )
+SvxRuler* ViewShell::CreateHRuler(::sd::Window* , bool )
 {
-    return NULL;
+    return nullptr;
 }
 
 SvxRuler* ViewShell::CreateVRuler(::sd::Window* )
 {
-    return NULL;
+    return nullptr;
 }
 
 void ViewShell::UpdateHRuler()
@@ -335,21 +331,21 @@ void ViewShell::SetZoom(long nZoom)
     Fraction aUIScale(nZoom, 100);
     aUIScale *= GetDoc()->GetUIScale();
 
-    if (mpHorizontalRuler.get() != NULL)
+    if (mpHorizontalRuler.get() != nullptr)
         mpHorizontalRuler->SetZoom(aUIScale);
 
-    if (mpVerticalRuler.get() != NULL)
+    if (mpVerticalRuler.get() != nullptr)
         mpVerticalRuler->SetZoom(aUIScale);
 
-    if (mpContentWindow.get() != NULL)
+    if (mpContentWindow.get() != nullptr)
     {
         mpContentWindow->SetZoomIntegral(nZoom);
 
         // #i74769# Here is a 2nd way (besides Window::Scroll) to set the visible prt
-        // of the window. It needs - like Scroll(SCROLL_CHILDREN) does - also to move
-        // the child windows. I am trying INVALIDATE_CHILDREN here which makes things better,
-        // but does not solve the problem completely. Neet to ask PL.
-        mpContentWindow->Invalidate(INVALIDATE_CHILDREN);
+        // of the window. It needs - like Scroll(ScrollFlags::Children) does - also to move
+        // the child windows. I am trying InvalidateFlags::Children here which makes things better,
+        // but does not solve the problem completely. Need to ask PL.
+        mpContentWindow->Invalidate(InvalidateFlags::Children);
     }
 
     Size aVisSizePixel = GetActiveWindow()->GetOutputSizePixel();
@@ -377,13 +373,13 @@ void ViewShell::SetZoomRect(const Rectangle& rZoomRect)
 
     Point aPos = GetActiveWindow()->GetWinViewPos();
 
-    if (mpHorizontalRuler.get() != NULL)
+    if (mpHorizontalRuler.get() != nullptr)
         mpHorizontalRuler->SetZoom(aUIScale);
 
-    if (mpVerticalRuler.get() != NULL)
+    if (mpVerticalRuler.get() != nullptr)
         mpVerticalRuler->SetZoom(aUIScale);
 
-    if (mpContentWindow.get() != NULL)
+    if (mpContentWindow.get() != nullptr)
     {
         Point aNewPos = mpContentWindow->GetWinViewPos();
         aNewPos.X() = aPos.X();
@@ -392,8 +388,10 @@ void ViewShell::SetZoomRect(const Rectangle& rZoomRect)
         mpContentWindow->SetWinViewPos(aNewPos);
         mpContentWindow->UpdateMapOrigin();
 
-        // #i74769# see above
-        mpContentWindow->Invalidate(INVALIDATE_CHILDREN);
+        // When tiled rendering, UpdateMapOrigin() doesn't touch the map mode.
+        if (!GetDoc()->isTiledRendering())
+            // #i74769# see above
+            mpContentWindow->Invalidate(InvalidateFlags::Children);
     }
 
     Size aVisSizePixel = GetActiveWindow()->GetOutputSizePixel();
@@ -413,9 +411,9 @@ void ViewShell::SetZoomRect(const Rectangle& rZoomRect)
  * Initialize imaging parameters for all split windows.
  */
 void ViewShell::InitWindows(const Point& rViewOrigin, const Size& rViewSize,
-                              const Point& rWinPos, sal_Bool bUpdate)
+                              const Point& rWinPos, bool bUpdate)
 {
-    if (mpContentWindow.get() != NULL)
+    if (mpContentWindow.get() != nullptr)
     {
         mpContentWindow->SetViewOrigin(rViewOrigin);
         mpContentWindow->SetViewSize(rViewSize);
@@ -444,17 +442,16 @@ void ViewShell::InitWindows(const Point& rViewOrigin, const Size& rViewSize,
  */
 void ViewShell::InvalidateWindows()
 {
-    if (mpContentWindow.get() != NULL)
+    if (mpContentWindow.get() != nullptr)
         mpContentWindow->Invalidate();
 }
 
-
 /**
  * Draw a selection rectangle with the ?provided pen on all split windows.
  */
 void ViewShell::DrawMarkRect(const Rectangle& rRect) const
 {
-    if (mpContentWindow.get() != NULL)
+    if (mpContentWindow.get() != nullptr)
     {
         mpContentWindow->InvertTracking(rRect, SHOWTRACK_OBJECT | SHOWTRACK_WINDOW);
     }
@@ -462,17 +459,17 @@ void ViewShell::DrawMarkRect(const Rectangle& rRect) const
 
 void ViewShell::SetPageSizeAndBorder(PageKind ePageKind, const Size& rNewSize,
                                        long nLeft, long nRight,
-                                       long nUpper, long nLower, sal_Bool bScaleAll,
+                                       long nUpper, long nLower, bool bScaleAll,
                                        Orientation eOrientation, sal_uInt16 nPaperBin,
-                                       sal_Bool bBackgroundFullSize)
+                                       bool bBackgroundFullSize)
 {
-    SdPage* pPage = 0;
-    SdUndoGroup* pUndoGroup = NULL;
+    SdPage* pPage = nullptr;
+    SdUndoGroup* pUndoGroup = nullptr;
     pUndoGroup = new SdUndoGroup(GetDoc());
     OUString aString(SdResId(STR_UNDO_CHANGE_PAGEFORMAT));
     pUndoGroup->SetComment(aString);
     SfxViewShell* pViewShell = GetViewShell();
-    OSL_ASSERT (pViewShell!=NULL);
+    OSL_ASSERT (pViewShell!=nullptr);
 
     sal_uInt16 i, nPageCnt = GetDoc()->GetMasterSdPageCount(ePageKind);
 
@@ -577,7 +574,7 @@ void ViewShell::SetPageSizeAndBorder(PageKind ePageKind, const Size& rNewSize,
 
     // adjust handout page to new format of the standard page
     if( (ePageKind == PK_STANDARD) || (ePageKind == PK_HANDOUT) )
-        GetDoc()->GetSdPage(0, PK_HANDOUT)->CreateTitleAndLayout(sal_True);
+        GetDoc()->GetSdPage(0, PK_HANDOUT)->CreateTitleAndLayout(true);
 
     // handed over undo group to undo manager
     pViewShell->GetViewFrame()->GetObjectShell()
@@ -586,14 +583,14 @@ void ViewShell::SetPageSizeAndBorder(PageKind ePageKind, const Size& rNewSize,
     long nWidth = pPage->GetSize().Width();
     long nHeight = pPage->GetSize().Height();
 
-    Point aPageOrg = Point(nWidth, nHeight / 2);
-    Size aViewSize = Size(nWidth * 3, nHeight * 2);
+    Point aPageOrg(nWidth, nHeight / 2);
+    Size aViewSize(nWidth * 3, nHeight * 2);
 
-    InitWindows(aPageOrg, aViewSize, Point(-1, -1), sal_True);
+    InitWindows(aPageOrg, aViewSize, Point(-1, -1), true);
 
     Point aVisAreaPos;
 
-    if ( GetDocSh()->GetCreateMode() == SFX_CREATE_MODE_EMBEDDED )
+    if ( GetDocSh()->GetCreateMode() == SfxObjectCreateMode::EMBEDDED )
     {
         aVisAreaPos = GetDocSh()->GetVisArea(ASPECT_CONTENT).TopLeft();
     }
@@ -617,7 +614,7 @@ void ViewShell::SetPageSizeAndBorder(PageKind ePageKind, const Size& rNewSize,
 
     // zoom onto (new) page size
     pViewShell->GetViewFrame()->GetDispatcher()->Execute(SID_SIZE_PAGE,
-            SFX_CALLMODE_ASYNCHRON | SFX_CALLMODE_RECORD);
+            SfxCallMode::ASYNCHRON | SfxCallMode::RECORD);
 
     Broadcast (ViewShellHint(ViewShellHint::HINT_PAGE_RESIZE_END));
 }
@@ -631,12 +628,10 @@ void ViewShell::SetZoomFactor(const Fraction& rZoomX, const Fraction&)
     SetZoom(nZoom);
 }
 
-
-
 void ViewShell::SetActiveWindow (::sd::Window* pWin)
 {
     SfxViewShell* pViewShell = GetViewShell();
-    OSL_ASSERT (pViewShell!=NULL);
+    OSL_ASSERT (pViewShell!=nullptr);
 
     if (pViewShell->GetWindow() != pWin)
     {
@@ -649,7 +644,7 @@ void ViewShell::SetActiveWindow (::sd::Window* pWin)
         }
     }
 
-    if (mpActiveWindow != pWin)
+    if (mpActiveWindow.get() != pWin)
         mpActiveWindow = pWin;
 
     // The rest of this function is not guarded anymore against calling this
@@ -667,13 +662,11 @@ void ViewShell::SetActiveWindow (::sd::Window* pWin)
     }
 }
 
-
-
-sal_Bool ViewShell::RequestHelp(const HelpEvent& rHEvt, ::sd::Window*)
+bool ViewShell::RequestHelp(const HelpEvent& rHEvt, ::sd::Window*)
 {
-    sal_Bool bReturn = sal_False;
+    bool bReturn = false;
 
-    if (rHEvt.GetMode())
+    if (bool(rHEvt.GetMode()))
     {
         if( GetView() )
             bReturn = GetView()->getSmartTags().RequestHelp(rHEvt);
@@ -684,29 +677,15 @@ sal_Bool ViewShell::RequestHelp(const HelpEvent& rHEvt, ::sd::Window*)
         }
     }
 
-    return(bReturn);
+    return bReturn;
 }
 
-
-
-
-FrameView* ViewShell::GetFrameView (void)
-{
-    return mpFrameView;
-}
-
-
-
-
 void ViewShell::SetFrameView (FrameView* pNewFrameView)
 {
     mpFrameView = pNewFrameView;
     ReadFrameViewData (mpFrameView);
 }
 
-
-
-
 /*************************************************************************
 |*
 |* Read FrameViews data and set actual views data
@@ -717,8 +696,6 @@ void ViewShell::ReadFrameViewData(FrameView*)
 {
 }
 
-
-
 /*************************************************************************
 |*
 |* Write actual views data to FrameView
@@ -729,16 +706,15 @@ void ViewShell::WriteFrameViewData()
 {
 }
 
-
-sal_Bool ViewShell::ActivateObject(SdrOle2Obj* pObj, long nVerb)
+bool ViewShell::ActivateObject(SdrOle2Obj* pObj, long nVerb)
 {
     ErrCode aErrCode = 0;
 
     SfxErrorContext aEC(ERRCTX_SO_DOVERB, GetActiveWindow(), RID_SO_ERRCTX);
-    sal_Bool bAbort = sal_False;
-    GetDocSh()->SetWaitCursor( sal_True );
+    bool bAbort = false;
+    GetDocSh()->SetWaitCursor( true );
     SfxViewShell* pViewShell = GetViewShell();
-    OSL_ASSERT (pViewShell!=NULL);
+    OSL_ASSERT (pViewShell!=nullptr);
     bool bChangeDefaultsForChart = false;
     OUString aName;
 
@@ -774,28 +750,28 @@ sal_Bool ViewShell::ActivateObject(SdrOle2Obj* pObj, long nVerb)
 
         if( !xObj.is() )
         {
-            aName = "";
+            aName.clear();
 
             // call dialog "insert OLE object"
-            GetDocSh()->SetWaitCursor( sal_False );
+            GetDocSh()->SetWaitCursor( false );
             pViewShell->GetViewFrame()->GetDispatcher()->Execute(
                 SID_INSERT_OBJECT,
-                SFX_CALLMODE_SYNCHRON | SFX_CALLMODE_RECORD);
+                SfxCallMode::SYNCHRON | SfxCallMode::RECORD);
             xObj = pObj->GetObjRef();
-            GetDocSh()->SetWaitCursor( sal_True );
+            GetDocSh()->SetWaitCursor( true );
 
             if (!xObj.is())
             {
-                bAbort = sal_True;
+                bAbort = true;
             }
         }
 
         if ( xObj.is() )
         {
             // OLE object is no longer empty
-            pObj->SetEmptyPresObj(sal_False);
-            pObj->SetOutlinerParaObject(NULL);
-            pObj->SetGraphic(NULL);
+            pObj->SetEmptyPresObj(false);
+            pObj->SetOutlinerParaObject(nullptr);
+            pObj->SetGraphic(nullptr);
 
             // the empty OLE object gets a new IPObj
             if (!aName.isEmpty())
@@ -883,10 +859,10 @@ sal_Bool ViewShell::ActivateObject(SdrOle2Obj* pObj, long nVerb)
 
         pSdClient->DoVerb(nVerb);   // if necessary, ErrCode is outputted by Sfx
         pViewShell->GetViewFrame()->GetBindings().Invalidate(
-            SID_NAVIGATOR_STATE, sal_True, sal_False);
+            SID_NAVIGATOR_STATE, true);
     }
 
-    GetDocSh()->SetWaitCursor( sal_False );
+    GetDocSh()->SetWaitCursor( false );
 
     if (aErrCode != 0 && !bAbort)
     {
@@ -910,25 +886,23 @@ void ViewShell::ReadUserData(const OUString&)
 {
     // zoom onto VisArea from FrameView
     GetViewShell()->GetViewFrame()->GetDispatcher()->Execute(SID_SIZE_VISAREA,
-        SFX_CALLMODE_ASYNCHRON | SFX_CALLMODE_RECORD);
+        SfxCallMode::ASYNCHRON | SfxCallMode::RECORD);
 }
 
-
 void ViewShell::WriteUserData(OUString&)
 {
     // writing of our data is always done in WriteFrameViewData()
     WriteFrameViewData();
 }
 
-
 /**
  * Switch ruler on/off
  */
-void ViewShell::SetRuler(sal_Bool bRuler)
+void ViewShell::SetRuler(bool bRuler)
 {
     mbHasRulers = ( bRuler && !GetDocSh()->IsPreview() ); // no rulers on preview mode
 
-    if (mpHorizontalRuler.get() != NULL)
+    if (mpHorizontalRuler.get() != nullptr)
     {
         if (mbHasRulers)
         {
@@ -940,7 +914,7 @@ void ViewShell::SetRuler(sal_Bool bRuler)
         }
     }
 
-    if (mpVerticalRuler.get() != NULL)
+    if (mpVerticalRuler.get() != nullptr)
     {
         if (mbHasRulers)
         {
@@ -952,12 +926,11 @@ void ViewShell::SetRuler(sal_Bool bRuler)
         }
     }
 
-    OSL_ASSERT(GetViewShell()!=NULL);
+    OSL_ASSERT(GetViewShell()!=nullptr);
     if (IsMainViewShell())
         GetViewShell()->InvalidateBorder();
 }
 
-
 sal_Int8 ViewShell::AcceptDrop (
     const AcceptDropEvent& rEvt,
     DropTargetHelper& rTargetHelper,
@@ -969,32 +942,30 @@ sal_Int8 ViewShell::AcceptDrop (
     return( pView ? pView->AcceptDrop( rEvt, rTargetHelper, pTargetWindow, nPage, nLayer ) : DND_ACTION_NONE );
 }
 
-
 sal_Int8 ViewShell::ExecuteDrop (
     const ExecuteDropEvent& rEvt,
-    DropTargetHelper& rTargetHelper,
+    DropTargetHelper& /*rTargetHelper*/,
     ::sd::Window* pTargetWindow,
     sal_uInt16 nPage,
     sal_uInt16 nLayer)
 {
     ::sd::View* pView = GetView();
-    return( pView ? pView->ExecuteDrop( rEvt, rTargetHelper, pTargetWindow, nPage, nLayer ) : DND_ACTION_NONE );
+    return pView ? pView->ExecuteDrop( rEvt, pTargetWindow, nPage, nLayer ) : DND_ACTION_NONE;
 }
 
-void ViewShell::WriteUserDataSequence ( ::com::sun::star::uno::Sequence <
-    ::com::sun::star::beans::PropertyValue >& rSequence, sal_Bool bBrowse)
+void ViewShell::WriteUserDataSequence ( css::uno::Sequence < css::beans::PropertyValue >& rSequence, bool bBrowse)
 {
     const sal_Int32 nIndex = rSequence.getLength();
     rSequence.realloc( nIndex + 1 );
 
-    OSL_ASSERT (GetViewShell()!=NULL);
+    OSL_ASSERT (GetViewShell()!=nullptr);
     // Get the view id from the view shell in the center pane.  This will
     // usually be the called view shell, but to be on the safe side we call
     // the main view shell explicitly.
     sal_uInt16 nViewID (IMPRESS_FACTORY_ID);
-    if (GetViewShellBase().GetMainViewShell().get() != NULL)
+    if (GetViewShellBase().GetMainViewShell().get() != nullptr)
         nViewID = GetViewShellBase().GetMainViewShell()->mpImpl->GetViewId();
-    rSequence[nIndex].Name = OUString( sUNO_View_ViewId );
+    rSequence[nIndex].Name = sUNO_View_ViewId;
     OUStringBuffer sBuffer( "view" );
     sBuffer.append( static_cast<sal_Int32>(nViewID));
     rSequence[nIndex].Value <<= sBuffer.makeStringAndClear();
@@ -1002,21 +973,20 @@ void ViewShell::WriteUserDataSequence ( ::com::sun::star::uno::Sequence <
     mpFrameView->WriteUserDataSequence( rSequence, bBrowse );
 }
 
-
-void ViewShell::ReadUserDataSequence ( const ::com::sun::star::uno::Sequence < ::com::sun::star::beans::PropertyValue >& rSequence, sal_Bool bBrowse )
+void ViewShell::ReadUserDataSequence ( const css::uno::Sequence < css::beans::PropertyValue >& rSequence, bool bBrowse )
 {
     mpFrameView->ReadUserDataSequence( rSequence, bBrowse );
 }
 
 void ViewShell::VisAreaChanged(const Rectangle& rRect)
 {
-    OSL_ASSERT (GetViewShell()!=NULL);
+    OSL_ASSERT (GetViewShell()!=nullptr);
     GetViewShell()->VisAreaChanged(rRect);
 }
 
 void ViewShell::SetWinViewPos(const Point& rWinPos, bool bUpdate)
 {
-    if (mpContentWindow.get() != NULL)
+    if (mpContentWindow.get() != nullptr)
     {
         mpContentWindow->SetWinViewPos(rWinPos);
 
