@@ -37,8 +37,8 @@
 #include <com/sun/star/rendering/XIntegerBitmap.hpp>
 #include <com/sun/star/rendering/XSpriteCanvas.hpp>
 #include <map>
+#include <memory>
 #include <vector>
-#include <boost/shared_ptr.hpp>
 
 using namespace ::com::sun::star;
 using namespace ::com::sun::star::uno;
@@ -49,9 +49,7 @@ namespace {
     class BorderSize
     {
     public:
-        BorderSize (void);
-        BorderSize (const BorderSize& rBorderSize);
-        BorderSize& operator= (const BorderSize& rBoderSize);
+        BorderSize();
         sal_Int32 mnLeft;
         sal_Int32 mnTop;
         sal_Int32 mnRight;
@@ -62,7 +60,7 @@ namespace {
     {
     public:
         RendererPaneStyle (
-            const ::boost::shared_ptr<PresenterTheme>& rpTheme,
+            const std::shared_ptr<PresenterTheme>& rpTheme,
             const OUString& rsStyleName);
 
         awt::Rectangle AddBorder (
@@ -88,15 +86,16 @@ namespace {
         PresenterTheme::SharedFontDescriptor mpFont;
         sal_Int32 mnFontXOffset;
         sal_Int32 mnFontYOffset;
-        enum Anchor { AnchorLeft, AnchorRight, AnchorCenter } meFontAnchor;
+        enum class Anchor { Left, Right, Center };
+        Anchor meFontAnchor;
         BorderSize maInnerBorderSize;
         BorderSize maOuterBorderSize;
         BorderSize maTotalBorderSize;
         enum Side { Left, Top, Right, Bottom };
     private:
-        void UpdateBorderSizes (void);
+        void UpdateBorderSizes();
         SharedBitmapDescriptor GetBitmap(
-            const ::boost::shared_ptr<PresenterTheme>& rpTheme,
+            const std::shared_ptr<PresenterTheme>& rpTheme,
             const OUString& rsStyleName,
             const OUString& rsBitmapName);
     };
@@ -107,8 +106,8 @@ class  PresenterPaneBorderPainter::Renderer
 public:
     Renderer (
         const Reference<XComponentContext>& rxContext,
-        const ::boost::shared_ptr<PresenterTheme>& rpTheme);
-    ~Renderer (void);
+        const std::shared_ptr<PresenterTheme>& rpTheme);
+    ~Renderer();
 
     void SetCanvas (const Reference<rendering::XCanvas>& rxCanvas);
     void PaintBorder (
@@ -118,7 +117,7 @@ public:
         const OUString& rsPaneURL);
     void PaintTitle (
         const OUString& rsTitle,
-        const ::boost::shared_ptr<RendererPaneStyle>& rpStyle,
+        const std::shared_ptr<RendererPaneStyle>& rpStyle,
         const awt::Rectangle& rUpdateBox,
         const awt::Rectangle& rOuterBox,
         const awt::Rectangle& rInnerBox,
@@ -127,13 +126,13 @@ public:
         const awt::Rectangle& rUpdateBox,
         const awt::Rectangle& rOuterBox,
         const OUString& rsPaneStyleName);
-    ::boost::shared_ptr<RendererPaneStyle> GetRendererPaneStyle (const OUString& rsResourceURL);
+    std::shared_ptr<RendererPaneStyle> GetRendererPaneStyle (const OUString& rsResourceURL);
     void SetCalloutAnchor (
         const awt::Point& rCalloutAnchor);
 
 private:
-    ::boost::shared_ptr<PresenterTheme> mpTheme;
-    typedef ::std::map<OUString, ::boost::shared_ptr<RendererPaneStyle> > RendererPaneStyleContainer;
+    std::shared_ptr<PresenterTheme> mpTheme;
+    typedef ::std::map<OUString, std::shared_ptr<RendererPaneStyle> > RendererPaneStyleContainer;
     RendererPaneStyleContainer maRendererPaneStyles;
     Reference<rendering::XCanvas> mxCanvas;
     Reference<drawing::XPresenterHelper> mxPresenterHelper;
@@ -165,7 +164,7 @@ PresenterPaneBorderPainter::PresenterPaneBorderPainter (
 {
 }
 
-PresenterPaneBorderPainter::~PresenterPaneBorderPainter (void)
+PresenterPaneBorderPainter::~PresenterPaneBorderPainter()
 {
 }
 
@@ -175,7 +174,7 @@ awt::Rectangle SAL_CALL PresenterPaneBorderPainter::addBorder (
     const OUString& rsPaneBorderStyleName,
     const css::awt::Rectangle& rRectangle,
     drawing::framework::BorderType eBorderType)
-    throw(css::uno::RuntimeException)
+    throw(css::uno::RuntimeException, std::exception)
 {
     ThrowIfDisposed();
 
@@ -188,7 +187,7 @@ awt::Rectangle SAL_CALL PresenterPaneBorderPainter::removeBorder (
     const OUString& rsPaneBorderStyleName,
     const css::awt::Rectangle& rRectangle,
     drawing::framework::BorderType eBorderType)
-    throw(css::uno::RuntimeException)
+    throw(css::uno::RuntimeException, std::exception)
 {
     ThrowIfDisposed();
 
@@ -203,7 +202,7 @@ void SAL_CALL PresenterPaneBorderPainter::paintBorder (
     const css::awt::Rectangle& rOuterBorderRectangle,
     const css::awt::Rectangle& rRepaintArea,
     const OUString& rsTitle)
-    throw(css::uno::RuntimeException)
+    throw(css::uno::RuntimeException, std::exception)
 {
     ThrowIfDisposed();
 
@@ -217,7 +216,7 @@ void SAL_CALL PresenterPaneBorderPainter::paintBorder (
     }
     ProvideTheme(rxCanvas);
 
-    if (mpRenderer.get() != NULL)
+    if (mpRenderer.get() != nullptr)
     {
         mpRenderer->SetCanvas(rxCanvas);
         mpRenderer->SetupClipping(
@@ -239,7 +238,7 @@ void SAL_CALL PresenterPaneBorderPainter::paintBorderWithCallout (
     const css::awt::Rectangle& rRepaintArea,
     const OUString& rsTitle,
     const css::awt::Point& rCalloutAnchor)
-    throw(css::uno::RuntimeException)
+    throw(css::uno::RuntimeException, std::exception)
 {
     ThrowIfDisposed();
 
@@ -253,7 +252,7 @@ void SAL_CALL PresenterPaneBorderPainter::paintBorderWithCallout (
     }
     ProvideTheme(rxCanvas);
 
-    if (mpRenderer.get() != NULL)
+    if (mpRenderer.get() != nullptr)
     {
         mpRenderer->SetCanvas(rxCanvas);
         mpRenderer->SetupClipping(
@@ -271,16 +270,16 @@ void SAL_CALL PresenterPaneBorderPainter::paintBorderWithCallout (
 
 awt::Point SAL_CALL PresenterPaneBorderPainter::getCalloutOffset (
     const OUString& rsPaneBorderStyleName)
-    throw(css::uno::RuntimeException)
+    throw(css::uno::RuntimeException, std::exception)
 {
     ThrowIfDisposed();
     ProvideTheme();
-    if (mpRenderer.get() != NULL)
+    if (mpRenderer.get() != nullptr)
     {
-        const ::boost::shared_ptr<RendererPaneStyle> pRendererPaneStyle(
+        const std::shared_ptr<RendererPaneStyle> pRendererPaneStyle(
             mpRenderer->GetRendererPaneStyle(rsPaneBorderStyleName));
-        if (pRendererPaneStyle.get() != NULL
-            && pRendererPaneStyle->mpBottomCallout.get() != NULL)
+        if (pRendererPaneStyle.get() != nullptr
+            && pRendererPaneStyle->mpBottomCallout.get() != nullptr)
         {
             return awt::Point (
                 0,
@@ -292,7 +291,7 @@ awt::Point SAL_CALL PresenterPaneBorderPainter::getCalloutOffset (
     return awt::Point(0,0);
 }
 
-//-----------------------------------------------------------------------------
+
 
 bool PresenterPaneBorderPainter::ProvideTheme (const Reference<rendering::XCanvas>& rxCanvas)
 {
@@ -301,7 +300,7 @@ bool PresenterPaneBorderPainter::ProvideTheme (const Reference<rendering::XCanva
     if ( ! mxContext.is())
         return false;
 
-    if (mpTheme.get() != NULL)
+    if (mpTheme.get() != nullptr)
     {
         // Check if the theme already has a canvas.
         if ( ! mpTheme->HasCanvas())
@@ -316,9 +315,9 @@ bool PresenterPaneBorderPainter::ProvideTheme (const Reference<rendering::XCanva
         bModified = true;
     }
 
-    if (mpTheme.get() != NULL && bModified)
+    if (mpTheme.get() != nullptr && bModified)
     {
-        if (mpRenderer.get() == NULL)
+        if (mpRenderer.get() == nullptr)
             mpRenderer.reset(new Renderer(mxContext, mpTheme));
         else
             mpRenderer->SetCanvas(rxCanvas);
@@ -327,12 +326,12 @@ bool PresenterPaneBorderPainter::ProvideTheme (const Reference<rendering::XCanva
     return bModified;
 }
 
-bool PresenterPaneBorderPainter::ProvideTheme (void)
+bool PresenterPaneBorderPainter::ProvideTheme()
 {
-    if (mpTheme.get() == NULL)
+    if (mpTheme.get() == nullptr)
     {
         // Create a theme without bitmaps (no canvas => no bitmaps).
-        return ProvideTheme(NULL);
+        return ProvideTheme(nullptr);
     }
     else
     {
@@ -342,10 +341,10 @@ bool PresenterPaneBorderPainter::ProvideTheme (void)
     }
 }
 
-void PresenterPaneBorderPainter::SetTheme (const ::boost::shared_ptr<PresenterTheme>& rpTheme)
+void PresenterPaneBorderPainter::SetTheme (const std::shared_ptr<PresenterTheme>& rpTheme)
 {
     mpTheme = rpTheme;
-    if (mpRenderer.get() == NULL)
+    if (mpRenderer.get() == nullptr)
         mpRenderer.reset(new Renderer(mxContext, mpTheme));
 }
 
@@ -354,10 +353,10 @@ awt::Rectangle PresenterPaneBorderPainter::AddBorder (
     const awt::Rectangle& rInnerBox,
     const css::drawing::framework::BorderType eBorderType) const
 {
-    if (mpRenderer.get() != NULL)
+    if (mpRenderer.get() != nullptr)
     {
-        const ::boost::shared_ptr<RendererPaneStyle> pRendererPaneStyle(mpRenderer->GetRendererPaneStyle(rsPaneURL));
-        if (pRendererPaneStyle.get() != NULL)
+        const std::shared_ptr<RendererPaneStyle> pRendererPaneStyle(mpRenderer->GetRendererPaneStyle(rsPaneURL));
+        if (pRendererPaneStyle.get() != nullptr)
             return pRendererPaneStyle->AddBorder(rInnerBox, eBorderType);
     }
     return rInnerBox;
@@ -368,17 +367,17 @@ awt::Rectangle PresenterPaneBorderPainter::RemoveBorder (
     const css::awt::Rectangle& rOuterBox,
     const css::drawing::framework::BorderType eBorderType) const
 {
-    if (mpRenderer.get() != NULL)
+    if (mpRenderer.get() != nullptr)
     {
-        const ::boost::shared_ptr<RendererPaneStyle> pRendererPaneStyle(mpRenderer->GetRendererPaneStyle(rsPaneURL));
-        if (pRendererPaneStyle.get() != NULL)
+        const std::shared_ptr<RendererPaneStyle> pRendererPaneStyle(mpRenderer->GetRendererPaneStyle(rsPaneURL));
+        if (pRendererPaneStyle.get() != nullptr)
             return pRendererPaneStyle->RemoveBorder(rOuterBox, eBorderType);
     }
     return rOuterBox;
 }
 
-void PresenterPaneBorderPainter::ThrowIfDisposed (void) const
-    throw (::com::sun::star::lang::DisposedException)
+void PresenterPaneBorderPainter::ThrowIfDisposed() const
+    throw (css::lang::DisposedException)
 {
     if (rBHelper.bDisposed || rBHelper.bInDispose)
     {
@@ -393,12 +392,12 @@ void PresenterPaneBorderPainter::ThrowIfDisposed (void) const
 
 PresenterPaneBorderPainter::Renderer::Renderer (
     const Reference<XComponentContext>& rxContext,
-    const ::boost::shared_ptr<PresenterTheme>& rpTheme)
+    const std::shared_ptr<PresenterTheme>& rpTheme)
     : mpTheme(rpTheme),
       maRendererPaneStyles(),
       mxCanvas(),
       mxPresenterHelper(),
-      maViewState(geometry::AffineMatrix2D(1,0,0, 0,1,0), NULL),
+      maViewState(geometry::AffineMatrix2D(1,0,0, 0,1,0), nullptr),
       mxViewStateClip(),
       mbHasCallout(false),
       maCalloutAnchor()
@@ -408,15 +407,15 @@ PresenterPaneBorderPainter::Renderer::Renderer (
     Reference<lang::XMultiComponentFactory> xFactory (rxContext->getServiceManager());
     if (xFactory.is())
     {
-        mxPresenterHelper = Reference<drawing::XPresenterHelper>(
+        mxPresenterHelper.set(
             xFactory->createInstanceWithContext(
-                OUString("com.sun.star.comp.Draw.PresenterHelper"),
+                "com.sun.star.comp.Draw.PresenterHelper",
                 rxContext),
             UNO_QUERY_THROW);
     }
 }
 
-PresenterPaneBorderPainter::Renderer::~Renderer (void)
+PresenterPaneBorderPainter::Renderer::~Renderer()
 {
 }
 
@@ -438,8 +437,8 @@ void PresenterPaneBorderPainter::Renderer::PaintBorder (
         return;
 
     // Create the outer and inner border of the, ahm, border.
-    ::boost::shared_ptr<RendererPaneStyle> pStyle (GetRendererPaneStyle(rsPaneURL));
-    if (pStyle.get() == NULL)
+    std::shared_ptr<RendererPaneStyle> pStyle (GetRendererPaneStyle(rsPaneURL));
+    if (pStyle.get() == nullptr)
         return;
 
     awt::Rectangle aOuterBox (rBBox);
@@ -507,7 +506,7 @@ void PresenterPaneBorderPainter::Renderer::PaintBorder (
 
 void PresenterPaneBorderPainter::Renderer::PaintTitle (
     const OUString& rsTitle,
-    const ::boost::shared_ptr<RendererPaneStyle>& rpStyle,
+    const std::shared_ptr<RendererPaneStyle>& rpStyle,
     const awt::Rectangle& rUpdateBox,
     const awt::Rectangle& rOuterBox,
     const awt::Rectangle& rInnerBox,
@@ -538,21 +537,20 @@ void PresenterPaneBorderPainter::Renderer::PaintTitle (
     geometry::RealRectangle2D aBox (xLayout->queryTextBounds());
     const double nTextHeight = aBox.Y2 - aBox.Y1;
     const double nTextWidth = aBox.X1 + aBox.X2;
-    double nX = rInnerBox.X + (rInnerBox.Width - nTextWidth)/2;
     const sal_Int32 nTitleBarHeight = rInnerBox.Y - rOuterBox.Y - 1;
     double nY = rOuterBox.Y + (nTitleBarHeight - nTextHeight) / 2 - aBox.Y1;
     if (nY >= rInnerBox.Y)
         nY = rInnerBox.Y - 1;
+    double nX;
     switch (rpStyle->meFontAnchor)
     {
-        default:
-        case RendererPaneStyle::AnchorLeft:
+    case RendererPaneStyle::Anchor::Left:
         nX = rInnerBox.X;
         break;
-        case RendererPaneStyle::AnchorRight:
+    case RendererPaneStyle::Anchor::Right:
         nX = rInnerBox.X + rInnerBox.Width - nTextWidth;
         break;
-        case RendererPaneStyle::AnchorCenter:
+    default: // RendererPaneStyle::Anchor::Center
         nX = rInnerBox.X + (rInnerBox.Width - nTextWidth)/2;
         break;
     }
@@ -569,7 +567,7 @@ void PresenterPaneBorderPainter::Renderer::PaintTitle (
 
     rendering::RenderState aRenderState(
         geometry::AffineMatrix2D(1,0,nX, 0,1,nY),
-        NULL,
+        nullptr,
         Sequence<double>(4),
         rendering::CompositeOperation::SOURCE);
 
@@ -604,10 +602,10 @@ void PresenterPaneBorderPainter::Renderer::PaintTitle (
     }
 }
 
-::boost::shared_ptr<RendererPaneStyle>
+std::shared_ptr<RendererPaneStyle>
     PresenterPaneBorderPainter::Renderer::GetRendererPaneStyle (const OUString& rsResourceURL)
 {
-    OSL_ASSERT(mpTheme.get()!=NULL);
+    OSL_ASSERT(mpTheme.get()!=nullptr);
 
     RendererPaneStyleContainer::const_iterator iStyle (maRendererPaneStyles.find(rsResourceURL));
     if (iStyle == maRendererPaneStyles.end())
@@ -620,7 +618,7 @@ void PresenterPaneBorderPainter::Renderer::PaintTitle (
             sPaneStyleName = sStyleName;
 
         // Create a new pane style object and initialize it with bitmaps.
-        ::boost::shared_ptr<RendererPaneStyle> pStyle (
+        std::shared_ptr<RendererPaneStyle> pStyle (
             new RendererPaneStyle(mpTheme,sPaneStyleName));
         iStyle = maRendererPaneStyles.insert(
             RendererPaneStyleContainer::value_type(rsResourceURL, pStyle)).first;
@@ -628,7 +626,7 @@ void PresenterPaneBorderPainter::Renderer::PaintTitle (
     if (iStyle != maRendererPaneStyles.end())
         return iStyle->second;
     else
-        return ::boost::shared_ptr<RendererPaneStyle>();
+        return std::shared_ptr<RendererPaneStyle>();
 }
 
 void PresenterPaneBorderPainter::Renderer::SetCalloutAnchor (
@@ -736,7 +734,7 @@ void PresenterPaneBorderPainter::Renderer::PaintBitmap(
         geometry::AffineMatrix2D(
             double(nW)/rpBitmap->mnWidth, 0, nX,
             0, double(nH)/rpBitmap->mnHeight, nY),
-        NULL,
+        nullptr,
         Sequence<double>(4),
         rendering::CompositeOperation::OVER);
 
@@ -752,14 +750,14 @@ void PresenterPaneBorderPainter::Renderer::SetupClipping (
     const awt::Rectangle& rOuterBox,
     const OUString& rsPaneStyleName)
 {
-    mxViewStateClip = NULL;
-    maViewState.Clip = NULL;
+    mxViewStateClip = nullptr;
+    maViewState.Clip = nullptr;
 
     if ( ! mxCanvas.is())
         return;
 
-    ::boost::shared_ptr<RendererPaneStyle> pStyle (GetRendererPaneStyle(rsPaneStyleName));
-    if (pStyle.get() == NULL)
+    std::shared_ptr<RendererPaneStyle> pStyle (GetRendererPaneStyle(rsPaneStyleName));
+    if (pStyle.get() == nullptr)
     {
         mxViewStateClip = PresenterGeometryHelper::CreatePolygon(
             rUpdateBox,
@@ -785,7 +783,7 @@ namespace {
 
 //===== BorderSize ============================================================
 
-BorderSize::BorderSize (void)
+BorderSize::BorderSize()
     : mnLeft(0),
       mnTop(0),
       mnRight(0),
@@ -793,30 +791,10 @@ BorderSize::BorderSize (void)
 {
 }
 
-BorderSize::BorderSize (const BorderSize& rBorderSize)
-    : mnLeft(rBorderSize.mnLeft),
-      mnTop(rBorderSize.mnTop),
-      mnRight(rBorderSize.mnRight),
-      mnBottom(rBorderSize.mnBottom)
-{
-}
-
-BorderSize& BorderSize::operator= (const BorderSize& rBorderSize)
-{
-    if (&rBorderSize != this)
-    {
-        mnLeft = rBorderSize.mnLeft;
-        mnTop = rBorderSize.mnTop;
-        mnRight = rBorderSize.mnRight;
-        mnBottom = rBorderSize.mnBottom;
-    }
-    return *this;
-}
-
 //===== RendererPaneStyle  ============================================================
 
 RendererPaneStyle::RendererPaneStyle (
-    const ::boost::shared_ptr<PresenterTheme>& rpTheme,
+    const std::shared_ptr<PresenterTheme>& rpTheme,
     const OUString& rsStyleName)
     : mpTopLeft(),
       mpTop(),
@@ -832,12 +810,12 @@ RendererPaneStyle::RendererPaneStyle (
       mpFont(),
       mnFontXOffset(0),
       mnFontYOffset(0),
-      meFontAnchor(AnchorCenter),
+      meFontAnchor(Anchor::Center),
       maInnerBorderSize(),
       maOuterBorderSize(),
       maTotalBorderSize()
 {
-    if (rpTheme.get() != NULL)
+    if (rpTheme.get() != nullptr)
     {
         mpTopLeft = GetBitmap(rpTheme, rsStyleName, "TopLeft");
         mpTop = GetBitmap(rpTheme, rsStyleName, "Top");
@@ -854,7 +832,7 @@ RendererPaneStyle::RendererPaneStyle (
         mpFont = rpTheme->GetFont(rsStyleName);
 
         OUString sAnchor ("Left");
-        if (mpFont.get() != NULL)
+        if (mpFont.get() != nullptr)
         {
             sAnchor = mpFont->msAnchor;
             mnFontXOffset = mpFont->mnXOffset;
@@ -862,11 +840,11 @@ RendererPaneStyle::RendererPaneStyle (
         }
 
         if ( sAnchor == "Left" )
-            meFontAnchor = AnchorLeft;
+            meFontAnchor = Anchor::Left;
         else if ( sAnchor == "Right" )
-            meFontAnchor = AnchorRight;
+            meFontAnchor = Anchor::Right;
         else
-            meFontAnchor = AnchorCenter;
+            meFontAnchor = Anchor::Center;
 
         // Get border sizes.
         try
@@ -898,7 +876,7 @@ awt::Rectangle RendererPaneStyle::AddBorder (
     const awt::Rectangle& rBox,
     const drawing::framework::BorderType eBorderType) const
 {
-    const BorderSize* pBorderSize = NULL;
+    const BorderSize* pBorderSize = nullptr;
     switch (eBorderType)
     {
         case drawing::framework::BorderType_INNER_BORDER:
@@ -924,7 +902,7 @@ awt::Rectangle RendererPaneStyle::RemoveBorder (
     const awt::Rectangle& rBox,
     const css::drawing::framework::BorderType eBorderType) const
 {
-    const BorderSize* pBorderSize = NULL;
+    const BorderSize* pBorderSize = nullptr;
     switch (eBorderType)
     {
         case drawing::framework::BorderType_INNER_BORDER:
@@ -949,12 +927,12 @@ awt::Rectangle RendererPaneStyle::RemoveBorder (
 const Reference<rendering::XCanvasFont> RendererPaneStyle::GetFont (
     const Reference<rendering::XCanvas>& rxCanvas) const
 {
-    if (mpFont.get() != NULL)
+    if (mpFont.get() != nullptr)
         mpFont->PrepareFont(rxCanvas);
     return mpFont->mxFont;
 }
 
-void RendererPaneStyle::UpdateBorderSizes (void)
+void RendererPaneStyle::UpdateBorderSizes()
 {
     maTotalBorderSize.mnLeft = maInnerBorderSize.mnLeft + maOuterBorderSize.mnLeft;
     maTotalBorderSize.mnTop = maInnerBorderSize.mnTop + maOuterBorderSize.mnTop;
@@ -963,12 +941,12 @@ void RendererPaneStyle::UpdateBorderSizes (void)
 }
 
 SharedBitmapDescriptor RendererPaneStyle::GetBitmap(
-    const ::boost::shared_ptr<PresenterTheme>& rpTheme,
+    const std::shared_ptr<PresenterTheme>& rpTheme,
     const OUString& rsStyleName,
     const OUString& rsBitmapName)
 {
     SharedBitmapDescriptor pDescriptor (rpTheme->GetBitmap(rsStyleName, rsBitmapName));
-    if (pDescriptor.get() != NULL)
+    if (pDescriptor.get() != nullptr)
         return pDescriptor;
     else
         return mpEmpty;
