@@ -35,7 +35,6 @@
 #include <com/sun/star/drawing/XSlideSorterBase.hpp>
 #include <com/sun/star/presentation/XSlideShow.hpp>
 #include <com/sun/star/presentation/XSlideShowView.hpp>
-#include <cppuhelper/compbase1.hxx>
 #include <boost/bind.hpp>
 
 using namespace ::com::sun::star;
@@ -74,10 +73,10 @@ public:
         : PresenterSlidePreview(rxContext, rxViewId, rxAnchorPane, rpPresenterController)
     {
     }
-    virtual ~NextSlidePreview (void) {}
+    virtual ~NextSlidePreview() {}
     virtual void SAL_CALL setCurrentPage (
         const css::uno::Reference<css::drawing::XDrawPage>& rxSlide)
-        throw (css::uno::RuntimeException, std::exception) SAL_OVERRIDE
+        throw (css::uno::RuntimeException, std::exception) override
     {
         Reference<presentation::XSlideShowController> xSlideShowController (
             mpPresenterController->GetSlideShowController());
@@ -105,7 +104,7 @@ public:
             {
                 if (nNextSlideIndex < nCount)
                 {
-                    xSlide = Reference<drawing::XDrawPage>(
+                    xSlide.set(
                         xSlideShowController->getSlideByIndex(nNextSlideIndex),
                          UNO_QUERY);
                 }
@@ -170,24 +169,24 @@ void PresenterViewFactory::Register (const Reference<frame::XController>& rxCont
         OSL_ASSERT(false);
         if (mxConfigurationController.is())
             mxConfigurationController->removeResourceFactoryForReference(this);
-        mxConfigurationController = NULL;
+        mxConfigurationController = nullptr;
 
         throw;
     }
 }
 
-PresenterViewFactory::~PresenterViewFactory (void)
+PresenterViewFactory::~PresenterViewFactory()
 {
 }
 
-void SAL_CALL PresenterViewFactory::disposing (void)
+void SAL_CALL PresenterViewFactory::disposing()
     throw (RuntimeException)
 {
     if (mxConfigurationController.is())
         mxConfigurationController->removeResourceFactoryForReference(this);
-    mxConfigurationController = NULL;
+    mxConfigurationController = nullptr;
 
-    if (mpResourceCache.get() != NULL)
+    if (mpResourceCache.get() != nullptr)
     {
         // Dispose all views in the cache.
         ResourceContainer::const_iterator iView (mpResourceCache->begin());
@@ -224,13 +223,13 @@ Reference<XResource> SAL_CALL PresenterViewFactory::createResource (
             mxConfigurationController->getResource(rxViewId->getAnchor()),
             UNO_QUERY_THROW);
         xView = GetViewFromCache(rxViewId, xAnchorPane);
-        if (xView == NULL)
+        if (xView == nullptr)
             xView = CreateView(rxViewId, xAnchorPane);
 
         // Activate the view.
         PresenterPaneContainer::SharedPaneDescriptor pDescriptor (
             mpPresenterController->GetPaneContainer()->FindPaneId(rxViewId->getAnchor()));
-        if (pDescriptor.get() != NULL)
+        if (pDescriptor.get() != nullptr)
             pDescriptor->SetActivationState(true);
     }
 
@@ -249,16 +248,16 @@ void SAL_CALL PresenterViewFactory::releaseResource (const Reference<XResource>&
     PresenterPaneContainer::SharedPaneDescriptor pDescriptor (
         mpPresenterController->GetPaneContainer()->FindPaneId(
             rxView->getResourceId()->getAnchor()));
-    if (pDescriptor.get() != NULL)
+    if (pDescriptor.get() != nullptr)
         pDescriptor->SetActivationState(false);
 
     // Dispose only views that we can not put into the cache.
     CachablePresenterView* pView = dynamic_cast<CachablePresenterView*>(rxView.get());
-    if (pView == NULL || mpResourceCache.get()==NULL)
+    if (pView == nullptr || mpResourceCache.get()==nullptr)
     {
         try
         {
-            if (pView != NULL)
+            if (pView != nullptr)
                 pView->ReleaseView();
             Reference<lang::XComponent> xComponent (rxView, UNO_QUERY);
             if (xComponent.is())
@@ -293,8 +292,8 @@ Reference<XResource> PresenterViewFactory::GetViewFromCache(
     const Reference<XResourceId>& rxViewId,
     const Reference<XPane>& rxAnchorPane) const
 {
-    if (mpResourceCache.get() == NULL)
-        return NULL;
+    if (mpResourceCache.get() == nullptr)
+        return nullptr;
 
     try
     {
@@ -311,7 +310,7 @@ Reference<XResource> PresenterViewFactory::GetViewFromCache(
             {
                 CachablePresenterView* pView
                     = dynamic_cast<CachablePresenterView*>(iView->second.first.get());
-                if (pView != NULL)
+                if (pView != nullptr)
                     pView->ActivatePresenterView();
                 return Reference<XResource>(iView->second.first, UNO_QUERY);
             }
@@ -322,7 +321,7 @@ Reference<XResource> PresenterViewFactory::GetViewFromCache(
     catch (RuntimeException&)
     {
     }
-    return NULL;
+    return nullptr;
 }
 
 Reference<XResource> PresenterViewFactory::CreateView(
@@ -362,12 +361,12 @@ Reference<XResource> PresenterViewFactory::CreateView(
 
         // Activate it.
         CachablePresenterView* pView = dynamic_cast<CachablePresenterView*>(xView.get());
-        if (pView != NULL)
+        if (pView != nullptr)
             pView->ActivatePresenterView();
     }
     catch (RuntimeException&)
     {
-        xView = NULL;
+        xView = nullptr;
     }
 
     return xView;
@@ -392,11 +391,11 @@ Reference<XView> PresenterViewFactory::CreateSlideShowView(
                 Reference<frame::XController>(mxControllerWeak),
                 mpPresenterController));
         pShowView->LateInit();
-        xView = Reference<XView>(pShowView.get());
+        xView.set(pShowView.get());
     }
     catch (RuntimeException&)
     {
-        xView = NULL;
+        xView = nullptr;
     }
 
     return xView;
@@ -415,7 +414,7 @@ Reference<XView> PresenterViewFactory::CreateSlidePreviewView(
 
     try
     {
-        xView = Reference<XView>(
+        xView.set(
             static_cast<XWeak*>(new NextSlidePreview(
                 mxComponentContext,
                 rxViewId,
@@ -425,7 +424,7 @@ Reference<XView> PresenterViewFactory::CreateSlidePreviewView(
     }
     catch (RuntimeException&)
     {
-        xView = NULL;
+        xView = nullptr;
     }
 
     return xView;
@@ -455,7 +454,7 @@ Reference<XView> PresenterViewFactory::CreateNotesView(
 
     try
     {
-        xView = Reference<XView>(static_cast<XWeak*>(
+        xView.set(static_cast<XWeak*>(
             new PresenterNotesView(
                 mxComponentContext,
                 rxViewId,
@@ -465,7 +464,7 @@ Reference<XView> PresenterViewFactory::CreateNotesView(
     }
     catch (RuntimeException&)
     {
-        xView = NULL;
+        xView = nullptr;
     }
 
     return xView;
@@ -491,14 +490,14 @@ Reference<XView> PresenterViewFactory::CreateSlideSorterView(
                 mpPresenterController));
         PresenterPaneContainer::SharedPaneDescriptor pDescriptor (
             mpPresenterController->GetPaneContainer()->FindPaneId(rxViewId->getAnchor()));
-        if (pDescriptor.get() != NULL)
+        if (pDescriptor.get() != nullptr)
             pDescriptor->maActivator = ::boost::bind(
-                &PresenterSlideSorter::SetActiveState, pView.get(), _1);
+                &PresenterSlideSorter::SetActiveState, _1);
         xView = pView.get();
     }
     catch (RuntimeException&)
     {
-        xView = NULL;
+        xView = nullptr;
     }
 
     return xView;
@@ -514,8 +513,8 @@ Reference<XView> PresenterViewFactory::CreateHelpView(
         mpPresenterController));
 }
 
-void PresenterViewFactory::ThrowIfDisposed (void) const
-    throw (::com::sun::star::lang::DisposedException)
+void PresenterViewFactory::ThrowIfDisposed() const
+    throw (css::lang::DisposedException)
 {
     if (rBHelper.bDisposed || rBHelper.bInDispose)
     {
@@ -528,22 +527,22 @@ void PresenterViewFactory::ThrowIfDisposed (void) const
 
 //===== CachablePresenterView =================================================
 
-CachablePresenterView::CachablePresenterView (void)
+CachablePresenterView::CachablePresenterView()
     : mbIsPresenterViewActive(true)
 {
 }
 
-void CachablePresenterView::ActivatePresenterView (void)
+void CachablePresenterView::ActivatePresenterView()
 {
     mbIsPresenterViewActive = true;
 }
 
-void CachablePresenterView::DeactivatePresenterView (void)
+void CachablePresenterView::DeactivatePresenterView()
 {
     mbIsPresenterViewActive = false;
 }
 
-void CachablePresenterView::ReleaseView (void)
+void CachablePresenterView::ReleaseView()
 {
 }
 
