@@ -42,8 +42,11 @@ import com.sun.star.document.XUndoAction;
 import com.sun.star.lang.EventObject;
 import com.sun.star.lang.IndexOutOfBoundsException;
 import com.sun.star.lang.XEventListener;
+
 import java.lang.reflect.InvocationTargetException;
+
 import org.openoffice.test.tools.OfficeDocument;
+
 import com.sun.star.document.XUndoManagerSupplier;
 import com.sun.star.document.XUndoManager;
 import com.sun.star.document.XUndoManagerListener;
@@ -60,28 +63,34 @@ import com.sun.star.script.ScriptEventDescriptor;
 import com.sun.star.script.XEventAttacherManager;
 import com.sun.star.script.XLibraryContainer;
 import com.sun.star.task.XJob;
+import com.sun.star.uno.Exception;
 import com.sun.star.uno.Type;
 import com.sun.star.uno.UnoRuntime;
 import com.sun.star.uno.XComponentContext;
 import com.sun.star.util.InvalidStateException;
 import com.sun.star.util.NotLockedException;
 import com.sun.star.view.XControlAccess;
+
 import complex.sfx2.undo.CalcDocumentTest;
 import complex.sfx2.undo.ChartDocumentTest;
 import complex.sfx2.undo.DocumentTest;
 import complex.sfx2.undo.DrawDocumentTest;
 import complex.sfx2.undo.ImpressDocumentTest;
 import complex.sfx2.undo.WriterDocumentTest;
+
 import java.lang.reflect.Method;
 import java.util.ArrayList;
 import java.util.Iterator;
 import java.util.Stack;
+
 import org.junit.After;
 import org.junit.AfterClass;
 import org.junit.Before;
 import org.junit.BeforeClass;
 import org.junit.Test;
+
 import static org.junit.Assert.*;
+
 import org.openoffice.test.OfficeConnection;
 import org.openoffice.test.tools.DocumentType;
 import org.openoffice.test.tools.SpreadsheetDocument;
@@ -92,7 +101,7 @@ import org.openoffice.test.tools.SpreadsheetDocument;
  */
 public class UndoManager
 {
-    // -----------------------------------------------------------------------------------------------------------------
+
     @Before
     public void beforeTest() throws com.sun.star.uno.Exception
     {
@@ -108,7 +117,7 @@ public class UndoManager
         globalFactory.insert( m_callbackFactory );
     }
 
-    // -----------------------------------------------------------------------------------------------------------------
+
     @Test
     public void checkWriterUndo() throws Exception
     {
@@ -116,15 +125,15 @@ public class UndoManager
         impl_checkUndo();
     }
 
-    // -----------------------------------------------------------------------------------------------------------------
+
 //FIXME fails fdo#35663   @Test
-    public void checkCalcUndo() throws Exception
+    public void checkCalcUndo() throws java.lang.Exception
     {
         m_currentTestCase = new CalcDocumentTest( getORB() );
         impl_checkUndo();
     }
 
-    // -----------------------------------------------------------------------------------------------------------------
+
     @Test
     public void checkDrawUndo() throws Exception
     {
@@ -132,7 +141,7 @@ public class UndoManager
         impl_checkUndo();
     }
 
-    // -----------------------------------------------------------------------------------------------------------------
+
     @Test
     public void checkImpressUndo() throws Exception
     {
@@ -140,7 +149,7 @@ public class UndoManager
         impl_checkUndo();
     }
 
-    // -----------------------------------------------------------------------------------------------------------------
+
     @Test
     public void checkChartUndo() throws Exception
     {
@@ -148,7 +157,7 @@ public class UndoManager
         impl_checkUndo();
     }
 
-    // -----------------------------------------------------------------------------------------------------------------
+
     @Test
     public void checkBrokenScripts() throws com.sun.star.uno.Exception, InterruptedException
     {
@@ -161,7 +170,7 @@ public class UndoManager
         impl_setupBrokenBasicScript();
         final String scriptURI = "vnd.sun.star.script:default.callbacks.brokenScript?language=Basic&location=document";
 
-        // .............................................................................................................
+
         // scenario 1: Pressing a button which is bound to execute the script
         // (This is one of the many cases where SfxObjectShell::CallXScript is invoked)
 
@@ -191,7 +200,7 @@ public class UndoManager
         // auto-closed the context after the macro finished.
         assertEquals( "undo context was not auto-closed as expected", 0, m_undoListener.getCurrentUndoContextDepth() );
 
-        // .............................................................................................................
+
         // scenario 2: dispatching the script URL. Technically, this is equivalent to configuring the
         // script into a menu or toolbar, and selecting the respective menu/toolbar item
         m_callbackCalled = false;
@@ -200,7 +209,7 @@ public class UndoManager
         // same as above: The script didn't close the context, but the OOo framework should have
         assertEquals( "undo context was not auto-closed as expected", 0, m_undoListener.getCurrentUndoContextDepth() );
 
-        // .............................................................................................................
+
         // scenario 3: assigning the script to some document event, and triggering this event
         final XEventsSupplier eventSupplier = UnoRuntime.queryInterface( XEventsSupplier.class, m_currentDocument.getDocument() );
         final XNameReplace events = UnoRuntime.queryInterface( XNameReplace.class, eventSupplier.getEvents() );
@@ -217,7 +226,7 @@ public class UndoManager
         // same as above: The script didn't close the context, but the OOo framework should have
         assertEquals( "undo context was not auto-closed as expected", 0, m_undoListener.getCurrentUndoContextDepth() );
 
-        // .............................................................................................................
+
         // scenario 4: let the script enter an Undo context, but not close it, as usual.
         // Additionally, let the script close the document - the OOo framework code which cares for
         // auto-closing of Undo contexts should survive this, ideally ...
@@ -229,7 +238,7 @@ public class UndoManager
         m_currentDocument = null;
     }
 
-    // -----------------------------------------------------------------------------------------------------------------
+
     @Test
     public void checkSerialization() throws com.sun.star.uno.Exception, InterruptedException
     {
@@ -282,7 +291,7 @@ public class UndoManager
         assertEquals( "not all actions have been undone", actionCount, actionsUndone[0].intValue() );
     }
 
-    // -----------------------------------------------------------------------------------------------------------------
+
     @After
     public void afterTest()
     {
@@ -295,7 +304,7 @@ public class UndoManager
         m_callbackFactory.dispose();
     }
 
-    // -----------------------------------------------------------------------------------------------------------------
+
     /**
      * @return returns the undo manager belonging to a given document
      */
@@ -307,7 +316,7 @@ public class UndoManager
         return undoManager;
     }
 
-    // -----------------------------------------------------------------------------------------------------------------
+
     private void impl_waitFor( final Object i_condition, final int i_milliSeconds ) throws InterruptedException
     {
         synchronized( i_condition )
@@ -316,7 +325,7 @@ public class UndoManager
         }
     }
 
-    // -----------------------------------------------------------------------------------------------------------------
+
     private void impl_setupBrokenBasicScript()
     {
         try
@@ -350,7 +359,7 @@ public class UndoManager
         }
     }
 
-    // -----------------------------------------------------------------------------------------------------------------
+
     private XPropertySet impl_setupButton() throws com.sun.star.uno.Exception
     {
         // let the document create a shape
@@ -383,43 +392,36 @@ public class UndoManager
         return UnoRuntime.queryInterface( XPropertySet.class, controlModel );
     }
 
-    // -----------------------------------------------------------------------------------------------------------------
+
     private void impl_assignScript( final XPropertySet i_controlModel, final String i_interfaceName,
-        final String i_interfaceMethod, final String i_scriptURI )
+        final String i_interfaceMethod, final String i_scriptURI ) throws Exception
     {
-        try
+        final XChild modelAsChild = UnoRuntime.queryInterface( XChild.class, i_controlModel );
+        final XIndexContainer parentForm = UnoRuntime.queryInterface( XIndexContainer.class, modelAsChild.getParent() );
+
+        final XEventAttacherManager manager = UnoRuntime.queryInterface( XEventAttacherManager.class, parentForm );
+
+        int containerPosition = -1;
+        for ( int i = 0; i < parentForm.getCount(); ++i )
         {
-            final XChild modelAsChild = UnoRuntime.queryInterface( XChild.class, i_controlModel );
-            final XIndexContainer parentForm = UnoRuntime.queryInterface( XIndexContainer.class, modelAsChild.getParent() );
-
-            final XEventAttacherManager manager = UnoRuntime.queryInterface( XEventAttacherManager.class, parentForm );
-
-            int containerPosition = -1;
-            for ( int i = 0; i < parentForm.getCount(); ++i )
+            final XPropertySet child = UnoRuntime.queryInterface( XPropertySet.class, parentForm.getByIndex( i ) );
+            if ( UnoRuntime.areSame( child, i_controlModel ) )
             {
-                final XPropertySet child = UnoRuntime.queryInterface( XPropertySet.class, parentForm.getByIndex( i ) );
-                if ( UnoRuntime.areSame( child, i_controlModel ) )
-                {
-                    containerPosition = i;
-                    break;
-                }
+                containerPosition = i;
+                break;
             }
-            assertFalse( "could not find the given control model within its parent", containerPosition == -1 );
-            manager.registerScriptEvent( containerPosition, new ScriptEventDescriptor(
-                i_interfaceName,
-                i_interfaceMethod,
-                "",
-                "Script",
-                i_scriptURI
-            ) );
-        }
-        catch( com.sun.star.uno.Exception e )
-        {
-            fail( "caught an exception while assigning the script event to the button: " + e.toString() );
         }
+        assertFalse( "could not find the given control model within its parent", containerPosition == -1 );
+        manager.registerScriptEvent( containerPosition, new ScriptEventDescriptor(
+            i_interfaceName,
+            i_interfaceMethod,
+            "",
+            "Script",
+            i_scriptURI
+        ) );
     }
 
-    // -----------------------------------------------------------------------------------------------------------------
+
     private void impl_clickButton( final XPropertySet i_buttonModel ) throws NoSuchElementException, IndexOutOfBoundsException
     {
         final XControlAccess controlAccess = UnoRuntime.queryInterface( XControlAccess.class,
@@ -429,16 +431,16 @@ public class UndoManager
         final XAccessibleAction controlActions = UnoRuntime.queryInterface( XAccessibleAction.class, accessible.getAccessibleContext() );
         for ( int i=0; i<controlActions.getAccessibleActionCount(); ++i )
         {
-            if ( controlActions.getAccessibleActionDescription(i).equals( "click" ) )
+            if (controlActions.getAccessibleActionDescription(i).equals("press"))
             {
                 controlActions.doAccessibleAction(i);
                 return;
             }
         }
-        fail( "did not find the accessible action named 'click'" );
+        fail("did not find the accessible action named 'press'");
     }
 
-    // -----------------------------------------------------------------------------------------------------------------
+
     private static class UndoListener implements XUndoManagerListener
     {
         public void undoActionAdded( UndoManagerEvent i_event )
@@ -569,7 +571,7 @@ public class UndoManager
         private int     getUndoActionCount() { return m_undoCount; }
         private int     getRedoActionCount() { return m_redoCount; }
         private String  getCurrentUndoContextTitle() { return m_activeUndoContexts.peek(); }
-        private String  getMostRecentlyAddedActionTitle() { return m_mostRecentlyAddedAction; };
+        private String  getMostRecentlyAddedActionTitle() { return m_mostRecentlyAddedAction; }
         private String  getMostRecentlyUndoneTitle() { return m_mostRecentlyUndone; }
         private int     getCurrentUndoContextDepth() { return m_activeUndoContexts.size(); }
         private boolean isDisposed() { return m_isDisposed; }
@@ -604,9 +606,9 @@ public class UndoManager
         private String  m_mostRecentlyAddedAction = null;
         private String  m_mostRecentlyUndone = null;
         private final Object    m_allContextsClosedCondition = new Object();
-    };
+    }
+
 
-    // -----------------------------------------------------------------------------------------------------------------
     private void impl_checkUndo() throws Exception
     {
         System.out.println( "testing: " + m_currentTestCase.getDocumentDescription() );
@@ -640,7 +642,7 @@ public class UndoManager
         assertTrue( "document is closed, but the UndoManagerListener has not been notified of the disposal", m_undoListener.isDisposed() );
     }
 
-    // -----------------------------------------------------------------------------------------------------------------
+
     private void impl_testSingleModification( final XUndoManager i_undoManager ) throws com.sun.star.uno.Exception
     {
         m_currentTestCase.doSingleModification();
@@ -669,7 +671,7 @@ public class UndoManager
         assertEquals( "UI-Undo does not notify the listener", 2, m_undoListener.getUndoActionCount() );
     }
 
-    // -----------------------------------------------------------------------------------------------------------------
+
     private void impl_testMultipleModifications( final XUndoManager i_undoManager ) throws com.sun.star.uno.Exception
     {
         m_undoListener.reset();
@@ -697,7 +699,7 @@ public class UndoManager
         m_currentTestCase.verifyInitialDocumentState();
     }
 
-    // -----------------------------------------------------------------------------------------------------------------
+
     private void impl_testCustomUndoActions( final XUndoManager i_undoManager ) throws com.sun.star.uno.Exception
     {
         i_undoManager.clear();
@@ -756,7 +758,7 @@ public class UndoManager
         assertTrue( action1.disposed() && action2.disposed() );
     }
 
-    // -----------------------------------------------------------------------------------------------------------------
+
     private void impl_testLocking( final XUndoManager i_undoManager ) throws com.sun.star.uno.Exception
     {
         i_undoManager.reset();
@@ -798,10 +800,10 @@ public class UndoManager
         assertTrue( "unlocking the manager when it is not locked should throw", caughtExpected );
     }
 
-    // -----------------------------------------------------------------------------------------------------------------
+
     private void impl_testContextHandling( final XUndoManager i_undoManager ) throws com.sun.star.uno.Exception
     {
-        // .............................................................................................................
+
         // part I: non-empty contexts
         i_undoManager.reset();
         m_undoListener.reset();
@@ -847,11 +849,11 @@ public class UndoManager
         assertFalse( m_undoListener.wasHiddenContextLeft() );
         assertFalse( m_undoListener.hasContextBeenCancelled() );
         assertEquals( "unexpected undo context depth leaving a non-empty context", 0, m_undoListener.getCurrentUndoContextDepth() );
-        // leaving a non-empty context should have cleare the redo stack
+        // leaving a non-empty context should have cleared the redo stack
         assertArrayEquals( new String[0], i_undoManager.getAllRedoActionTitles() );
         assertTrue( m_undoListener.wasRedoStackCleared() );
 
-        // .............................................................................................................
+
         // part II: empty contexts
         i_undoManager.reset();
         m_undoListener.reset();
@@ -866,7 +868,7 @@ public class UndoManager
             i_undoManager.isUndoPossible() );
     }
 
-    // -----------------------------------------------------------------------------------------------------------------
+
     private void impl_testNestedContexts( final XUndoManager i_undoManager ) throws com.sun.star.uno.Exception
     {
         i_undoManager.reset();
@@ -894,7 +896,7 @@ public class UndoManager
         assertTrue( "nested actions not properly undone", action1.undoCalled() && action2.undoCalled() && action3.undoCalled() );
     }
 
-    // -----------------------------------------------------------------------------------------------------------------
+
     private void impl_testErrorHandling( final XUndoManager i_undoManager ) throws com.sun.star.uno.Exception
     {
         i_undoManager.reset();
@@ -1008,7 +1010,7 @@ public class UndoManager
         }
     }
 
-    // -----------------------------------------------------------------------------------------------------------------
+
     private void impl_testStackHandling( final XUndoManager i_undoManager ) throws com.sun.star.uno.Exception
     {
         i_undoManager.reset();
@@ -1034,7 +1036,7 @@ public class UndoManager
         assertFalse( "adding a new action should have cleared the Redo stack", i_undoManager.isRedoPossible() );
     }
 
-    // -----------------------------------------------------------------------------------------------------------------
+
     private void impl_testClearance( final XUndoManager i_undoManager ) throws com.sun.star.uno.Exception
     {
         i_undoManager.reset();
@@ -1096,7 +1098,7 @@ public class UndoManager
         assertEquals( "seems that |reset| did not really close the open contexts", 1, m_undoListener.getCurrentUndoContextDepth() );
     }
 
-    // -----------------------------------------------------------------------------------------------------------------
+
     private void impl_testHiddenContexts( final XUndoManager i_undoManager ) throws com.sun.star.uno.Exception
     {
         i_undoManager.reset();
@@ -1179,13 +1181,13 @@ public class UndoManager
         assertTrue( action3.undoCalled() );
     }
 
-    // -----------------------------------------------------------------------------------------------------------------
+
     private XComponentContext getContext()
     {
         return m_connection.getComponentContext();
     }
 
-    // -----------------------------------------------------------------------------------------------------------------
+
     private XMultiServiceFactory getORB()
     {
         final XMultiServiceFactory xMSF1 = UnoRuntime.queryInterface(
@@ -1193,9 +1195,9 @@ public class UndoManager
         return xMSF1;
     }
 
-    // -----------------------------------------------------------------------------------------------------------------
+
     @BeforeClass
-    public static void setUpConnection() throws Exception
+    public static void setUpConnection() throws java.lang.Exception
     {
         System.out.println( "--------------------------------------------------------------------------------" );
         System.out.println( "starting class: " + UndoManager.class.getName() );
@@ -1203,7 +1205,7 @@ public class UndoManager
         m_connection.setUp();
     }
 
-    // -----------------------------------------------------------------------------------------------------------------
+
     @AfterClass
     public static void tearDownConnection() throws InterruptedException, com.sun.star.uno.Exception
     {
@@ -1214,7 +1216,7 @@ public class UndoManager
         System.out.println( "--------------------------------------------------------------------------------" );
     }
 
-    // -----------------------------------------------------------------------------------------------------------------
+
     private static class CustomUndoAction implements XUndoAction, XComponent
     {
         CustomUndoAction()
@@ -1299,7 +1301,7 @@ public class UndoManager
         private final short m_failWhich;
     }
 
-    // -----------------------------------------------------------------------------------------------------------------
+
     private static class CountingUndoAction implements XUndoAction
     {
         CountingUndoAction( final int i_expectedOrder, final Object i_lock, final Integer[] i_actionsUndoneCounter )
@@ -1332,19 +1334,19 @@ public class UndoManager
         private Integer[]       m_actionsUndoneCounter;
     }
 
-    // -----------------------------------------------------------------------------------------------------------------
+
     private static String getCallbackUndoContextTitle()
     {
         return "Some Unfinished Undo Context";
     }
 
-    // -----------------------------------------------------------------------------------------------------------------
+
     private static String getCallbackComponentServiceName()
     {
         return "org.openoffice.complex.sfx2.Callback";
     }
 
-    // -----------------------------------------------------------------------------------------------------------------
+
     /**
      * a factory for a callback component which, at OOo runtime, is inserted into OOo's "component repository"
      */
@@ -1399,9 +1401,9 @@ public class UndoManager
         }
 
         private final ArrayList<XEventListener> m_eventListeners = new ArrayList<XEventListener>();
-    };
+    }
+
 
-    // -----------------------------------------------------------------------------------------------------------------
     private class CallbackComponent implements XJob, XTypeProvider
     {
         CallbackComponent()
@@ -1435,7 +1437,7 @@ public class UndoManager
 
         public byte[] getImplementationId()
         {
-            return getClass().toString().getBytes();
+            return new byte[0];
         }
     }
 
