@@ -17,8 +17,12 @@
  *   the License at http://www.apache.org/licenses/LICENSE-2.0 .
  */
 
-#include <config_folders.h>
+#include <sal/config.h>
 
+#include <cassert>
+
+#include <boost/logic/tribool.hpp>
+#include <config_folders.h>
 #include <shutdownicon.hxx>
 #include <app.hrc>
 #include <sfx2/app.hxx>
@@ -35,6 +39,7 @@
 #include <com/sun/star/util/URLTransformer.hpp>
 #include <com/sun/star/util/XURLTransformer.hpp>
 #include <com/sun/star/ui/dialogs/XFilePickerControlAccess.hpp>
+#include <com/sun/star/ui/dialogs/XFilePicker2.hpp>
 #include <com/sun/star/ui/dialogs/XFilterManager.hpp>
 #include <com/sun/star/ui/dialogs/TemplateDescription.hpp>
 #include <com/sun/star/ui/dialogs/ExtendedFilePickerElementIds.hpp>
@@ -45,19 +50,20 @@
 #include <sfx2/filedlghelper.hxx>
 #include <sfx2/fcontnr.hxx>
 #include <comphelper/processfactory.hxx>
-#include <cppuhelper/compbase1.hxx>
+#include <cppuhelper/implbase.hxx>
+#include <cppuhelper/supportsservice.hxx>
 #include <sfx2/dispatch.hxx>
 #include <comphelper/extract.hxx>
 #include <tools/urlobj.hxx>
 #include <osl/security.hxx>
 #include <osl/file.hxx>
 #include <rtl/bootstrap.hxx>
+#include <rtl/ref.hxx>
 #include <rtl/ustrbuf.hxx>
 #ifdef UNX // need symlink
 #include <unistd.h>
 #include <errno.h>
 #endif
-#include <vcl/timer.hxx>
 
 #include <sfx2/sfxresid.hxx>
 
@@ -70,10 +76,6 @@ using namespace ::com::sun::star::lang;
 using namespace ::com::sun::star::beans;
 using namespace ::com::sun::star::util;
 using namespace ::com::sun::star::ui::dialogs;
-#ifdef WNT
-#else
-using namespace ::rtl;
-#endif
 using namespace ::sfx2;
 
 #ifdef ENABLE_QUICKSTART_APPLET
@@ -82,33 +84,45 @@ extern "C" { static void SAL_CALL thisModule() {} }
 # endif
 #endif
 
-#if defined(UNX) && defined(ENABLE_SYSTRAY_GTK) && !defined(PLUGIN_NAME)
-#define PLUGIN_NAME "libqstart_gtklo.so"
-#endif
-
-class SfxNotificationListener_Impl : public cppu::WeakImplHelper1< XDispatchResultListener >
+class SfxNotificationListener_Impl : public cppu::WeakImplHelper< XDispatchResultListener >
 {
 public:
-    virtual void SAL_CALL dispatchFinished( const DispatchResultEvent& aEvent ) throw( RuntimeException );
-    virtual void SAL_CALL disposing( const EventObject& aEvent ) throw( RuntimeException );
+    virtual void SAL_CALL dispatchFinished( const DispatchResultEvent& aEvent ) throw( RuntimeException, std::exception ) override;
+    virtual void SAL_CALL disposing( const EventObject& aEvent ) throw( RuntimeException, std::exception ) override;
 };
 
-void SAL_CALL SfxNotificationListener_Impl::dispatchFinished( const DispatchResultEvent& ) throw( RuntimeException )
+void SAL_CALL SfxNotificationListener_Impl::dispatchFinished( const DispatchResultEvent& ) throw( RuntimeException, std::exception )
 {
     ShutdownIcon::LeaveModalMode();
 }
 
-void SAL_CALL SfxNotificationListener_Impl::disposing( const EventObject& ) throw( RuntimeException )
+void SAL_CALL SfxNotificationListener_Impl::disposing( const EventObject& ) throw( RuntimeException, std::exception )
 {
 }
 
-SFX_IMPL_XSERVICEINFO_CTX( ShutdownIcon, "com.sun.star.office.Quickstart", "com.sun.star.comp.desktop.QuickstartWrapper" )  \
-SFX_IMPL_ONEINSTANCEFACTORY( ShutdownIcon );
+OUString SAL_CALL ShutdownIcon::getImplementationName()
+    throw (css::uno::RuntimeException, std::exception)
+{
+    return OUString("com.sun.star.comp.desktop.QuickstartWrapper");
+}
+
+sal_Bool SAL_CALL ShutdownIcon::supportsService(OUString const & ServiceName)
+    throw (css::uno::RuntimeException, std::exception)
+{
+    return cppu::supportsService(this, ServiceName);
+}
+
+css::uno::Sequence<OUString> SAL_CALL ShutdownIcon::getSupportedServiceNames()
+    throw (css::uno::RuntimeException, std::exception)
+{
+    css::uno::Sequence< OUString > aSeq { "com.sun.star.office.Quickstart" };
+    return aSeq;
+}
 
 bool ShutdownIcon::bModalMode = false;
-ShutdownIcon* ShutdownIcon::pShutdownIcon = NULL;
+ShutdownIcon* ShutdownIcon::pShutdownIcon = nullptr;
 
-#if !defined( ENABLE_QUICKSTART_APPLET ) || defined( UNX )
+#if !defined( ENABLE_QUICKSTART_APPLET )
 // To remove conditionals
 extern "C" {
     static void disabled_initSystray() { }
@@ -116,116 +130,57 @@ extern "C" {
 }
 #endif
 
-bool ShutdownIcon::LoadModule( osl::Module **pModule,
-                               oslGenericFunction *pInit,
-                               oslGenericFunction *pDeInit )
-{
-    if ( pModule )
-    {
-        OSL_ASSERT ( pInit && pDeInit );
-        *pInit = *pDeInit = NULL;
-        *pModule = NULL;
-    }
+namespace {
 
+boost::logic::tribool loaded(boost::logic::indeterminate);
+oslGenericFunction pInitSystray(nullptr);
+oslGenericFunction pDeInitSystray(nullptr);
+
+bool LoadModule()
+{
+    if (boost::logic::indeterminate(loaded))
+    {
 #ifdef ENABLE_QUICKSTART_APPLET
 #  ifdef WIN32
-    if ( pModule )
-    {
-        *pInit = win32_init_sys_tray;
-        *pDeInit = win32_shutdown_sys_tray;
-    }
-    return true;
+        pInitSystray = win32_init_sys_tray;
+        pDeInitSystray = win32_shutdown_sys_tray;
+        loaded = true;
 #  elif defined MACOSX
-    *pInit = aqua_init_systray;
-    *pDeInit = aqua_shutdown_systray;
-    return true;
+        pInitSystray = aqua_init_systray;
+        pDeInitSystray = aqua_shutdown_systray;
+        loaded = true;
 #  else // UNX
-    osl::Module *pPlugin;
-    pPlugin = new osl::Module();
-
-    oslGenericFunction pTmpInit = NULL;
-    oslGenericFunction pTmpDeInit = NULL;
-
-#define DOSTRING( x )                       #x
-#define STRING( x )                         DOSTRING( x )
-
-    if ( pPlugin->loadRelative( &thisModule, OUString (STRING( PLUGIN_NAME  ) ) ) )
-    {
-        pTmpInit = pPlugin->getFunctionSymbol(
-            OUString( "plugin_init_sys_tray"  ) );
-        pTmpDeInit = pPlugin->getFunctionSymbol(
-            OUString( "plugin_shutdown_sys_tray"  ) );
-    }
-    if ( !pTmpInit || !pTmpDeInit )
-    {
-        delete pPlugin;
-        pPlugin = NULL;
-    }
-    if ( pModule )
-    {
-        *pModule = pPlugin;
-        *pInit = pTmpInit;
-        *pDeInit = pTmpDeInit;
-    }
-    else
-    {
-        bool bRet = pPlugin != NULL;
-        delete pPlugin;
-        return bRet;
-    }
+        osl::Module plugin;
+        oslGenericFunction pTmpInit = nullptr;
+        oslGenericFunction pTmpDeInit = nullptr;
+        if ( plugin.loadRelative( &thisModule, "libqstart_gtklo.so" ) )
+        {
+            pTmpInit = plugin.getFunctionSymbol( "plugin_init_sys_tray" );
+            pTmpDeInit = plugin.getFunctionSymbol( "plugin_shutdown_sys_tray" );
+        }
+        if ( !pTmpInit || !pTmpDeInit )
+        {
+            loaded = false;
+        }
+        else
+        {
+            plugin.release();
+            pInitSystray = pTmpInit;
+            pDeInitSystray = pTmpDeInit;
+            loaded = true;
+        }
 #  endif // UNX
+#else
+        pInitSystray = disabled_initSystray;
+        pDeInitSystray = disabled_deInitSystray;
+        loaded = false;
 #endif // ENABLE_QUICKSTART_APPLET
-
-#if !defined( ENABLE_QUICKSTART_APPLET ) || defined( UNX )
-    // Avoid unreachable code. In the ENABLE_QUICKSTART_APPLET && !UNX
-    // case, we have already returned.
-    if ( pModule )
-    {
-        if ( !*pInit )
-            *pInit = disabled_initSystray;
-        if ( !*pDeInit )
-            *pDeInit = disabled_deInitSystray;
     }
-
-    return true;
-#endif // !ENABLE_QUICKSTART_APPLET || UNX
+    assert(!boost::logic::indeterminate(loaded));
+    return loaded;
 }
 
-// These two timeouts are necessary to avoid there being
-// plugin frames still on the stack, after unloading that
-// code, causing a crash during disabling / termination.
-class IdleUnloader : Timer
-{
-    ::osl::Module *m_pModule;
-public:
-    IdleUnloader (::osl::Module **pModule) :
-        m_pModule (*pModule)
-    {
-        *pModule = NULL;
-        Start();
-    }
-    virtual void Timeout()
-    {
-        delete m_pModule;
-        delete this;
-    }
-};
-
-class IdleTerminate : Timer
-{
-    Reference< XDesktop2 > m_xDesktop;
-public:
-    IdleTerminate (Reference< XDesktop2 > xDesktop)
-    {
-        m_xDesktop = xDesktop;
-        Start();
-    }
-    virtual void Timeout()
-    {
-        m_xDesktop->terminate();
-        delete this;
-    }
-};
+}
 
 void ShutdownIcon::initSystray()
 {
@@ -233,9 +188,9 @@ void ShutdownIcon::initSystray()
         return;
     m_bInitialized = true;
 
-    (void) LoadModule( &m_pPlugin, &m_pInitSystray, &m_pDeInitSystray );
+    (void) LoadModule();
     m_bVeto = true;
-    m_pInitSystray();
+    pInitSystray();
 }
 
 void ShutdownIcon::deInitSystray()
@@ -243,31 +198,27 @@ void ShutdownIcon::deInitSystray()
     if (!m_bInitialized)
         return;
 
-    if (m_pDeInitSystray)
-        m_pDeInitSystray();
+    if (pDeInitSystray)
+        pDeInitSystray();
 
     m_bVeto = false;
-    m_pInitSystray = 0;
-    m_pDeInitSystray = 0;
-    new IdleUnloader (&m_pPlugin);
+    pInitSystray = nullptr;
+    pDeInitSystray = nullptr;
 
     delete m_pFileDlg;
-    m_pFileDlg = NULL;
+    m_pFileDlg = nullptr;
     m_bInitialized = false;
 }
 
 
-ShutdownIcon::ShutdownIcon( const Reference< XComponentContext > & rxContext ) :
+ShutdownIcon::ShutdownIcon( const css::uno::Reference< XComponentContext > & rxContext ) :
     ShutdownIconServiceBase( m_aMutex ),
     m_bVeto ( false ),
     m_bListenForTermination ( false ),
     m_bSystemDialogs( false ),
-    m_pResMgr( NULL ),
-    m_pFileDlg( NULL ),
+    m_pResMgr( nullptr ),
+    m_pFileDlg( nullptr ),
     m_xContext( rxContext ),
-    m_pInitSystray( 0 ),
-    m_pDeInitSystray( 0 ),
-    m_pPlugin( 0 ),
     m_bInitialized( false )
 {
     m_bSystemDialogs = SvtMiscOptions().UseSystemFileDialog();
@@ -276,43 +227,42 @@ ShutdownIcon::ShutdownIcon( const Reference< XComponentContext > & rxContext ) :
 ShutdownIcon::~ShutdownIcon()
 {
     deInitSystray();
-    new IdleUnloader (&m_pPlugin);
 }
 
-// ---------------------------------------------------------------------------
+
 
 void ShutdownIcon::OpenURL( const OUString& aURL, const OUString& rTarget, const Sequence< PropertyValue >& aArgs )
 {
     if ( getInstance() && getInstance()->m_xDesktop.is() )
     {
-        Reference < XDispatchProvider > xDispatchProvider( getInstance()->m_xDesktop, UNO_QUERY );
+        css::uno::Reference < XDispatchProvider > xDispatchProvider( getInstance()->m_xDesktop, UNO_QUERY );
         if ( xDispatchProvider.is() )
         {
-            com::sun::star::util::URL aDispatchURL;
+            css::util::URL aDispatchURL;
             aDispatchURL.Complete = aURL;
 
-            Reference< util::XURLTransformer > xURLTransformer( util::URLTransformer::create( ::comphelper::getProcessComponentContext() ) );
+            css::uno::Reference< util::XURLTransformer > xURLTransformer( util::URLTransformer::create( ::comphelper::getProcessComponentContext() ) );
             try
             {
-                Reference< com::sun::star::frame::XDispatch > xDispatch;
+                css::uno::Reference< css::frame::XDispatch > xDispatch;
 
                 xURLTransformer->parseStrict( aDispatchURL );
                 xDispatch = xDispatchProvider->queryDispatch( aDispatchURL, rTarget, 0 );
                 if ( xDispatch.is() )
                     xDispatch->dispatch( aDispatchURL, aArgs );
             }
-            catch ( com::sun::star::uno::RuntimeException& )
+            catch ( css::uno::RuntimeException& )
             {
                 throw;
             }
-            catch ( com::sun::star::uno::Exception& )
+            catch ( css::uno::Exception& )
             {
             }
         }
     }
 }
 
-// ---------------------------------------------------------------------------
+
 
 void ShutdownIcon::FileOpen()
 {
@@ -324,30 +274,27 @@ void ShutdownIcon::FileOpen()
     }
 }
 
-// ---------------------------------------------------------------------------
+
 
 void ShutdownIcon::FromTemplate()
 {
     if ( getInstance() && getInstance()->m_xDesktop.is() )
     {
-        Reference < ::com::sun::star::frame::XFramesSupplier > xDesktop ( getInstance()->m_xDesktop, UNO_QUERY);
-        Reference < ::com::sun::star::frame::XFrame > xFrame( xDesktop->getActiveFrame() );
+        css::uno::Reference < css::frame::XFramesSupplier > xDesktop ( getInstance()->m_xDesktop, UNO_QUERY);
+        css::uno::Reference < css::frame::XFrame > xFrame( xDesktop->getActiveFrame() );
         if ( !xFrame.is() )
-            xFrame = Reference < ::com::sun::star::frame::XFrame >( xDesktop, UNO_QUERY );
+            xFrame.set( xDesktop, UNO_QUERY );
 
         URL aTargetURL;
-        aTargetURL.Complete = "slot:5500";
-        Reference< util::XURLTransformer > xTrans( util::URLTransformer::create( ::comphelper::getProcessComponentContext() ) );
+        aTargetURL.Complete = ".uno:NewDoc";
+        css::uno::Reference< util::XURLTransformer > xTrans( util::URLTransformer::create( ::comphelper::getProcessComponentContext() ) );
         xTrans->parseStrict( aTargetURL );
 
-        Reference < ::com::sun::star::frame::XDispatchProvider > xProv( xFrame, UNO_QUERY );
-        Reference < ::com::sun::star::frame::XDispatch > xDisp;
+        css::uno::Reference < css::frame::XDispatchProvider > xProv( xFrame, UNO_QUERY );
+        css::uno::Reference < css::frame::XDispatch > xDisp;
         if ( xProv.is() )
         {
-            if (aTargetURL.Protocol == "slot:")
-                xDisp = xProv->queryDispatch( aTargetURL, OUString(), 0 );
-            else
-                xDisp = xProv->queryDispatch( aTargetURL, OUString("_blank"), 0 );
+            xDisp = xProv->queryDispatch( aTargetURL, "_self", 0 );
         }
         if ( xDisp.is() )
         {
@@ -355,11 +302,11 @@ void ShutdownIcon::FromTemplate()
             PropertyValue* pArg = aArgs.getArray();
             pArg[0].Name = "Referer";
             pArg[0].Value <<= OUString("private:user");
-            Reference< ::com::sun::star::frame::XNotifyingDispatch > xNotifyer( xDisp, UNO_QUERY );
-            if ( xNotifyer.is() )
+            css::uno::Reference< css::frame::XNotifyingDispatch > xNotifier(xDisp, UNO_QUERY);
+            if (xNotifier.is())
             {
                 EnterModalMode();
-                xNotifyer->dispatchWithNotification( aTargetURL, aArgs, new SfxNotificationListener_Impl() );
+                xNotifier->dispatchWithNotification(aTargetURL, aArgs, new SfxNotificationListener_Impl());
             }
             else
                 xDisp->dispatch( aTargetURL, aArgs );
@@ -367,7 +314,7 @@ void ShutdownIcon::FromTemplate()
     }
 }
 
-// ---------------------------------------------------------------------------
+
 #include <tools/rcid.h>
 OUString ShutdownIcon::GetResString( int id )
 {
@@ -377,13 +324,13 @@ OUString ShutdownIcon::GetResString( int id )
         m_pResMgr = SfxResId::GetResMgr();
     ResId aResId( id, *m_pResMgr );
     aResId.SetRT( RSC_STRING );
-    if( !m_pResMgr || !m_pResMgr->IsAvailable( aResId ) )
+    if (!m_pResMgr->IsAvailable(aResId))
         return OUString();
 
     return ResId(id, *m_pResMgr).toString();
 }
 
-// ---------------------------------------------------------------------------
+
 
 OUString ShutdownIcon::GetUrlDescription( const OUString& aUrl )
 {
@@ -392,7 +339,7 @@ OUString ShutdownIcon::GetUrlDescription( const OUString& aUrl )
     return OUString( SvFileInformationManager::GetDescription( INetURLObject( aUrl ) ) );
 }
 
-// ---------------------------------------------------------------------------
+
 
 void ShutdownIcon::StartFileDialog()
 {
@@ -405,26 +352,26 @@ void ShutdownIcon::StartFileDialog()
         // Destroy instance as changing the system file dialog setting
         // forces us to create a new FileDialogHelper instance!
         delete m_pFileDlg;
-        m_pFileDlg = NULL;
+        m_pFileDlg = nullptr;
     }
 
     if ( !m_pFileDlg )
         m_pFileDlg = new FileDialogHelper(
                 ui::dialogs::TemplateDescription::FILEOPEN_READONLY_VERSION,
                 SFXWB_MULTISELECTION, OUString() );
-    m_pFileDlg->StartExecuteModal( STATIC_LINK( this, ShutdownIcon, DialogClosedHdl_Impl ) );
+    m_pFileDlg->StartExecuteModal( LINK( this, ShutdownIcon, DialogClosedHdl_Impl ) );
 }
 
-// ---------------------------------------------------------------------------
 
-IMPL_STATIC_LINK( ShutdownIcon, DialogClosedHdl_Impl, FileDialogHelper*, EMPTYARG )
+
+IMPL_LINK_TYPED( ShutdownIcon, DialogClosedHdl_Impl, FileDialogHelper*, /*unused*/, void )
 {
-    DBG_ASSERT( pThis->m_pFileDlg, "ShutdownIcon, DialogClosedHdl_Impl(): no file dialog" );
+    DBG_ASSERT( m_pFileDlg, "ShutdownIcon, DialogClosedHdl_Impl(): no file dialog" );
 
     // use constructor for filling up filters automatically!
-    if ( ERRCODE_NONE == pThis->m_pFileDlg->GetError() )
+    if ( ERRCODE_NONE == m_pFileDlg->GetError() )
     {
-        Reference< XFilePicker >    xPicker = pThis->m_pFileDlg->GetFilePicker();
+        css::uno::Reference< XFilePicker2 >    xPicker = m_pFileDlg->GetFilePicker();
 
         try
         {
@@ -432,44 +379,44 @@ IMPL_STATIC_LINK( ShutdownIcon, DialogClosedHdl_Impl, FileDialogHelper*, EMPTYAR
             if ( xPicker.is() )
             {
 
-                Reference < XFilePickerControlAccess > xPickerControls ( xPicker, UNO_QUERY );
-                Reference < XFilterManager > xFilterManager ( xPicker, UNO_QUERY );
+                css::uno::Reference < XFilePickerControlAccess > xPickerControls ( xPicker, UNO_QUERY );
+                css::uno::Reference < XFilterManager > xFilterManager ( xPicker, UNO_QUERY );
 
-                Sequence< OUString >        sFiles = xPicker->getFiles();
+                Sequence< OUString >        sFiles = xPicker->getSelectedFiles();
                 int                         nFiles = sFiles.getLength();
 
                 int                         nArgs=3;
                 Sequence< PropertyValue >   aArgs(3);
 
-                Reference < com::sun::star::task::XInteractionHandler2 > xInteraction(
-                    task::InteractionHandler::createWithParent(::comphelper::getProcessComponentContext(), 0) );
+                css::uno::Reference < css::task::XInteractionHandler2 > xInteraction(
+                    task::InteractionHandler::createWithParent(::comphelper::getProcessComponentContext(), nullptr) );
 
                 aArgs[0].Name = "InteractionHandler";
                 aArgs[0].Value <<= xInteraction;
 
-                sal_Int16 nMacroExecMode = ::com::sun::star::document::MacroExecMode::USE_CONFIG;
+                sal_Int16 nMacroExecMode = css::document::MacroExecMode::USE_CONFIG;
                 aArgs[1].Name = "MacroExecutionMode";
                 aArgs[1].Value <<= nMacroExecMode;
 
-                sal_Int16 nUpdateDoc = ::com::sun::star::document::UpdateDocMode::ACCORDING_TO_CONFIG;
+                sal_Int16 nUpdateDoc = css::document::UpdateDocMode::ACCORDING_TO_CONFIG;
                 aArgs[2].Name = "UpdateDocMode";
                 aArgs[2].Value <<= nUpdateDoc;
 
                 // use the filedlghelper to get the current filter name,
                 // because it removes the extensions before you get the filter name.
-                OUString aFilterName( pThis->m_pFileDlg->GetCurrentFilter() );
+                OUString aFilterName( m_pFileDlg->GetCurrentFilter() );
 
                 if ( xPickerControls.is() )
                 {
 
                     // Set readonly flag
 
-                    sal_Bool    bReadOnly = sal_False;
+                    bool    bReadOnly = false;
 
 
                     xPickerControls->getValue( ExtendedFilePickerElementIds::CHECKBOX_READONLY, 0 ) >>= bReadOnly;
 
-                    // Only set porperty if readonly is set to TRUE
+                    // Only set property if readonly is set to TRUE
 
                     if ( bReadOnly )
                     {
@@ -505,7 +452,7 @@ IMPL_STATIC_LINK( ShutdownIcon, DialogClosedHdl_Impl, FileDialogHelper*, EMPTYAR
 
                 if ( !aFilterName.isEmpty() )
                 {
-                    const SfxFilter* pFilter = SFX_APP()->GetFilterMatcher().GetFilter4UIName( aFilterName, 0, SFX_FILTER_NOTINFILEDLG );
+                    const SfxFilter* pFilter = SfxGetpApp()->GetFilterMatcher().GetFilter4UIName( aFilterName, SfxFilterFlags::NONE, SfxFilterFlags::NOTINFILEDLG );
 
                     if ( pFilter )
                     {
@@ -521,7 +468,7 @@ IMPL_STATIC_LINK( ShutdownIcon, DialogClosedHdl_Impl, FileDialogHelper*, EMPTYAR
                 }
 
                 if ( 1 == nFiles )
-                    OpenURL( sFiles[0], OUString( "_default"  ), aArgs );
+                    OpenURL( sFiles[0], "_default", aArgs );
                 else
                 {
                     OUString    aBaseDirURL = sFiles[0];
@@ -533,7 +480,7 @@ IMPL_STATIC_LINK( ShutdownIcon, DialogClosedHdl_Impl, FileDialogHelper*, EMPTYAR
                     {
                         OUString    aURL = aBaseDirURL;
                         aURL += sFiles[iFiles];
-                        OpenURL( aURL, OUString( "_default"  ), aArgs );
+                        OpenURL( aURL, "_default", aArgs );
                     }
                 }
             }
@@ -550,16 +497,15 @@ IMPL_STATIC_LINK( ShutdownIcon, DialogClosedHdl_Impl, FileDialogHelper*, EMPTYAR
     // the settings.
     if ( SvtMiscOptions().UseSystemFileDialog() )
     {
-        delete pThis->m_pFileDlg;
-        pThis->m_pFileDlg = NULL;
+        delete m_pFileDlg;
+        m_pFileDlg = NULL;
     }
 #endif
 
     LeaveModalMode();
-    return 0;
 }
 
-// ---------------------------------------------------------------------------
+
 
 void ShutdownIcon::addTerminateListener()
 {
@@ -570,7 +516,7 @@ void ShutdownIcon::addTerminateListener()
     if (pInst->m_bListenForTermination)
         return;
 
-    Reference< XDesktop2 > xDesktop = pInst->m_xDesktop;
+    css::uno::Reference< XDesktop2 > xDesktop = pInst->m_xDesktop;
     if ( ! xDesktop.is())
         return;
 
@@ -578,7 +524,7 @@ void ShutdownIcon::addTerminateListener()
     pInst->m_bListenForTermination = true;
 }
 
-// ---------------------------------------------------------------------------
+
 
 void ShutdownIcon::terminateDesktop()
 {
@@ -586,7 +532,7 @@ void ShutdownIcon::terminateDesktop()
     if ( ! pInst)
         return;
 
-    Reference< XDesktop2 > xDesktop = pInst->m_xDesktop;
+    css::uno::Reference< XDesktop2 > xDesktop = pInst->m_xDesktop;
     if ( ! xDesktop.is())
         return;
 
@@ -595,15 +541,15 @@ void ShutdownIcon::terminateDesktop()
     xDesktop->removeTerminateListener( pInst );
 
     // terminate desktop only if no tasks exist
-    Reference< XIndexAccess > xTasks ( xDesktop->getFrames(), UNO_QUERY );
+    css::uno::Reference< XIndexAccess > xTasks ( xDesktop->getFrames(), UNO_QUERY );
     if( xTasks.is() && xTasks->getCount() < 1 )
-        new IdleTerminate( xDesktop );
+        Application::Quit();
 
     // remove the instance pointer
-    ShutdownIcon::pShutdownIcon = 0;
+    ShutdownIcon::pShutdownIcon = nullptr;
 }
 
-// ---------------------------------------------------------------------------
+
 
 ShutdownIcon* ShutdownIcon::getInstance()
 {
@@ -611,14 +557,14 @@ ShutdownIcon* ShutdownIcon::getInstance()
     return pShutdownIcon;
 }
 
-// ---------------------------------------------------------------------------
+
 
 ShutdownIcon* ShutdownIcon::createInstance()
 {
     if (pShutdownIcon)
         return pShutdownIcon;
 
-    ShutdownIcon *pIcon = NULL;
+    ShutdownIcon *pIcon = nullptr;
     try {
         pIcon = new ShutdownIcon( comphelper::getProcessComponentContext() );
         pIcon->init ();
@@ -630,7 +576,7 @@ ShutdownIcon* ShutdownIcon::createInstance()
     return pShutdownIcon;
 }
 
-void ShutdownIcon::init() throw( ::com::sun::star::uno::Exception )
+void ShutdownIcon::init() throw( css::uno::Exception, std::exception )
 {
     // access resource system and sfx only protected by solarmutex
     ::SolarMutexGuard aSolarGuard;
@@ -639,61 +585,62 @@ void ShutdownIcon::init() throw( ::com::sun::star::uno::Exception )
     ::osl::ResettableMutexGuard aGuard( m_aMutex );
     m_pResMgr = pResMgr;
     aGuard.clear();
-    Reference < XDesktop2 > xDesktop = Desktop::create( m_xContext );
+    css::uno::Reference < XDesktop2 > xDesktop = Desktop::create( m_xContext );
     aGuard.reset();
     m_xDesktop = xDesktop;
 }
 
-// ---------------------------------------------------------------------------
+
 
 void SAL_CALL ShutdownIcon::disposing()
 {
     m_xContext.clear();
     m_xDesktop.clear();
+
+    deInitSystray();
 }
 
-// ---------------------------------------------------------------------------
+
 
 // XEventListener
-void SAL_CALL ShutdownIcon::disposing( const ::com::sun::star::lang::EventObject& )
-    throw(::com::sun::star::uno::RuntimeException)
+void SAL_CALL ShutdownIcon::disposing( const css::lang::EventObject& )
+    throw(css::uno::RuntimeException, std::exception)
 {
 }
 
-// ---------------------------------------------------------------------------
+
 
 // XTerminateListener
-void SAL_CALL ShutdownIcon::queryTermination( const ::com::sun::star::lang::EventObject& )
-throw(::com::sun::star::frame::TerminationVetoException, ::com::sun::star::uno::RuntimeException)
+void SAL_CALL ShutdownIcon::queryTermination( const css::lang::EventObject& )
+throw(css::frame::TerminationVetoException, css::uno::RuntimeException, std::exception)
 {
     SAL_INFO("sfx.appl", "ShutdownIcon::queryTermination: veto is " << m_bVeto);
     ::osl::ClearableMutexGuard  aGuard( m_aMutex );
 
     if ( m_bVeto )
-        throw ::com::sun::star::frame::TerminationVetoException();
+        throw css::frame::TerminationVetoException();
 }
 
 
-// ---------------------------------------------------------------------------
 
-void SAL_CALL ShutdownIcon::notifyTermination( const ::com::sun::star::lang::EventObject& )
-throw(::com::sun::star::uno::RuntimeException)
+
+void SAL_CALL ShutdownIcon::notifyTermination( const css::lang::EventObject& )
+throw(css::uno::RuntimeException, std::exception)
 {
 }
 
 
-// ---------------------------------------------------------------------------
 
-void SAL_CALL ShutdownIcon::initialize( const ::com::sun::star::uno::Sequence< ::com::sun::star::uno::Any>& aArguments )
-    throw( ::com::sun::star::uno::Exception )
+
+void SAL_CALL ShutdownIcon::initialize( const css::uno::Sequence< css::uno::Any>& aArguments )
+    throw( css::uno::Exception, std::exception )
 {
     ::osl::ResettableMutexGuard aGuard( m_aMutex );
 
     // third argument only sets veto, everything else will be ignored!
     if (aArguments.getLength() > 2)
     {
-        sal_Bool bVeto = sal_True;
-        bVeto = ::cppu::any2bool(aArguments[2]);
+        bool bVeto = ::cppu::any2bool(aArguments[2]);
         m_bVeto = bVeto;
         return;
     }
@@ -704,8 +651,7 @@ void SAL_CALL ShutdownIcon::initialize( const ::com::sun::star::uno::Sequence< :
         {
             try
             {
-                sal_Bool bQuickstart = sal_False;
-                bQuickstart = ::cppu::any2bool( aArguments[0] );
+                bool bQuickstart = ::cppu::any2bool( aArguments[0] );
                 if( !bQuickstart && !GetAutostart() )
                     return;
                 aGuard.clear();
@@ -718,35 +664,34 @@ void SAL_CALL ShutdownIcon::initialize( const ::com::sun::star::uno::Sequence< :
                 ShutdownIcon::pShutdownIcon = this;
                 initSystray();
             }
-            catch(const ::com::sun::star::lang::IllegalArgumentException&)
+            catch(const css::lang::IllegalArgumentException&)
             {
             }
         }
     }
     if ( aArguments.getLength() > 1 )
     {
-            sal_Bool bAutostart = sal_False;
-            bAutostart = ::cppu::any2bool( aArguments[1] );
+            bool bAutostart = ::cppu::any2bool( aArguments[1] );
             if (bAutostart && !GetAutostart())
-                SetAutostart( sal_True );
+                SetAutostart( true );
             if (!bAutostart && GetAutostart())
-                SetAutostart( sal_False );
+                SetAutostart( false );
     }
 
 }
 
-// -------------------------------
+
 
 void ShutdownIcon::EnterModalMode()
 {
-    bModalMode = sal_True;
+    bModalMode = true;
 }
 
-// -------------------------------
+
 
 void ShutdownIcon::LeaveModalMode()
 {
-    bModalMode = sal_False;
+    bModalMode = false;
 }
 
 #ifdef WNT
@@ -760,13 +705,13 @@ bool ShutdownIcon::IsQuickstarterInstalled()
     return false;
 #else // !ENABLE_QUICKSTART_APPLET
 #ifdef UNX
-    return LoadModule( NULL, NULL, NULL);
+    return LoadModule();
 #endif // UNX
 #endif // !ENABLE_QUICKSTART_APPLET
 }
 #endif // !WNT
 
-// ---------------------------------------------------------------------------
+
 
 #if defined (ENABLE_QUICKSTART_APPLET) && defined (UNX)
 /**
@@ -863,7 +808,7 @@ void ShutdownIcon::SetAutostart( bool bActivate )
         getAutostartDir( true );
 
         OUString aPath( "${BRAND_BASE_DIR}/" LIBO_SHARE_FOLDER "/xdg/qstart.desktop"  );
-        Bootstrap::expandMacros( aPath );
+        rtl::Bootstrap::expandMacros( aPath );
 
         OUString aDesktopFile;
         ::osl::File::getSystemPathFromFileURL( aPath, aDesktopFile );
@@ -906,19 +851,19 @@ static const ::sal_Int32 PROPHANDLE_TERMINATEVETOSTATE = 0;
 
 // XFastPropertySet
 void SAL_CALL ShutdownIcon::setFastPropertyValue(       ::sal_Int32                  nHandle,
-                                                  const ::com::sun::star::uno::Any& aValue )
-    throw (::com::sun::star::beans::UnknownPropertyException,
-            ::com::sun::star::beans::PropertyVetoException,
-            ::com::sun::star::lang::IllegalArgumentException,
-            ::com::sun::star::lang::WrappedTargetException,
-            ::com::sun::star::uno::RuntimeException)
+                                                  const css::uno::Any& aValue )
+    throw (css::beans::UnknownPropertyException,
+            css::beans::PropertyVetoException,
+            css::lang::IllegalArgumentException,
+            css::lang::WrappedTargetException,
+            css::uno::RuntimeException, std::exception)
 {
     switch(nHandle)
     {
         case PROPHANDLE_TERMINATEVETOSTATE :
              {
                 // use new value in case it's a valid information only
-                ::sal_Bool bState( sal_False );
+                bool bState( false );
                 if (! (aValue >>= bState))
                     return;
 
@@ -929,17 +874,17 @@ void SAL_CALL ShutdownIcon::setFastPropertyValue(       ::sal_Int32
              break;
 
         default :
-            throw ::com::sun::star::beans::UnknownPropertyException();
+            throw css::beans::UnknownPropertyException();
     }
 }
 
 // XFastPropertySet
-::com::sun::star::uno::Any SAL_CALL ShutdownIcon::getFastPropertyValue( ::sal_Int32 nHandle )
-    throw (::com::sun::star::beans::UnknownPropertyException,
-            ::com::sun::star::lang::WrappedTargetException,
-            ::com::sun::star::uno::RuntimeException)
+css::uno::Any SAL_CALL ShutdownIcon::getFastPropertyValue( ::sal_Int32 nHandle )
+    throw (css::beans::UnknownPropertyException,
+            css::lang::WrappedTargetException,
+            css::uno::RuntimeException, std::exception)
 {
-    ::com::sun::star::uno::Any aValue;
+    css::uno::Any aValue;
     switch(nHandle)
     {
         case PROPHANDLE_TERMINATEVETOSTATE :
@@ -950,10 +895,37 @@ void SAL_CALL ShutdownIcon::setFastPropertyValue(       ::sal_Int32
              break;
 
         default :
-            throw ::com::sun::star::beans::UnknownPropertyException();
+            throw css::beans::UnknownPropertyException();
     }
 
     return aValue;
 }
 
+namespace {
+
+struct Instance {
+    explicit Instance(
+        css::uno::Reference<css::uno::XComponentContext> const & context):
+        instance(static_cast<cppu::OWeakObject *>(new ShutdownIcon(context)))
+    {}
+
+    rtl::Reference<css::uno::XInterface> instance;
+};
+
+struct Singleton:
+    public rtl::StaticWithArg<
+        Instance, css::uno::Reference<css::uno::XComponentContext>, Singleton>
+{};
+
+}
+
+extern "C" SAL_DLLPUBLIC_EXPORT css::uno::XInterface * SAL_CALL
+com_sun_star_comp_desktop_QuickstartWrapper_get_implementation(
+    css::uno::XComponentContext *context,
+    css::uno::Sequence<css::uno::Any> const &)
+{
+    return cppu::acquire(static_cast<cppu::OWeakObject *>(
+                Singleton::get(context).instance.get()));
+}
+
 /* vim:set shiftwidth=4 softtabstop=4 expandtab: */
