@@ -17,10 +17,14 @@
  *   the License at http://www.apache.org/licenses/LICENSE-2.0 .
  */
 
-
+#include <assert.h>
 #include <stdlib.h>
+
+#include <sal/log.hxx>
+
 #include <tools/rcid.h>
 #include <tools/stream.hxx>
+#include "tools/resmgr.hxx"
 
 #include <sfx2/module.hxx>
 #include <sfx2/objface.hxx>
@@ -31,48 +35,39 @@
 #include <sfx2/objsh.hxx>
 #include <rtl/strbuf.hxx>
 
-DBG_NAME(SfxInterface)
+extern "C" {
 
-//====================================================================
-
-extern "C"
-#ifdef WNT
-int _cdecl
-#else
-int
-#endif
-
-SfxCompareSlots_Impl( const void* pSmaller, const void* pBigger )
+static int SAL_CALL
+SfxCompareSlots_qsort( const void* pSmaller, const void* pBigger )
 {
-    return ( (int) ((SfxSlot*)pSmaller)->GetSlotId() ) -
-           ( (int) ((SfxSlot*)pBigger)->GetSlotId() );
+    return ( (int) static_cast<SfxSlot const *>(pSmaller)->GetSlotId() ) -
+           ( (int) static_cast<SfxSlot const *>(pBigger)->GetSlotId() );
 }
 
-//=========================================================================
+static int SAL_CALL
+SfxCompareSlots_bsearch( const void* pSmaller, const void* pBigger )
+{
+    return ( (int) *static_cast<sal_uInt16 const *>(pSmaller) ) -
+           ( (int) static_cast<SfxSlot const *>(pBigger)->GetSlotId() );
+}
+
+}
 
 struct SfxObjectUI_Impl
 {
     sal_uInt16  nPos;
-    ResId   aResId;
-    sal_Bool    bVisible;
-    sal_Bool    bContext;
-    OUString* pName;
+    sal_uInt32  nResId;
+    bool        bVisible;
+    bool        bContext;
     sal_uInt32  nFeature;
 
-    SfxObjectUI_Impl(sal_uInt16 n, const ResId& rResId, sal_Bool bVis, sal_uInt32 nFeat) :
+    SfxObjectUI_Impl(sal_uInt16 n, sal_uInt32 nId, bool bVis, sal_uInt32 nFeat) :
         nPos(n),
-        aResId(rResId.GetId(), *rResId.GetResMgr()),
+        nResId(nId),
         bVisible(bVis),
-        bContext(sal_False),
-        pName(0),
+        bContext(false),
         nFeature(nFeat)
     {
-        aResId.SetRT(rResId.GetRT());
-    }
-
-    ~SfxObjectUI_Impl()
-    {
-        delete pName;
     }
 };
 
@@ -85,13 +80,13 @@ struct SfxInterface_Impl
     ResId                   aPopupRes;      // registered PopupMenu
     ResId                   aStatBarRes;    // registered StatusBar
     SfxModule*              pModule;
-    sal_Bool                bRegistered;
+    bool                    bRegistered;
 
     SfxInterface_Impl() :
-        aPopupRes(0,*SfxApplication::GetOrCreate()->GetSfxResManager()),
-        aStatBarRes(0,*SfxApplication::GetOrCreate()->GetSfxResManager())
-    , pModule(NULL)
-    , bRegistered(sal_False)
+        aPopupRes(nullptr, *SfxApplication::GetSfxResManager()),
+        aStatBarRes(nullptr, *SfxApplication::GetSfxResManager())
+    , pModule(nullptr)
+    , bRegistered(false)
     {
     }
 
@@ -105,23 +100,19 @@ struct SfxInterface_Impl
     }
 };
 
-static SfxObjectUI_Impl* CreateObjectBarUI_Impl( sal_uInt16 nPos, const ResId& rResId, sal_uInt32 nFeature, const OUString *pStr );
+static SfxObjectUI_Impl* CreateObjectBarUI_Impl(sal_uInt16 nPos, sal_uInt32 nResId, sal_uInt32 nFeature);
 
-//====================================================================
-
-//====================================================================
 // constuctor, registeres a new unit
-
 SfxInterface::SfxInterface( const char *pClassName,
-                            const ResId& rNameResId,
+                            bool bUsableSuperClass,
                             SfxInterfaceId nId,
                             const SfxInterface* pParent,
                             SfxSlot &rSlotMap, sal_uInt16 nSlotCount ):
     pName(pClassName),
     pGenoType(pParent),
     nClassId(nId),
-    aNameResId(rNameResId.GetId(),*rNameResId.GetResMgr()),
-    pImpData(0)
+    bSuperClass(bUsableSuperClass),
+    pImpData(nullptr)
 {
     pImpData = new SfxInterface_Impl;
     SetSlotMap( rSlotMap, nSlotCount );
@@ -129,12 +120,12 @@ SfxInterface::SfxInterface( const char *pClassName,
 
 void SfxInterface::Register( SfxModule* pMod )
 {
-    pImpData->bRegistered = sal_True;
+    pImpData->bRegistered = true;
     pImpData->pModule = pMod;
     if ( pMod )
         pMod->GetSlotPool()->RegisterInterface(*this);
     else
-        SFX_APP()->GetAppSlotPool_Impl().RegisterInterface(*this);
+        SfxGetpApp()->GetAppSlotPool_Impl().RegisterInterface(*this);
 }
 
 void SfxInterface::SetSlotMap( SfxSlot& rSlotMap, sal_uInt16 nSlotCount )
@@ -148,16 +139,15 @@ void SfxInterface::SetSlotMap( SfxSlot& rSlotMap, sal_uInt16 nSlotCount )
     if ( !pIter->pNextSlot )
     {
         // sort the SfxSlots by id
-        qsort( pSlots, nCount, sizeof(SfxSlot), SfxCompareSlots_Impl );
+        qsort( pSlots, nCount, sizeof(SfxSlot), SfxCompareSlots_qsort );
 
         // link masters and slaves
         sal_uInt16 nIter = 1;
         for ( pIter = pSlots; nIter <= nCount; ++pIter, ++nIter )
         {
 
-            DBG_ASSERT( nIter == nCount ||
-                        pIter->GetSlotId() != (pIter+1)->GetSlotId(),
-                        "doppelte SID" );
+            assert( nIter == nCount ||
+                    pIter->GetSlotId() != (pIter+1)->GetSlotId() );
 
             // every master refers to his first slave (ENUM),
             // all slaves refer to their master.
@@ -165,11 +155,11 @@ void SfxInterface::SetSlotMap( SfxSlot& rSlotMap, sal_uInt16 nSlotCount )
             if ( pIter->GetKind() == SFX_KIND_ENUM )
             {
                 pIter->pLinkedSlot = GetSlot( pIter->nMasterSlotId );
-                DBG_ASSERT( pIter->pLinkedSlot, "slave without master" );
+                assert( pIter->pLinkedSlot );
                 if ( !pIter->pLinkedSlot->pLinkedSlot )
-                    ( (SfxSlot*) pIter->pLinkedSlot)->pLinkedSlot = pIter;
+                    const_cast<SfxSlot*>(pIter->pLinkedSlot)->pLinkedSlot = pIter;
 
-                if ( 0 == pIter->GetNextSlot() )
+                if ( nullptr == pIter->GetNextSlot() )
                 {
                     SfxSlot *pLastSlot = pIter;
                     for ( sal_uInt16 n = nIter; n < Count(); ++n )
@@ -184,9 +174,9 @@ void SfxInterface::SetSlotMap( SfxSlot& rSlotMap, sal_uInt16 nSlotCount )
                     pLastSlot->pNextSlot = pIter;
                 }
             }
-            else if ( 0 == pIter->GetNextSlot() )
+            else if ( nullptr == pIter->GetNextSlot() )
             {
-                // Slots refering in circle to the next with the same
+                // Slots referring in circle to the next with the same
                 // Status method.
                 SfxSlot *pLastSlot = pIter;
                 for ( sal_uInt16 n = nIter; n < Count(); ++n )
@@ -210,7 +200,7 @@ void SfxInterface::SetSlotMap( SfxSlot& rSlotMap, sal_uInt16 nSlotCount )
         {
 
             if ( pNext->GetSlotId() <= pIter->GetSlotId() )
-                OSL_FAIL("Wrong order!");
+                SAL_WARN( "sfx.control", "Wrong order" );
 
             if ( pIter->GetKind() == SFX_KIND_ENUM )
             {
@@ -227,7 +217,7 @@ void SfxInterface::SetSlotMap( SfxSlot& rSlotMap, sal_uInt16 nSlotCount )
                         aStr.append(" , ");
                         aStr.append(static_cast<sal_Int32>(
                             pSlave->GetSlotId()));
-                        OSL_FAIL(aStr.getStr());
+                        SAL_WARN("sfx.control", aStr.getStr());
                     }
 
                     if ( pSlave->nMasterSlotId != pMasterSlot->GetSlotId() )
@@ -238,7 +228,7 @@ void SfxInterface::SetSlotMap( SfxSlot& rSlotMap, sal_uInt16 nSlotCount )
                         aStr.append(" , ");
                         aStr.append(static_cast<sal_Int32>(
                             pSlave->GetSlotId()));
-                        OSL_FAIL(aStr.getStr());
+                        SAL_WARN("sfx.control", aStr.getStr());
                     }
 
                     pSlave = pSlave->pNextSlot;
@@ -256,7 +246,7 @@ void SfxInterface::SetSlotMap( SfxSlot& rSlotMap, sal_uInt16 nSlotCount )
                         aStr.append(" , ");
                         aStr.append(static_cast<sal_Int32>(
                             pIter->pLinkedSlot->GetSlotId()));
-                        OSL_FAIL(aStr.getStr());
+                        SAL_WARN("sfx.control", aStr.getStr());
                     }
                 }
 
@@ -271,7 +261,7 @@ void SfxInterface::SetSlotMap( SfxSlot& rSlotMap, sal_uInt16 nSlotCount )
                             pCurSlot->GetSlotId()));
                         aStr.append(" , ");
                         aStr.append(static_cast<sal_Int32>(pIter->GetSlotId()));
-                        OSL_FAIL(aStr.getStr());
+                        SAL_WARN("sfx.control", aStr.getStr());
                     }
                 }
                 while ( pCurSlot != pIter );
@@ -283,39 +273,40 @@ void SfxInterface::SetSlotMap( SfxSlot& rSlotMap, sal_uInt16 nSlotCount )
 #endif
 }
 
-//--------------------------------------------------------------------
+
 
 SfxInterface::~SfxInterface()
 {
     SfxModule *pMod = pImpData->pModule;
-    sal_Bool bRegistered = pImpData->bRegistered;
+    bool bRegistered = pImpData->bRegistered;
     delete pImpData;
-    DBG_ASSERT( bRegistered, "Interface not registered!" );
+    assert( bRegistered );
     if ( bRegistered )
     {
         if ( pMod )
             pMod->GetSlotPool()->ReleaseInterface(*this);
         else
-            SFX_APP()->GetAppSlotPool_Impl().ReleaseInterface(*this);
+            SfxGetpApp()->GetAppSlotPool_Impl().ReleaseInterface(*this);
     }
 }
 
-//--------------------------------------------------------------------
+
 
 // searches for the specified func
 
 const SfxSlot* SfxInterface::GetSlot( sal_uInt16 nFuncId ) const
 {
-    DBG_CHKTHIS(SfxInterface, 0);
-    DBG_ASSERT( this && pSlots && nCount, "" );
+
+    assert( pSlots );
+    assert( nCount );
 
     // find the id using binary search
     void* p = bsearch( &nFuncId, pSlots, nCount, sizeof(SfxSlot),
-                       SfxCompareSlots_Impl );
+                       SfxCompareSlots_bsearch );
     if ( !p && pGenoType )
         return pGenoType->GetSlot( nFuncId );
 
-    return p ? (const SfxSlot*)p : 0;
+    return p ? static_cast<const SfxSlot*>(p) : nullptr;
 }
 
 const SfxSlot* SfxInterface::GetSlot( const OUString& rCommand ) const
@@ -333,122 +324,96 @@ const SfxSlot* SfxInterface::GetSlot( const OUString& rCommand ) const
             return pSlots+n;
     }
 
-    return pGenoType ? pGenoType->GetSlot( aCommand ) : NULL;
+    return pGenoType ? pGenoType->GetSlot( aCommand ) : nullptr;
 }
 
-//--------------------------------------------------------------------
+
 
 const SfxSlot* SfxInterface::GetRealSlot( const SfxSlot *pSlot ) const
 {
-    DBG_CHKTHIS(SfxInterface, 0);
-    DBG_ASSERT( this && pSlots && nCount, "" );
+
+    assert( pSlots );
+    assert( nCount );
 
     if ( !ContainsSlot_Impl(pSlot) )
     {
         if(pGenoType)
             return pGenoType->GetRealSlot(pSlot);
-        OSL_FAIL("unknown Slot");
-        return 0;
+        SAL_WARN( "sfx.control", "unknown Slot" );
+        return nullptr;
     }
 
     return pSlot->pLinkedSlot;
 }
 
-//--------------------------------------------------------------------
+
 
 const SfxSlot* SfxInterface::GetRealSlot( sal_uInt16 nSlotId ) const
 {
-    DBG_CHKTHIS(SfxInterface, 0);
-    DBG_ASSERT( this && pSlots && nCount, "" );
+
+    assert( pSlots );
+    assert( nCount );
 
     const SfxSlot *pSlot = GetSlot(nSlotId);
     if ( !pSlot )
     {
         if(pGenoType)
             return pGenoType->GetRealSlot(nSlotId);
-        OSL_FAIL("unkonown Slot");
-        return 0;
+        SAL_WARN( "sfx.control", "unknown Slot" );
+        return nullptr;
     }
 
     return pSlot->pLinkedSlot;
 }
 
-//--------------------------------------------------------------------
-
 void SfxInterface::RegisterPopupMenu( const ResId& rResId )
 {
-    DBG_CHKTHIS(SfxInterface, 0);
+
     pImpData->aPopupRes = rResId;
 }
 
-//--------------------------------------------------------------------
-
-void SfxInterface::RegisterObjectBar( sal_uInt16 nPos, const ResId& rResId,
-        const OUString *pStr )
+void SfxInterface::RegisterObjectBar(sal_uInt16 nPos, sal_uInt32 nResId)
 {
-    RegisterObjectBar( nPos, rResId, 0UL, pStr );
+    RegisterObjectBar(nPos, nResId, 0UL);
 }
 
-
-void SfxInterface::RegisterObjectBar( sal_uInt16 nPos, const ResId& rResId, sal_uInt32 nFeature, const OUString *pStr )
+void SfxInterface::RegisterObjectBar(sal_uInt16 nPos, sal_uInt32 nResId, sal_uInt32 nFeature)
 {
-    SfxObjectUI_Impl* pUI = CreateObjectBarUI_Impl( nPos, rResId, nFeature, pStr );
+    SfxObjectUI_Impl* pUI = CreateObjectBarUI_Impl(nPos, nResId, nFeature);
     if ( pUI )
         pImpData->aObjectBars.push_back(pUI);
 }
 
-SfxObjectUI_Impl* CreateObjectBarUI_Impl( sal_uInt16 nPos, const ResId& rResId, sal_uInt32 nFeature, const OUString *pStr )
+SfxObjectUI_Impl* CreateObjectBarUI_Impl(sal_uInt16 nPos, sal_uInt32 nResId, sal_uInt32 nFeature)
 {
     if ((nPos & SFX_VISIBILITY_MASK) == 0)
         nPos |= SFX_VISIBILITY_STANDARD;
 
-    SfxObjectUI_Impl* pUI = new SfxObjectUI_Impl(nPos, rResId, sal_True, nFeature);
-
-    if (pStr == 0)
-    {
-        ResId aResId(rResId);
-        aResId.SetRT(RSC_STRING);
-        aResId.SetResMgr(rResId.GetResMgr());
-        if( ! aResId.GetResMgr() )
-            aResId.SetResMgr( SfxApplication::GetOrCreate()->GetOffResManager_Impl() );
-        if ( !aResId.GetResMgr() || !aResId.GetResMgr()->IsAvailable(aResId) )
-            pUI->pName = new OUString ("NoName");
-        else
-            pUI->pName = new OUString(aResId.toString());
-    }
-    else
-        pUI->pName = new OUString(*pStr);
-
-    return pUI;
+    return new SfxObjectUI_Impl(nPos, nResId, true, nFeature);
 }
 
-const ResId& SfxInterface::GetObjectBarResId( sal_uInt16 nNo ) const
+sal_uInt32 SfxInterface::GetObjectBarId(sal_uInt16 nNo) const
 {
-    sal_Bool bGenoType = (pGenoType != 0 && !pGenoType->HasName());
+    bool bGenoType = (pGenoType != nullptr && pGenoType->UseAsSuperClass());
     if ( bGenoType )
     {
         // Are there toolbars in the super class?
         sal_uInt16 nBaseCount = pGenoType->GetObjectBarCount();
         if ( nNo < nBaseCount )
             // The Super class comes first
-            return pGenoType->GetObjectBarResId( nNo );
+            return pGenoType->GetObjectBarId(nNo);
         else
             nNo = nNo - nBaseCount;
     }
 
-#ifdef DBG_UTIL
-    sal_uInt16 nObjBarCount = pImpData->aObjectBars.size();
-    DBG_ASSERT( nNo<nObjBarCount,"Objectbar is unknown!" );
-#endif
-    return pImpData->aObjectBars[nNo]->aResId;
+    assert( nNo<pImpData->aObjectBars.size() );
+
+    return pImpData->aObjectBars[nNo]->nResId;
 }
 
-//--------------------------------------------------------------------
-
-
 sal_uInt16 SfxInterface::GetObjectBarPos( sal_uInt16 nNo ) const
 {
-    sal_Bool bGenoType = (pGenoType != 0 && !pGenoType->HasName());
+    bool bGenoType = (pGenoType != nullptr && pGenoType->UseAsSuperClass());
     if ( bGenoType )
     {
         // Are there toolbars in the super class?
@@ -460,33 +425,27 @@ sal_uInt16 SfxInterface::GetObjectBarPos( sal_uInt16 nNo ) const
             nNo = nNo - nBaseCount;
     }
 
-#ifdef DBG_UTIL
-    sal_uInt16 nObjBarCount = pImpData->aObjectBars.size();
-    DBG_ASSERT( nNo<nObjBarCount,"Objectbar is unknown!" );
-#endif
+    assert( nNo<pImpData->aObjectBars.size() );
+
     return pImpData->aObjectBars[nNo]->nPos;
 }
 
-//--------------------------------------------------------------------
-
-
 sal_uInt16 SfxInterface::GetObjectBarCount() const
 {
-    if (pGenoType && ! pGenoType->HasName())
+    if (pGenoType && pGenoType->UseAsSuperClass())
         return pImpData->aObjectBars.size() + pGenoType->GetObjectBarCount();
     else
         return pImpData->aObjectBars.size();
 }
 
-//--------------------------------------------------------------------
-void SfxInterface::RegisterChildWindow(sal_uInt16 nId, sal_Bool bContext, const OUString* pChildWinName)
+void SfxInterface::RegisterChildWindow(sal_uInt16 nId, bool bContext)
 {
-    RegisterChildWindow( nId, bContext, 0UL, pChildWinName );
+    RegisterChildWindow(nId, bContext, 0UL);
 }
 
-void SfxInterface::RegisterChildWindow(sal_uInt16 nId, sal_Bool bContext, sal_uInt32 nFeature, const OUString*)
+void SfxInterface::RegisterChildWindow(sal_uInt16 nId, bool bContext, sal_uInt32 nFeature)
 {
-    SfxObjectUI_Impl* pUI = new SfxObjectUI_Impl(0, ResId(nId, *SfxApplication::GetOrCreate()->GetOffResManager_Impl()), sal_True, nFeature);
+    SfxObjectUI_Impl* pUI = new SfxObjectUI_Impl(0, nId, true, nFeature);
     pUI->bContext = bContext;
     pImpData->aChildWindows.push_back(pUI);
 }
@@ -496,7 +455,6 @@ void SfxInterface::RegisterStatusBar(const ResId& rResId)
     pImpData->aStatBarRes = rResId;
 }
 
-
 sal_uInt32 SfxInterface::GetChildWindowId (sal_uInt16 nNo) const
 {
     if ( pGenoType )
@@ -510,11 +468,9 @@ sal_uInt32 SfxInterface::GetChildWindowId (sal_uInt16 nNo) const
             nNo = nNo - nBaseCount;
     }
 
-#ifdef DBG_UTIL
-    sal_uInt16 nCWCount = pImpData->aChildWindows.size();
-    DBG_ASSERT( nNo<nCWCount,"ChildWindow is unknown!" );
-#endif
-    sal_uInt32 nRet = pImpData->aChildWindows[nNo]->aResId.GetId();
+    assert( nNo<pImpData->aChildWindows.size() );
+
+    sal_uInt32 nRet = pImpData->aChildWindows[nNo]->nResId;
     if ( pImpData->aChildWindows[nNo]->bContext )
         nRet += sal_uInt32( nClassId ) << 16;
     return nRet;
@@ -533,14 +489,12 @@ sal_uInt32 SfxInterface::GetChildWindowFeature (sal_uInt16 nNo) const
             nNo = nNo - nBaseCount;
     }
 
-#ifdef DBG_UTIL
-    sal_uInt16 nCWCount = pImpData->aChildWindows.size();
-    DBG_ASSERT( nNo<nCWCount,"ChildWindow is unknown!" );
-#endif
+    assert( nNo<pImpData->aChildWindows.size() );
+
     return pImpData->aChildWindows[nNo]->nFeature;
 }
 
-//--------------------------------------------------------------------
+
 
 
 sal_uInt16 SfxInterface::GetChildWindowCount() const
@@ -551,13 +505,11 @@ sal_uInt16 SfxInterface::GetChildWindowCount() const
         return pImpData->aChildWindows.size();
 }
 
-
 const ResId& SfxInterface::GetPopupMenuResId() const
 {
     return pImpData->aPopupRes;
 }
 
-
 const ResId& SfxInterface::GetStatusBarResId() const
 {
     if (pImpData->aStatBarRes.GetId() == 0 && pGenoType)
@@ -566,32 +518,9 @@ const ResId& SfxInterface::GetStatusBarResId() const
         return pImpData->aStatBarRes;
 }
 
-
-
-const OUString* SfxInterface::GetObjectBarName ( sal_uInt16 nNo ) const
-{
-    sal_Bool bGenoType = (pGenoType != 0 && !pGenoType->HasName());
-    if ( bGenoType )
-    {
-        // Are there toolbars in the super class?
-        sal_uInt16 nBaseCount = pGenoType->GetObjectBarCount();
-        if ( nNo < nBaseCount )
-            // The Super class comes first
-            return pGenoType->GetObjectBarName( nNo );
-        else
-            nNo = nNo - nBaseCount;
-    }
-
-#ifdef DBG_UTIL
-    sal_uInt16 nObjBarCount = pImpData->aObjectBars.size();
-    DBG_ASSERT( nNo<nObjBarCount,"Objectbar is unknown!" );
-#endif
-    return pImpData->aObjectBars[nNo]->pName;
-}
-
 sal_uInt32 SfxInterface::GetObjectBarFeature ( sal_uInt16 nNo ) const
 {
-    sal_Bool bGenoType = (pGenoType != 0 && !pGenoType->HasName());
+    bool bGenoType = (pGenoType != nullptr && pGenoType->UseAsSuperClass());
     if ( bGenoType )
     {
         // Are there toolbars in the super class?
@@ -603,16 +532,14 @@ sal_uInt32 SfxInterface::GetObjectBarFeature ( sal_uInt16 nNo ) const
             nNo = nNo - nBaseCount;
     }
 
-#ifdef DBG_UTIL
-    sal_uInt16 nObjBarCount = pImpData->aObjectBars.size();
-    DBG_ASSERT( nNo<nObjBarCount,"Objectbar is unknown!" );
-#endif
+    assert( nNo<pImpData->aObjectBars.size() );
+
     return pImpData->aObjectBars[nNo]->nFeature;
 }
 
-sal_Bool SfxInterface::IsObjectBarVisible(sal_uInt16 nNo) const
+bool SfxInterface::IsObjectBarVisible(sal_uInt16 nNo) const
 {
-    sal_Bool bGenoType = (pGenoType != 0 && !pGenoType->HasName());
+    bool bGenoType = (pGenoType != nullptr && pGenoType->UseAsSuperClass());
     if ( bGenoType )
     {
         // Are there toolbars in the super class?
@@ -624,34 +551,9 @@ sal_Bool SfxInterface::IsObjectBarVisible(sal_uInt16 nNo) const
             nNo = nNo - nBaseCount;
     }
 
-#ifdef DBG_UTIL
-    sal_uInt16 nObjBarCount = pImpData->aObjectBars.size();
-    DBG_ASSERT( nNo<nObjBarCount,"Objectbar is unknown!" );
-#endif
+    assert( nNo<pImpData->aObjectBars.size() );
+
     return pImpData->aObjectBars[nNo]->bVisible;
 }
 
-const SfxInterface* SfxInterface::GetRealInterfaceForSlot( const SfxSlot *pRealSlot ) const
-{
-    DBG_ASSERT( pImpData->bRegistered, "Interface not registered!" );
-    const SfxInterface* pInterface = this;
-
-    // The slot could also originate from the interface of a shell base class.
-    do
-    {
-        const SfxSlot *pLastSlot  = (*pInterface)[pInterface->Count()-1];
-        const SfxSlot *pFirstSlot = (*pInterface)[0];
-
-        // Is pInterface the Owner of pRealSlot ?
-        if ( pFirstSlot <= pRealSlot && pRealSlot <= pLastSlot )
-            break;
-
-        // Otherwise try the Interface of Super class
-        pInterface = pInterface->pGenoType;
-    }
-    while ( pInterface );
-
-    return pInterface;
-}
-
 /* vim:set shiftwidth=4 softtabstop=4 expandtab: */
