@@ -29,14 +29,18 @@
 #include <drawinglayer/processor2d/baseprocessor2d.hxx>
 #include <drawinglayer/processor2d/processorfromoutputdevice.hxx>
 #include <rtl/ustring.hxx>
+#include <svtools/optionsdrawinglayer.hxx>
 #include <vcl/decoview.hxx>
 #include <vcl/svapp.hxx>
 #include <vcl/scrbar.hxx>
 #include <vcl/help.hxx>
+#include <vcl/settings.hxx>
 
 #include <com/sun/star/accessibility/AccessibleEventId.hpp>
 #include <com/sun/star/accessibility/AccessibleStateType.hpp>
 
+#include <memory>
+
 using namespace basegfx;
 using namespace basegfx::tools;
 using namespace drawinglayer::attribute;
@@ -53,15 +57,9 @@ enum
     SCROLL_OFFSET = 4
 };
 
-ThumbnailView::ThumbnailView (Window *pParent, WinBits nWinStyle, bool bDisableTransientChildren)
+ThumbnailView::ThumbnailView (vcl::Window *pParent, WinBits nWinStyle, bool bDisableTransientChildren)
     : Control( pParent, nWinStyle )
-{
-    ImplInit();
-    mbIsTransientChildrenDisabled = bDisableTransientChildren;
-}
-
-ThumbnailView::ThumbnailView (Window *pParent, const ResId &rResId, bool bDisableTransientChildren)
-    : Control( pParent, rResId )
+    , mpItemAttrs(new ThumbnailItemAttributes)
 {
     ImplInit();
     mbIsTransientChildrenDisabled = bDisableTransientChildren;
@@ -69,18 +67,21 @@ ThumbnailView::ThumbnailView (Window *pParent, const ResId &rResId, bool bDisabl
 
 ThumbnailView::~ThumbnailView()
 {
-    com::sun::star::uno::Reference< ::com::sun::star::lang::XComponent>
-            xComponent(GetAccessible(sal_False),
-                       com::sun::star::uno::UNO_QUERY);
+    disposeOnce();
+}
+
+void ThumbnailView::dispose()
+{
+    css::uno::Reference< css::lang::XComponent> xComponent(GetAccessible(false), css::uno::UNO_QUERY);
 
     if (xComponent.is())
         xComponent->dispose ();
 
-    delete mpScrBar;
+    mpScrBar.disposeAndClear();
     delete mpItemAttrs;
-    delete mpProcessor;
 
     ImplDeleteItems();
+    Control::dispose();
 }
 
 void ThumbnailView::MouseMove(const MouseEvent& rMEvt)
@@ -91,26 +92,17 @@ void ThumbnailView::MouseMove(const MouseEvent& rMEvt)
 
     for (size_t i = 0; i < nItemCount; i++)
     {
-        bool bNeedsPaint = false;
         ThumbnailViewItem *pItem = mFilteredItemList[i];
 
         if (pItem->mbVisible && !rMEvt.IsLeaveWindow() && pItem->getDrawArea().IsInside(aPoint))
         {
             aHelp = pItem->getHelpText();
-
-            if (!pItem->isHighlighted())
-                bNeedsPaint = true;
-            pItem->setHighlight(true);
-        }
-        else
-        {
-            if (pItem->isHighlighted())
-                bNeedsPaint = true;
-            pItem->setHighlight(false);
         }
 
-        if (bNeedsPaint && IsReallyVisible() && IsUpdateMode())
-            Invalidate(pItem->getDrawArea());
+        Rectangle aToInvalidate(pItem->updateHighlight(pItem->mbVisible && !rMEvt.IsLeaveWindow(), aPoint));
+
+        if (!aToInvalidate.IsEmpty() && IsReallyVisible() && IsUpdateMode())
+            Invalidate(aToInvalidate);
     }
 
     if (mbShowTooltips)
@@ -123,7 +115,7 @@ void ThumbnailView::AppendItem(ThumbnailViewItem *pItem)
     {
         // Save current start,end range, iterator might get invalidated
         size_t nSelStartPos = 0;
-        ThumbnailViewItem *pSelStartItem = NULL;
+        ThumbnailViewItem *pSelStartItem = nullptr;
 
         if (mpStartSelRange != mFilteredItemList.end())
         {
@@ -132,7 +124,7 @@ void ThumbnailView::AppendItem(ThumbnailViewItem *pItem)
         }
 
         mFilteredItemList.push_back(pItem);
-        mpStartSelRange = pSelStartItem != NULL ? mFilteredItemList.begin() + nSelStartPos : mFilteredItemList.end();
+        mpStartSelRange = pSelStartItem != nullptr ? mFilteredItemList.begin() + nSelStartPos : mFilteredItemList.end();
     }
 
     mItemList.push_back(pItem);
@@ -140,29 +132,31 @@ void ThumbnailView::AppendItem(ThumbnailViewItem *pItem)
 
 void ThumbnailView::ImplInit()
 {
-    mpScrBar            = NULL;
-    mnHeaderHeight      = 0;
-    mnItemWidth         = 0;
-    mnItemHeight        = 0;
-    mnItemPadding       = 0;
-    mnVisLines          = 0;
-    mnLines             = 0;
-    mnFineness          = 5;
-    mnFirstLine         = 0;
-    mnCols              = 0;
-    mnSpacing           = 0;
-    mbScroll            = false;
-    mbHasVisibleItems   = false;
-    mbShowTooltips      = false;
+    mpScrBar = nullptr;
+    mnHeaderHeight = 0;
+    mnItemWidth = 0;
+    mnItemHeight = 0;
+    mnItemPadding = 0;
+    mnVisLines = 0;
+    mnLines = 0;
+    mnFineness = 5;
+    mnFirstLine = 0;
+    mnCols = 0;
+    mbScroll = false;
+    mbHasVisibleItems = false;
+    mbShowTooltips = false;
     maFilterFunc = ViewFilterAll();
-    maColor = GetSettings().GetStyleSettings().GetFieldColor();
+    maFillColor = GetSettings().GetStyleSettings().GetFieldColor();
+    maTextColor = GetSettings().GetStyleSettings().GetWindowTextColor();
+    maHighlightColor = GetSettings().GetStyleSettings().GetHighlightColor();
+    maHighlightTextColor = GetSettings().GetStyleSettings().GetWindowTextColor();
+
+    const SvtOptionsDrawinglayer aSvtOptionsDrawinglayer;
+    mfHighlightTransparence = aSvtOptionsDrawinglayer.GetTransparentSelectionPercent() * 0.01;
+
     mpStartSelRange = mFilteredItemList.end();
 
-    // Create the processor and process the primitives
-    const drawinglayer::geometry::ViewInformation2D aNewViewInfos;
-    mpProcessor = drawinglayer::processor2d::createBaseProcessor2DFromOutputDevice(*this, aNewViewInfos );
-
-    ImplInitSettings( true, true, true );
+    ApplySettings(*this);
 }
 
 void ThumbnailView::ImplDeleteItems()
@@ -184,10 +178,10 @@ void ThumbnailView::ImplDeleteItems()
 
         if ( pItem->isVisible() && ImplHasAccessibleListeners() )
         {
-            ::com::sun::star::uno::Any aOldAny, aNewAny;
+            css::uno::Any aOldAny, aNewAny;
 
             aOldAny <<= pItem->GetAccessible( mbIsTransientChildrenDisabled );
-            ImplFireAccessibleEvent( ::com::sun::star::accessibility::AccessibleEventId::CHILD, aOldAny, aNewAny );
+            ImplFireAccessibleEvent( css::accessibility::AccessibleEventId::CHILD, aOldAny, aNewAny );
         }
 
         delete pItem;
@@ -199,42 +193,22 @@ void ThumbnailView::ImplDeleteItems()
     mpStartSelRange = mFilteredItemList.end();
 }
 
-void ThumbnailView::ImplInitSettings( bool bFont, bool bForeground, bool bBackground )
+void ThumbnailView::ApplySettings(vcl::RenderContext& rRenderContext)
 {
-    const StyleSettings& rStyleSettings = GetSettings().GetStyleSettings();
+    const StyleSettings& rStyleSettings = rRenderContext.GetSettings().GetStyleSettings();
 
-    if ( bFont )
-    {
-        Font aFont;
-        aFont = rStyleSettings.GetAppFont();
-        if ( IsControlFont() )
-            aFont.Merge( GetControlFont() );
-        SetZoomedPointFont( aFont );
-    }
+    ApplyControlFont(*this, rStyleSettings.GetAppFont());
+    ApplyControlForeground(*this, rStyleSettings.GetButtonTextColor());
+    rRenderContext.SetTextFillColor();
+    rRenderContext.SetBackground(maFillColor);
 
-    if ( bForeground || bFont )
-    {
-        Color aColor;
-        if ( IsControlForeground() )
-            aColor = GetControlForeground();
-        else
-            aColor = rStyleSettings.GetButtonTextColor();
-        SetTextColor( aColor );
-        SetTextFillColor();
-    }
-
-    if ( bBackground )
-    {
-        Color aColor = rStyleSettings.GetFieldColor();
-        SetBackground( aColor );
-    }
-
-
-    mpItemAttrs = new ThumbnailItemAttributes;
-    mpItemAttrs->aFillColor = maColor.getBColor();
-    mpItemAttrs->aHighlightColor = rStyleSettings.GetHighlightColor().getBColor();
+    mpItemAttrs->aFillColor = maFillColor.getBColor();
+    mpItemAttrs->aTextColor = maTextColor.getBColor();
+    mpItemAttrs->aHighlightColor = maHighlightColor.getBColor();
+    mpItemAttrs->aHighlightTextColor = maHighlightTextColor.getBColor();
+    mpItemAttrs->fHighlightTransparence = mfHighlightTransparence;
     mpItemAttrs->aFontAttr = getFontAttributeFromVclFont(mpItemAttrs->aFontSize,GetFont(),false,true);
-    mpItemAttrs->nMaxTextLenght = -1;
+    mpItemAttrs->nMaxTextLength = 0;
 }
 
 void ThumbnailView::ImplInitScrollBar()
@@ -243,26 +217,26 @@ void ThumbnailView::ImplInitScrollBar()
     {
         if ( !mpScrBar )
         {
-            mpScrBar = new ScrollBar( this, WB_VSCROLL | WB_DRAG );
+            mpScrBar = VclPtr<ScrollBar>::Create( this, WB_VSCROLL | WB_DRAG );
             mpScrBar->SetScrollHdl( LINK( this, ThumbnailView, ImplScrollHdl ) );
         }
         else
         {
             // adapt the width because of the changed settings
             long nScrBarWidth = GetSettings().GetStyleSettings().GetScrollBarSize();
-            mpScrBar->setPosSizePixel( 0, 0, nScrBarWidth, 0, WINDOW_POSSIZE_WIDTH );
+            mpScrBar->setPosSizePixel( 0, 0, nScrBarWidth, 0, PosSizeFlags::Width );
         }
     }
 }
 
-void ThumbnailView::DrawItem (ThumbnailViewItem *pItem)
+void ThumbnailView::DrawItem(ThumbnailViewItem *pItem)
 {
     if (pItem->isVisible())
     {
         Rectangle aRect = pItem->getDrawArea();
 
-        if ( (aRect.GetHeight() > 0) && (aRect.GetWidth() > 0) )
-            pItem->Paint(mpProcessor,mpItemAttrs);
+        if ((aRect.GetHeight() > 0) && (aRect.GetWidth() > 0))
+            Invalidate(aRect);
     }
 }
 
@@ -270,7 +244,7 @@ void ThumbnailView::OnItemDblClicked (ThumbnailViewItem*)
 {
 }
 
-::com::sun::star::uno::Reference< ::com::sun::star::accessibility::XAccessible > ThumbnailView::CreateAccessible()
+css::uno::Reference< css::accessibility::XAccessible > ThumbnailView::CreateAccessible()
 {
     return new ThumbnailViewAcc( this, mbIsTransientChildrenDisabled );
 }
@@ -283,7 +257,7 @@ void ThumbnailView::CalculateItemPositions (bool bScrollBarUsed)
     Size        aWinSize = GetOutputSizePixel();
     size_t      nItemCount = mFilteredItemList.size();
     WinBits     nStyle = GetStyle();
-    ScrollBar*  pDelScrBar = NULL;
+    VclPtr<ScrollBar>  pDelScrBar;
 
     // consider the scrolling
     if ( nStyle & WB_VSCROLL )
@@ -294,7 +268,7 @@ void ThumbnailView::CalculateItemPositions (bool bScrollBarUsed)
         {
             // delete ScrollBar not until later, to prevent recursive calls
             pDelScrBar = mpScrBar;
-            mpScrBar = NULL;
+            mpScrBar = nullptr;
         }
     }
 
@@ -379,10 +353,10 @@ void ThumbnailView::CalculateItemPositions (bool bScrollBarUsed)
             {
                 if ( ImplHasAccessibleListeners() )
                 {
-                    ::com::sun::star::uno::Any aOldAny, aNewAny;
+                    css::uno::Any aOldAny, aNewAny;
 
                     aNewAny <<= pItem->GetAccessible( mbIsTransientChildrenDisabled );
-                    ImplFireAccessibleEvent( ::com::sun::star::accessibility::AccessibleEventId::CHILD, aOldAny, aNewAny );
+                    ImplFireAccessibleEvent( css::accessibility::AccessibleEventId::CHILD, aOldAny, aNewAny );
                 }
 
                 pItem->show(true);
@@ -391,7 +365,7 @@ void ThumbnailView::CalculateItemPositions (bool bScrollBarUsed)
             }
 
             pItem->setDrawArea(Rectangle( Point(x,y), Size(mnItemWidth, mnItemHeight) ));
-            pItem->calculateItemsPosition(mnThumbnailHeight,mnDisplayHeight,mnItemPadding,mpItemAttrs->nMaxTextLenght,mpItemAttrs);
+            pItem->calculateItemsPosition(mnThumbnailHeight,mnDisplayHeight,mnItemPadding,mpItemAttrs->nMaxTextLength,mpItemAttrs);
 
             if ( !((nCurCount+1) % mnCols) )
             {
@@ -407,10 +381,10 @@ void ThumbnailView::CalculateItemPositions (bool bScrollBarUsed)
             {
                 if ( ImplHasAccessibleListeners() )
                 {
-                    ::com::sun::star::uno::Any aOldAny, aNewAny;
+                    css::uno::Any aOldAny, aNewAny;
 
                     aOldAny <<= pItem->GetAccessible( mbIsTransientChildrenDisabled );
-                    ImplFireAccessibleEvent( ::com::sun::star::accessibility::AccessibleEventId::CHILD, aOldAny, aNewAny );
+                    ImplFireAccessibleEvent( css::accessibility::AccessibleEventId::CHILD, aOldAny, aNewAny );
                 }
 
                 pItem->show(false);
@@ -448,7 +422,7 @@ void ThumbnailView::CalculateItemPositions (bool bScrollBarUsed)
     }
 
     // delete ScrollBar
-    delete pDelScrBar;
+    pDelScrBar.disposeAndClear();
 }
 
 size_t ThumbnailView::ImplGetItem( const Point& rPos ) const
@@ -469,7 +443,7 @@ size_t ThumbnailView::ImplGetItem( const Point& rPos ) const
 
 ThumbnailViewItem* ThumbnailView::ImplGetItem( size_t nPos )
 {
-    return ( nPos < mFilteredItemList.size() ) ? mFilteredItemList[nPos] : NULL;
+    return ( nPos < mFilteredItemList.size() ) ? mFilteredItemList[nPos] : nullptr;
 }
 
 sal_uInt16 ThumbnailView::ImplGetVisibleItemCount() const
@@ -498,12 +472,12 @@ ThumbnailViewItem* ThumbnailView::ImplGetVisibleItem( sal_uInt16 nVisiblePos )
             return pItem;
     }
 
-    return NULL;
+    return nullptr;
 }
 
-void ThumbnailView::ImplFireAccessibleEvent( short nEventId, const ::com::sun::star::uno::Any& rOldValue, const ::com::sun::star::uno::Any& rNewValue )
+void ThumbnailView::ImplFireAccessibleEvent( short nEventId, const css::uno::Any& rOldValue, const css::uno::Any& rNewValue )
 {
-    ThumbnailViewAcc* pAcc = ThumbnailViewAcc::getImplementation( GetAccessible( sal_False ) );
+    ThumbnailViewAcc* pAcc = ThumbnailViewAcc::getImplementation( GetAccessible( false ) );
 
     if( pAcc )
         pAcc->FireAccessibleEvent( nEventId, rOldValue, rNewValue );
@@ -511,11 +485,11 @@ void ThumbnailView::ImplFireAccessibleEvent( short nEventId, const ::com::sun::s
 
 bool ThumbnailView::ImplHasAccessibleListeners()
 {
-    ThumbnailViewAcc* pAcc = ThumbnailViewAcc::getImplementation( GetAccessible( sal_False ) );
+    ThumbnailViewAcc* pAcc = ThumbnailViewAcc::getImplementation( GetAccessible( false ) );
     return( pAcc && pAcc->HasAccessibleListeners() );
 }
 
-IMPL_LINK( ThumbnailView,ImplScrollHdl, ScrollBar*, pScrollBar )
+IMPL_LINK_TYPED( ThumbnailView,ImplScrollHdl, ScrollBar*, pScrollBar, void )
 {
     if ( pScrollBar->GetDelta() )
     {
@@ -524,13 +498,6 @@ IMPL_LINK( ThumbnailView,ImplScrollHdl, ScrollBar*, pScrollBar )
         if ( IsReallyVisible() && IsUpdateMode() )
             Invalidate();
     }
-    return 0;
-}
-
-IMPL_LINK (ThumbnailView, OnItemSelected, ThumbnailViewItem*, pItem)
-{
-    maItemStateHdl.Call(pItem);
-    return 0;
 }
 
 void ThumbnailView::KeyInput( const KeyEvent& rKEvt )
@@ -551,8 +518,8 @@ void ThumbnailView::KeyInput( const KeyEvent& rKEvt )
     bool bValidRange = false;
     bool bHasSelRange = mpStartSelRange != mFilteredItemList.end();
     size_t nNextPos = nLastPos;
-    KeyCode aKeyCode = rKEvt.GetKeyCode();
-    ThumbnailViewItem* pNext = NULL;
+    vcl::KeyCode aKeyCode = rKEvt.GetKeyCode();
+    ThumbnailViewItem* pNext = nullptr;
 
     if (aKeyCode.IsShift() && bHasSelRange)
     {
@@ -600,7 +567,7 @@ void ThumbnailView::KeyInput( const KeyEvent& rKEvt )
                 {
                     //If we are in the second last row just go the one in
                     //the row below, if theres not row below just go to the
-                    //last item but for the last row dont do anything.
+                    //last item but for the last row don't do anything.
                     if ( nLastPos + mnCols < mFilteredItemList.size( ) )
                     {
                         bValidRange = true;
@@ -635,6 +602,7 @@ void ThumbnailView::KeyInput( const KeyEvent& rKEvt )
                 if ( bFoundLast )
                     OnItemDblClicked( mFilteredItemList[nLastPos] );
             }
+            //fall-through
         default:
             Control::KeyInput( rKEvt );
     }
@@ -720,7 +688,7 @@ void ThumbnailView::MakeItemVisible( sal_uInt16 nItemId )
             bFound = true;
         }
     }
-    sal_uInt16 nRow = nPos / mnCols;
+    sal_uInt16 nRow = mnCols ? nPos / mnCols : 0;
 
     // Move the visible rows as little as possible to include that one
     if ( nRow < mnFirstLine )
@@ -853,62 +821,67 @@ void ThumbnailView::MouseButtonUp( const MouseEvent& rMEvt )
 
 void ThumbnailView::Command( const CommandEvent& rCEvt )
 {
-    if ( (rCEvt.GetCommand() == COMMAND_WHEEL) ||
-         (rCEvt.GetCommand() == COMMAND_STARTAUTOSCROLL) ||
-         (rCEvt.GetCommand() == COMMAND_AUTOSCROLL) )
+    if ( (rCEvt.GetCommand() == CommandEventId::Wheel) ||
+         (rCEvt.GetCommand() == CommandEventId::StartAutoScroll) ||
+         (rCEvt.GetCommand() == CommandEventId::AutoScroll) )
     {
-        if ( HandleScrollCommand( rCEvt, NULL, mpScrBar ) )
+        if ( HandleScrollCommand( rCEvt, nullptr, mpScrBar ) )
             return;
     }
 
     Control::Command( rCEvt );
 }
 
-void ThumbnailView::Paint( const Rectangle &aRect)
+void ThumbnailView::Paint(vcl::RenderContext& rRenderContext, const Rectangle& rRect)
 {
-    size_t      nItemCount = mItemList.size();
+    size_t nItemCount = mItemList.size();
 
     // Draw background
     drawinglayer::primitive2d::Primitive2DSequence aSeq(1);
-    aSeq[0] = drawinglayer::primitive2d::Primitive2DReference( new PolyPolygonColorPrimitive2D(
-                                        B2DPolyPolygon(Polygon(aRect,5,5).getB2DPolygon()),
-                                        maColor.getBColor()));
+    aSeq[0] = drawinglayer::primitive2d::Primitive2DReference(
+            new PolyPolygonColorPrimitive2D(
+                    B2DPolyPolygon( ::tools::Polygon(Rectangle(Point(), GetOutputSizePixel()), 0, 0).getB2DPolygon()),
+                    maFillColor.getBColor()));
 
-    mpProcessor->process(aSeq);
+    // Create the processor and process the primitives
+    const drawinglayer::geometry::ViewInformation2D aNewViewInfos;
+
+    std::unique_ptr<drawinglayer::processor2d::BaseProcessor2D> pProcessor(
+        drawinglayer::processor2d::createBaseProcessor2DFromOutputDevice(rRenderContext, aNewViewInfos));
+    pProcessor->process(aSeq);
 
     // draw items
-    for ( size_t i = 0; i < nItemCount; i++ )
+    for (size_t i = 0; i < nItemCount; i++)
     {
         ThumbnailViewItem *const pItem = mItemList[i];
 
-        if ( pItem->isVisible() )
-            DrawItem(pItem);
+        if (pItem->isVisible())
+        {
+            pItem->Paint(pProcessor.get(), mpItemAttrs);
+        }
     }
 
-    if ( mpScrBar && mpScrBar->IsVisible() )
-        mpScrBar->Paint(aRect);
+    if (mpScrBar && mpScrBar->IsVisible())
+        mpScrBar->Invalidate(rRect);
 }
 
 void ThumbnailView::GetFocus()
 {
-    if(GETFOCUS_TAB & GetGetFocusFlags())
+    // Select the first item if nothing selected
+    int nSelected = -1;
+    for (size_t i = 0, n = mItemList.size(); i < n && nSelected == -1; ++i)
     {
-        // Select the first item if nothing selected
-        int nSelected = -1;
-        for (size_t i = 0, n = mItemList.size(); i < n && nSelected == -1; ++i)
-        {
-            if (mItemList[i]->isSelected())
-                nSelected = i;
-        }
+        if (mItemList[i]->isSelected())
+            nSelected = i;
+    }
 
-        if ( nSelected == -1 && mItemList.size( ) > 0 )
-        {
-            SelectItem( 1 );
-        }
+    if (nSelected == -1 && mItemList.size() > 0)
+    {
+        SelectItem(1);
     }
 
     // Tell the accessible object that we got the focus.
-    ThumbnailViewAcc* pAcc = ThumbnailViewAcc::getImplementation( GetAccessible( sal_False ) );
+    ThumbnailViewAcc* pAcc = ThumbnailViewAcc::getImplementation( GetAccessible( false ) );
     if( pAcc )
         pAcc->GetFocus();
 
@@ -920,7 +893,7 @@ void ThumbnailView::LoseFocus()
     Control::LoseFocus();
 
     // Tell the accessible object that we lost the focus.
-    ThumbnailViewAcc* pAcc = ThumbnailViewAcc::getImplementation( GetAccessible( sal_False ) );
+    ThumbnailViewAcc* pAcc = ThumbnailViewAcc::getImplementation( GetAccessible( false ) );
     if( pAcc )
         pAcc->LoseFocus();
 }
@@ -938,38 +911,34 @@ void ThumbnailView::StateChanged( StateChangedType nType )
 {
     Control::StateChanged( nType );
 
-    if ( nType == STATE_CHANGE_INITSHOW )
+    if ( nType == StateChangedType::InitShow )
     {
         if ( IsReallyVisible() && IsUpdateMode() )
             Invalidate();
     }
-    else if ( nType == STATE_CHANGE_UPDATEMODE )
+    else if ( nType == StateChangedType::UpdateMode )
     {
         if ( IsReallyVisible() && IsUpdateMode() )
             Invalidate();
     }
-    else if ( nType == STATE_CHANGE_TEXT )
+    else if ( nType == StateChangedType::Text )
     {
     }
-    else if ( (nType == STATE_CHANGE_ZOOM) ||
-              (nType == STATE_CHANGE_CONTROLFONT) )
+    else if ( (nType == StateChangedType::Zoom) ||
+              (nType == StateChangedType::ControlFont) )
     {
-        ImplInitSettings( true, false, false );
         Invalidate();
     }
-    else if ( nType == STATE_CHANGE_CONTROLFOREGROUND )
+    else if ( nType == StateChangedType::ControlForeground )
     {
-        ImplInitSettings( false, true, false );
         Invalidate();
     }
-    else if ( nType == STATE_CHANGE_CONTROLBACKGROUND )
+    else if ( nType == StateChangedType::ControlBackground )
     {
-        ImplInitSettings( false, false, true );
         Invalidate();
     }
-    else if ( (nType == STATE_CHANGE_STYLE) || (nType == STATE_CHANGE_ENABLE) )
+    else if ( (nType == StateChangedType::Style) || (nType == StateChangedType::Enable) )
     {
-        ImplInitSettings( false, false, true );
         Invalidate();
     }
 }
@@ -978,13 +947,12 @@ void ThumbnailView::DataChanged( const DataChangedEvent& rDCEvt )
 {
     Control::DataChanged( rDCEvt );
 
-    if ( (rDCEvt.GetType() == DATACHANGED_FONTS) ||
-         (rDCEvt.GetType() == DATACHANGED_DISPLAY) ||
-         (rDCEvt.GetType() == DATACHANGED_FONTSUBSTITUTION) ||
-         ((rDCEvt.GetType() == DATACHANGED_SETTINGS) &&
-          (rDCEvt.GetFlags() & SETTINGS_STYLE)) )
+    if ( (rDCEvt.GetType() == DataChangedEventType::FONTS) ||
+         (rDCEvt.GetType() == DataChangedEventType::DISPLAY) ||
+         (rDCEvt.GetType() == DataChangedEventType::FONTSUBSTITUTION) ||
+         ((rDCEvt.GetType() == DataChangedEventType::SETTINGS) &&
+          (rDCEvt.GetFlags() & AllSettingsFlags::STYLE)) )
     {
-        ImplInitSettings( true, true, true );
         Invalidate();
     }
 }
@@ -1085,7 +1053,7 @@ sal_uInt16 ThumbnailView::getNextItemId() const
 
 void ThumbnailView::setItemMaxTextLength(sal_uInt32 nLength)
 {
-    mpItemAttrs->nMaxTextLenght = nLength;
+    mpItemAttrs->nMaxTextLength = nLength;
 }
 
 void ThumbnailView::setItemDimensions(long itemWidth, long thumbnailHeight, long displayHeight, int itemPadding)
@@ -1141,46 +1109,27 @@ void ThumbnailView::SelectItem( sal_uInt16 nItemId )
 
             if( pItemAcc )
             {
-                ::com::sun::star::uno::Any aOldAny, aNewAny;
+                css::uno::Any aOldAny, aNewAny;
                 if( !mbIsTransientChildrenDisabled )
                 {
-                    aNewAny <<= ::com::sun::star::uno::Reference< ::com::sun::star::uno::XInterface >(
+                    aNewAny <<= css::uno::Reference< css::uno::XInterface >(
                         static_cast< ::cppu::OWeakObject* >( pItemAcc ));
-                    ImplFireAccessibleEvent( ::com::sun::star::accessibility::AccessibleEventId::ACTIVE_DESCENDANT_CHANGED, aOldAny, aNewAny );
+                    ImplFireAccessibleEvent( css::accessibility::AccessibleEventId::ACTIVE_DESCENDANT_CHANGED, aOldAny, aNewAny );
                 }
                 else
                 {
-                    aNewAny <<= ::com::sun::star::accessibility::AccessibleStateType::FOCUSED;
-                    pItemAcc->FireAccessibleEvent( ::com::sun::star::accessibility::AccessibleEventId::STATE_CHANGED, aOldAny, aNewAny );
+                    aNewAny <<= css::accessibility::AccessibleStateType::FOCUSED;
+                    pItemAcc->FireAccessibleEvent( css::accessibility::AccessibleEventId::STATE_CHANGED, aOldAny, aNewAny );
                 }
             }
 
             // selection event
-            ::com::sun::star::uno::Any aOldAny, aNewAny;
-            ImplFireAccessibleEvent( ::com::sun::star::accessibility::AccessibleEventId::SELECTION_CHANGED, aOldAny, aNewAny );
+            css::uno::Any aOldAny, aNewAny;
+            ImplFireAccessibleEvent( css::accessibility::AccessibleEventId::SELECTION_CHANGED, aOldAny, aNewAny );
         }
     }
 }
 
-void ThumbnailView::DeselectItem( sal_uInt16 nItemId )
-{
-    size_t nItemPos = GetItemPos( nItemId );
-    if ( nItemPos == THUMBNAILVIEW_ITEM_NOTFOUND )
-        return;
-
-    ThumbnailViewItem* pItem = mFilteredItemList[nItemPos];
-    if (pItem->isSelected())
-    {
-        pItem->setSelection(false);
-        maItemStateHdl.Call(pItem);
-
-        if (IsReallyVisible() && IsUpdateMode())
-            Invalidate();
-
-        // TODO Trigger event in accessible object?
-    }
-}
-
 bool ThumbnailView::IsItemSelected( sal_uInt16 nItemId ) const
 {
     size_t nItemPos = GetItemPos( nItemId );
@@ -1208,38 +1157,19 @@ void ThumbnailView::deselectItems()
         Invalidate();
 }
 
-OUString ThumbnailView::GetItemText( sal_uInt16 nItemId ) const
-{
-    size_t nPos = GetItemPos( nItemId );
-
-    if ( nPos != THUMBNAILVIEW_ITEM_NOTFOUND )
-        return mFilteredItemList[nPos]->maTitle;
-
-    return OUString();
-}
-
 void ThumbnailView::ShowTooltips( bool bShowTooltips )
 {
     mbShowTooltips = bShowTooltips;
 }
 
-void ThumbnailView::SetColor( const Color& rColor )
-{
-    maColor = rColor;
-    mpItemAttrs->aFillColor = rColor.getBColor();
-
-    if ( IsReallyVisible() && IsUpdateMode() )
-        Invalidate();
-}
-
-void ThumbnailView::filterItems (const boost::function<bool (const ThumbnailViewItem*) > &func)
+void ThumbnailView::filterItems(const std::function<bool (const ThumbnailViewItem*)> &func)
 {
     mnFirstLine = 0;        // start at the top of the list instead of the current position
     maFilterFunc = func;
 
     size_t nSelPos = 0;
     bool bHasSelRange = false;
-    ThumbnailViewItem *curSel = mpStartSelRange != mFilteredItemList.end() ? *mpStartSelRange : NULL;
+    ThumbnailViewItem *curSel = mpStartSelRange != mFilteredItemList.end() ? *mpStartSelRange : nullptr;
 
     mFilteredItemList.clear();
 
@@ -1263,10 +1193,10 @@ void ThumbnailView::filterItems (const boost::function<bool (const ThumbnailView
             {
                 if ( ImplHasAccessibleListeners() )
                 {
-                    ::com::sun::star::uno::Any aOldAny, aNewAny;
+                    css::uno::Any aOldAny, aNewAny;
 
                     aOldAny <<= pItem->GetAccessible( mbIsTransientChildrenDisabled );
-                    ImplFireAccessibleEvent( ::com::sun::star::accessibility::AccessibleEventId::CHILD, aOldAny, aNewAny );
+                    ImplFireAccessibleEvent( css::accessibility::AccessibleEventId::CHILD, aOldAny, aNewAny );
                 }
 
                 pItem->show(false);
@@ -1283,7 +1213,7 @@ void ThumbnailView::filterItems (const boost::function<bool (const ThumbnailView
     Invalidate();
 }
 
-void ThumbnailView::sortItems (const boost::function<bool (const ThumbnailViewItem*, const ThumbnailViewItem*) > &func)
+void ThumbnailView::sortItems(const std::function<bool (const ThumbnailViewItem*, const ThumbnailViewItem*)> &func)
 {
     std::sort(mItemList.begin(),mItemList.end(),func);
 
@@ -1292,7 +1222,7 @@ void ThumbnailView::sortItems (const boost::function<bool (const ThumbnailViewIt
     Invalidate();
 }
 
-bool ThumbnailView::renameItem(ThumbnailViewItem*, OUString)
+bool ThumbnailView::renameItem(ThumbnailViewItem*, const OUString&)
 {
     // Do nothing by default
     return false;
@@ -1389,9 +1319,9 @@ BitmapEx ThumbnailView::readThumbnail(const OUString &msURL)
     BitmapEx aThumbnail;
     if (xIStream.is())
     {
-        ::std::auto_ptr<SvStream> pStream (
+        std::unique_ptr<SvStream> pStream (
             ::utl::UcbStreamHelper::CreateStream (xIStream));
-        ::vcl::PNGReader aReader (*pStream);
+        vcl::PNGReader aReader (*pStream);
         aThumbnail = aReader.Read ();
     }
 
@@ -1402,5 +1332,3 @@ BitmapEx ThumbnailView::readThumbnail(const OUString &msURL)
 }
 
 /* vim:set shiftwidth=4 softtabstop=4 expandtab: */
-
-
