@@ -18,7 +18,9 @@
  */
 
 #include "backingwindow.hxx"
+#include "inputdlg.hxx"
 
+#include <vcl/settings.hxx>
 #include <vcl/svapp.hxx>
 #include <vcl/virdev.hxx>
 
@@ -26,6 +28,13 @@
 #include <svtools/openfiledroptargetlistener.hxx>
 #include <svtools/colorcfg.hxx>
 #include <svtools/langhelp.hxx>
+#include <sfx2/filedlghelper.hxx>
+#include <sfx2/sfxresid.hxx>
+#include <sfx2/templatecontaineritem.hxx>
+#include <vcl/msgbox.hxx>
+#include <vcl/toolbox.hxx>
+
+#include <vcl/menubtn.hxx>
 
 #include <comphelper/processfactory.hxx>
 #include <comphelper/sequenceashashmap.hxx>
@@ -42,6 +51,9 @@
 #include <com/sun/star/system/SystemShellExecuteFlags.hpp>
 #include <com/sun/star/util/URLTransformer.hpp>
 #include <com/sun/star/task/InteractionHandler.hpp>
+#include <com/sun/star/ui/dialogs/TemplateDescription.hpp>
+
+#include <officecfg/Office/Common.hxx>
 
 using namespace ::com::sun::star;
 using namespace ::com::sun::star::beans;
@@ -55,24 +67,44 @@ const char IMPRESS_WIZARD_URL[] = "private:factory/simpress?slot=6686";
 const char DRAW_URL[] =           "private:factory/sdraw";
 const char BASE_URL[] =           "private:factory/sdatabase?Interactive";
 const char MATH_URL[] =           "private:factory/smath";
-const char TEMPLATE_URL[] =       "slot:5500";
+const char TEMPLATE_URL[] =       ".uno:NewDoc";
 const char OPEN_URL[] =           ".uno:Open";
+const char REMOTE_URL[] =         ".uno:OpenRemote";
 const char SERVICENAME_CFGREADACCESS[] = "com.sun.star.configuration.ConfigurationAccess";
 
-const int nButtonsFontSize = 15;
-const Color aButtonsBackground(114, 168, 84); // TDF green
-const Color aButtonsText(COL_WHITE);
+// increase size of the text in the buttons on the left fMultiplier-times
+float fMultiplier = 1.4f;
 
-BackingWindow::BackingWindow( Window* i_pParent ) :
+/***
+ *
+ * Order items in ascending order (useful for the selection sets and move/copy operations since the associated ids
+ * change when processed by the SfxDocumentTemplates class so we want to process to ones with higher id first)
+ *
+ ***/
+
+static bool cmpSelectionItems (const ThumbnailViewItem *pItem1, const ThumbnailViewItem *pItem2)
+{
+    return pItem1->mnId > pItem2->mnId;
+}
+
+
+BackingWindow::BackingWindow( vcl::Window* i_pParent ) :
     Window( i_pParent ),
     mxDesktop( Desktop::create(comphelper::getProcessComponentContext()) ),
+    mbLocalViewInitialized(false),
+    maButtonsTextColor(officecfg::Office::Common::Help::StartCenter::StartCenterTextColor::get()),
+    mbIsSaveMode( false ),
     mbInitControls( false ),
     mnHideExternalLinks( 0 ),
-    mpAccExec( NULL )
+    maSelTemplates(cmpSelectionItems),
+    maSelFolders(cmpSelectionItems)
+
 {
     m_pUIBuilder = new VclBuilder(this, getUIRootDir(), "sfx/ui/startcenter.ui", "StartCenter" );
 
     get(mpOpenButton, "open_all");
+    get(mpRemoteButton, "open_remote");
+    get(mpRecentButton, "open_recent");
     get(mpTemplateButton, "templates_all");
 
     get(mpCreateLabel, "create_label");
@@ -85,17 +117,36 @@ BackingWindow::BackingWindow( Window* i_pParent ) :
     get(mpMathAllButton, "math_all");
 
     get(mpHelpButton, "help");
+    //set an alternative help label that doesn't hotkey the H of the Help menu
+    mpHelpButton->SetText(get<Window>("althelplabel")->GetText());
     get(mpExtensionsButton, "extensions");
 
+    //Containers are invisible to cursor traversal
+    //So on pressing "right" when in Help the
+    //extension button is considered as a candidate
+
+    //But the containers are not invisible to the PushButton ctor which checks
+    //if the preceding window of its parent is a button and if it then
+    //defaults to grouping with it and if it is not a button defaults to
+    //setting itself as the start of a new group.
+
+    //So here take the second button and set it as explicitly not the start
+    //of a group, i.e. allow it to be grouped with the preceding
+    //PushButton so when seen as a candidate by cursor travelling
+    //it will be accepted as a continuation of the group.
+    WinBits nBits = mpExtensionsButton->GetStyle();
+    nBits &= ~WB_GROUP;
+    nBits |= WB_NOGROUP;
+    mpExtensionsButton->SetStyle(nBits);
+    assert(mpHelpButton->GetStyle() & WB_GROUP);
+    assert(!(mpExtensionsButton->GetStyle() & WB_GROUP));
+
     get(mpAllButtonsBox, "all_buttons_box");
     get(mpButtonsBox, "buttons_box");
     get(mpSmallButtonsBox, "small_buttons_box");
-    get(mpThinBox1, "thin_box1");
-    get(mpThinBox2, "thin_box2");
-    get(mpHelpBox, "help_box");
-    get(mpExtensionsBox, "extensions_box");
 
     get(mpAllRecentThumbnails, "all_recent");
+    get(mpLocalView, "local_view");
 
     maDndWindows.push_back(mpAllRecentThumbnails);
 
@@ -135,33 +186,24 @@ BackingWindow::BackingWindow( Window* i_pParent ) :
     Reference<XDesktop2> xDesktop = Desktop::create( comphelper::getProcessComponentContext() );
     mxDesktopDispatchProvider = xDesktop;
 
-    mpOpenButton->SetHelpId( ".HelpId:StartCenter:OpenButton" );
-    mpTemplateButton->SetHelpId( ".HelpId:StartCenter:TemplateButton" );
-
-    mpWriterAllButton->SetHelpId( ".HelpId:StartCenter:WriterButton" );
-    mpCalcAllButton->SetHelpId( ".HelpId:StartCenter:CalcButton" );
-    mpImpressAllButton->SetHelpId( ".HelpId:StartCenter:ImpressButton" );
-    mpDrawAllButton->SetHelpId( ".HelpId:StartCenter:DrawButton" );
-    mpDBAllButton->SetHelpId( ".HelpId:StartCenter:DBButton" );
-    mpMathAllButton->SetHelpId( ".HelpId:StartCenter:MathButton" );
-
-    mpHelpButton->SetHelpId(".HelpId:StartCenter:Info");
-    mpExtensionsButton->SetHelpId(".HelpId:StartCenter:Extensions");
-
     // init background
     SetBackground();
 }
 
 
 BackingWindow::~BackingWindow()
+{
+    disposeOnce();
+}
+
+void BackingWindow::dispose()
 {
     // deregister drag&drop helper
     if (mxDropTargetListener.is())
     {
-        for (std::vector<Window*>::iterator aI = maDndWindows.begin(),
-            aEnd = maDndWindows.end(); aI != aEnd; ++aI)
+        for (auto aI = maDndWindows.begin(), aEnd = maDndWindows.end(); aI != aEnd; ++aI)
         {
-            Window *pDndWin = *aI;
+            vcl::Window *pDndWin = *aI;
             css::uno::Reference< css::datatransfer::dnd::XDropTarget > xDropTarget =
                     pDndWin->GetDropTarget();
             if (xDropTarget.is())
@@ -170,8 +212,28 @@ BackingWindow::~BackingWindow()
                 xDropTarget->setActive(false);
             }
         }
-        mxDropTargetListener = css::uno::Reference< css::datatransfer::dnd::XDropTargetListener >();
+        mxDropTargetListener.clear();
     }
+    disposeBuilder();
+    mpOpenButton.clear();
+    mpRemoteButton.clear();
+    mpRecentButton.clear();
+    mpTemplateButton.clear();
+    mpCreateLabel.clear();
+    mpWriterAllButton.clear();
+    mpCalcAllButton.clear();
+    mpImpressAllButton.clear();
+    mpDrawAllButton.clear();
+    mpDBAllButton.clear();
+    mpMathAllButton.clear();
+    mpHelpButton.clear();
+    mpExtensionsButton.clear();
+    mpAllButtonsBox.clear();
+    mpButtonsBox.clear();
+    mpSmallButtonsBox.clear();
+    mpAllRecentThumbnails.clear();
+    mpLocalView.clear();
+    vcl::Window::dispose();
 }
 
 void BackingWindow::initControls()
@@ -198,31 +260,42 @@ void BackingWindow::initControls()
             aFileNewAppsAvailable.insert( sURL );
     }
 
-    if (aModuleOptions.IsModuleInstalled(SvtModuleOptions::E_SWRITER))
+    if (aModuleOptions.IsModuleInstalled(SvtModuleOptions::EModule::WRITER))
         mpAllRecentThumbnails->mnFileTypes |= TYPE_WRITER;
 
-    if (aModuleOptions.IsModuleInstalled(SvtModuleOptions::E_SCALC))
+    if (aModuleOptions.IsModuleInstalled(SvtModuleOptions::EModule::CALC))
         mpAllRecentThumbnails->mnFileTypes |= TYPE_CALC;
 
-    if (aModuleOptions.IsModuleInstalled(SvtModuleOptions::E_SIMPRESS))
+    if (aModuleOptions.IsModuleInstalled(SvtModuleOptions::EModule::IMPRESS))
         mpAllRecentThumbnails->mnFileTypes |= TYPE_IMPRESS;
 
-    if (aModuleOptions.IsModuleInstalled(SvtModuleOptions::E_SDRAW))
+    if (aModuleOptions.IsModuleInstalled(SvtModuleOptions::EModule::DRAW))
         mpAllRecentThumbnails->mnFileTypes |= TYPE_DRAW;
 
-    if (aModuleOptions.IsModuleInstalled(SvtModuleOptions::E_SDATABASE))
+    if (aModuleOptions.IsModuleInstalled(SvtModuleOptions::EModule::DATABASE))
         mpAllRecentThumbnails->mnFileTypes |= TYPE_DATABASE;
 
-    if (aModuleOptions.IsModuleInstalled(SvtModuleOptions::E_SMATH))
+    if (aModuleOptions.IsModuleInstalled(SvtModuleOptions::EModule::MATH))
         mpAllRecentThumbnails->mnFileTypes |= TYPE_MATH;
 
     mpAllRecentThumbnails->mnFileTypes |= TYPE_OTHER;
-    mpAllRecentThumbnails->loadRecentDocs();
+    mpAllRecentThumbnails->Reload();
     mpAllRecentThumbnails->ShowTooltips( true );
 
-    setupButton( mpOpenButton );
-    setupButton( mpTemplateButton );
+    //initialize Template view
+    mpLocalView->SetStyle( mpLocalView->GetStyle() | WB_VSCROLL);
+    mpLocalView->Hide();
 
+    mpTemplateButton->SetMenuMode( MENUBUTTON_MENUMODE_TIMED );
+
+    //set handlers
+    mpLocalView->setOpenRegionHdl(LINK(this, BackingWindow, OpenRegionHdl));
+    mpLocalView->setOpenTemplateHdl(LINK(this,BackingWindow,OpenTemplateHdl));
+
+    setupButton( mpOpenButton );
+    setupButton( mpRemoteButton );
+    setupButton( mpRecentButton );
+    setupButton( mpTemplateButton );
     setupButton( mpWriterAllButton );
     setupButton( mpDrawAllButton );
     setupButton( mpCalcAllButton );
@@ -233,95 +306,174 @@ void BackingWindow::initControls()
     mpExtensionsButton->SetClickHdl(LINK(this, BackingWindow, ExtLinkClickHdl));
 
     // setup nice colors
-    mpCreateLabel->SetControlForeground(aButtonsText);
-    Font aFont(mpCreateLabel->GetControlFont());
-    aFont.SetHeight(nButtonsFontSize);
+    mpCreateLabel->SetControlForeground(maButtonsTextColor);
+    vcl::Font aFont(mpCreateLabel->GetSettings().GetStyleSettings().GetLabelFont());
+    aFont.SetSize(Size(0, aFont.GetSize().Height() * fMultiplier));
     mpCreateLabel->SetControlFont(aFont);
 
-    mpHelpButton->SetControlForeground(aButtonsText);
-    mpExtensionsButton->SetControlForeground(aButtonsText);
+    mpHelpButton->SetControlForeground(maButtonsTextColor);
+    mpExtensionsButton->SetControlForeground(maButtonsTextColor);
+
+    const Color aButtonsBackground(officecfg::Office::Common::Help::StartCenter::StartCenterBackgroundColor::get());
 
     mpAllButtonsBox->SetBackground(aButtonsBackground);
     mpSmallButtonsBox->SetBackground(aButtonsBackground);
-    mpHelpBox->SetBackground(aButtonsBackground);
-    mpExtensionsBox->SetBackground(aButtonsBackground);
 
     // motif image under the buttons
     Wallpaper aWallpaper(get<FixedImage>("motif")->GetImage().GetBitmapEx());
-    aWallpaper.SetStyle(WALLPAPER_BOTTOMRIGHT);
+    aWallpaper.SetStyle(WallpaperStyle::BottomRight);
     aWallpaper.SetColor(aButtonsBackground);
 
     mpButtonsBox->SetBackground(aWallpaper);
 
-    // thin white rectangle aronud the Help and Extensions buttons
-    mpThinBox1->SetBackground(aButtonsText);
-    mpThinBox2->SetBackground(aButtonsText);
-
     Resize();
 
+    // compute the menubar height
+    sal_Int32 nMenuHeight = 0;
+    SystemWindow* pSystemWindow = GetSystemWindow();
+    if (pSystemWindow)
+    {
+        MenuBar* pMenuBar = pSystemWindow->GetMenuBar();
+        if (pMenuBar)
+            nMenuHeight = pMenuBar->ImplGetWindow()->GetOutputSizePixel().Height();
+    }
+
     set_width_request(mpAllRecentThumbnails->get_width_request() + mpAllButtonsBox->GetOptimalSize().Width());
-    set_height_request(mpAllButtonsBox->GetOptimalSize().Height());
+    set_height_request(nMenuHeight + mpAllButtonsBox->GetOptimalSize().Height());
+}
+
+void BackingWindow::initializeLocalView()
+{
+    if (!mbLocalViewInitialized)
+    {
+        mbLocalViewInitialized = true;
+        mpLocalView->Populate();
+        mpLocalView->showRootRegion();
+        mpLocalView->filterItems(ViewFilter_Application(FILTER_APPLICATION::NONE));
+    }
 }
 
 void BackingWindow::setupButton( PushButton* pButton )
 {
     // the buttons should have a bit bigger font
-    Font aFont(pButton->GetControlFont());
-    aFont.SetHeight(nButtonsFontSize);
+    vcl::Font aFont(pButton->GetSettings().GetStyleSettings().GetPushButtonFont());
+    aFont.SetSize(Size(0, aFont.GetSize().Height() * fMultiplier));
     pButton->SetControlFont(aFont);
 
     // color that fits the theme
-    pButton->SetControlForeground(aButtonsText);
-
+    pButton->SetControlForeground(maButtonsTextColor);
     pButton->SetClickHdl( LINK( this, BackingWindow, ClickHdl ) );
 }
 
-void BackingWindow::Paint( const Rectangle& )
+void BackingWindow::setupButton( MenuButton* pButton )
+{
+    vcl::Font aFont(pButton->GetSettings().GetStyleSettings().GetPushButtonFont());
+    aFont.SetSize(Size(0, aFont.GetSize().Height() * fMultiplier));
+    pButton->SetControlFont(aFont);
+
+    // color that fits the theme
+    pButton->SetControlForeground(maButtonsTextColor);
+
+    PopupMenu* pMenu = pButton->GetPopupMenu();
+    pMenu->SetMenuFlags(pMenu->GetMenuFlags() | MenuFlags::AlwaysShowDisabledEntries);
+
+    pButton->SetClickHdl(LINK(this, BackingWindow, ClickHdl));
+    pButton->SetSelectHdl(LINK(this, BackingWindow, MenuSelectHdl));
+}
+
+void BackingWindow::Paint(vcl::RenderContext& rRenderContext, const Rectangle&)
 {
     Resize();
 
-    Wallpaper aBack( svtools::ColorConfig().GetColorValue(::svtools::APPBACKGROUND).nColor );
-    Region aClip( Rectangle( Point( 0, 0 ), GetOutputSizePixel() ) );
+    Wallpaper aBack(svtools::ColorConfig().GetColorValue(::svtools::APPBACKGROUND).nColor);
+    vcl::Region aClip(Rectangle(Point(0, 0), GetOutputSizePixel()));
 
-    aClip.Exclude( maStartCentButtons );
+    aClip.Exclude(maStartCentButtons);
 
-    Push( PUSH_CLIPREGION );
-    IntersectClipRegion( aClip );
-    DrawWallpaper( Rectangle( Point( 0, 0 ), GetOutputSizePixel() ), aBack );
-    Pop();
+    rRenderContext.Push(PushFlags::CLIPREGION);
+    rRenderContext.IntersectClipRegion(aClip);
+    rRenderContext.DrawWallpaper(Rectangle(Point(0, 0), GetOutputSizePixel()), aBack);
+    rRenderContext.Pop();
 
-    VirtualDevice aDev( *this );
-    aDev.EnableRTL( IsRTLEnabled() );
-    aDev.SetOutputSizePixel( maStartCentButtons.GetSize() );
-    Point aOffset( Point( 0, 0 ) - maStartCentButtons.TopLeft());
-    aDev.DrawWallpaper( Rectangle( aOffset, GetOutputSizePixel() ), aBack );
+    ScopedVclPtrInstance<VirtualDevice> pVDev(rRenderContext);
+    pVDev->EnableRTL(rRenderContext.IsRTLEnabled());
+    pVDev->SetOutputSizePixel(maStartCentButtons.GetSize());
+    Point aOffset(Point(0, 0) - maStartCentButtons.TopLeft());
+    pVDev->DrawWallpaper(Rectangle(aOffset, GetOutputSizePixel()), aBack);
 
-    DrawOutDev( maStartCentButtons.TopLeft(), maStartCentButtons.GetSize(),
-                Point( 0, 0 ), maStartCentButtons.GetSize(),
-                aDev );
+    rRenderContext.DrawOutDev(maStartCentButtons.TopLeft(), maStartCentButtons.GetSize(),
+                              Point(0, 0), maStartCentButtons.GetSize(),
+                              *pVDev.get());
 }
 
-long BackingWindow::Notify( NotifyEvent& rNEvt )
+bool BackingWindow::PreNotify( NotifyEvent& rNEvt )
 {
-    if( rNEvt.GetType() == EVENT_KEYINPUT )
+    if( rNEvt.GetType() == MouseNotifyEvent::KEYINPUT )
     {
-        // try the 'normal' accelerators (so that eg. Ctrl+Q works)
-        if( !mpAccExec )
+        const KeyEvent* pEvt = rNEvt.GetKeyEvent();
+        const vcl::KeyCode& rKeyCode(pEvt->GetKeyCode());
+
+        // Subwindows of BackingWindow: Sidebar and Thumbnail view
+        if( rKeyCode.GetCode() == KEY_F6 )
         {
-            mpAccExec = svt::AcceleratorExecute::createAcceleratorHelper();
+            if( rKeyCode.IsShift() ) // Shift + F6
+            {
+                if( mpAllRecentThumbnails->HasFocus() )
+                {
+                    mpOpenButton->GrabFocus();
+                    return true;
+                }
+            }
+            else if ( rKeyCode.IsMod1() ) // Ctrl + F6
+            {
+                mpAllRecentThumbnails->GrabFocus();
+                return true;
+            }
+            else // F6
+            {
+                if( mpAllButtonsBox->HasChildPathFocus() )
+                {
+                    mpAllRecentThumbnails->GrabFocus();
+                    return true;
+                }
+            }
+        }
+
+        // try the 'normal' accelerators (so that eg. Ctrl+Q works)
+        if (!mpAccExec)
+        {
+            mpAccExec.reset(svt::AcceleratorExecute::createAcceleratorHelper());
             mpAccExec->init( comphelper::getProcessComponentContext(), mxFrame);
         }
 
-        const KeyEvent* pEvt = rNEvt.GetKeyEvent();
-        const KeyCode& rKeyCode(pEvt->GetKeyCode());
-        if( pEvt && mpAccExec->execute(rKeyCode) )
-            return 1;
+        const OUString aCommand = mpAccExec->findCommand(svt::AcceleratorExecute::st_VCLKey2AWTKey(rKeyCode));
+        if ((aCommand != "vnd.sun.star.findbar:FocusToFindbar") && pEvt && mpAccExec->execute(rKeyCode))
+            return true;
     }
 
-    return Window::Notify( rNEvt );
+    return Window::PreNotify( rNEvt );
 }
 
-void BackingWindow::setOwningFrame( const com::sun::star::uno::Reference< com::sun::star::frame::XFrame >& xFrame )
+void BackingWindow::GetFocus()
+{
+    GetFocusFlags nFlags = GetParent()->GetGetFocusFlags();
+    if( nFlags & GetFocusFlags::F6 )
+    {
+        if( nFlags & GetFocusFlags::Forward ) // F6
+        {
+            mpOpenButton->GrabFocus();
+            return;
+        }
+        else // Shift + F6 or Ctrl + F6
+        {
+            mpAllRecentThumbnails->GrabFocus();
+            return;
+        }
+    }
+    Window::GetFocus();
+}
+
+void BackingWindow::setOwningFrame( const css::uno::Reference< css::frame::XFrame >& xFrame )
 {
     mxFrame = xFrame;
     if( ! mbInitControls )
@@ -330,10 +482,9 @@ void BackingWindow::setOwningFrame( const com::sun::star::uno::Reference< com::s
     // establish drag&drop mode
     mxDropTargetListener.set(new OpenFileDropTargetListener(mxContext, mxFrame));
 
-    for (std::vector<Window*>::iterator aI = maDndWindows.begin(),
-        aEnd = maDndWindows.end(); aI != aEnd; ++aI)
+    for (auto aI = maDndWindows.begin(), aEnd = maDndWindows.end(); aI != aEnd; ++aI)
     {
-        Window *pDndWin = *aI;
+        vcl::Window *pDndWin = *aI;
         css::uno::Reference< css::datatransfer::dnd::XDropTarget > xDropTarget =
             pDndWin->GetDropTarget();
         if (xDropTarget.is())
@@ -349,14 +500,14 @@ void BackingWindow::Resize()
     maStartCentButtons = Rectangle( Point(0, 0), GetOutputSizePixel() );
 
     if (isLayoutEnabled(this))
-        VclContainer::setLayoutAllocation(*GetWindow(WINDOW_FIRSTCHILD),
+        VclContainer::setLayoutAllocation(*GetWindow(GetWindowType::FirstChild),
             maStartCentButtons.TopLeft(), maStartCentButtons.GetSize());
 
-    if( !IsInPaint())
+    if (!IsInPaint())
         Invalidate();
 }
 
-IMPL_LINK(BackingWindow, ExtLinkClickHdl, Button*, pButton)
+IMPL_LINK_TYPED(BackingWindow, ExtLinkClickHdl, Button*, pButton, void)
 {
     OUString aNode;
 
@@ -393,10 +544,9 @@ IMPL_LINK(BackingWindow, ExtLinkClickHdl, Button*, pButton)
         {
         }
     }
-    return 0;
 }
 
-IMPL_LINK( BackingWindow, ClickHdl, Button*, pButton )
+IMPL_LINK_TYPED( BackingWindow, ClickHdl, Button*, pButton, void )
 {
     // dispatch the appropriate URL and end the dialog
     if( pButton == mpWriterAllButton )
@@ -415,60 +565,122 @@ IMPL_LINK( BackingWindow, ClickHdl, Button*, pButton )
     {
         Reference< XDispatchProvider > xFrame( mxFrame, UNO_QUERY );
 
-        Sequence< com::sun::star::beans::PropertyValue > aArgs(1);
+        Sequence< css::beans::PropertyValue > aArgs(1);
         PropertyValue* pArg = aArgs.getArray();
         pArg[0].Name = "Referer";
         pArg[0].Value <<= OUString("private:user");
 
         dispatchURL( OPEN_URL, OUString(), xFrame, aArgs );
     }
-    else if( pButton == mpTemplateButton )
+    else if( pButton == mpRemoteButton )
     {
         Reference< XDispatchProvider > xFrame( mxFrame, UNO_QUERY );
 
-        Sequence< com::sun::star::beans::PropertyValue > aArgs(1);
+        Sequence< css::beans::PropertyValue > aArgs(0);
+
+        dispatchURL( REMOTE_URL, OUString(), xFrame, aArgs );
+    }
+    else if( pButton == mpRecentButton )
+    {
+        mpLocalView->Hide();
+        mpAllRecentThumbnails->Show();
+        mpAllRecentThumbnails->GrabFocus();
+    }
+    else if( pButton == mpTemplateButton )
+    {
+        mpAllRecentThumbnails->Hide();
+        initializeLocalView();
+        mpLocalView->filterItems(ViewFilter_Application(FILTER_APPLICATION::NONE));
+        mpLocalView->Show();
+        mpLocalView->reload();
+        mpLocalView->GrabFocus();
+    }
+}
+
+IMPL_LINK_TYPED( BackingWindow, MenuSelectHdl, MenuButton*, pButton, void )
+{
+    initializeLocalView();
+
+    OString sId = pButton->GetCurItemIdent();
+
+    if( sId == "filter_writer" )
+    {
+        mpLocalView->filterItems(ViewFilter_Application(FILTER_APPLICATION::WRITER));
+    }
+    else if( sId == "filter_calc" )
+    {
+        mpLocalView->filterItems(ViewFilter_Application(FILTER_APPLICATION::CALC));
+    }
+    else if( sId == "filter_impress" )
+    {
+        mpLocalView->filterItems(ViewFilter_Application(FILTER_APPLICATION::IMPRESS));
+    }
+    else if( sId == "filter_draw" )
+    {
+        mpLocalView->filterItems(ViewFilter_Application(FILTER_APPLICATION::DRAW));
+    }
+    else if( sId == "edit" )
+    {
+        Reference< XDispatchProvider > xFrame( mxFrame, UNO_QUERY );
+
+        Sequence< css::beans::PropertyValue > aArgs(1);
         PropertyValue* pArg = aArgs.getArray();
         pArg[0].Name = "Referer";
         pArg[0].Value <<= OUString("private:user");
 
         dispatchURL( TEMPLATE_URL, OUString(), xFrame, aArgs );
+
     }
-    return 0;
+
+    mpAllRecentThumbnails->Hide();
+    mpLocalView->Show();
+    mpLocalView->reload();
+    mpLocalView->GrabFocus();
 }
 
-IMPL_LINK( BackingWindow, OpenTemplateHdl, ThumbnailViewItem*, pItem)
+
+IMPL_LINK_NOARG_TYPED( BackingWindow, OpenRegionHdl, void*, void)
 {
-    uno::Sequence< PropertyValue > aArgs(4);
-    aArgs[0].Name = "AsTemplate";
-    aArgs[0].Value <<= sal_True;
-    aArgs[1].Name = "MacroExecutionMode";
-    aArgs[1].Value <<= MacroExecMode::USE_CONFIG;
-    aArgs[2].Name = "UpdateDocMode";
-    aArgs[2].Value <<= UpdateDocMode::ACCORDING_TO_CONFIG;
-    aArgs[3].Name = "InteractionHandler";
-    aArgs[3].Value <<= task::InteractionHandler::createWithParent( ::comphelper::getProcessComponentContext(), 0 );
+    maSelFolders.clear();
+    maSelTemplates.clear();
+}
 
-    TemplateViewItem *pTemplateItem = static_cast<TemplateViewItem*>(pItem);
-
-    try
+IMPL_LINK_TYPED(BackingWindow, OpenTemplateHdl, ThumbnailViewItem*, pItem, void)
+{
+    if (!mbIsSaveMode)
     {
-        mxDesktop->loadComponentFromURL(pTemplateItem->getPath(),"_default", 0, aArgs );
-    }
-    catch( const uno::Exception& )
-    {
-    }
+        uno::Sequence< PropertyValue > aArgs(4);
+        aArgs[0].Name = "AsTemplate";
+        aArgs[0].Value <<= sal_True;
+        aArgs[1].Name = "MacroExecutionMode";
+        aArgs[1].Value <<= MacroExecMode::USE_CONFIG;
+        aArgs[2].Name = "UpdateDocMode";
+        aArgs[2].Value <<= UpdateDocMode::ACCORDING_TO_CONFIG;
+        aArgs[3].Name = "InteractionHandler";
+        aArgs[3].Value <<= task::InteractionHandler::createWithParent( ::comphelper::getProcessComponentContext(), nullptr );
 
-    return 0;
+        TemplateViewItem *pTemplateItem = static_cast<TemplateViewItem*>(pItem);
+
+        Reference< XDispatchProvider > xFrame( mxFrame, UNO_QUERY );
+
+        try
+        {
+            dispatchURL( pTemplateItem->getPath(), "_default", xFrame, aArgs );
+        }
+        catch( const uno::Exception& )
+        {
+        }
+    }
 }
 
 struct ImplDelayedDispatch
 {
     Reference< XDispatch >      xDispatch;
-    com::sun::star::util::URL   aDispatchURL;
+    css::util::URL   aDispatchURL;
     Sequence< PropertyValue >   aArgs;
 
     ImplDelayedDispatch( const Reference< XDispatch >& i_xDispatch,
-                         const com::sun::star::util::URL& i_rURL,
+                         const css::util::URL& i_rURL,
                          const Sequence< PropertyValue >& i_rArgs )
     : xDispatch( i_xDispatch ),
       aDispatchURL( i_rURL ),
@@ -478,9 +690,9 @@ struct ImplDelayedDispatch
     ~ImplDelayedDispatch() {}
 };
 
-static long implDispatchDelayed( void*, void* pArg )
+static void implDispatchDelayed( void*, void* pArg )
 {
-    struct ImplDelayedDispatch* pDispatch = reinterpret_cast<ImplDelayedDispatch*>(pArg);
+    struct ImplDelayedDispatch* pDispatch = static_cast<ImplDelayedDispatch*>(pArg);
     try
     {
         pDispatch->xDispatch->dispatch( pDispatch->aDispatchURL, pDispatch->aArgs );
@@ -491,8 +703,6 @@ static long implDispatchDelayed( void*, void* pArg )
 
     // clean up
     delete pDispatch;
-
-    return 0;
 }
 
 void BackingWindow::dispatchURL( const OUString& i_rURL,
@@ -508,11 +718,11 @@ void BackingWindow::dispatchURL( const OUString& i_rURL,
         return;
 
     // get an URL transformer to clean up the URL
-    com::sun::star::util::URL aDispatchURL;
+    css::util::URL aDispatchURL;
     aDispatchURL.Complete = i_rURL;
 
-    Reference < com::sun::star::util::XURLTransformer > xURLTransformer(
-        com::sun::star::util::URLTransformer::create( comphelper::getProcessComponentContext() ) );
+    Reference < css::util::XURLTransformer > xURLTransformer(
+        css::util::URLTransformer::create( comphelper::getProcessComponentContext() ) );
     try
     {
         // clean up the URL
@@ -525,16 +735,15 @@ void BackingWindow::dispatchURL( const OUString& i_rURL,
         if ( xDispatch.is() )
         {
             ImplDelayedDispatch* pDisp = new ImplDelayedDispatch( xDispatch, aDispatchURL, i_rArgs );
-            sal_uLong nEventId = 0;
-            if( ! Application::PostUserEvent( nEventId, Link( NULL, implDispatchDelayed ), pDisp ) )
+            if( Application::PostUserEvent( Link<void*,void>( nullptr, implDispatchDelayed ), pDisp ) == nullptr )
                 delete pDisp; // event could not be posted for unknown reason, at least don't leak
         }
     }
-    catch (const com::sun::star::uno::RuntimeException&)
+    catch (const css::uno::RuntimeException&)
     {
         throw;
     }
-    catch (const com::sun::star::uno::Exception&)
+    catch (const css::uno::Exception&)
     {
     }
 }
@@ -542,7 +751,7 @@ void BackingWindow::dispatchURL( const OUString& i_rURL,
 Size BackingWindow::GetOptimalSize() const
 {
     if (isLayoutEnabled(this))
-        return VclContainer::getLayoutRequisition(*GetWindow(WINDOW_FIRSTCHILD));
+        return VclContainer::getLayoutRequisition(*GetWindow(GetWindowType::FirstChild));
 
     return Window::GetOptimalSize();
 }
