@@ -10,7 +10,7 @@
 #include <sfx2/checkin.hxx>
 #include <vcl/msgbox.hxx>
 
-SfxCheckinDialog::SfxCheckinDialog( Window* pParent ) :
+SfxCheckinDialog::SfxCheckinDialog( vcl::Window* pParent ) :
     ModalDialog( pParent, "CheckinDialog", "sfx/ui/checkin.ui" )
 {
     get( m_pCommentED, "VersionComment" );
@@ -20,6 +20,19 @@ SfxCheckinDialog::SfxCheckinDialog( Window* pParent ) :
     m_pOKBtn->SetClickHdl( LINK( this, SfxCheckinDialog, OKHdl ) );
 }
 
+SfxCheckinDialog::~SfxCheckinDialog()
+{
+    disposeOnce();
+}
+
+void SfxCheckinDialog::dispose()
+{
+    m_pCommentED.clear();
+    m_pMajorCB.clear();
+    m_pOKBtn.clear();
+    ModalDialog::dispose();
+}
+
 OUString SfxCheckinDialog::GetComment( )
 {
     return m_pCommentED->GetText( );
@@ -30,10 +43,9 @@ bool SfxCheckinDialog::IsMajor( )
     return m_pMajorCB->IsChecked( );
 }
 
-IMPL_LINK_NOARG( SfxCheckinDialog, OKHdl )
+IMPL_LINK_NOARG_TYPED( SfxCheckinDialog, OKHdl, Button*, void )
 {
     EndDialog( RET_OK );
-    return 0;
 }
 
 /* vim:set shiftwidth=4 softtabstop=4 expandtab: */
