@@ -18,8 +18,8 @@
  */
 
 #include <sfx2/sidebar/Sidebar.hxx>
-#include "SidebarController.hxx"
-#include "ResourceManager.hxx"
+#include <sfx2/sidebar/SidebarController.hxx>
+#include <sfx2/sidebar/ResourceManager.hxx>
 
 using namespace css;
 
@@ -30,8 +30,10 @@ void Sidebar::ShowPanel (
     const css::uno::Reference<frame::XFrame>& rxFrame)
 {
     SidebarController* pController = SidebarController::GetSidebarControllerForFrame(rxFrame);
-    const PanelDescriptor* pPanelDescriptor = ResourceManager::Instance().GetPanelDescriptor(rsPanelId);
-    if (pController!=NULL && pPanelDescriptor != NULL)
+
+    const PanelDescriptor* pPanelDescriptor = pController->GetResourceManager()->GetPanelDescriptor(rsPanelId);
+
+    if (pController!=nullptr && pPanelDescriptor != nullptr)
     {
         // This should be a lot more sophisticated:
         // - Make the deck switching asynchronous
