@@ -17,25 +17,24 @@
  *   the License at http://www.apache.org/licenses/LICENSE-2.0 .
  */
 #include <sfx2/sidebar/Theme.hxx>
-#include "Paint.hxx"
-#include "SidebarResource.hxx"
+#include <sfx2/sidebar/Paint.hxx>
+#include <sfx2/sidebar/SidebarResource.hxx>
 #include <sfx2/sidebar/Tools.hxx>
 #include <sfx2/app.hxx>
 
 #include <tools/svborder.hxx>
 #include <tools/rc.hxx>
 #include <vcl/svapp.hxx>
+#include <vcl/settings.hxx>
 
 using namespace css;
-using namespace cssu;
-
+using namespace css::uno;
 
 namespace sfx2 { namespace sidebar {
 
-
 Theme& Theme::GetCurrentTheme()
 {
-    return SFX_APP()->GetSidebarTheme();
+    return SfxGetpApp()->GetSidebarTheme();
 }
 
 Theme::Theme()
@@ -57,16 +56,10 @@ Theme::Theme()
     SetupPropertyMaps();
 }
 
-
-
-
-Theme::~Theme (void)
+Theme::~Theme()
 {
 }
 
-
-
-
 Image Theme::GetImage (const ThemeItem eItem)
 {
     const PropertyType eType (GetPropertyType(eItem));
@@ -76,9 +69,6 @@ Image Theme::GetImage (const ThemeItem eItem)
     return rTheme.maImages[nIndex];
 }
 
-
-
-
 Color Theme::GetColor (const ThemeItem eItem)
 {
     const PropertyType eType (GetPropertyType(eItem));
@@ -93,9 +83,6 @@ Color Theme::GetColor (const ThemeItem eItem)
         return COL_WHITE;
 }
 
-
-
-
 const Paint& Theme::GetPaint (const ThemeItem eItem)
 {
     const PropertyType eType (GetPropertyType(eItem));
@@ -105,17 +92,11 @@ const Paint& Theme::GetPaint (const ThemeItem eItem)
     return rTheme.maPaints[nIndex];
 }
 
-
-
-
 const Wallpaper Theme::GetWallpaper (const ThemeItem eItem)
 {
     return GetPaint(eItem).GetWallpaper();
 }
 
-
-
-
 sal_Int32 Theme::GetInteger (const ThemeItem eItem)
 {
     const PropertyType eType (GetPropertyType(eItem));
@@ -125,9 +106,6 @@ sal_Int32 Theme::GetInteger (const ThemeItem eItem)
     return rTheme.maIntegers[nIndex];
 }
 
-
-
-
 bool Theme::GetBoolean (const ThemeItem eItem)
 {
     const PropertyType eType (GetPropertyType(eItem));
@@ -137,19 +115,13 @@ bool Theme::GetBoolean (const ThemeItem eItem)
     return rTheme.maBooleans[nIndex];
 }
 
-
-
-
-bool Theme::IsHighContrastMode (void)
+bool Theme::IsHighContrastMode()
 {
     const Theme& rTheme (GetCurrentTheme());
     return rTheme.mbIsHighContrastMode;
 }
 
-
-
-
-void Theme::HandleDataChange (void)
+void Theme::HandleDataChange()
 {
     Theme& rTheme (GetCurrentTheme());
 
@@ -163,23 +135,14 @@ void Theme::HandleDataChange (void)
     GetCurrentTheme().UpdateTheme();
 }
 
-
-
-
-void Theme::InitializeTheme (void)
+void Theme::InitializeTheme()
 {
-    setPropertyValue(
-        maPropertyIdToNameMap[Bool_UseSymphonyIcons],
-        Any(false));
     setPropertyValue(
         maPropertyIdToNameMap[Bool_UseSystemColors],
         Any(false));
 }
 
-
-
-
-void Theme::UpdateTheme (void)
+void Theme::UpdateTheme()
 {
     SidebarResource aLocalResource;
 
@@ -374,7 +337,6 @@ void Theme::UpdateTheme (void)
             Any(true));
 
         */
-
         // Gradient style
         Color aGradientStop2 (aBaseBackgroundColor);
         aGradientStop2.IncreaseLuminance(17);
@@ -422,21 +384,18 @@ void Theme::UpdateTheme (void)
     }
 }
 
-
-
-
-void SAL_CALL Theme::disposing (void)
+void SAL_CALL Theme::disposing()
 {
     ChangeListeners aListeners;
-    maChangeListeners.swap(aListeners);
+    aListeners.swap(maChangeListeners);
 
     const lang::EventObject aEvent (static_cast<XWeak*>(this));
 
     for (ChangeListeners::const_iterator
-             iContainer(maChangeListeners.begin()),
-             iContainerEnd(maChangeListeners.end());
-         iContainerEnd!=iContainerEnd;
-         ++iContainerEnd)
+             iContainer(aListeners.begin()),
+             iContainerEnd(aListeners.end());
+         iContainer != iContainerEnd;
+         ++iContainer)
     {
         for (ChangeListenerContainer::const_iterator
                  iListener(iContainer->second.begin()),
@@ -455,38 +414,31 @@ void SAL_CALL Theme::disposing (void)
     }
 }
 
-
-
-
-Reference<beans::XPropertySet> Theme::GetPropertySet (void)
+Reference<beans::XPropertySet> Theme::GetPropertySet()
 {
     return Reference<beans::XPropertySet>(static_cast<XWeak*>(&GetCurrentTheme()), UNO_QUERY);
 }
 
-
-
-
-Reference<beans::XPropertySetInfo> SAL_CALL Theme::getPropertySetInfo (void)
-    throw(cssu::RuntimeException)
+Reference<beans::XPropertySetInfo> SAL_CALL Theme::getPropertySetInfo()
+    throw(css::uno::RuntimeException, std::exception)
 {
     return Reference<beans::XPropertySetInfo>(this);
 }
 
-
-
-
 void SAL_CALL Theme::setPropertyValue (
     const ::rtl::OUString& rsPropertyName,
-    const cssu::Any& rValue)
-    throw(cssu::RuntimeException)
+    const css::uno::Any& rValue)
+    throw (css::beans::UnknownPropertyException,
+           css::uno::RuntimeException,
+           std::exception)
 {
     PropertyNameToIdMap::const_iterator iId (maPropertyNameToIdMap.find(rsPropertyName));
     if (iId == maPropertyNameToIdMap.end())
-        throw beans::UnknownPropertyException(rsPropertyName, NULL);
+        throw beans::UnknownPropertyException(rsPropertyName);
 
     const PropertyType eType (GetPropertyType(iId->second));
     if (eType == PT_Invalid)
-        throw beans::UnknownPropertyException(rsPropertyName, NULL);
+        throw beans::UnknownPropertyException(rsPropertyName);
 
     const ThemeItem eItem (iId->second);
 
@@ -519,14 +471,11 @@ void SAL_CALL Theme::setPropertyValue (
     BroadcastPropertyChange(GetChangeListeners(eItem, false), aEvent);
 }
 
-
-
-
 Any SAL_CALL Theme::getPropertyValue (
     const ::rtl::OUString& rsPropertyName)
     throw(css::beans::UnknownPropertyException,
         css::lang::WrappedTargetException,
-        cssu::RuntimeException)
+        css::uno::RuntimeException, std::exception)
 {
     PropertyNameToIdMap::const_iterator iId (maPropertyNameToIdMap.find(rsPropertyName));
     if (iId == maPropertyNameToIdMap.end())
@@ -541,15 +490,12 @@ Any SAL_CALL Theme::getPropertyValue (
     return maRawValues[eItem];
 }
 
-
-
-
 void SAL_CALL Theme::addPropertyChangeListener(
     const ::rtl::OUString& rsPropertyName,
-    const cssu::Reference<css::beans::XPropertyChangeListener>& rxListener)
+    const css::uno::Reference<css::beans::XPropertyChangeListener>& rxListener)
     throw(css::beans::UnknownPropertyException,
         css::lang::WrappedTargetException,
-        cssu::RuntimeException)
+        css::uno::RuntimeException, std::exception)
 {
     ThemeItem eItem (__AnyItem);
     if (rsPropertyName.getLength() > 0)
@@ -565,19 +511,16 @@ void SAL_CALL Theme::addPropertyChangeListener(
         eItem = iId->second;
     }
     ChangeListenerContainer* pListeners = GetChangeListeners(eItem, true);
-    if (pListeners != NULL)
+    if (pListeners != nullptr)
         pListeners->push_back(rxListener);
 }
 
-
-
-
 void SAL_CALL Theme::removePropertyChangeListener(
     const ::rtl::OUString& rsPropertyName,
-    const cssu::Reference<css::beans::XPropertyChangeListener>& rxListener)
+    const css::uno::Reference<css::beans::XPropertyChangeListener>& rxListener)
     throw(css::beans::UnknownPropertyException,
         css::lang::WrappedTargetException,
-        cssu::RuntimeException)
+        css::uno::RuntimeException, std::exception)
 {
     ThemeItem eItem (__AnyItem);
     if (rsPropertyName.getLength() > 0)
@@ -593,7 +536,7 @@ void SAL_CALL Theme::removePropertyChangeListener(
         eItem = iId->second;
     }
     ChangeListenerContainer* pContainer = GetChangeListeners(eItem, false);
-    if (pContainer != NULL)
+    if (pContainer != nullptr)
     {
         ChangeListenerContainer::iterator iListener (::std::find(pContainer->begin(), pContainer->end(), rxListener));
         if (iListener != pContainer->end())
@@ -607,15 +550,12 @@ void SAL_CALL Theme::removePropertyChangeListener(
     }
 }
 
-
-
-
 void SAL_CALL Theme::addVetoableChangeListener(
     const ::rtl::OUString& rsPropertyName,
-    const cssu::Reference<css::beans::XVetoableChangeListener>& rxListener)
+    const css::uno::Reference<css::beans::XVetoableChangeListener>& rxListener)
     throw(css::beans::UnknownPropertyException,
         css::lang::WrappedTargetException,
-        cssu::RuntimeException)
+        css::uno::RuntimeException, std::exception)
 {
     ThemeItem eItem (__AnyItem);
     if (rsPropertyName.getLength() > 0)
@@ -631,19 +571,16 @@ void SAL_CALL Theme::addVetoableChangeListener(
         eItem = iId->second;
     }
     VetoableListenerContainer* pListeners = GetVetoableListeners(eItem, true);
-    if (pListeners != NULL)
+    if (pListeners != nullptr)
         pListeners->push_back(rxListener);
 }
 
-
-
-
 void SAL_CALL Theme::removeVetoableChangeListener(
     const ::rtl::OUString& rsPropertyName,
-    const cssu::Reference<css::beans::XVetoableChangeListener>& rxListener)
+    const css::uno::Reference<css::beans::XVetoableChangeListener>& rxListener)
     throw(css::beans::UnknownPropertyException,
         css::lang::WrappedTargetException,
-        cssu::RuntimeException)
+        css::uno::RuntimeException, std::exception)
 {
     ThemeItem eItem (__AnyItem);
     if (rsPropertyName.getLength() > 0)
@@ -659,7 +596,7 @@ void SAL_CALL Theme::removeVetoableChangeListener(
         eItem = iId->second;
     }
     VetoableListenerContainer* pContainer = GetVetoableListeners(eItem, false);
-    if (pContainer != NULL)
+    if (pContainer != nullptr)
     {
         VetoableListenerContainer::iterator iListener (::std::find(pContainer->begin(), pContainer->end(), rxListener));
         if (iListener != pContainer->end())
@@ -672,11 +609,8 @@ void SAL_CALL Theme::removeVetoableChangeListener(
     }
 }
 
-
-
-
-cssu::Sequence<css::beans::Property> SAL_CALL Theme::getProperties (void)
-    throw(cssu::RuntimeException)
+css::uno::Sequence<css::beans::Property> SAL_CALL Theme::getProperties()
+    throw(css::uno::RuntimeException, std::exception)
 {
     ::std::vector<beans::Property> aProperties;
 
@@ -695,17 +629,14 @@ cssu::Sequence<css::beans::Property> SAL_CALL Theme::getProperties (void)
         aProperties.push_back(aProperty);
     }
 
-    return cssu::Sequence<css::beans::Property>(
+    return css::uno::Sequence<css::beans::Property>(
         &aProperties.front(),
         aProperties.size());
 }
 
-
-
-
 beans::Property SAL_CALL Theme::getPropertyByName (const ::rtl::OUString& rsPropertyName)
     throw(css::beans::UnknownPropertyException,
-        cssu::RuntimeException)
+        css::uno::RuntimeException, std::exception)
 {
     PropertyNameToIdMap::const_iterator iId (maPropertyNameToIdMap.find(rsPropertyName));
     if (iId == maPropertyNameToIdMap.end())
@@ -724,11 +655,8 @@ beans::Property SAL_CALL Theme::getPropertyByName (const ::rtl::OUString& rsProp
         0);
 }
 
-
-
-
 sal_Bool SAL_CALL Theme::hasPropertyByName (const ::rtl::OUString& rsPropertyName)
-    throw(cssu::RuntimeException)
+    throw(css::uno::RuntimeException, std::exception)
 {
     PropertyNameToIdMap::const_iterator iId (maPropertyNameToIdMap.find(rsPropertyName));
     if (iId == maPropertyNameToIdMap.end())
@@ -741,10 +669,7 @@ sal_Bool SAL_CALL Theme::hasPropertyByName (const ::rtl::OUString& rsPropertyNam
     return sal_True;
 }
 
-
-
-
-void Theme::SetupPropertyMaps (void)
+void Theme::SetupPropertyMaps()
 {
     maPropertyIdToNameMap.resize(__Post_Rect);
     maImages.resize(__Image_Color - __Pre_Image - 1);
@@ -754,7 +679,7 @@ void Theme::SetupPropertyMaps (void)
     maBooleans.resize(__Bool_Rect - __Int_Bool - 1);
     maRectangles.resize(__Post_Rect - __Bool_Rect - 1);
 
-    #define AddEntry(e) maPropertyNameToIdMap[OUString(#e)]=e; maPropertyIdToNameMap[e]=OUString(#e)
+    #define AddEntry(e) maPropertyNameToIdMap[OUString(#e)]=e; maPropertyIdToNameMap[e]=#e
 
     AddEntry(Image_Grip);
     AddEntry(Image_Expand);
@@ -806,7 +731,6 @@ void Theme::SetupPropertyMaps (void)
     AddEntry(Int_TabBarBottomPadding);
     AddEntry(Int_ButtonCornerRadius);
 
-    AddEntry(Bool_UseSymphonyIcons);
     AddEntry(Bool_UseSystemColors);
     AddEntry(Bool_UseToolBoxItemSeparator);
     AddEntry(Bool_IsHighContrastModeActive);
@@ -819,9 +743,6 @@ void Theme::SetupPropertyMaps (void)
     maRawValues.resize(maPropertyIdToNameMap.size());
 }
 
-
-
-
 Theme::PropertyType Theme::GetPropertyType (const ThemeItem eItem)
 {
     switch(eItem)
@@ -880,7 +801,6 @@ Theme::PropertyType Theme::GetPropertyType (const ThemeItem eItem)
         case Int_ButtonCornerRadius:
             return PT_Integer;
 
-        case Bool_UseSymphonyIcons:
         case Bool_UseSystemColors:
         case Bool_UseToolBoxItemSeparator:
         case Bool_IsHighContrastModeActive:
@@ -895,40 +815,34 @@ Theme::PropertyType Theme::GetPropertyType (const ThemeItem eItem)
     }
 }
 
-
-
-
-cssu::Type Theme::GetCppuType (const PropertyType eType)
+css::uno::Type Theme::GetCppuType (const PropertyType eType)
 {
     switch(eType)
     {
         case PT_Image:
-            return getCppuType((rtl::OUString*)NULL);
+            return cppu::UnoType<rtl::OUString>::get();
 
         case PT_Color:
-            return getCppuType((sal_uInt32*)NULL);
+            return cppu::UnoType<sal_uInt32>::get();
 
         case PT_Paint:
-            return getCppuVoidType();
+            return cppu::UnoType<void>::get();
 
         case PT_Integer:
-            return getCppuType((sal_Int32*)NULL);
+            return cppu::UnoType<sal_Int32>::get();
 
         case PT_Boolean:
-            return getCppuType((sal_Bool*)NULL);
+            return cppu::UnoType<sal_Bool>::get();
 
         case PT_Rectangle:
-            return getCppuType((awt::Rectangle*)NULL);
+            return cppu::UnoType<awt::Rectangle>::get();
 
         case PT_Invalid:
         default:
-            return getCppuVoidType();
+            return cppu::UnoType<void>::get();
     }
 }
 
-
-
-
 sal_Int32 Theme::GetIndex (const ThemeItem eItem, const PropertyType eType)
 {
     switch(eType)
@@ -952,9 +866,6 @@ sal_Int32 Theme::GetIndex (const ThemeItem eItem, const PropertyType eType)
     }
 }
 
-
-
-
 Theme::VetoableListenerContainer* Theme::GetVetoableListeners (
     const ThemeItem eItem,
     const bool bCreate)
@@ -968,12 +879,9 @@ Theme::VetoableListenerContainer* Theme::GetVetoableListeners (
         return &maVetoableListeners[eItem];
     }
     else
-        return NULL;
+        return nullptr;
 }
 
-
-
-
 Theme::ChangeListenerContainer* Theme::GetChangeListeners (
     const ThemeItem eItem,
     const bool bCreate)
@@ -987,17 +895,14 @@ Theme::ChangeListenerContainer* Theme::GetChangeListeners (
         return &maChangeListeners[eItem];
     }
     else
-        return NULL;
+        return nullptr;
 }
 
-
-
-
 bool Theme::DoVetoableListenersVeto (
     const VetoableListenerContainer* pListeners,
-    const beans::PropertyChangeEvent& rEvent) const
+    const beans::PropertyChangeEvent& rEvent)
 {
-    if (pListeners == NULL)
+    if (pListeners == nullptr)
         return false;
 
     VetoableListenerContainer aListeners (*pListeners);
@@ -1023,14 +928,11 @@ bool Theme::DoVetoableListenersVeto (
     return false;
 }
 
-
-
-
 void Theme::BroadcastPropertyChange (
     const ChangeListenerContainer* pListeners,
-    const beans::PropertyChangeEvent& rEvent) const
+    const beans::PropertyChangeEvent& rEvent)
 {
-    if (pListeners == NULL)
+    if (pListeners == nullptr)
         return;
 
     const ChangeListenerContainer aListeners (*pListeners);
@@ -1051,9 +953,6 @@ void Theme::BroadcastPropertyChange (
     }
 }
 
-
-
-
 void Theme::ProcessNewValue (
     const Any& rValue,
     const ThemeItem eItem,
@@ -1067,7 +966,7 @@ void Theme::ProcessNewValue (
             ::rtl::OUString sURL;
             if (rValue >>= sURL)
             {
-                maImages[nIndex] = Tools::GetImage(sURL, NULL);
+                maImages[nIndex] = Tools::GetImage(sURL, nullptr);
             }
             break;
         }
@@ -1096,10 +995,10 @@ void Theme::ProcessNewValue (
         }
         case PT_Boolean:
         {
-            sal_Bool nValue (0);
-            if (rValue >>= nValue)
+            bool bValue (false);
+            if (rValue >>= bValue)
             {
-                maBooleans[nIndex] = (nValue==sal_True);
+                maBooleans[nIndex] = bValue;
                 if (eItem == Bool_IsHighContrastModeActive)
                 {
                     mbIsHighContrastModeSetManually = true;
