@@ -19,7 +19,6 @@
 
 
 #include <sal/macros.h>
-#include "frmload.hxx"
 #include "objshimp.hxx"
 #include <sfx2/app.hxx>
 #include <sfx2/dispatch.hxx>
@@ -29,6 +28,7 @@
 #include <sfx2/doctempl.hxx>
 #include <sfx2/fcontnr.hxx>
 #include <sfx2/frame.hxx>
+#include <sfx2/objsh.hxx>
 #include <sfx2/request.hxx>
 #include <sfx2/sfx.hrc>
 #include <sfx2/sfxsids.hrc>
@@ -42,17 +42,23 @@
 #include <com/sun/star/frame/XFrame.hpp>
 #include <com/sun/star/frame/XLoadable.hpp>
 #include <com/sun/star/frame/XModel.hpp>
+#include <com/sun/star/task/XInteractionHandler.hpp>
 #include <com/sun/star/task/XInteractionHandler2.hpp>
 #include <com/sun/star/document/XViewDataSupplier.hpp>
 #include <com/sun/star/container/XIndexAccess.hpp>
+#include <com/sun/star/frame/XSynchronousFrameLoader.hpp>
+#include <com/sun/star/frame/XController2.hpp>
+#include <com/sun/star/frame/XModel2.hpp>
+#include <com/sun/star/lang/XServiceInfo.hpp>
+#include <com/sun/star/lang/XInitialization.hpp>
 
 #include <comphelper/interaction.hxx>
 #include <comphelper/namedvaluecollection.hxx>
-#include <comphelper/sequenceashashmap.hxx>
-#include <comphelper/processfactory.hxx>
 #include <cppuhelper/exc_hlp.hxx>
+#include <cppuhelper/implbase.hxx>
 #include <cppuhelper/supportsservice.hxx>
 #include <framework/interaction.hxx>
+#include <rtl/ref.hxx>
 #include <rtl/ustring.h>
 #include <sot/storinfo.hxx>
 #include <svtools/ehdl.hxx>
@@ -66,6 +72,7 @@
 #include <ucbhelper/simpleinteractionrequest.hxx>
 #include <osl/mutex.hxx>
 
+using namespace com::sun::star;
 using ::com::sun::star::beans::PropertyValue;
 using ::com::sun::star::container::XContainerQuery;
 using ::com::sun::star::container::XEnumeration;
@@ -87,7 +94,6 @@ using ::com::sun::star::uno::UNO_QUERY;
 using ::com::sun::star::uno::UNO_QUERY_THROW;
 using ::com::sun::star::uno::UNO_SET_THROW;
 using ::com::sun::star::uno::makeAny;
-using ::com::sun::star::uno::XComponentContext;
 using ::com::sun::star::util::XCloseable;
 using ::com::sun::star::document::XViewDataSupplier;
 using ::com::sun::star::container::XIndexAccess;
@@ -95,7 +101,100 @@ using ::com::sun::star::frame::XController2;
 using ::com::sun::star::frame::XController;
 using ::com::sun::star::frame::XModel2;
 
-SfxFrameLoader_Impl::SfxFrameLoader_Impl( const Reference< XComponentContext >& _rxContext )
+namespace {
+
+class SfxFrameLoader_Impl : public ::cppu::WeakImplHelper< css::frame::XSynchronousFrameLoader, css::lang::XServiceInfo >
+{
+    css::uno::Reference < css::uno::XComponentContext >  m_aContext;
+
+public:
+    explicit SfxFrameLoader_Impl( const css::uno::Reference < css::uno::XComponentContext >& _rxContext );
+
+    virtual OUString SAL_CALL getImplementationName()
+        throw (css::uno::RuntimeException, std::exception) override;
+
+    virtual sal_Bool SAL_CALL supportsService(OUString const & ServiceName)
+        throw (css::uno::RuntimeException, std::exception) override;
+
+    virtual css::uno::Sequence<OUString> SAL_CALL getSupportedServiceNames()
+        throw (css::uno::RuntimeException, std::exception) override;
+
+
+    // XSynchronousFrameLoader
+
+    virtual sal_Bool SAL_CALL load( const css::uno::Sequence< css::beans::PropertyValue >& _rArgs, const css::uno::Reference< css::frame::XFrame >& _rxFrame ) throw( css::uno::RuntimeException, std::exception ) override;
+    virtual void SAL_CALL cancel() throw( css::uno::RuntimeException, std::exception ) override;
+
+protected:
+    virtual                 ~SfxFrameLoader_Impl();
+
+private:
+    const SfxFilter*    impl_getFilterFromServiceName_nothrow(
+                            const OUString& i_rServiceName
+                        ) const;
+
+    static OUString     impl_askForFilter_nothrow(
+                            const css::uno::Reference< css::task::XInteractionHandler >& i_rxHandler,
+                            const OUString& i_rDocumentURL
+                        );
+
+    const SfxFilter*    impl_detectFilterForURL(
+                            const OUString& _rURL,
+                            const ::comphelper::NamedValueCollection& i_rDescriptor,
+                            const SfxFilterMatcher& rMatcher
+                        ) const;
+
+    static bool         impl_createNewDocWithSlotParam(
+                            const sal_uInt16 _nSlotID,
+                            const css::uno::Reference< css::frame::XFrame >& i_rxFrame,
+                            const bool i_bHidden
+                        );
+
+    void                impl_determineFilter(
+                                  ::comphelper::NamedValueCollection& io_rDescriptor
+                        ) const;
+
+    bool                impl_determineTemplateDocument(
+                            ::comphelper::NamedValueCollection& io_rDescriptor
+                        ) const;
+
+    static sal_uInt16   impl_findSlotParam(
+                            const OUString& i_rFactoryURL
+                        );
+
+    static SfxObjectShellRef   impl_findObjectShell(
+                            const css::uno::Reference< css::frame::XModel2 >& i_rxDocument
+                        );
+
+    static void         impl_handleCaughtError_nothrow(
+                            const css::uno::Any& i_rCaughtError,
+                            const ::comphelper::NamedValueCollection& i_rDescriptor
+                        );
+
+    static void         impl_removeLoaderArguments(
+                            ::comphelper::NamedValueCollection& io_rDescriptor
+                        );
+
+    static sal_Int16   impl_determineEffectiveViewId_nothrow(
+                            const SfxObjectShell& i_rDocument,
+                            const ::comphelper::NamedValueCollection& i_rDescriptor
+                        );
+
+    static ::comphelper::NamedValueCollection
+                        impl_extractViewCreationArgs(
+                                  ::comphelper::NamedValueCollection& io_rDescriptor
+                        );
+
+    static css::uno::Reference< css::frame::XController2 >
+                        impl_createDocumentView(
+                            const css::uno::Reference< css::frame::XModel2 >& i_rModel,
+                            const css::uno::Reference< css::frame::XFrame >& i_rFrame,
+                            const ::comphelper::NamedValueCollection& i_rViewFactoryArgs,
+                            const OUString& i_rViewName
+                        );
+};
+
+SfxFrameLoader_Impl::SfxFrameLoader_Impl( const Reference< css::uno::XComponentContext >& _rxContext )
     :m_aContext( _rxContext )
 {
 }
@@ -104,7 +203,7 @@ SfxFrameLoader_Impl::~SfxFrameLoader_Impl()
 {
 }
 
-// --------------------------------------------------------------------------------------------------------------------
+
 const SfxFilter* SfxFrameLoader_Impl::impl_detectFilterForURL( const OUString& sURL,
         const ::comphelper::NamedValueCollection& i_rDescriptor, const SfxFilterMatcher& rMatcher ) const
 {
@@ -112,7 +211,7 @@ const SfxFilter* SfxFrameLoader_Impl::impl_detectFilterForURL( const OUString& s
     try
     {
         if ( sURL.isEmpty() )
-            return 0;
+            return nullptr;
 
         Reference< XTypeDetection > xDetect(
             m_aContext->getServiceManager()->createInstanceWithContext("com.sun.star.document.TypeDetection", m_aContext),
@@ -142,16 +241,16 @@ const SfxFilter* SfxFrameLoader_Impl::impl_detectFilterForURL( const OUString& s
     catch( const Exception& )
     {
         DBG_UNHANDLED_EXCEPTION();
-        sFilter = OUString();
+        sFilter.clear();
     }
 
-    const SfxFilter* pFilter = 0;
+    const SfxFilter* pFilter = nullptr;
     if (!sFilter.isEmpty())
         pFilter = rMatcher.GetFilter4FilterName(sFilter);
     return pFilter;
 }
 
-// --------------------------------------------------------------------------------------------------------------------
+
 const SfxFilter* SfxFrameLoader_Impl::impl_getFilterFromServiceName_nothrow( const OUString& i_rServiceName ) const
 {
     try
@@ -163,8 +262,8 @@ const SfxFilter* SfxFrameLoader_Impl::impl_getFilterFromServiceName_nothrow( con
             m_aContext->getServiceManager()->createInstanceWithContext("com.sun.star.document.FilterFactory", m_aContext),
             UNO_QUERY_THROW );
 
-        const SfxFilterMatcher& rMatcher = SFX_APP()->GetFilterMatcher();
-        const SfxFilterFlags nMust = SFX_FILTER_IMPORT;
+        const SfxFilterMatcher& rMatcher = SfxGetpApp()->GetFilterMatcher();
+        const SfxFilterFlags nMust = SfxFilterFlags::IMPORT;
         const SfxFilterFlags nDont = SFX_FILTER_NOTINSTALLED;
 
         Reference < XEnumeration > xEnum( xQuery->createSubSetEnumerationByProperties(
@@ -182,7 +281,7 @@ const SfxFilter* SfxFrameLoader_Impl::impl_getFilterFromServiceName_nothrow( con
 
             SfxFilterFlags nFlags = pFilter->GetFilterFlags();
             if  (   ( ( nFlags & nMust ) == nMust )
-                &&  ( ( nFlags & nDont ) == 0 )
+                &&  ( ( nFlags & nDont ) == SfxFilterFlags::NONE )
                 )
             {
                 return pFilter;
@@ -193,12 +292,12 @@ const SfxFilter* SfxFrameLoader_Impl::impl_getFilterFromServiceName_nothrow( con
     {
         DBG_UNHANDLED_EXCEPTION();
     }
-    return NULL;
+    return nullptr;
 }
 
-// --------------------------------------------------------------------------------------------------------------------
+
 OUString SfxFrameLoader_Impl::impl_askForFilter_nothrow( const Reference< XInteractionHandler >& i_rxHandler,
-                                                                 const OUString& i_rDocumentURL ) const
+                                                                 const OUString& i_rDocumentURL )
 {
     ENSURE_OR_THROW( i_rxHandler.is(), "invalid interaction handler" );
 
@@ -218,21 +317,21 @@ OUString SfxFrameLoader_Impl::impl_askForFilter_nothrow( const Reference< XInter
     return sFilterName;
 }
 
-// --------------------------------------------------------------------------------------------------------------------
+
 namespace
 {
-    sal_Bool lcl_getDispatchResult( const SfxPoolItem* _pResult )
+    bool lcl_getDispatchResult( const SfxPoolItem* _pResult )
     {
         if ( !_pResult )
-            return sal_False;
+            return false;
 
         // default must be set to true, because some return values
-        // cant be checked, but nonetheless indicate "success"!
-        sal_Bool bSuccess = sal_True;
+        // can't be checked, but nonetheless indicate "success"!
+        bool bSuccess = true;
 
         // On the other side some special slots return a boolean state,
         // which can be set to FALSE.
-        SfxBoolItem *pItem = PTR_CAST( SfxBoolItem, _pResult );
+        const SfxBoolItem *pItem = dynamic_cast<const SfxBoolItem*>( _pResult  );
         if ( pItem )
             bSuccess = pItem->GetValue();
 
@@ -240,18 +339,18 @@ namespace
     }
 }
 
-// --------------------------------------------------------------------------------------------------------------------
-sal_Bool SfxFrameLoader_Impl::impl_createNewDocWithSlotParam( const sal_uInt16 _nSlotID, const Reference< XFrame >& i_rxFrame,
+
+bool SfxFrameLoader_Impl::impl_createNewDocWithSlotParam( const sal_uInt16 _nSlotID, const Reference< XFrame >& i_rxFrame,
                                                               const bool i_bHidden )
 {
-    SfxRequest aRequest( _nSlotID, SFX_CALLMODE_SYNCHRON, SFX_APP()->GetPool() );
+    SfxRequest aRequest( _nSlotID, SfxCallMode::SYNCHRON, SfxGetpApp()->GetPool() );
     aRequest.AppendItem( SfxUnoFrameItem( SID_FILLFRAME, i_rxFrame ) );
     if ( i_bHidden )
-        aRequest.AppendItem( SfxBoolItem( SID_HIDDEN, sal_True ) );
-    return lcl_getDispatchResult( SFX_APP()->ExecuteSlot( aRequest ) );
+        aRequest.AppendItem( SfxBoolItem( SID_HIDDEN, true ) );
+    return lcl_getDispatchResult( SfxGetpApp()->ExecuteSlot( aRequest ) );
 }
 
-// --------------------------------------------------------------------------------------------------------------------
+
 void SfxFrameLoader_Impl::impl_determineFilter( ::comphelper::NamedValueCollection& io_rDescriptor ) const
 {
     const OUString     sURL         = io_rDescriptor.getOrDefault( "URL",                OUString() );
@@ -261,8 +360,8 @@ void SfxFrameLoader_Impl::impl_determineFilter( ::comphelper::NamedValueCollecti
     const Reference< XInteractionHandler >
                               xInteraction = io_rDescriptor.getOrDefault( "InteractionHandler", Reference< XInteractionHandler >() );
 
-    const SfxFilterMatcher& rMatcher = SFX_APP()->GetFilterMatcher();
-    const SfxFilter* pFilter = NULL;
+    const SfxFilterMatcher& rMatcher = SfxGetpApp()->GetFilterMatcher();
+    const SfxFilter* pFilter = nullptr;
 
     // get filter by its name directly ...
     if ( !sFilterName.isEmpty() )
@@ -292,7 +391,7 @@ void SfxFrameLoader_Impl::impl_determineFilter( ::comphelper::NamedValueCollecti
         // add property "AsTemplate" to descriptor. But suppress this step
         // if such property already exists.
         if ( pFilter->IsOwnTemplateFormat() && !io_rDescriptor.has( "AsTemplate" ) )
-            io_rDescriptor.put( "AsTemplate", sal_Bool( sal_True ) );
+            io_rDescriptor.put( "AsTemplate", true );
 
         // The DocumentService property will finally be used to determine the document type to create, so
         // override it with the service name as indicated by the found filter.
@@ -300,10 +399,11 @@ void SfxFrameLoader_Impl::impl_determineFilter( ::comphelper::NamedValueCollecti
     }
 }
 
-// --------------------------------------------------------------------------------------------------------------------
-SfxObjectShellRef SfxFrameLoader_Impl::impl_findObjectShell( const Reference< XModel2 >& i_rxDocument ) const
+
+SfxObjectShellRef SfxFrameLoader_Impl::impl_findObjectShell( const Reference< XModel2 >& i_rxDocument )
 {
-    for ( SfxObjectShell* pDoc = SfxObjectShell::GetFirst( NULL, sal_False ); pDoc; pDoc = SfxObjectShell::GetNext( *pDoc, NULL, sal_False ) )
+    for ( SfxObjectShell* pDoc = SfxObjectShell::GetFirst( nullptr, false ); pDoc;
+                                    pDoc = SfxObjectShell::GetNext( *pDoc, nullptr, false ) )
     {
         if ( i_rxDocument == pDoc->GetModel() )
         {
@@ -312,63 +412,69 @@ SfxObjectShellRef SfxFrameLoader_Impl::impl_findObjectShell( const Reference< XM
     }
 
     SAL_WARN( "sfx.view", "SfxFrameLoader_Impl::impl_findObjectShell: model is not based on SfxObjectShell - wrong frame loader usage!" );
-    return NULL;
+    return nullptr;
 }
 
-// --------------------------------------------------------------------------------------------------------------------
+
 bool SfxFrameLoader_Impl::impl_determineTemplateDocument( ::comphelper::NamedValueCollection& io_rDescriptor ) const
 {
-    const OUString sTemplateRegioName = io_rDescriptor.getOrDefault( "TemplateRegionName", OUString() );
-    const OUString sTemplateName      = io_rDescriptor.getOrDefault( "TemplateName",       OUString() );
-    const OUString sServiceName       = io_rDescriptor.getOrDefault( "DocumentService",    OUString() );
-    const OUString sURL               = io_rDescriptor.getOrDefault( "URL",                OUString() );
+    try
+    {
+        const OUString sTemplateRegioName = io_rDescriptor.getOrDefault( "TemplateRegionName", OUString() );
+        const OUString sTemplateName      = io_rDescriptor.getOrDefault( "TemplateName",       OUString() );
+        const OUString sServiceName       = io_rDescriptor.getOrDefault( "DocumentService",    OUString() );
+        const OUString sURL               = io_rDescriptor.getOrDefault( "URL",                OUString() );
 
-    // determine the full URL of the template to use, if any
-    OUString sTemplateURL;
-    if ( !sTemplateRegioName.isEmpty() && !sTemplateName.isEmpty() )
-    {
-        SfxDocumentTemplates aTmpFac;
-        aTmpFac.GetFull( sTemplateRegioName, sTemplateName, sTemplateURL );
-    }
-    else
-    {
-        if ( !sServiceName.isEmpty() )
-            sTemplateURL = SfxObjectFactory::GetStandardTemplate( sServiceName );
-        else
-            sTemplateURL = SfxObjectFactory::GetStandardTemplate( SfxObjectShell::GetServiceNameFromFactory( sURL ) );
-    }
-
-    if ( !sTemplateURL.isEmpty() )
-    {
-        // detect the filter for the template. Might still be NULL (if the template is broken, or does not
-        // exist, or some such), but this is handled by our caller the same way as if no template/URL was present.
-        const SfxFilter* pTemplateFilter = impl_detectFilterForURL( sTemplateURL, io_rDescriptor, SFX_APP()->GetFilterMatcher() );
-        if ( pTemplateFilter )
+        // determine the full URL of the template to use, if any
+        OUString sTemplateURL;
+        if ( !sTemplateRegioName.isEmpty() && !sTemplateName.isEmpty() )
         {
-            // load the template document, but, well, "as template"
-            io_rDescriptor.put( "FilterName", OUString( pTemplateFilter->GetName() ) );
-            io_rDescriptor.put( "FileName", OUString( sTemplateURL ) );
-            io_rDescriptor.put( "AsTemplate", sal_True );
-
-            // #i21583#
-            // the DocumentService property will finally be used to create the document. Thus, override any possibly
-            // present value with the document service of the template.
-            io_rDescriptor.put( "DocumentService", OUString( pTemplateFilter->GetServiceName() ) );
-            return true;
+            SfxDocumentTemplates aTmpFac;
+            aTmpFac.GetFull( sTemplateRegioName, sTemplateName, sTemplateURL );
         }
+        else
+        {
+            if ( !sServiceName.isEmpty() )
+                sTemplateURL = SfxObjectFactory::GetStandardTemplate( sServiceName );
+            else
+                sTemplateURL = SfxObjectFactory::GetStandardTemplate( SfxObjectShell::GetServiceNameFromFactory( sURL ) );
+        }
+
+        if ( !sTemplateURL.isEmpty() )
+        {
+            // detect the filter for the template. Might still be NULL (if the template is broken, or does not
+            // exist, or some such), but this is handled by our caller the same way as if no template/URL was present.
+            const SfxFilter* pTemplateFilter = impl_detectFilterForURL( sTemplateURL, io_rDescriptor, SfxGetpApp()->GetFilterMatcher() );
+            if ( pTemplateFilter )
+            {
+                // load the template document, but, well, "as template"
+                io_rDescriptor.put( "FilterName", OUString( pTemplateFilter->GetName() ) );
+                io_rDescriptor.put( "FileName", OUString( sTemplateURL ) );
+                io_rDescriptor.put( "AsTemplate", sal_True );
+
+                // #i21583#
+                // the DocumentService property will finally be used to create the document. Thus, override any possibly
+                // present value with the document service of the template.
+                io_rDescriptor.put( "DocumentService", OUString( pTemplateFilter->GetServiceName() ) );
+                return true;
+            }
+        }
+    }
+    catch (...)
+    {
     }
     return false;
 }
 
-// --------------------------------------------------------------------------------------------------------------------
-sal_uInt16 SfxFrameLoader_Impl::impl_findSlotParam( const OUString& i_rFactoryURL ) const
+
+sal_uInt16 SfxFrameLoader_Impl::impl_findSlotParam( const OUString& i_rFactoryURL )
 {
     OUString sSlotParam;
     const sal_Int32 nParamPos = i_rFactoryURL.indexOf( '?' );
     if ( nParamPos >= 0 )
     {
         // currently only the "slot" parameter is supported
-        const sal_Int32 nSlotPos = i_rFactoryURL.indexOfAsciiL( RTL_CONSTASCII_STRINGPARAM( "slot=" ), nParamPos );
+        const sal_Int32 nSlotPos = i_rFactoryURL.indexOf( "slot=", nParamPos );
         if ( nSlotPos > 0 )
             sSlotParam = i_rFactoryURL.copy( nSlotPos + 5 );
     }
@@ -379,8 +485,8 @@ sal_uInt16 SfxFrameLoader_Impl::impl_findSlotParam( const OUString& i_rFactoryUR
     return 0;
 }
 
-// --------------------------------------------------------------------------------------------------------------------
-void SfxFrameLoader_Impl::impl_handleCaughtError_nothrow( const Any& i_rCaughtError, const ::comphelper::NamedValueCollection& i_rDescriptor ) const
+
+void SfxFrameLoader_Impl::impl_handleCaughtError_nothrow( const Any& i_rCaughtError, const ::comphelper::NamedValueCollection& i_rDescriptor )
 {
     try
     {
@@ -394,7 +500,7 @@ void SfxFrameLoader_Impl::impl_handleCaughtError_nothrow( const Any& i_rCaughtEr
 
         const Reference< XInteractionHandler2 > xHandler( xInteraction, UNO_QUERY );
     #if OSL_DEBUG_LEVEL > 0
-        const sal_Bool bHandled =
+        const bool bHandled =
     #endif
         xHandler.is() && xHandler->handleInteractionRequest( pRequest.get() );
 
@@ -411,7 +517,7 @@ void SfxFrameLoader_Impl::impl_handleCaughtError_nothrow( const Any& i_rCaughtEr
     }
 }
 
-// --------------------------------------------------------------------------------------------------------------------
+
 void SfxFrameLoader_Impl::impl_removeLoaderArguments( ::comphelper::NamedValueCollection& io_rDescriptor )
 {
     // remove the arguments which are for the loader only, and not for a call to attachResource
@@ -419,11 +525,12 @@ void SfxFrameLoader_Impl::impl_removeLoaderArguments( ::comphelper::NamedValueCo
     io_rDescriptor.remove( "Model" );
 }
 
-// --------------------------------------------------------------------------------------------------------------------
+
 ::comphelper::NamedValueCollection SfxFrameLoader_Impl::impl_extractViewCreationArgs( ::comphelper::NamedValueCollection& io_rDescriptor )
 {
     const sal_Char* pKnownViewArgs[] = {
-        "JumpMark"
+        "JumpMark",
+        "PickListEntry"
     };
 
     ::comphelper::NamedValueCollection aViewArgs;
@@ -438,7 +545,7 @@ void SfxFrameLoader_Impl::impl_removeLoaderArguments( ::comphelper::NamedValueCo
     return aViewArgs;
 }
 
-// --------------------------------------------------------------------------------------------------------------------
+
 sal_Int16 SfxFrameLoader_Impl::impl_determineEffectiveViewId_nothrow( const SfxObjectShell& i_rDocument, const ::comphelper::NamedValueCollection& i_rDescriptor )
 {
     sal_Int16 nViewId = i_rDescriptor.getOrDefault( "ViewId", sal_Int16( 0 ) );
@@ -480,11 +587,11 @@ sal_Int16 SfxFrameLoader_Impl::impl_determineEffectiveViewId_nothrow( const SfxO
     }
 
     if ( nViewId == 0 )
-        nViewId = i_rDocument.GetFactory().GetViewFactory( 0 ).GetOrdinal();
+        nViewId = i_rDocument.GetFactory().GetViewFactory().GetOrdinal();
     return nViewId;
 }
 
-// --------------------------------------------------------------------------------------------------------------------
+
 Reference< XController2 > SfxFrameLoader_Impl::impl_createDocumentView( const Reference< XModel2 >& i_rModel,
         const Reference< XFrame >& i_rFrame, const ::comphelper::NamedValueCollection& i_rViewFactoryArgs,
         const OUString& i_rViewName )
@@ -506,16 +613,16 @@ Reference< XController2 > SfxFrameLoader_Impl::impl_createDocumentView( const Re
     return xController;
 }
 
-// --------------------------------------------------------------------------------------------------------------------
+
 sal_Bool SAL_CALL SfxFrameLoader_Impl::load( const Sequence< PropertyValue >& rArgs,
                                              const Reference< XFrame >& _rTargetFrame )
-    throw( RuntimeException )
+    throw( RuntimeException, std::exception )
 {
     ENSURE_OR_THROW( _rTargetFrame.is(), "illegal NULL frame" );
 
     SolarMutexGuard aGuard;
 
-    SAL_INFO( "sfx.view", "sfx2 (mb93783) ::SfxFrameLoader::load" );
+    SAL_INFO( "sfx.view", "SfxFrameLoader::load" );
 
     ::comphelper::NamedValueCollection aDescriptor( rArgs );
 
@@ -561,10 +668,10 @@ sal_Bool SAL_CALL SfxFrameLoader_Impl::load( const Sequence< PropertyValue >& rA
         aDescriptor.put( "FileName", aDescriptor.get( "URL" ) );
     }
 
-    sal_Bool bLoadSuccess = sal_False;
+    bool bLoadSuccess = false;
     try
     {
-        // extract view releant arguments from the loader args
+        // extract view relevant arguments from the loader args
         ::comphelper::NamedValueCollection aViewCreationArgs( impl_extractViewCreationArgs( aDescriptor ) );
 
         // no model passed from outside? => create one from scratch
@@ -617,8 +724,17 @@ sal_Bool SAL_CALL SfxFrameLoader_Impl::load( const Sequence< PropertyValue >& rA
         const OUString sViewName( xDoc->GetFactory().GetViewFactory( nViewNo ).GetAPIViewName() );
 
         // plug the document into the frame
-        impl_createDocumentView( xModel, _rTargetFrame, aViewCreationArgs, sViewName );
-        bLoadSuccess = sal_True;
+        Reference<XController2> xController =
+            impl_createDocumentView( xModel, _rTargetFrame, aViewCreationArgs, sViewName );
+
+        Reference<lang::XInitialization> xInit(xController, UNO_QUERY);
+        if (xInit.is())
+        {
+            uno::Sequence<uno::Any> aArgs; // empty for now.
+            xInit->initialize(aArgs);
+        }
+
+        bLoadSuccess = true;
     }
     catch ( Exception& )
     {
@@ -644,32 +760,24 @@ sal_Bool SAL_CALL SfxFrameLoader_Impl::load( const Sequence< PropertyValue >& rA
     return bLoadSuccess;
 }
 
-void SfxFrameLoader_Impl::cancel() throw( RuntimeException )
+void SfxFrameLoader_Impl::cancel() throw( RuntimeException, std::exception )
 {
 }
 
-SFX_IMPL_SINGLEFACTORY( SfxFrameLoader_Impl )
-
 /* XServiceInfo */
-OUString SAL_CALL SfxFrameLoader_Impl::getImplementationName() throw( RuntimeException )
+OUString SAL_CALL SfxFrameLoader_Impl::getImplementationName() throw( RuntimeException, std::exception )
 {
-    return impl_getStaticImplementationName();
+    return OUString("com.sun.star.comp.office.FrameLoader");
 }
                                                                                                                                 \
 /* XServiceInfo */
-sal_Bool SAL_CALL SfxFrameLoader_Impl::supportsService( const OUString& sServiceName ) throw( RuntimeException )
+sal_Bool SAL_CALL SfxFrameLoader_Impl::supportsService( const OUString& sServiceName ) throw( RuntimeException, std::exception )
 {
     return cppu::supportsService(this, sServiceName);
 }
 
 /* XServiceInfo */
-Sequence< OUString > SAL_CALL SfxFrameLoader_Impl::getSupportedServiceNames() throw( RuntimeException )
-{
-    return impl_getStaticSupportedServiceNames();
-}
-
-/* Helper for XServiceInfo */
-Sequence< OUString > SfxFrameLoader_Impl::impl_getStaticSupportedServiceNames()
+Sequence< OUString > SAL_CALL SfxFrameLoader_Impl::getSupportedServiceNames() throw( RuntimeException, std::exception )
 {
     Sequence< OUString > seqServiceNames( 2 );
     seqServiceNames.getArray() [0] = "com.sun.star.frame.SynchronousFrameLoader";
@@ -677,16 +785,14 @@ Sequence< OUString > SfxFrameLoader_Impl::impl_getStaticSupportedServiceNames()
     return seqServiceNames ;
 }
 
-/* Helper for XServiceInfo */
-OUString SfxFrameLoader_Impl::impl_getStaticImplementationName()
-{
-    return OUString( "com.sun.star.comp.office.FrameLoader" );
 }
 
-/* Helper for registry */
-Reference< css::uno::XInterface > SAL_CALL SfxFrameLoader_Impl::impl_createInstance( const Reference< XMultiServiceFactory >& xServiceManager ) throw( Exception )
+extern "C" SAL_DLLPUBLIC_EXPORT css::uno::XInterface * SAL_CALL
+com_sun_star_comp_office_FrameLoader_get_implementation(
+    css::uno::XComponentContext *context,
+    css::uno::Sequence<css::uno::Any> const &)
 {
-    return Reference< css::uno::XInterface >( *new SfxFrameLoader_Impl( comphelper::getComponentContext(xServiceManager) ) );
+    return cppu::acquire(new SfxFrameLoader_Impl(context));
 }
 
 /* vim:set shiftwidth=4 softtabstop=4 expandtab: */
