@@ -40,7 +40,7 @@
 #include "com/sun/star/uno/XComponentContext.hpp"
 #include "com/sun/star/uno/XCurrentContext.hpp"
 #include "cppuhelper/factory.hxx"
-#include "cppuhelper/implbase2.hxx"
+#include <cppuhelper/implbase.hxx>
 #include "cppuhelper/implementationentry.hxx"
 #include "cppuhelper/weak.hxx"
 #include "rtl/string.h"
@@ -65,7 +65,7 @@ css::uno::Sequence< OUString > SAL_CALL getServiceSupportedServiceNames() {
 }
 
 class Service:
-    public cppu::WeakImplHelper2<
+    public cppu::WeakImplHelper<
         css::lang::XServiceInfo, css::beans::XPropertySet >,
     private boost::noncopyable
 {
@@ -76,19 +76,19 @@ private:
     virtual ~Service() {}
 
     virtual OUString SAL_CALL getImplementationName()
-        throw (css::uno::RuntimeException, std::exception) SAL_OVERRIDE
+        throw (css::uno::RuntimeException, std::exception) override
     { return getServiceImplementationName(); }
 
     virtual sal_Bool SAL_CALL supportsService(OUString const & ServiceName)
-        throw (css::uno::RuntimeException, std::exception) SAL_OVERRIDE
+        throw (css::uno::RuntimeException, std::exception) override
     { return ServiceName == getSupportedServiceNames()[0]; }
 
     virtual css::uno::Sequence< OUString > SAL_CALL
-    getSupportedServiceNames() throw (css::uno::RuntimeException, std::exception) SAL_OVERRIDE
+    getSupportedServiceNames() throw (css::uno::RuntimeException, std::exception) override
     { return getServiceSupportedServiceNames(); }
 
     virtual css::uno::Reference< css::beans::XPropertySetInfo > SAL_CALL
-    getPropertySetInfo() throw (css::uno::RuntimeException, std::exception) SAL_OVERRIDE
+    getPropertySetInfo() throw (css::uno::RuntimeException, std::exception) override
     { return css::uno::Reference< css::beans::XPropertySetInfo >(); }
 
     virtual void SAL_CALL setPropertyValue(
@@ -97,20 +97,20 @@ private:
             css::beans::UnknownPropertyException,
             css::beans::PropertyVetoException,
             css::lang::IllegalArgumentException,
-            css::lang::WrappedTargetException, css::uno::RuntimeException, std::exception) SAL_OVERRIDE;
+            css::lang::WrappedTargetException, css::uno::RuntimeException, std::exception) override;
 
     virtual css::uno::Any SAL_CALL getPropertyValue(
         OUString const & PropertyName)
         throw (
             css::beans::UnknownPropertyException,
-            css::lang::WrappedTargetException, css::uno::RuntimeException, std::exception) SAL_OVERRIDE;
+            css::lang::WrappedTargetException, css::uno::RuntimeException, std::exception) override;
 
     virtual void SAL_CALL addPropertyChangeListener(
         OUString const &,
         css::uno::Reference< css::beans::XPropertyChangeListener > const &)
         throw (
             css::beans::UnknownPropertyException,
-            css::lang::WrappedTargetException, css::uno::RuntimeException, std::exception) SAL_OVERRIDE
+            css::lang::WrappedTargetException, css::uno::RuntimeException, std::exception) override
     {}
 
     virtual void SAL_CALL removePropertyChangeListener(
@@ -118,7 +118,7 @@ private:
         css::uno::Reference< css::beans::XPropertyChangeListener > const &)
         throw (
             css::beans::UnknownPropertyException,
-            css::lang::WrappedTargetException, css::uno::RuntimeException, std::exception) SAL_OVERRIDE
+            css::lang::WrappedTargetException, css::uno::RuntimeException, std::exception) override
     {}
 
     virtual void SAL_CALL addVetoableChangeListener(
@@ -126,7 +126,7 @@ private:
         css::uno::Reference< css::beans::XVetoableChangeListener > const &)
         throw (
             css::beans::UnknownPropertyException,
-            css::lang::WrappedTargetException, css::uno::RuntimeException, std::exception) SAL_OVERRIDE
+            css::lang::WrappedTargetException, css::uno::RuntimeException, std::exception) override
     {}
 
     virtual void SAL_CALL removeVetoableChangeListener(
@@ -134,7 +134,7 @@ private:
         css::uno::Reference< css::beans::XVetoableChangeListener > const &)
         throw (
             css::beans::UnknownPropertyException,
-            css::lang::WrappedTargetException, css::uno::RuntimeException, std::exception) SAL_OVERRIDE
+            css::lang::WrappedTargetException, css::uno::RuntimeException, std::exception) override
     {}
 
     bool enabled_;
@@ -145,10 +145,8 @@ Service::Service(): enabled_(false) {
         css::uno::getCurrentContext());
     if (context.is()) {
         OUString desktop;
-        context->getValueByName(
-            OUString("system.desktop-environment")) >>=
-            desktop;
-        enabled_ = desktop == "KDE4" && KApplication::kApplication() != 0;
+        context->getValueByName("system.desktop-environment") >>= desktop;
+        enabled_ = desktop == "KDE4" && KApplication::kApplication() != nullptr;
     }
 }
 
@@ -194,9 +192,9 @@ css::uno::Reference< css::uno::XInterface > SAL_CALL createInstance(
 
 static cppu::ImplementationEntry const services[] = {
     { &createInstance, &getServiceImplementationName,
-      &getServiceSupportedServiceNames, &cppu::createSingleComponentFactory, 0,
+      &getServiceSupportedServiceNames, &cppu::createSingleComponentFactory, nullptr,
       0 },
-    { 0, 0, 0, 0, 0, 0 }
+    { nullptr, nullptr, nullptr, nullptr, nullptr, 0 }
 };
 
 }
