@@ -36,13 +36,6 @@
 #pragma warning(pop)
 #endif
 
-//---------------------------------------
-
-// Size of a CLSID as a string
-const int CLSID_STRING_SIZE = 39;
-
-//---------------------------------------
-
 bool SetRegistryKey(HKEY RootKey, const char* KeyName, const char* ValueName, const char* Value)
 {
     HKEY hSubKey;
@@ -64,7 +57,7 @@ bool SetRegistryKey(HKEY RootKey, const char* KeyName, const char* ValueName, co
     return (ERROR_SUCCESS == rc);
 }
 
-//---------------------------------------
+
 
 bool DeleteRegistryKey(HKEY RootKey, const char* KeyName)
 {
@@ -163,7 +156,7 @@ std::string ClsidToString(const CLSID& clsid)
     return std::string(buff);
 }
 
-//---------------------------------------
+
 
 bool QueryRegistryKey(HKEY RootKey, const char* KeyName, const char* ValueName, char *pszData, DWORD dwBufLen)
 {
