@@ -18,8 +18,6 @@
  */
 
 
-// must be first
-#include <canvas/debug.hxx>
 #include <tools/diagnose_ex.h>
 
 #include <math.h>
@@ -39,7 +37,6 @@
 #include <basegfx/matrix/b2dhommatrix.hxx>
 #include <basegfx/matrix/b2dhommatrixtools.hxx>
 
-#include <canvas/verbosetrace.hxx>
 #include <canvas/canvastools.hxx>
 #include <cppcanvas/vclfactory.hxx>
 #include <cppcanvas/basegfxfactory.hxx>
@@ -47,9 +44,6 @@
 #include "viewshape.hxx"
 #include "tools.hxx"
 
-#include <boost/bind.hpp>
-
-
 using namespace ::com::sun::star;
 
 namespace slideshow
@@ -63,7 +57,7 @@ namespace slideshow
         bool ViewShape::prefetch( RendererCacheEntry&                   io_rCacheEntry,
                                   const ::cppcanvas::CanvasSharedPtr&   rDestinationCanvas,
                                   const GDIMetaFileSharedPtr&           rMtf,
-                                  const ShapeAttributeLayerSharedPtr&   rAttr ) const
+                                  const ShapeAttributeLayerSharedPtr&   rAttr )
         {
             ENSURE_OR_RETURN_FALSE( rMtf,
                                "ViewShape::prefetch(): no valid metafile!" );
@@ -158,9 +152,9 @@ namespace slideshow
                     }
                 }
 
-                io_rCacheEntry.mpRenderer = ::cppcanvas::VCLFactory::getInstance().createRenderer( rDestinationCanvas,
-                                                                                                   *rMtf.get(),
-                                                                                                   aParms );
+                io_rCacheEntry.mpRenderer = ::cppcanvas::VCLFactory::createRenderer( rDestinationCanvas,
+                                                                                     *rMtf.get(),
+                                                                                     aParms );
 
                 io_rCacheEntry.mpMtf               = rMtf;
                 io_rCacheEntry.mpDestinationCanvas = rDestinationCanvas;
@@ -231,18 +225,14 @@ namespace slideshow
             else
             {
                 // render subsets of whole metafile
-                // --------------------------------
+
 
                 bool bRet(true);
-                VectorOfDocTreeNodes::const_iterator        aIter( rSubsets.begin() );
-                const VectorOfDocTreeNodes::const_iterator  aEnd ( rSubsets.end() );
-                while( aIter != aEnd )
+                for( const auto& rSubset : rSubsets )
                 {
-                    if( !pRenderer->drawSubset( aIter->getStartIndex(),
-                                                aIter->getEndIndex() ) )
+                    if( !pRenderer->drawSubset( rSubset.getStartIndex(),
+                                                rSubset.getEndIndex() ) )
                         bRet = false;
-
-                    ++aIter;
                 }
 
                 return bRet;
@@ -381,7 +371,7 @@ namespace slideshow
 
             ENSURE_OR_RETURN_FALSE( mpSprite, "ViewShape::renderSprite(): No sprite" );
 
-            VERBOSE_TRACE( "ViewShape::renderSprite(): Rendering sprite 0x%p",
+            SAL_INFO("slideshow", "ViewShape::renderSprite(): Rendering sprite " <<
                            mpSprite.get() );
 
 
@@ -505,7 +495,7 @@ namespace slideshow
                          rMtf,
                          pAttr,
                          aShapeTransformation,
-                         NULL, // clipping is done via Sprite::clip()
+                         nullptr, // clipping is done via Sprite::clip()
                          rSubsets );
         }
 
@@ -524,7 +514,7 @@ namespace slideshow
 
             if( !bIsVisible )
             {
-                VERBOSE_TRACE( "ViewShape::render(): skipping shape %p", this );
+                SAL_INFO("slideshow", "ViewShape::render(): skipping shape " << this );
 
                 // shape is invisible, no need to update anything.
                 return true;
@@ -549,14 +539,15 @@ namespace slideshow
             if( !bRedrawRequired )
                 return true;
 
-            VERBOSE_TRACE( "ViewShape::render(): rendering shape %p at position (%f,%f)",
-                           this,
-                           rBounds.getMinX(),
-                           rBounds.getMinY() );
+            SAL_INFO( "slideshow", "ViewShape::render(): rendering shape " <<
+                      this <<
+                      " at position (" <<
+                      rBounds.getMinX() << "," <<
+                      rBounds.getMinY() << ")" );
 
 
             // shape needs repaint - setup all that's needed
-            // ---------------------------------------------
+
 
             boost::optional<basegfx::B2DPolyPolygon> aClip;
 
@@ -580,7 +571,7 @@ namespace slideshow
                         // render with global alpha - have to prepare
                         // a bitmap, and render that with modulated
                         // alpha
-                        // -------------------------------------------
+
 
                         const ::basegfx::B2DHomMatrix aTransform(
                             getShapeTransformation( rBounds,
@@ -619,7 +610,7 @@ namespace slideshow
                         {
                             // create a bitmap of appropriate size
                             ::cppcanvas::BitmapSharedPtr pBitmap(
-                                ::cppcanvas::BaseGfxFactory::getInstance().createAlphaBitmap(
+                                ::cppcanvas::BaseGfxFactory::createAlphaBitmap(
                                     rDestinationCanvas,
                                     aBmpSize ) );
 
@@ -644,7 +635,7 @@ namespace slideshow
                         // which happens to be the destination
                         // canvas transformation without any
                         // translational components.
-                        //
+
                         // But then, the render transformation as
                         // calculated by getShapeTransformation()
                         // above outputs the shape at its real
@@ -672,7 +663,7 @@ namespace slideshow
                                    rMtf,
                                    pAttr,
                                    aTransform,
-                                   !aClip ? NULL : &(*aClip),
+                                   !aClip ? nullptr : &(*aClip),
                                    rSubsets ) )
                         {
                             return false;
@@ -716,12 +707,12 @@ namespace slideshow
                          rMtf,
                          pAttr,
                          aTransform,
-                         !aClip ? NULL : &(*aClip),
+                         !aClip ? nullptr : &(*aClip),
                          rSubsets );
         }
 
 
-        // -------------------------------------------------------------------------------------
+
 
         ViewShape::ViewShape( const ViewLayerSharedPtr& rViewLayer ) :
             mpViewLayer( rViewLayer ),
@@ -748,12 +739,8 @@ namespace slideshow
             // already there?
             if( (aIter=::std::find_if( maRenderers.begin(),
                                        aEnd,
-                                       ::boost::bind(
-                                           ::std::equal_to< ::cppcanvas::CanvasSharedPtr >(),
-                                           ::boost::cref( rDestinationCanvas ),
-                                           ::boost::bind(
-                                               &RendererCacheEntry::getDestinationCanvas,
-                                               _1 ) ) ) ) == aEnd )
+                                       [&rDestinationCanvas]( const RendererCacheEntry& rCacheEntry )
+                                       { return rDestinationCanvas == rCacheEntry.getDestinationCanvas(); } ) ) == aEnd )
             {
                 if( maRenderers.size() >= MAX_RENDER_CACHE_ENTRIES )
                 {
