@@ -800,7 +800,7 @@ void SmXMLEncloseContext_Impl::EndElement()
     contents are treated as a single "inferred <mrow>" containing its
     arguments
     */
-    if (GetSmImport().GetNodeStack().size() - nElementCount > 1)
+    if (GetSmImport().GetNodeStack().size() - nElementCount != 1)
         SmXMLRowContext_Impl::EndElement();
 }
 
@@ -873,7 +873,7 @@ void SmXMLStyleContext_Impl::EndElement()
     arguments
     */
     SmNodeStack &rNodeStack = GetSmImport().GetNodeStack();
-    if (rNodeStack.size() - nElementCount > 1)
+    if (rNodeStack.size() - nElementCount != 1)
         SmXMLRowContext_Impl::EndElement();
     aStyleHelper.ApplyAttrs();
 }
@@ -898,7 +898,7 @@ void SmXMLPaddedContext_Impl::EndElement()
     contents are treated as a single "inferred <mrow>" containing its
     arguments
     */
-    if (GetSmImport().GetNodeStack().size() - nElementCount > 1)
+    if (GetSmImport().GetNodeStack().size() - nElementCount != 1)
         SmXMLRowContext_Impl::EndElement();
 }
 
@@ -922,7 +922,7 @@ void SmXMLPhantomContext_Impl::EndElement()
     contents are treated as a single "inferred <mrow>" containing its
     arguments
     */
-    if (GetSmImport().GetNodeStack().size() - nElementCount > 1)
+    if (GetSmImport().GetNodeStack().size() - nElementCount != 1)
         SmXMLRowContext_Impl::EndElement();
 
     SmToken aToken;
@@ -2201,7 +2201,7 @@ void SmXMLSqrtContext_Impl::EndElement()
     contents are treated as a single "inferred <mrow>" containing its
     arguments
     */
-    if (GetSmImport().GetNodeStack().size() - nElementCount > 1)
+    if (GetSmImport().GetNodeStack().size() - nElementCount != 1)
         SmXMLRowContext_Impl::EndElement();
 
     SmToken aToken;
