@@ -23,21 +23,18 @@
 #include <svl/languageoptions.hxx>
 #include <i18nlangtag/mslangid.hxx>
 #include <unotools/configitem.hxx>
-#include <tools/debug.hxx>
 #include <com/sun/star/uno/Any.h>
 #include <com/sun/star/uno/Sequence.hxx>
 #include <osl/mutex.hxx>
 #include <svl/smplhint.hxx>
 #include <rtl/instance.hxx>
 #include <unotools/syslocale.hxx>
-#include <itemholder2.hxx>
+#include "itemholder2.hxx"
 
 using namespace ::com::sun::star;
 using namespace ::com::sun::star::uno;
 
-#define CFG_READONLY_DEFAULT    sal_False
-
-// SvtCJKOptions_Impl ----------------------------------------------------------
+#define CFG_READONLY_DEFAULT false
 
 class SvtCTLOptions_Impl : public utl::ConfigItem
 {
@@ -57,12 +54,13 @@ private:
     bool                        m_bROCTLCursorMovement;
     bool                        m_bROCTLTextNumerals;
 
+    virtual void    ImplCommit() override;
+
 public:
     SvtCTLOptions_Impl();
-    ~SvtCTLOptions_Impl();
+    virtual ~SvtCTLOptions_Impl();
 
-    virtual void    Notify( const Sequence< OUString >& _aPropertyNames );
-    virtual void    Commit();
+    virtual void    Notify( const Sequence< OUString >& _aPropertyNames ) override;
     void            Load();
 
     bool            IsLoaded() { return m_bIsLoaded; }
@@ -73,7 +71,7 @@ public:
     bool            IsCTLSequenceChecking() const { return m_bCTLSequenceChecking;}
 
     void            SetCTLSequenceCheckingRestricted( bool _bEnable );
-    bool            IsCTLSequenceCheckingRestricted( void ) const   { return m_bCTLRestricted; }
+    bool            IsCTLSequenceCheckingRestricted() const   { return m_bCTLRestricted; }
 
     void            SetCTLSequenceCheckingTypeAndReplace( bool _bEnable );
     bool            IsCTLSequenceCheckingTypeAndReplace() const { return m_bCTLTypeAndReplace; }
@@ -104,7 +102,7 @@ bool SvtCTLOptions_Impl::IsReadOnly(SvtCTLOptions::EOption eOption) const
         case SvtCTLOptions::E_CTLTEXTNUMERALS     : bReadOnly = m_bROCTLTextNumerals      ; break;
         case SvtCTLOptions::E_CTLSEQUENCECHECKINGRESTRICTED: bReadOnly = m_bROCTLRestricted  ; break;
         case SvtCTLOptions::E_CTLSEQUENCECHECKINGTYPEANDREPLACE: bReadOnly = m_bROCTLTypeAndReplace; break;
-        default: OSL_FAIL(  "SvtCTLOptions_Impl::IsReadOnly() - invalid option" );
+        default: assert(false);
     }
     return bReadOnly;
 }
@@ -112,11 +110,11 @@ SvtCTLOptions_Impl::SvtCTLOptions_Impl() :
 
     utl::ConfigItem("Office.Common/I18N/CTL"),
 
-    m_bIsLoaded             ( sal_False ),
-    m_bCTLFontEnabled       ( sal_False ),
-    m_bCTLSequenceChecking  ( sal_False ),
-    m_bCTLRestricted        ( sal_False ),
-    m_bCTLTypeAndReplace    ( sal_False ),
+    m_bIsLoaded             ( false ),
+    m_bCTLFontEnabled       ( false ),
+    m_bCTLSequenceChecking  ( false ),
+    m_bCTLRestricted        ( false ),
+    m_bCTLTypeAndReplace    ( false ),
     m_eCTLCursorMovement    ( SvtCTLOptions::MOVEMENT_LOGICAL ),
     m_eCTLTextNumerals      ( SvtCTLOptions::NUMERALS_ARABIC ),
 
@@ -130,17 +128,16 @@ SvtCTLOptions_Impl::SvtCTLOptions_Impl() :
 }
 SvtCTLOptions_Impl::~SvtCTLOptions_Impl()
 {
-    if ( IsModified() == sal_True )
-        Commit();
+    assert(!IsModified()); // should have been committed
 }
-// -----------------------------------------------------------------------------
+
 void SvtCTLOptions_Impl::Notify( const Sequence< OUString >& )
 {
     Load();
     NotifyListeners(SFX_HINT_CTL_SETTINGS_CHANGED);
 }
-// -----------------------------------------------------------------------------
-void SvtCTLOptions_Impl::Commit()
+
+void SvtCTLOptions_Impl::ImplCommit()
 {
     Sequence< OUString > &rPropertyNames = PropertyNames::get();
     OUString* pOrgNames = rPropertyNames.getArray();
@@ -153,7 +150,7 @@ void SvtCTLOptions_Impl::Commit()
     Any* pValues = aValues.getArray();
     sal_Int32 nRealCount = 0;
 
-    const uno::Type& rType = ::getBooleanCppuType();
+    const uno::Type& rType = cppu::UnoType<bool>::get();
 
     for ( int nProp = 0; nProp < nOrgCount; nProp++ )
     {
@@ -231,7 +228,7 @@ void SvtCTLOptions_Impl::Commit()
     //broadcast changes
     NotifyListeners(SFX_HINT_CTL_SETTINGS_CHANGED);
 }
-// -----------------------------------------------------------------------------
+
 void SvtCTLOptions_Impl::Load()
 {
     Sequence< OUString >& rPropertyNames = PropertyNames::get();
@@ -251,11 +248,11 @@ void SvtCTLOptions_Impl::Load()
     Sequence< sal_Bool > aROStates = GetReadOnlyStates( rPropertyNames );
     const Any* pValues = aValues.getConstArray();
     const sal_Bool* pROStates = aROStates.getConstArray();
-    DBG_ASSERT( aValues.getLength() == rPropertyNames.getLength(), "GetProperties failed" );
-    DBG_ASSERT( aROStates.getLength() == rPropertyNames.getLength(), "GetReadOnlyStates failed" );
+    assert(aValues.getLength() == rPropertyNames.getLength() && "GetProperties failed");
+    assert(aROStates.getLength() == rPropertyNames.getLength() && "GetReadOnlyStates failed");
     if ( aValues.getLength() == rPropertyNames.getLength() && aROStates.getLength() == rPropertyNames.getLength() )
     {
-        sal_Bool bValue = sal_False;
+        bool bValue = false;
         sal_Int32 nValue = 0;
 
         for ( int nProp = 0; nProp < rPropertyNames.getLength(); nProp++ )
@@ -286,11 +283,9 @@ void SvtCTLOptions_Impl::Load()
 
     if (!m_bCTLFontEnabled)
     {
-        bool bAutoEnableCTL = false;
-
-        sal_uInt16 nScriptType = SvtLanguageOptions::GetScriptTypeOfLanguage(LANGUAGE_SYSTEM);
+        SvtScriptType nScriptType = SvtLanguageOptions::GetScriptTypeOfLanguage(LANGUAGE_SYSTEM);
         //system locale is CTL
-        bAutoEnableCTL = (nScriptType & SCRIPTTYPE_COMPLEX);
+        bool bAutoEnableCTL = bool(nScriptType & SvtScriptType::COMPLEX);
 
         LanguageType eSystemLanguage = LANGUAGE_SYSTEM;
 
@@ -302,8 +297,8 @@ void SvtCTLOptions_Impl::Load()
             eSystemLanguage = aSystemLocaleSettings.GetWin16SystemLanguage();
             if (eSystemLanguage != LANGUAGE_SYSTEM)
             {
-                sal_uInt16 nWinScript = SvtLanguageOptions::GetScriptTypeOfLanguage( eSystemLanguage );
-                bAutoEnableCTL = (nWinScript & SCRIPTTYPE_COMPLEX);
+                SvtScriptType nWinScript = SvtLanguageOptions::GetScriptTypeOfLanguage( eSystemLanguage );
+                bAutoEnableCTL = bool(nWinScript & SvtScriptType::COMPLEX);
             }
 
             //CTL keyboard is installed
@@ -313,7 +308,7 @@ void SvtCTLOptions_Impl::Load()
 
         if (bAutoEnableCTL)
         {
-            m_bCTLFontEnabled = sal_True;
+            m_bCTLFontEnabled = true;
             sal_uInt16 nLanguage = SvtSysLocale().GetLanguageTag().getLanguageType();
             //enable sequence checking for the appropriate languages
             m_bCTLSequenceChecking = m_bCTLRestricted = m_bCTLTypeAndReplace =
@@ -323,7 +318,7 @@ void SvtCTLOptions_Impl::Load()
         }
     }
 
-    m_bIsLoaded = sal_True;
+    m_bIsLoaded = true;
 }
 void SvtCTLOptions_Impl::SetCTLFontEnabled( bool _bEnabled )
 {
@@ -379,14 +374,12 @@ void SvtCTLOptions_Impl::SetCTLTextNumerals( SvtCTLOptions::TextNumerals _eNumer
         NotifyListeners(0);
     }
 }
-// global ----------------------------------------------------------------
+// global
 
-static SvtCTLOptions_Impl*  pCTLOptions = NULL;
+static SvtCTLOptions_Impl*  pCTLOptions = nullptr;
 static sal_Int32            nCTLRefCount = 0;
 namespace { struct CTLMutex : public rtl::Static< osl::Mutex, CTLMutex > {}; }
 
-// class SvtCTLOptions --------------------------------------------------
-
 SvtCTLOptions::SvtCTLOptions( bool bDontLoad )
 {
     // Global access, must be guarded (multithreading)
@@ -404,7 +397,7 @@ SvtCTLOptions::SvtCTLOptions( bool bDontLoad )
     m_pImp->AddListener(this);
 }
 
-// -----------------------------------------------------------------------
+
 
 SvtCTLOptions::~SvtCTLOptions()
 {
@@ -415,84 +408,84 @@ SvtCTLOptions::~SvtCTLOptions()
     if ( !--nCTLRefCount )
         DELETEZ( pCTLOptions );
 }
-// -----------------------------------------------------------------------------
+
 void SvtCTLOptions::SetCTLFontEnabled( bool _bEnabled )
 {
-    DBG_ASSERT( pCTLOptions->IsLoaded(), "CTL options not loaded" );
+    assert(pCTLOptions->IsLoaded());
     pCTLOptions->SetCTLFontEnabled( _bEnabled );
 }
-// -----------------------------------------------------------------------------
+
 bool SvtCTLOptions::IsCTLFontEnabled() const
 {
-    DBG_ASSERT( pCTLOptions->IsLoaded(), "CTL options not loaded" );
+    assert(pCTLOptions->IsLoaded());
     return pCTLOptions->IsCTLFontEnabled();
 }
-// -----------------------------------------------------------------------------
+
 void SvtCTLOptions::SetCTLSequenceChecking( bool _bEnabled )
 {
-    DBG_ASSERT( pCTLOptions->IsLoaded(), "CTL options not loaded" );
+    assert(pCTLOptions->IsLoaded());
     pCTLOptions->SetCTLSequenceChecking(_bEnabled);
 }
-// -----------------------------------------------------------------------------
+
 bool SvtCTLOptions::IsCTLSequenceChecking() const
 {
-    DBG_ASSERT( pCTLOptions->IsLoaded(), "CTL options not loaded" );
+    assert(pCTLOptions->IsLoaded());
     return pCTLOptions->IsCTLSequenceChecking();
 }
-// -----------------------------------------------------------------------------
+
 void SvtCTLOptions::SetCTLSequenceCheckingRestricted( bool _bEnable )
 {
-    DBG_ASSERT( pCTLOptions->IsLoaded(), "CTL options not loaded" );
+    assert(pCTLOptions->IsLoaded());
     pCTLOptions->SetCTLSequenceCheckingRestricted(_bEnable);
 }
-// -----------------------------------------------------------------------------
-bool SvtCTLOptions::IsCTLSequenceCheckingRestricted( void ) const
+
+bool SvtCTLOptions::IsCTLSequenceCheckingRestricted() const
 {
-    DBG_ASSERT( pCTLOptions->IsLoaded(), "CTL options not loaded" );
+    assert(pCTLOptions->IsLoaded());
     return pCTLOptions->IsCTLSequenceCheckingRestricted();
 }
-// -----------------------------------------------------------------------------
+
 void SvtCTLOptions::SetCTLSequenceCheckingTypeAndReplace( bool _bEnable )
 {
-    DBG_ASSERT( pCTLOptions->IsLoaded(), "CTL options not loaded" );
+    assert(pCTLOptions->IsLoaded());
     pCTLOptions->SetCTLSequenceCheckingTypeAndReplace(_bEnable);
 }
-// -----------------------------------------------------------------------------
+
 bool SvtCTLOptions::IsCTLSequenceCheckingTypeAndReplace() const
 {
-    DBG_ASSERT( pCTLOptions->IsLoaded(), "CTL options not loaded" );
+    assert(pCTLOptions->IsLoaded());
     return pCTLOptions->IsCTLSequenceCheckingTypeAndReplace();
 }
-// -----------------------------------------------------------------------------
+
 void SvtCTLOptions::SetCTLCursorMovement( SvtCTLOptions::CursorMovement _eMovement )
 {
-    DBG_ASSERT( pCTLOptions->IsLoaded(), "CTL options not loaded" );
+    assert(pCTLOptions->IsLoaded());
     pCTLOptions->SetCTLCursorMovement( _eMovement );
 }
-// -----------------------------------------------------------------------------
+
 SvtCTLOptions::CursorMovement SvtCTLOptions::GetCTLCursorMovement() const
 {
-    DBG_ASSERT( pCTLOptions->IsLoaded(), "CTL options not loaded" );
+    assert(pCTLOptions->IsLoaded());
     return pCTLOptions->GetCTLCursorMovement();
 }
-// -----------------------------------------------------------------------------
+
 void SvtCTLOptions::SetCTLTextNumerals( SvtCTLOptions::TextNumerals _eNumerals )
 {
-    DBG_ASSERT( pCTLOptions->IsLoaded(), "CTL options not loaded" );
+    assert(pCTLOptions->IsLoaded());
     pCTLOptions->SetCTLTextNumerals( _eNumerals );
 }
-// -----------------------------------------------------------------------------
+
 SvtCTLOptions::TextNumerals SvtCTLOptions::GetCTLTextNumerals() const
 {
-    DBG_ASSERT( pCTLOptions->IsLoaded(), "CTL options not loaded" );
+    assert(pCTLOptions->IsLoaded());
     return pCTLOptions->GetCTLTextNumerals();
 }
-// -----------------------------------------------------------------------------
+
 bool SvtCTLOptions::IsReadOnly(EOption eOption) const
 {
-    DBG_ASSERT( pCTLOptions->IsLoaded(), "CTL options not loaded" );
+    assert(pCTLOptions->IsLoaded());
     return pCTLOptions->IsReadOnly(eOption);
 }
-// -----------------------------------------------------------------------------
+
 
 /* vim:set shiftwidth=4 softtabstop=4 expandtab: */
