@@ -50,14 +50,14 @@ struct ImplWizButtonData
 
 void WizardDialog::ImplInitData()
 {
-    mpFirstPage     = NULL;
-    mpFirstBtn      = NULL;
-    mpCurTabPage    = NULL;
-    mpPrevBtn       = NULL;
-    mpNextBtn       = NULL;
-    mpViewWindow    = NULL;
+    mpFirstPage     = nullptr;
+    mpFirstBtn      = nullptr;
+    mpCurTabPage    = nullptr;
+    mpPrevBtn       = nullptr;
+    mpNextBtn       = nullptr;
+    mpViewWindow    = nullptr;
     mnCurLevel      = 0;
-    meViewAlign     = WINDOWALIGN_LEFT;
+    meViewAlign     = WindowAlign::Left;
     mbEmptyViewMargin =  false;
     mnLeftAlignCount = 0;
 
@@ -100,13 +100,13 @@ void WizardDialog::ImplCalcSize( Size& rSize )
     if ( mpViewWindow && mpViewWindow->IsVisible() )
     {
         Size aViewSize = mpViewWindow->GetSizePixel();
-        if ( meViewAlign == WINDOWALIGN_TOP )
+        if ( meViewAlign == WindowAlign::Top )
             rSize.Height() += aViewSize.Height();
-        else if ( meViewAlign == WINDOWALIGN_LEFT )
+        else if ( meViewAlign == WindowAlign::Left )
             rSize.Width() += aViewSize.Width();
-        else if ( meViewAlign == WINDOWALIGN_BOTTOM )
+        else if ( meViewAlign == WindowAlign::Bottom )
             rSize.Height() += aViewSize.Height();
-        else if ( meViewAlign == WINDOWALIGN_RIGHT )
+        else if ( meViewAlign == WindowAlign::Right )
             rSize.Width() += aViewSize.Width();
     }
 }
@@ -196,14 +196,14 @@ void WizardDialog::ImplPosCtrls()
         long    nViewHeight = 0;
         long    nDlgHeight = nOffY;
         PosSizeFlags nViewPosFlags = PosSizeFlags::Pos;
-        if ( meViewAlign == WINDOWALIGN_TOP )
+        if ( meViewAlign == WindowAlign::Top )
         {
             nViewOffX       = WIZARDDIALOG_VIEW_DLGOFFSET_X;
             nViewOffY       = WIZARDDIALOG_VIEW_DLGOFFSET_Y;
             nViewWidth      = aDlgSize.Width()-(WIZARDDIALOG_VIEW_DLGOFFSET_X*2);
             nViewPosFlags  |= PosSizeFlags::Width;
         }
-        else if ( meViewAlign == WINDOWALIGN_LEFT )
+        else if ( meViewAlign == WindowAlign::Left )
         {
             if ( mbEmptyViewMargin )
             {
@@ -219,14 +219,14 @@ void WizardDialog::ImplPosCtrls()
             }
             nViewPosFlags  |= PosSizeFlags::Height;
         }
-        else if ( meViewAlign == WINDOWALIGN_BOTTOM )
+        else if ( meViewAlign == WindowAlign::Bottom )
         {
             nViewOffX       = WIZARDDIALOG_VIEW_DLGOFFSET_X;
             nViewOffY       = nDlgHeight-mpViewWindow->GetSizePixel().Height()-WIZARDDIALOG_VIEW_DLGOFFSET_Y;
             nViewWidth      = aDlgSize.Width()-(WIZARDDIALOG_VIEW_DLGOFFSET_X*2);
             nViewPosFlags  |= PosSizeFlags::Width;
         }
-        else if ( meViewAlign == WINDOWALIGN_RIGHT )
+        else if ( meViewAlign == WindowAlign::Right )
         {
             nViewOffX       = aDlgSize.Width()-mpViewWindow->GetSizePixel().Width()-WIZARDDIALOG_VIEW_DLGOFFSET_X;
             nViewOffY       = WIZARDDIALOG_VIEW_DLGOFFSET_Y;
@@ -283,20 +283,20 @@ void WizardDialog::ImplPosTabPage()
     if ( mpViewWindow && mpViewWindow->IsVisible() )
     {
         Size aViewSize = mpViewWindow->GetSizePixel();
-        if ( meViewAlign == WINDOWALIGN_TOP )
+        if ( meViewAlign == WindowAlign::Top )
         {
             nOffY += aViewSize.Height()+WIZARDDIALOG_VIEW_DLGOFFSET_Y;
             aDlgSize.Height() -= aViewSize.Height()+WIZARDDIALOG_VIEW_DLGOFFSET_Y;
         }
-        else if ( meViewAlign == WINDOWALIGN_LEFT )
+        else if ( meViewAlign == WindowAlign::Left )
         {
             long nViewOffset = mbEmptyViewMargin ? 0 : WIZARDDIALOG_VIEW_DLGOFFSET_X;
             nOffX += aViewSize.Width() + nViewOffset;
             aDlgSize.Width() -= nOffX;
         }
-        else if ( meViewAlign == WINDOWALIGN_BOTTOM )
+        else if ( meViewAlign == WindowAlign::Bottom )
             aDlgSize.Height() -= aViewSize.Height()+WIZARDDIALOG_VIEW_DLGOFFSET_Y;
-        else if ( meViewAlign == WINDOWALIGN_RIGHT )
+        else if ( meViewAlign == WindowAlign::Right )
             aDlgSize.Width() -= aViewSize.Width()+WIZARDDIALOG_VIEW_DLGOFFSET_X;
     }
     Point aPos( nOffX, nOffY );
@@ -343,7 +343,7 @@ TabPage* WizardDialog::ImplGetPage( sal_uInt16 nLevel ) const
 
     if ( pPageData )
         return pPageData->mpPage;
-    return NULL;
+    return nullptr;
 }
 
 WizardDialog::WizardDialog( vcl::Window* pParent, WinBits nStyle ) :
@@ -492,10 +492,7 @@ void WizardDialog::ActivatePage()
 
 bool WizardDialog::DeactivatePage()
 {
-    if ( maDeactivateHdl.IsSet() )
-        return maDeactivateHdl.Call( this );
-    else
-        return true;
+    return true;
 }
 
 
@@ -553,7 +550,7 @@ bool WizardDialog::Finish( long nResult )
 void WizardDialog::AddPage( TabPage* pPage )
 {
     ImplWizPageData* pNewPageData = new ImplWizPageData;
-    pNewPageData->mpNext    = NULL;
+    pNewPageData->mpNext    = nullptr;
     pNewPageData->mpPage    = pPage;
 
     if ( !mpFirstPage )
@@ -571,7 +568,7 @@ void WizardDialog::AddPage( TabPage* pPage )
 
 void WizardDialog::RemovePage( TabPage* pPage )
 {
-    ImplWizPageData*  pPrevPageData = NULL;
+    ImplWizPageData*  pPrevPageData = nullptr;
     ImplWizPageData*  pPageData = mpFirstPage;
     while ( pPageData )
     {
@@ -582,7 +579,7 @@ void WizardDialog::RemovePage( TabPage* pPage )
             else
                 mpFirstPage = pPageData->mpNext;
             if ( pPage == mpCurTabPage )
-                mpCurTabPage = NULL;
+                mpCurTabPage = nullptr;
             delete pPageData;
             return;
         }
@@ -612,7 +609,7 @@ void WizardDialog::SetPage( sal_uInt16 nLevel, TabPage* pPage )
     if ( pPageData )
     {
         if ( pPageData->mpPage == mpCurTabPage )
-            mpCurTabPage = NULL;
+            mpCurTabPage = nullptr;
         pPageData->mpPage = pPage;
     }
 }
@@ -631,7 +628,7 @@ TabPage* WizardDialog::GetPage( sal_uInt16 nLevel ) const
         nTempLevel++;
     }
 
-    return NULL;
+    return nullptr;
 }
 
 
@@ -639,7 +636,7 @@ TabPage* WizardDialog::GetPage( sal_uInt16 nLevel ) const
 void WizardDialog::AddButton( Button* pButton, long nOffset )
 {
     ImplWizButtonData* pNewBtnData = new ImplWizButtonData;
-    pNewBtnData->mpNext     = NULL;
+    pNewBtnData->mpNext     = nullptr;
     pNewBtnData->mpButton   = pButton;
     pNewBtnData->mnOffset   = nOffset;
 
@@ -658,7 +655,7 @@ void WizardDialog::AddButton( Button* pButton, long nOffset )
 
 void WizardDialog::RemoveButton( Button* pButton )
 {
-    ImplWizButtonData*  pPrevBtnData = NULL;
+    ImplWizButtonData*  pPrevBtnData = nullptr;
     ImplWizButtonData*  pBtnData = mpFirstBtn;
     while ( pBtnData )
     {
