@@ -20,60 +20,61 @@
 #include <com/sun/star/accessibility/AccessibleRole.hpp>
 
 #include <vcl/svapp.hxx>
+#include <vcl/settings.hxx>
 
-#include <ipwin.hxx>
+#include "ipwin.hxx"
 #include <hatchwindow.hxx>
 
 /************************************************************************/
 /*************************************************************************
 |*    SvResizeHelper::SvResizeHelper()
 |*
-|*    Beschreibung
+|*    Description
 *************************************************************************/
 SvResizeHelper::SvResizeHelper()
     : aBorder( 5, 5 )
     , nGrab( -1 )
-    , bResizeable( sal_True )
+    , bResizeable( true )
 {
 }
 
 /*************************************************************************
 |*    SvResizeHelper::FillHandleRects()
 |*
-|*    Beschreibung: Die acht Handles zum vergroessern
+|*    Description: the eight handles to magnify
 *************************************************************************/
 void SvResizeHelper::FillHandleRectsPixel( Rectangle aRects[ 8 ] ) const
 {
-    // nur wegen EMPTY_RECT
+    // only because of EMPTY_RECT
     Point aBottomRight = aOuter.BottomRight();
 
-    // Links Oben
+    // upper left
     aRects[ 0 ] = Rectangle( aOuter.TopLeft(), aBorder );
-    // Oben Mitte
+    // upper middle
     aRects[ 1 ] = Rectangle( Point( aOuter.Center().X() - aBorder.Width() / 2,
                                     aOuter.Top() ),
                             aBorder );
-    // Oben Rechts
+    // upper right
     aRects[ 2 ] = Rectangle( Point( aBottomRight.X() - aBorder.Width() +1,
                                     aOuter.Top() ),
                             aBorder );
-    // Mitte Rechts
+    // middle right
     aRects[ 3 ] = Rectangle( Point( aBottomRight.X() - aBorder.Width() +1,
                                     aOuter.Center().Y() - aBorder.Height() / 2 ),
                             aBorder );
-    // Unten Rechts
+    // lower right
     aRects[ 4 ] = Rectangle( Point( aBottomRight.X() - aBorder.Width() +1,
                                     aBottomRight.Y() - aBorder.Height() +1 ),
                             aBorder );
-    // Mitte Unten
+    // lower middle
     aRects[ 5 ] = Rectangle( Point( aOuter.Center().X() - aBorder.Width() / 2,
                                     aBottomRight.Y() - aBorder.Height() +1),
                             aBorder );
-    // Links Unten
+    // lower left
     aRects[ 6 ] = Rectangle( Point( aOuter.Left(),
                                     aBottomRight.Y() - aBorder.Height() +1),
                             aBorder );
-    // Mitte Links
+    // middle left
     aRects[ 7 ] = Rectangle( Point( aOuter.Left(),
                                     aOuter.Center().Y() - aBorder.Height() / 2 ),
                             aBorder );
@@ -82,20 +83,20 @@ void SvResizeHelper::FillHandleRectsPixel( Rectangle aRects[ 8 ] ) const
 /*************************************************************************
 |*    SvResizeHelper::FillMoveRectsPixel()
 |*
-|*    Beschreibung: Die vier Kanten werden berechnet
+|*    Description: the four edges are calculated
 *************************************************************************/
 void SvResizeHelper::FillMoveRectsPixel( Rectangle aRects[ 4 ] ) const
 {
-    // Oben
+    // upper
     aRects[ 0 ] = aOuter;
     aRects[ 0 ].Bottom() = aRects[ 0 ].Top() + aBorder.Height() -1;
-    // Rechts
+    // right
     aRects[ 1 ] = aOuter;
     aRects[ 1 ].Left() = aRects[ 1 ].Right() - aBorder.Width() -1;
-    //Unten
+    // lower
     aRects[ 2 ] = aOuter;
     aRects[ 2 ].Top() = aRects[ 2 ].Bottom() - aBorder.Height() -1;
-    //Links
+    // left
     aRects[ 3 ] = aOuter;
     aRects[ 3 ].Right() = aRects[ 3 ].Left() + aBorder.Width() -1;
 }
@@ -103,41 +104,41 @@ void SvResizeHelper::FillMoveRectsPixel( Rectangle aRects[ 4 ] ) const
 /*************************************************************************
 |*    SvResizeHelper::Draw()
 |*
-|*    Beschreibung
+|*    Description
 *************************************************************************/
-void SvResizeHelper::Draw( OutputDevice * pDev )
+void SvResizeHelper::Draw(vcl::RenderContext& rRenderContext)
 {
-    pDev->Push();
-    pDev->SetMapMode( MapMode() );
+    rRenderContext.Push();
+    rRenderContext.SetMapMode( MapMode() );
     Color aColBlack;
     Color aFillColor( COL_LIGHTGRAY );
 
-    pDev->SetFillColor( aFillColor );
-    pDev->SetLineColor();
+    rRenderContext.SetFillColor( aFillColor );
+    rRenderContext.SetLineColor();
 
-    Rectangle   aMoveRects[ 4 ];
+    Rectangle aMoveRects[ 4 ];
     FillMoveRectsPixel( aMoveRects );
     sal_uInt16 i;
-    for( i = 0; i < 4; i++ )
-        pDev->DrawRect( aMoveRects[ i ] );
-    if( bResizeable )
+    for (i = 0; i < 4; i++)
+        rRenderContext.DrawRect(aMoveRects[i]);
+    if (bResizeable)
     {
-        // Handles malen
-        pDev->SetFillColor( aColBlack );
-        Rectangle   aRects[ 8 ];
-        FillHandleRectsPixel( aRects );
-        for( i = 0; i < 8; i++ )
-            pDev->DrawRect( aRects[ i ] );
+        // draw handles
+        rRenderContext.SetFillColor(aColBlack);
+        Rectangle aRects[ 8 ];
+        FillHandleRectsPixel(aRects);
+        for (i = 0; i < 8; i++)
+            rRenderContext.DrawRect( aRects[ i ] );
     }
-    pDev->Pop();
+    rRenderContext.Pop();
 }
 
 /*************************************************************************
 |*    SvResizeHelper::InvalidateBorder()
 |*
-|*    Beschreibung
+|*    Description
 *************************************************************************/
-void SvResizeHelper::InvalidateBorder( Window * pWin )
+void SvResizeHelper::InvalidateBorder( vcl::Window * pWin )
 {
     Rectangle   aMoveRects[ 4 ];
     FillMoveRectsPixel( aMoveRects );
@@ -148,29 +149,29 @@ void SvResizeHelper::InvalidateBorder( Window * pWin )
 /*************************************************************************
 |*    SvResizeHelper::SelectBegin()
 |*
-|*    Beschreibung
+|*    Description
 *************************************************************************/
-sal_Bool SvResizeHelper::SelectBegin( Window * pWin, const Point & rPos )
+bool SvResizeHelper::SelectBegin( vcl::Window * pWin, const Point & rPos )
 {
     if( -1 == nGrab )
     {
         nGrab = SelectMove( pWin, rPos );
         if( -1 != nGrab )
         {
-            aSelPos = rPos; // Start-Position merken
+            aSelPos = rPos; // store start position
             pWin->CaptureMouse();
-            return sal_True;
+            return true;
         }
     }
-    return sal_False;
+    return false;
 }
 
 /*************************************************************************
 |*    SvResizeHelper::SelectMove()
 |*
-|*    Beschreibung
+|*    Description
 *************************************************************************/
-short SvResizeHelper::SelectMove( Window * pWin, const Point & rPos )
+short SvResizeHelper::SelectMove( vcl::Window * pWin, const Point & rPos )
 {
     if( -1 == nGrab )
     {
@@ -182,7 +183,7 @@ short SvResizeHelper::SelectMove( Window * pWin, const Point & rPos )
                 if( aRects[ i ].IsInside( rPos ) )
                     return i;
         }
-        // Move-Rect ueberlappen Handles
+        // Move-Rect overlaps Handles
         Rectangle aMoveRects[ 4 ];
         FillMoveRectsPixel( aMoveRects );
         for( sal_uInt16 i = 0; i < 4; i++ )
@@ -201,16 +202,16 @@ short SvResizeHelper::SelectMove( Window * pWin, const Point & rPos )
 
 Point SvResizeHelper::GetTrackPosPixel( const Rectangle & rRect ) const
 {
-    // wie das Rechteck zurueckkommt ist egal, es zaehlt welches Handle
-    // initial angefasst wurde
+    // not important how the rectangle is returned, it is important
+    // which handle has been touched
     Point aPos;
     Rectangle aRect( rRect );
     aRect.Justify();
-    // nur wegen EMPTY_RECT
+    // only because of EMPTY_RECT
     Point aBR = aOuter.BottomRight();
     Point aTR = aOuter.TopRight();
     Point aBL = aOuter.BottomLeft();
-    bool bRTL = Application::GetSettings().GetLayoutRTL();
+    bool bRTL = AllSettings::GetLayoutRTL();
     switch( nGrab )
     {
         case 0:
@@ -265,7 +266,7 @@ Point SvResizeHelper::GetTrackPosPixel( const Rectangle & rRect ) const
 /*************************************************************************
 |*    SvResizeHelper::GetTrackRectPixel()
 |*
-|*    Beschreibung
+|*    Description
 *************************************************************************/
 Rectangle SvResizeHelper::GetTrackRectPixel( const Point & rTrackPos ) const
 {
@@ -275,7 +276,7 @@ Rectangle SvResizeHelper::GetTrackRectPixel( const Point & rTrackPos ) const
         Point aDiff = rTrackPos - aSelPos;
         aTrackRect = aOuter;
         Point aBR = aOuter.BottomRight();
-        bool bRTL = Application::GetSettings().GetLayoutRTL();
+        bool bRTL = AllSettings::GetLayoutRTL();
         switch( nGrab )
         {
             case 0:
@@ -346,81 +347,59 @@ void SvResizeHelper::ValidateRect( Rectangle & rValidate ) const
     {
         case 0:
             if( rValidate.Top() > rValidate.Bottom() )
-            {
                 rValidate.Top() = rValidate.Bottom();
-                rValidate.Bottom() = RECT_EMPTY;
-            }
             if( rValidate.Left() > rValidate.Right() )
-            {
                 rValidate.Left() = rValidate.Right();
-                rValidate.Right() = RECT_EMPTY;
-            }
             break;
         case 1:
             if( rValidate.Top() > rValidate.Bottom() )
-            {
                 rValidate.Top() = rValidate.Bottom();
-                rValidate.Bottom() = RECT_EMPTY;
-            }
             break;
         case 2:
             if( rValidate.Top() > rValidate.Bottom() )
-            {
                 rValidate.Top() = rValidate.Bottom();
-                rValidate.Bottom() = RECT_EMPTY;
-            }
             if( rValidate.Left() > rValidate.Right() )
-                rValidate.Right() = RECT_EMPTY;
+                rValidate.Right() = rValidate.Left();
             break;
         case 3:
             if( rValidate.Left() > rValidate.Right() )
-                rValidate.Right() = RECT_EMPTY;
+                rValidate.Right() = rValidate.Left();
             break;
         case 4:
             if( rValidate.Top() > rValidate.Bottom() )
-                rValidate.Bottom() = RECT_EMPTY;
+                rValidate.Bottom() = rValidate.Top();
             if( rValidate.Left() > rValidate.Right() )
-                rValidate.Right() = RECT_EMPTY;
+                rValidate.Right() = rValidate.Left();
             break;
         case 5:
             if( rValidate.Top() > rValidate.Bottom() )
-                rValidate.Bottom() = RECT_EMPTY;
+                rValidate.Bottom() = rValidate.Top();
             break;
         case 6:
             if( rValidate.Top() > rValidate.Bottom() )
-                rValidate.Bottom() = RECT_EMPTY;
+                rValidate.Bottom() = rValidate.Top();
             if( rValidate.Left() > rValidate.Right() )
-            {
                 rValidate.Left() = rValidate.Right();
-                rValidate.Right() = RECT_EMPTY;
-            }
             break;
         case 7:
             if( rValidate.Left() > rValidate.Right() )
-            {
                 rValidate.Left() = rValidate.Right();
-                rValidate.Right() = RECT_EMPTY;
-            }
             break;
     }
-    if( rValidate.Right() == RECT_EMPTY )
-        rValidate.Right() = rValidate.Left();
-    if( rValidate.Bottom() == RECT_EMPTY )
-        rValidate.Bottom() = rValidate.Top();
 
     // Mindestgr"osse 5 x 5
     if( rValidate.Left() + 5 > rValidate.Right() )
-        rValidate.Right() = rValidate.Left() +5;
+        rValidate.Right() = rValidate.Left() + 5;
     if( rValidate.Top() + 5 > rValidate.Bottom() )
-        rValidate.Bottom() = rValidate.Top() +5;
+        rValidate.Bottom() = rValidate.Top() + 5;
 }
 
 /*************************************************************************
 |*    SvResizeHelper::SelectRelease()
 |*
-|*    Beschreibung
+|*    Description
 *************************************************************************/
-sal_Bool SvResizeHelper::SelectRelease( Window * pWin, const Point & rPos,
+bool SvResizeHelper::SelectRelease( vcl::Window * pWin, const Point & rPos,
                                     Rectangle & rOutPosSize )
 {
     if( -1 != nGrab )
@@ -430,17 +409,17 @@ sal_Bool SvResizeHelper::SelectRelease( Window * pWin, const Point & rPos,
         nGrab = -1;
         pWin->ReleaseMouse();
         pWin->HideTracking();
-        return sal_True;
+        return true;
     }
-    return sal_False;
+    return false;
 }
 
 /*************************************************************************
 |*    SvResizeHelper::Release()
 |*
-|*    Beschreibung
+|*    Description
 *************************************************************************/
-void SvResizeHelper::Release( Window * pWin )
+void SvResizeHelper::Release( vcl::Window * pWin )
 {
     if( nGrab != -1 )
     {
@@ -453,28 +432,28 @@ void SvResizeHelper::Release( Window * pWin )
 /*************************************************************************
 |*    SvResizeWindow::SvResizeWindow()
 |*
-|*    Beschreibung
+|*    Description
 *************************************************************************/
 SvResizeWindow::SvResizeWindow
 (
-    Window * pParent,
+    vcl::Window * pParent,
     VCLXHatchWindow* pWrapper
 )
     : Window( pParent, WB_CLIPCHILDREN )
     , m_nMoveGrab( -1 )
-    , m_bActive( sal_False )
+    , m_bActive( false )
     , m_pWrapper( pWrapper )
 {
-    OSL_ENSURE( pParent != NULL && pWrapper != NULL, "Wrong initialization of hatch window!\n" );
+    OSL_ENSURE( pParent != nullptr && pWrapper != nullptr, "Wrong initialization of hatch window!\n" );
     SetBackground();
-    SetAccessibleRole( ::com::sun::star::accessibility::AccessibleRole::EMBEDDED_OBJECT );
+    SetAccessibleRole( css::accessibility::AccessibleRole::EMBEDDED_OBJECT );
     m_aResizer.SetOuterRectPixel( Rectangle( Point(), GetOutputSizePixel() ) );
 }
 
 /*************************************************************************
 |*    SvResizeWindow::SetHatchBorderPixel()
 |*
-|*    Beschreibung
+|*    Description
 *************************************************************************/
 void SvResizeWindow::SetHatchBorderPixel( const Size & rSize )
 {
@@ -484,7 +463,7 @@ void SvResizeWindow::SetHatchBorderPixel( const Size & rSize )
 /*************************************************************************
 |*    SvResizeWindow::SelectMouse()
 |*
-|*    Beschreibung
+|*    Description
 *************************************************************************/
 void SvResizeWindow::SelectMouse( const Point & rPos )
 {
@@ -492,21 +471,21 @@ void SvResizeWindow::SelectMouse( const Point & rPos )
     if( nGrab >= 4 )
         nGrab -= 4;
     if( m_nMoveGrab != nGrab )
-    { // Pointer hat sich geaendert
+    { // Pointer did change
         if( -1 == nGrab )
             SetPointer( m_aOldPointer );
         else
         {
-            PointerStyle aStyle = POINTER_MOVE;
+            PointerStyle aStyle = PointerStyle::Move;
             if( nGrab == 3 )
-                aStyle = POINTER_ESIZE;
+                aStyle = PointerStyle::ESize;
             else if( nGrab == 2 )
-                aStyle = POINTER_NESIZE;
+                aStyle = PointerStyle::NESize;
             else if( nGrab == 1 )
-                aStyle = POINTER_SSIZE;
+                aStyle = PointerStyle::SSize;
             else if( nGrab == 0 )
-                aStyle = POINTER_SESIZE;
-            if( m_nMoveGrab == -1 ) // das erste mal
+                aStyle = PointerStyle::SESize;
+            if( m_nMoveGrab == -1 ) // the first time
             {
                 m_aOldPointer = GetPointer();
                 SetPointer( Pointer( aStyle ) );
@@ -521,7 +500,7 @@ void SvResizeWindow::SelectMouse( const Point & rPos )
 /*************************************************************************
 |*    SvResizeWindow::MouseButtonDown()
 |*
-|*    Beschreibung
+|*    Description
 *************************************************************************/
 void SvResizeWindow::MouseButtonDown( const MouseEvent & rEvt )
 {
@@ -532,7 +511,7 @@ void SvResizeWindow::MouseButtonDown( const MouseEvent & rEvt )
 /*************************************************************************
 |*    SvResizeWindow::MouseMove()
 |*
-|*    Beschreibung
+|*    Description
 *************************************************************************/
 void SvResizeWindow::MouseMove( const MouseEvent & rEvt )
 {
@@ -556,7 +535,7 @@ void SvResizeWindow::MouseMove( const MouseEvent & rEvt )
 /*************************************************************************
 |*    SvResizeWindow::MouseButtonUp()
 |*
-|*    Beschreibung
+|*    Description
 *************************************************************************/
 void SvResizeWindow::MouseButtonUp( const MouseEvent & rEvt )
 {
@@ -583,7 +562,7 @@ void SvResizeWindow::MouseButtonUp( const MouseEvent & rEvt )
 /*************************************************************************
 |*    SvResizeWindow::KeyEvent()
 |*
-|*    Beschreibung
+|*    Description
 *************************************************************************/
 void SvResizeWindow::KeyInput( const KeyEvent & rEvt )
 {
@@ -597,44 +576,44 @@ void SvResizeWindow::KeyInput( const KeyEvent & rEvt )
 /*************************************************************************
 |*    SvResizeWindow::Resize()
 |*
-|*    Beschreibung
+|*    Description
 *************************************************************************/
 void SvResizeWindow::Resize()
 {
-    m_aResizer.InvalidateBorder( this ); // alten Bereich
+    m_aResizer.InvalidateBorder( this ); // old area
     m_aResizer.SetOuterRectPixel( Rectangle( Point(), GetOutputSizePixel() ) );
-    m_aResizer.InvalidateBorder( this ); // neuen Bereich
+    m_aResizer.InvalidateBorder( this ); // new area
 }
 
 /*************************************************************************
 |*    SvResizeWindow::Paint()
 |*
-|*    Beschreibung
+|*    Description
 *************************************************************************/
-void SvResizeWindow::Paint( const Rectangle & /*rRect*/ )
+void SvResizeWindow::Paint(vcl::RenderContext& rRenderContext, const Rectangle & /*rRect*/ )
 {
-    m_aResizer.Draw( this );
+    m_aResizer.Draw(rRenderContext);
 }
 
-long SvResizeWindow::PreNotify( NotifyEvent& rEvt )
+bool SvResizeWindow::PreNotify( NotifyEvent& rEvt )
 {
-    if ( rEvt.GetType() == EVENT_GETFOCUS && !m_bActive )
+    if ( rEvt.GetType() == MouseNotifyEvent::GETFOCUS && !m_bActive )
     {
-        m_bActive = sal_True;
+        m_bActive = true;
         m_pWrapper->Activated();
     }
 
     return Window::PreNotify(rEvt);
 }
 
-long SvResizeWindow::Notify( NotifyEvent& rEvt )
+bool SvResizeWindow::Notify( NotifyEvent& rEvt )
 {
-    if ( rEvt.GetType() == EVENT_LOSEFOCUS && m_bActive )
+    if ( rEvt.GetType() == MouseNotifyEvent::LOSEFOCUS && m_bActive )
     {
-        sal_Bool bHasFocus = HasChildPathFocus(sal_True);
+        bool bHasFocus = HasChildPathFocus(true);
         if ( !bHasFocus )
         {
-            m_bActive = sal_False;
+            m_bActive = false;
             m_pWrapper->Deactivated();
         }
     }
