@@ -68,7 +68,7 @@ namespace svt { namespace table
         ITableControl&  m_rTable;
 
     public:
-        SuppressCursor( ITableControl& _rTable )
+        explicit SuppressCursor( ITableControl& _rTable )
             :m_rTable( _rTable )
         {
             m_rTable.hideCursor();
@@ -96,132 +96,126 @@ namespace svt { namespace table
         }
 
         // ITableModel overridables
-        virtual TableSize           getColumnCount() const SAL_OVERRIDE
+        virtual TableSize           getColumnCount() const override
         {
             return 0;
         }
-        virtual TableSize           getRowCount() const SAL_OVERRIDE
+        virtual TableSize           getRowCount() const override
         {
             return 0;
         }
-        virtual bool                hasColumnHeaders() const SAL_OVERRIDE
+        virtual bool                hasColumnHeaders() const override
         {
             return false;
         }
-        virtual bool                hasRowHeaders() const SAL_OVERRIDE
+        virtual bool                hasRowHeaders() const override
         {
             return false;
         }
-        virtual bool                isCellEditable( ColPos col, RowPos row ) const SAL_OVERRIDE
-        {
-            (void)col;
-            (void)row;
-            return false;
-        }
-        virtual PColumnModel        getColumnModel( ColPos column ) SAL_OVERRIDE
+        virtual PColumnModel        getColumnModel( ColPos column ) override
         {
             OSL_FAIL( "EmptyTableModel::getColumnModel: invalid call!" );
             (void)column;
             return PColumnModel();
         }
-        virtual PTableRenderer      getRenderer() const SAL_OVERRIDE
+        virtual PTableRenderer      getRenderer() const override
         {
             return PTableRenderer();
         }
-        virtual PTableInputHandler  getInputHandler() const SAL_OVERRIDE
+        virtual PTableInputHandler  getInputHandler() const override
         {
             return PTableInputHandler();
         }
-        virtual TableMetrics        getRowHeight() const SAL_OVERRIDE
+        virtual TableMetrics        getRowHeight() const override
         {
             return 5 * 100;
         }
-        virtual TableMetrics        getColumnHeaderHeight() const SAL_OVERRIDE
+        virtual TableMetrics        getColumnHeaderHeight() const override
         {
             return 0;
         }
-        virtual TableMetrics        getRowHeaderWidth() const SAL_OVERRIDE
+        virtual TableMetrics        getRowHeaderWidth() const override
         {
             return 0;
         }
-        virtual ScrollbarVisibility getVerticalScrollbarVisibility() const SAL_OVERRIDE
+        virtual ScrollbarVisibility getVerticalScrollbarVisibility() const override
         {
             return ScrollbarShowNever;
         }
-        virtual ScrollbarVisibility getHorizontalScrollbarVisibility() const SAL_OVERRIDE
+        virtual ScrollbarVisibility getHorizontalScrollbarVisibility() const override
         {
             return ScrollbarShowNever;
         }
-        virtual void addTableModelListener( const PTableModelListener& i_listener ) SAL_OVERRIDE
+        virtual void addTableModelListener( const PTableModelListener& i_listener ) override
         {
             (void)i_listener;
         }
-        virtual void removeTableModelListener( const PTableModelListener& i_listener ) SAL_OVERRIDE
+        virtual void removeTableModelListener( const PTableModelListener& i_listener ) override
         {
             (void)i_listener;
         }
-        virtual ::boost::optional< ::Color > getLineColor() const SAL_OVERRIDE
+        virtual ::boost::optional< ::Color > getLineColor() const override
         {
             return ::boost::optional< ::Color >();
         }
-        virtual ::boost::optional< ::Color > getHeaderBackgroundColor() const SAL_OVERRIDE
+        virtual ::boost::optional< ::Color > getHeaderBackgroundColor() const override
         {
             return ::boost::optional< ::Color >();
         }
-        virtual ::boost::optional< ::Color > getHeaderTextColor() const SAL_OVERRIDE
+        virtual ::boost::optional< ::Color > getHeaderTextColor() const override
         {
             return ::boost::optional< ::Color >();
         }
-        virtual ::boost::optional< ::Color >    getActiveSelectionBackColor() const SAL_OVERRIDE
+        virtual ::boost::optional< ::Color >    getActiveSelectionBackColor() const override
         {
             return ::boost::optional< ::Color >();
         }
-        virtual ::boost::optional< ::Color >    getInactiveSelectionBackColor() const SAL_OVERRIDE
+        virtual ::boost::optional< ::Color >    getInactiveSelectionBackColor() const override
         {
             return ::boost::optional< ::Color >();
         }
-        virtual ::boost::optional< ::Color >    getActiveSelectionTextColor() const SAL_OVERRIDE
+        virtual ::boost::optional< ::Color >    getActiveSelectionTextColor() const override
         {
             return ::boost::optional< ::Color >();
         }
-        virtual ::boost::optional< ::Color >    getInactiveSelectionTextColor() const SAL_OVERRIDE
+        virtual ::boost::optional< ::Color >    getInactiveSelectionTextColor() const override
         {
             return ::boost::optional< ::Color >();
         }
-        virtual ::boost::optional< ::Color > getTextColor() const SAL_OVERRIDE
+        virtual ::boost::optional< ::Color > getTextColor() const override
         {
             return ::boost::optional< ::Color >();
         }
-        virtual ::boost::optional< ::Color > getTextLineColor() const SAL_OVERRIDE
+        virtual ::boost::optional< ::Color > getTextLineColor() const override
         {
             return ::boost::optional< ::Color >();
         }
-        virtual ::boost::optional< ::std::vector< ::Color > > getRowBackgroundColors() const SAL_OVERRIDE
+        virtual ::boost::optional< ::std::vector< ::Color > > getRowBackgroundColors() const override
         {
             return ::boost::optional< ::std::vector< ::Color > >();
         }
-        virtual ::com::sun::star::style::VerticalAlignment getVerticalAlign() const SAL_OVERRIDE
+        virtual css::style::VerticalAlignment getVerticalAlign() const override
         {
-            return com::sun::star::style::VerticalAlignment(0);
+            return css::style::VerticalAlignment(0);
         }
-        virtual ITableDataSort* getSortAdapter() SAL_OVERRIDE
+        virtual ITableDataSort* getSortAdapter() override
         {
-            return NULL;
+            return nullptr;
         }
-        virtual bool isEnabled() const SAL_OVERRIDE
+        virtual bool isEnabled() const override
         {
             return true;
         }
-        virtual void getCellContent( ColPos const i_col, RowPos const i_row, ::com::sun::star::uno::Any& o_cellContent ) SAL_OVERRIDE
+        virtual void getCellContent( ColPos const i_col, RowPos const i_row, css::uno::Any& o_cellContent ) override
         {
             (void)i_row;
             (void)i_col;
             o_cellContent.clear();
         }
-        virtual void getCellToolTip( ColPos const, RowPos const, ::com::sun::star::uno::Any& ) SAL_OVERRIDE
+        virtual void getCellToolTip( ColPos const, RowPos const, css::uno::Any& ) override
         {
         }
-        virtual Any getRowHeading( RowPos const i_rowPos ) const SAL_OVERRIDE
+        virtual Any getRowHeading( RowPos const i_rowPos ) const override
         {
             (void)i_rowPos;
             return Any();
@@ -243,15 +237,15 @@ namespace svt { namespace table
         ,m_nTopRow              ( 0                             )
         ,m_nCursorHidden        ( 1                             )
         ,m_pDataWindow          ( VclPtr<TableDataWindow>::Create( *this )  )
-        ,m_pVScroll             ( NULL                          )
-        ,m_pHScroll             ( NULL                          )
-        ,m_pScrollCorner        ( NULL                          )
+        ,m_pVScroll             ( nullptr                          )
+        ,m_pHScroll             ( nullptr                          )
+        ,m_pScrollCorner        ( nullptr                          )
         ,m_pSelEngine           (                               )
         ,m_aSelectedRows        (                               )
         ,m_pTableFunctionSet    ( new TableFunctionSet( this  ) )
         ,m_nAnchor              ( -1                            )
         ,m_bUpdatingColWidths   ( false                         )
-        ,m_pAccessibleTable     ( NULL                          )
+        ,m_pAccessibleTable     ( nullptr                          )
     {
         m_pSelEngine = new SelectionEngine( m_pDataWindow.get(), m_pTableFunctionSet );
         m_pSelEngine->SetSelectionMode(SINGLE_SELECTION);
@@ -431,18 +425,16 @@ namespace svt { namespace table
     }
 
 
-    void TableControl_Impl::columnInserted( ColPos const i_colIndex )
+    void TableControl_Impl::columnInserted()
     {
         m_nColumnCount = m_pModel->getColumnCount();
         impl_ni_relayout();
 
         m_rAntiImpl.Invalidate();
-
-        OSL_UNUSED( i_colIndex );
    }
 
 
-    void TableControl_Impl::columnRemoved( ColPos const i_colIndex )
+    void TableControl_Impl::columnRemoved()
     {
         m_nColumnCount = m_pModel->getColumnCount();
 
@@ -458,8 +450,6 @@ namespace svt { namespace table
         impl_ni_relayout();
 
         m_rAntiImpl.Invalidate();
-
-        OSL_UNUSED( i_colIndex );
     }
 
 
@@ -472,12 +462,9 @@ namespace svt { namespace table
     }
 
 
-    void TableControl_Impl::cellsUpdated( ColPos const i_firstCol, ColPos i_lastCol, RowPos const i_firstRow, RowPos const i_lastRow )
+    void TableControl_Impl::cellsUpdated( RowPos const i_firstRow, RowPos const i_lastRow )
     {
         invalidateRowRange( i_firstRow, i_lastRow );
-
-        OSL_UNUSED( i_firstCol );
-        OSL_UNUSED( i_lastCol );
     }
 
 
@@ -635,7 +622,7 @@ namespace svt { namespace table
         bool lcl_updateScrollbar( vcl::Window& _rParent, VclPtr<ScrollBar>& _rpBar,
             bool const i_needBar, long _nVisibleUnits,
             long _nPosition, long _nLineSize, long _nRange,
-            bool _bHorizontal, const Link<>& _rScrollHandler )
+            bool _bHorizontal, const Link<ScrollBar*,void>& _rScrollHandler )
         {
             // do we currently have the scrollbar?
             bool bHaveBar = _rpBar != nullptr;
@@ -1815,7 +1802,7 @@ namespace svt { namespace table
 
         case TableAreaAll:
             m_pDataWindow->Invalidate();
-            m_pDataWindow->GetParent()->Invalidate( INVALIDATE_TRANSPARENT );
+            m_pDataWindow->GetParent()->Invalidate( InvalidateFlags::Transparent );
             break;
         }
     }
@@ -1892,7 +1879,7 @@ namespace svt { namespace table
     void TableControl_Impl::invalidateRect(const Rectangle &rInvalidateRect)
     {
         m_pDataWindow->Invalidate( rInvalidateRect,
-            m_pDataWindow->GetControlBackground().GetTransparency() ? INVALIDATE_TRANSPARENT : 0 );
+            m_pDataWindow->GetControlBackground().GetTransparency() ? InvalidateFlags::Transparent : InvalidateFlags::NONE );
     }
 
 
@@ -2047,7 +2034,7 @@ namespace svt { namespace table
         m_pModel->getCellContent( i_col, i_row, aCellValue );
 
         OUString sCellStringContent;
-        m_pModel->getRenderer()->GetFormattedCellString( aCellValue, i_col, i_row, sCellStringContent );
+        m_pModel->getRenderer()->GetFormattedCellString( aCellValue, sCellStringContent );
 
         return sCellStringContent;
     }
@@ -2082,12 +2069,12 @@ namespace svt { namespace table
                 &&  std::abs( nPixelDelta ) < aDataArea.GetHeight()
                 )
             {
-                m_pDataWindow->Scroll( 0, (long)-nPixelDelta, aDataArea, SCROLL_CLIP | SCROLL_UPDATE | SCROLL_CHILDREN);
+                m_pDataWindow->Scroll( 0, (long)-nPixelDelta, aDataArea, ScrollFlags::Clip | ScrollFlags::Update | ScrollFlags::Children);
             }
             else
             {
-                m_pDataWindow->Invalidate( INVALIDATE_UPDATE );
-                m_pDataWindow->GetParent()->Invalidate( INVALIDATE_TRANSPARENT );
+                m_pDataWindow->Invalidate( InvalidateFlags::Update );
+                m_pDataWindow->GetParent()->Invalidate( InvalidateFlags::Transparent );
             }
 
             // update the position at the vertical scrollbar
@@ -2145,7 +2132,7 @@ namespace svt { namespace table
                 -   m_aColumnWidths[ m_nLeftColumn ].getStart();
 
             // update our column positions
-            // Do this *before* scrolling, as SCROLL_UPDATE will trigger a paint, which already needs the correct
+            // Do this *before* scrolling, as ScrollFlags::Update will trigger a paint, which already needs the correct
             // information in m_aColumnWidths
             for (   ColumnPositions::iterator colPos = m_aColumnWidths.begin();
                     colPos != m_aColumnWidths.end();
@@ -2160,12 +2147,12 @@ namespace svt { namespace table
                 &&  std::abs( nPixelDelta ) < aDataArea.GetWidth()
                 )
             {
-                m_pDataWindow->Scroll( nPixelDelta, 0, aDataArea, SCROLL_CLIP | SCROLL_UPDATE );
+                m_pDataWindow->Scroll( nPixelDelta, 0, aDataArea, ScrollFlags::Clip | ScrollFlags::Update );
             }
             else
             {
-                m_pDataWindow->Invalidate( INVALIDATE_UPDATE );
-                m_pDataWindow->GetParent()->Invalidate( INVALIDATE_TRANSPARENT );
+                m_pDataWindow->Invalidate( InvalidateFlags::Update );
+                m_pDataWindow->GetParent()->Invalidate( InvalidateFlags::Transparent );
             }
 
             // update the position at the horizontal scrollbar
@@ -2392,16 +2379,15 @@ namespace svt { namespace table
     }
 
 
-    IMPL_LINK_NOARG( TableControl_Impl, OnUpdateScrollbars )
+    IMPL_LINK_NOARG_TYPED( TableControl_Impl, OnUpdateScrollbars, void*, void )
     {
         // TODO: can't we simply use lcl_updateScrollbar here, so the scrollbars ranges are updated, instead of
         // doing a complete re-layout?
         impl_ni_relayout();
-        return 1L;
     }
 
 
-    IMPL_LINK( TableControl_Impl, OnScroll, ScrollBar*, _pScrollbar )
+    IMPL_LINK_TYPED( TableControl_Impl, OnScroll, ScrollBar*, _pScrollbar, void )
     {
         DBG_ASSERT( ( _pScrollbar == m_pVScroll ) || ( _pScrollbar == m_pHScroll ),
             "TableControl_Impl::OnScroll: where did this come from?" );
@@ -2410,15 +2396,13 @@ namespace svt { namespace table
             impl_ni_ScrollRows( _pScrollbar->GetDelta() );
         else
             impl_ni_ScrollColumns( _pScrollbar->GetDelta() );
-
-        return 0L;
     }
 
 
     Reference< XAccessible > TableControl_Impl::getAccessible( vcl::Window& i_parentWindow )
     {
         DBG_TESTSOLARMUTEX();
-        if ( m_pAccessibleTable == NULL )
+        if ( m_pAccessibleTable == nullptr )
         {
             Reference< XAccessible > const xAccParent = i_parentWindow.GetAccessible();
             if ( xAccParent.is() )
@@ -2440,13 +2424,13 @@ namespace svt { namespace table
     {
         if ( m_pAccessibleTable )
             m_pAccessibleTable->DisposeAccessImpl();
-        m_pAccessibleTable = NULL;
+        m_pAccessibleTable = nullptr;
     }
 
 
     bool TableControl_Impl::impl_isAccessibleAlive() const
     {
-        return ( NULL != m_pAccessibleTable ) && m_pAccessibleTable->isAlive();
+        return ( nullptr != m_pAccessibleTable ) && m_pAccessibleTable->isAlive();
     }
 
 
