@@ -18,7 +18,7 @@
  */
 
 
-#include "svtools/toolpanel/drawerlayouter.hxx"
+#include <svtools/toolpanel/drawerlayouter.hxx>
 #include "toolpaneldrawer.hxx"
 
 #include <com/sun/star/accessibility/XAccessible.hpp>
@@ -26,19 +26,19 @@
 #include <comphelper/accimplaccess.hxx>
 #include <tools/diagnose_ex.h>
 
-//......................................................................................................................
+
 namespace svt
 {
-//......................................................................................................................
+
 
     using ::com::sun::star::uno::Reference;
     using ::com::sun::star::accessibility::XAccessible;
 
-    //==================================================================================================================
+
     //= DrawerDeckLayouter
-    //==================================================================================================================
-    //------------------------------------------------------------------------------------------------------------------
-    DrawerDeckLayouter::DrawerDeckLayouter( ::Window& i_rParentWindow, IToolPanelDeck& i_rPanels )
+
+
+    DrawerDeckLayouter::DrawerDeckLayouter( vcl::Window& i_rParentWindow, IToolPanelDeck& i_rPanels )
         :m_rParentWindow( i_rParentWindow )
         ,m_rPanelDeck( i_rPanels )
         ,m_aDrawers()
@@ -51,15 +51,12 @@ namespace svt
             PanelInserted( m_rPanelDeck.GetPanel( i ), i );
     }
 
-    //------------------------------------------------------------------------------------------------------------------
+
     DrawerDeckLayouter::~DrawerDeckLayouter()
     {
     }
 
-    //------------------------------------------------------------------------------------------------------------------
-    IMPLEMENT_IREFERENCE( DrawerDeckLayouter )
 
-    //------------------------------------------------------------------------------------------------------------------
     Rectangle DrawerDeckLayouter::Layout( const Rectangle& i_rDeckPlayground )
     {
         const size_t nPanelCount( m_rPanelDeck.GetPanelCount() );
@@ -95,14 +92,14 @@ namespace svt
             aLowerDrawerPos.Move( 0, -nDrawerHeight );
         }
 
-        // fincally calculate the rectangle for the active panel
+        // finally calculate the rectangle for the active panel
         return Rectangle(
             aUpperDrawerPos,
             Size( nWidth, aLowerDrawerPos.Y() - aUpperDrawerPos.Y() + 1 )
         );
     }
 
-    //------------------------------------------------------------------------------------------------------------------
+
     void DrawerDeckLayouter::Destroy()
     {
         while ( !m_aDrawers.empty() )
@@ -110,7 +107,7 @@ namespace svt
         m_rPanelDeck.RemoveListener( *this );
     }
 
-    //------------------------------------------------------------------------------------------------------------------
+
     void DrawerDeckLayouter::SetFocusToPanelSelector()
     {
         const size_t nPanelCount( m_rPanelDeck.GetPanelCount() );
@@ -124,24 +121,24 @@ namespace svt
         m_aDrawers[ *aActivePanel ]->GrabFocus();
     }
 
-    //------------------------------------------------------------------------------------------------------------------
+
     size_t DrawerDeckLayouter::GetAccessibleChildCount() const
     {
         return m_aDrawers.size();
     }
 
-    //------------------------------------------------------------------------------------------------------------------
+
     Reference< XAccessible > DrawerDeckLayouter::GetAccessibleChild( const size_t i_nChildIndex, const Reference< XAccessible >& i_rParentAccessible )
     {
-        ENSURE_OR_RETURN( i_nChildIndex < m_aDrawers.size(), "illegal index", NULL );
+        ENSURE_OR_RETURN( i_nChildIndex < m_aDrawers.size(), "illegal index", nullptr );
 
-        const PToolPanelDrawer pDrawer( m_aDrawers[ i_nChildIndex ] );
+        VclPtr<ToolPanelDrawer> pDrawer( m_aDrawers[ i_nChildIndex ] );
 
-        Reference< XAccessible > xItemAccessible = pDrawer->GetAccessible( sal_False );
+        Reference< XAccessible > xItemAccessible = pDrawer->GetAccessible( false );
         if ( !xItemAccessible.is() )
         {
-            xItemAccessible = pDrawer->GetAccessible( sal_True );
-            ENSURE_OR_RETURN( xItemAccessible.is(), "illegal accessible provided by the drawer implementation!", NULL );
+            xItemAccessible = pDrawer->GetAccessible();
+            ENSURE_OR_RETURN( xItemAccessible.is(), "illegal accessible provided by the drawer implementation!", nullptr );
             OSL_VERIFY( ::comphelper::OAccessibleImplementationAccess::setAccessibleParent( xItemAccessible->getAccessibleContext(),
                 i_rParentAccessible ) );
         }
@@ -149,22 +146,22 @@ namespace svt
         return xItemAccessible;
     }
 
-    //------------------------------------------------------------------------------------------------------------------
+
     void DrawerDeckLayouter::PanelInserted( const PToolPanel& i_pPanel, const size_t i_nPosition )
     {
         OSL_PRECOND( i_nPosition <= m_aDrawers.size(), "DrawerDeckLayouter::PanelInserted: inconsistency!" );
 
-        PToolPanelDrawer pDrawer( new ToolPanelDrawer( m_rParentWindow, i_pPanel->GetDisplayName() ) );
+        VclPtrInstance<ToolPanelDrawer> pDrawer( m_rParentWindow, i_pPanel->GetDisplayName() );
         pDrawer->SetHelpId( i_pPanel->GetHelpID() );
         // proper Z-Order
         if ( i_nPosition == 0 )
         {
-            pDrawer->SetZOrder( NULL, WINDOW_ZORDER_FIRST );
+            pDrawer->SetZOrder( nullptr, ZOrderFlags::First );
         }
         else
         {
-            const PToolPanelDrawer pFirstDrawer( m_aDrawers[ i_nPosition - 1 ] );
-            pDrawer->SetZOrder( pFirstDrawer.get(), WINDOW_ZORDER_BEHIND );
+            ToolPanelDrawer* pFirstDrawer( m_aDrawers[ i_nPosition - 1 ] );
+            pDrawer->SetZOrder( pFirstDrawer, ZOrderFlags::Behind );
         }
 
         pDrawer->Show();
@@ -173,14 +170,14 @@ namespace svt
         impl_triggerRearrange();
     }
 
-    //------------------------------------------------------------------------------------------------------------------
+
     void DrawerDeckLayouter::PanelRemoved( const size_t i_nPosition )
     {
         impl_removeDrawer( i_nPosition );
         impl_triggerRearrange();
     }
 
-    //------------------------------------------------------------------------------------------------------------------
+
     void DrawerDeckLayouter::impl_triggerRearrange() const
     {
         // this is somewhat hacky, it assumes that the parent of our panels is a tool panel deck, which, in its
@@ -188,7 +185,7 @@ namespace svt
         m_rParentWindow.Resize();
     }
 
-    //------------------------------------------------------------------------------------------------------------------
+
     void DrawerDeckLayouter::ActivePanelChanged( const ::boost::optional< size_t >& i_rOldActive, const ::boost::optional< size_t >& i_rNewActive )
     {
         if ( !!i_rOldActive )
@@ -206,20 +203,17 @@ namespace svt
         impl_triggerRearrange();
     }
 
-    //------------------------------------------------------------------------------------------------------------------
+
     void DrawerDeckLayouter::LayouterChanged( const PDeckLayouter& i_rNewLayouter )
     {
         // not interested in
         (void)i_rNewLayouter;
     }
 
-    //------------------------------------------------------------------------------------------------------------------
-    size_t DrawerDeckLayouter::impl_getPanelPositionFromWindow( const Window* i_pDrawerWindow ) const
+
+    size_t DrawerDeckLayouter::impl_getPanelPositionFromWindow( const vcl::Window* i_pDrawerWindow ) const
     {
-        for (   ::std::vector< PToolPanelDrawer >::const_iterator drawerPos = m_aDrawers.begin();
-                drawerPos != m_aDrawers.end();
-                ++drawerPos
-            )
+        for ( auto drawerPos = m_aDrawers.begin(); drawerPos != m_aDrawers.end(); ++drawerPos )
         {
             if ( drawerPos->get() == i_pDrawerWindow )
                 return drawerPos - m_aDrawers.begin();
@@ -227,28 +221,24 @@ namespace svt
         return m_aDrawers.size();
     }
 
-    //------------------------------------------------------------------------------------------------------------------
+
     void DrawerDeckLayouter::impl_removeDrawer( const size_t i_nPosition )
     {
         OSL_PRECOND( i_nPosition < m_aDrawers.size(), "DrawerDeckLayouter::impl_removeDrawer: invalid panel position!" );
         m_aDrawers[ i_nPosition ]->RemoveEventListener( LINK( this, DrawerDeckLayouter, OnWindowEvent ) );
-        OSL_ENSURE( m_aDrawers[ i_nPosition ].unique(), "DrawerDeckLayouter::impl_removeDrawer: somebody else is still holding a reference!" );
         m_aDrawers.erase( m_aDrawers.begin() + i_nPosition );
     }
 
-    //------------------------------------------------------------------------------------------------------------------
-    IMPL_LINK( DrawerDeckLayouter, OnWindowEvent, VclSimpleEvent*, i_pEvent )
-    {
-        const VclWindowEvent* pWindowEvent = PTR_CAST( VclWindowEvent, i_pEvent );
-        ENSURE_OR_RETURN( pWindowEvent, "no WindowEvent", 0L );
 
+    IMPL_LINK_TYPED( DrawerDeckLayouter, OnWindowEvent, VclWindowEvent&, rWindowEvent, void )
+    {
         bool bActivatePanel = false;
-        switch ( pWindowEvent->GetId() )
+        switch ( rWindowEvent.GetId() )
         {
             case VCLEVENT_WINDOW_MOUSEBUTTONUP:
             {
-                const MouseEvent* pMouseEvent = static_cast< const MouseEvent* >( pWindowEvent->GetData() );
-                ENSURE_OR_RETURN( pMouseEvent, "no mouse event with MouseButtonUp", 0L );
+                const MouseEvent* pMouseEvent = static_cast< const MouseEvent* >( rWindowEvent.GetData() );
+                ENSURE_OR_RETURN_VOID( pMouseEvent, "no mouse event with MouseButtonUp" );
                 if ( pMouseEvent->GetButtons() == MOUSE_LEFT )
                 {
                     bActivatePanel = true;
@@ -257,9 +247,9 @@ namespace svt
             break;
             case VCLEVENT_WINDOW_KEYINPUT:
             {
-                const KeyEvent* pKeyEvent = static_cast< const KeyEvent* >( pWindowEvent->GetData() );
-                ENSURE_OR_RETURN( pKeyEvent, "no key event with KeyInput", 0L );
-                const KeyCode& rKeyCode( pKeyEvent->GetKeyCode() );
+                const KeyEvent* pKeyEvent = static_cast< const KeyEvent* >( rWindowEvent.GetData() );
+                ENSURE_OR_RETURN_VOID( pKeyEvent, "no key event with KeyInput" );
+                const vcl::KeyCode& rKeyCode( pKeyEvent->GetKeyCode() );
                 if ( ( rKeyCode.GetModifier() == 0 ) && ( rKeyCode.GetCode() == KEY_RETURN ) )
                 {
                     bActivatePanel = true;
@@ -269,7 +259,7 @@ namespace svt
         }
         if ( bActivatePanel )
         {
-            const size_t nPanelPos = impl_getPanelPositionFromWindow( pWindowEvent->GetWindow() );
+            const size_t nPanelPos = impl_getPanelPositionFromWindow( rWindowEvent.GetWindow() );
             if ( nPanelPos != m_rPanelDeck.GetActivePanel() )
             {
                 m_rPanelDeck.ActivatePanel( nPanelPos );
@@ -279,19 +269,17 @@ namespace svt
                 PToolPanel pPanel( m_rPanelDeck.GetPanel( nPanelPos ) );
                 pPanel->GrabFocus();
             }
-            return 1L;
         }
-        return 0L;
     }
 
-    //------------------------------------------------------------------------------------------------------------------
+
     void DrawerDeckLayouter::Dying()
     {
         Destroy();
     }
 
-//......................................................................................................................
+
 } // namespace svt
-//......................................................................................................................
+
 
 /* vim:set shiftwidth=4 softtabstop=4 expandtab: */
