@@ -63,88 +63,88 @@ void SvxFontWorkControllerItem::StateChanged( sal_uInt16 /*nSID*/, SfxItemState
         case SID_FORMTEXT_STYLE:
         {
             const XFormTextStyleItem* pStateItem =
-                                PTR_CAST(XFormTextStyleItem, pItem);
-            DBG_ASSERT(pStateItem || pItem == 0, "XFormTextStyleItem expected");
+                                dynamic_cast<const XFormTextStyleItem*>( pItem );
+            DBG_ASSERT(pStateItem || pItem == nullptr, "XFormTextStyleItem expected");
             rFontWorkDlg.SetStyle_Impl(pStateItem);
             break;
         }
         case SID_FORMTEXT_ADJUST:
         {
             const XFormTextAdjustItem* pStateItem =
-                                PTR_CAST(XFormTextAdjustItem, pItem);
-            DBG_ASSERT(pStateItem || pItem == 0, "XFormTextAdjustItem expected");
+                                dynamic_cast<const XFormTextAdjustItem*>( pItem );
+            DBG_ASSERT(pStateItem || pItem == nullptr, "XFormTextAdjustItem expected");
             rFontWorkDlg.SetAdjust_Impl(pStateItem);
             break;
         }
         case SID_FORMTEXT_DISTANCE:
         {
             const XFormTextDistanceItem* pStateItem =
-                                PTR_CAST(XFormTextDistanceItem, pItem);
-            DBG_ASSERT(pStateItem || pItem == 0, "XFormTextDistanceItem erwartet");
+                                dynamic_cast<const XFormTextDistanceItem*>( pItem );
+            DBG_ASSERT(pStateItem || pItem == nullptr, "XFormTextDistanceItem erwartet");
             rFontWorkDlg.SetDistance_Impl(pStateItem);
             break;
         }
         case SID_FORMTEXT_START:
         {
             const XFormTextStartItem* pStateItem =
-                                PTR_CAST(XFormTextStartItem, pItem);
-            DBG_ASSERT(pStateItem || pItem == 0, "XFormTextStartItem expected");
+                                dynamic_cast<const XFormTextStartItem*>( pItem );
+            DBG_ASSERT(pStateItem || pItem == nullptr, "XFormTextStartItem expected");
             rFontWorkDlg.SetStart_Impl(pStateItem);
             break;
         }
         case SID_FORMTEXT_MIRROR:
         {
             const XFormTextMirrorItem* pStateItem =
-                                PTR_CAST(XFormTextMirrorItem, pItem);
-            DBG_ASSERT(pStateItem || pItem == 0, "XFormTextMirrorItem expected");
+                                dynamic_cast<const XFormTextMirrorItem*>( pItem );
+            DBG_ASSERT(pStateItem || pItem == nullptr, "XFormTextMirrorItem expected");
             rFontWorkDlg.SetMirror_Impl(pStateItem);
             break;
         }
         case SID_FORMTEXT_HIDEFORM:
         {
             const XFormTextHideFormItem* pStateItem =
-                                PTR_CAST(XFormTextHideFormItem, pItem);
-            DBG_ASSERT(pStateItem || pItem == 0, "XFormTextHideFormItem expected");
+                                dynamic_cast<const XFormTextHideFormItem*>( pItem );
+            DBG_ASSERT(pStateItem || pItem == nullptr, "XFormTextHideFormItem expected");
             rFontWorkDlg.SetShowForm_Impl(pStateItem);
             break;
         }
         case SID_FORMTEXT_OUTLINE:
         {
             const XFormTextOutlineItem* pStateItem =
-                                PTR_CAST(XFormTextOutlineItem, pItem);
-            DBG_ASSERT(pStateItem || pItem == 0, "XFormTextOutlineItem expected");
+                                dynamic_cast<const XFormTextOutlineItem*>( pItem );
+            DBG_ASSERT(pStateItem || pItem == nullptr, "XFormTextOutlineItem expected");
             rFontWorkDlg.SetOutline_Impl(pStateItem);
             break;
         }
         case SID_FORMTEXT_SHADOW:
         {
             const XFormTextShadowItem* pStateItem =
-                                PTR_CAST(XFormTextShadowItem, pItem);
-            DBG_ASSERT(pStateItem || pItem == 0, "XFormTextShadowItem expected");
+                                dynamic_cast<const XFormTextShadowItem*>( pItem );
+            DBG_ASSERT(pStateItem || pItem == nullptr, "XFormTextShadowItem expected");
             rFontWorkDlg.SetShadow_Impl(pStateItem);
             break;
         }
         case SID_FORMTEXT_SHDWCOLOR:
         {
             const XFormTextShadowColorItem* pStateItem =
-                                PTR_CAST(XFormTextShadowColorItem, pItem);
-            DBG_ASSERT(pStateItem || pItem == 0, "XFormTextShadowColorItem expected");
+                                dynamic_cast<const XFormTextShadowColorItem*>( pItem );
+            DBG_ASSERT(pStateItem || pItem == nullptr, "XFormTextShadowColorItem expected");
             rFontWorkDlg.SetShadowColor_Impl(pStateItem);
             break;
         }
         case SID_FORMTEXT_SHDWXVAL:
         {
             const XFormTextShadowXValItem* pStateItem =
-                                PTR_CAST(XFormTextShadowXValItem, pItem);
-            DBG_ASSERT(pStateItem || pItem == 0, "XFormTextShadowXValItem expected");
+                                dynamic_cast<const XFormTextShadowXValItem*>( pItem );
+            DBG_ASSERT(pStateItem || pItem == nullptr, "XFormTextShadowXValItem expected");
             rFontWorkDlg.SetShadowXVal_Impl(pStateItem);
             break;
         }
         case SID_FORMTEXT_SHDWYVAL:
         {
             const XFormTextShadowYValItem* pStateItem =
-                                PTR_CAST(XFormTextShadowYValItem, pItem);
-            DBG_ASSERT(pStateItem || pItem == 0, "XFormTextShadowYValItem expected");
+                                dynamic_cast<const XFormTextShadowYValItem*>( pItem );
+            DBG_ASSERT(pStateItem || pItem == nullptr, "XFormTextShadowYValItem expected");
             rFontWorkDlg.SetShadowYVal_Impl(pStateItem);
             break;
         }
@@ -164,9 +164,7 @@ SvxFontWorkChildWindow::SvxFontWorkChildWindow
     SfxChildWindow( _pParent, nId )
 {
     VclPtrInstance<SvxFontWorkDialog> pDlg(pBindings, this, _pParent);
-    pWindow = pDlg.get();
-
-    eChildAlignment = SfxChildAlignment::NOALIGNMENT;
+    SetWindow(pDlg);
 
     pDlg->Initialize( pInfo );
 }
@@ -196,37 +194,40 @@ SvxFontWorkDialog::SvxFontWorkDialog(SfxBindings *pBindinx,
     get(m_pTbxStyle, "style");
     nStyleOffId = m_pTbxStyle->GetItemId(0);
     m_pTbxStyle->SetItemBits(nStyleOffId, ToolBoxItemBits::AUTOCHECK);
-    nStyleRotateId = m_pTbxStyle->GetItemId(1);
+    // separator is item "1"
+    nStyleRotateId = m_pTbxStyle->GetItemId(2);
     m_pTbxStyle->SetItemBits(nStyleRotateId, ToolBoxItemBits::AUTOCHECK|ToolBoxItemBits::RADIOCHECK);
-    nStyleUprightId = m_pTbxStyle->GetItemId(2);
+    nStyleUprightId = m_pTbxStyle->GetItemId(3);
     m_pTbxStyle->SetItemBits(nStyleUprightId, ToolBoxItemBits::AUTOCHECK|ToolBoxItemBits::RADIOCHECK);
-    nStyleSlantXId = m_pTbxStyle->GetItemId(3);
+    nStyleSlantXId = m_pTbxStyle->GetItemId(4);
     m_pTbxStyle->SetItemBits(nStyleSlantXId, ToolBoxItemBits::AUTOCHECK|ToolBoxItemBits::RADIOCHECK);
-    nStyleSlantYId = m_pTbxStyle->GetItemId(4);
+    nStyleSlantYId = m_pTbxStyle->GetItemId(5);
     m_pTbxStyle->SetItemBits(nStyleSlantYId, ToolBoxItemBits::AUTOCHECK|ToolBoxItemBits::RADIOCHECK);
 
     get(m_pTbxShadow, "shadow");
     nShowFormId = m_pTbxShadow->GetItemId(0);
     m_pTbxShadow->SetItemBits(nShowFormId, ToolBoxItemBits::AUTOCHECK|ToolBoxItemBits::CHECKABLE);
     nOutlineId = m_pTbxShadow->GetItemId(1);
-    m_pTbxShadow->SetItemBits(nOutlineId, ToolBoxItemBits::AUTOCHECK|ToolBoxItemBits::RADIOCHECK);
-    nShadowOffId = m_pTbxShadow->GetItemId(2);
+    m_pTbxShadow->SetItemBits(nOutlineId, ToolBoxItemBits::AUTOCHECK|ToolBoxItemBits::CHECKABLE);
+    // separator is item "2"
+    nShadowOffId = m_pTbxShadow->GetItemId(3);
     m_pTbxShadow->SetItemBits(nShadowOffId, ToolBoxItemBits::AUTOCHECK|ToolBoxItemBits::RADIOCHECK);
-    nShadowNormalId = m_pTbxShadow->GetItemId(3);
+    nShadowNormalId = m_pTbxShadow->GetItemId(4);
     m_pTbxShadow->SetItemBits(nShadowNormalId, ToolBoxItemBits::AUTOCHECK|ToolBoxItemBits::RADIOCHECK);
-    nShadowSlantId = m_pTbxShadow->GetItemId(4);
+    nShadowSlantId = m_pTbxShadow->GetItemId(5);
     m_pTbxShadow->SetItemBits(nShadowSlantId, ToolBoxItemBits::AUTOCHECK|ToolBoxItemBits::RADIOCHECK);
 
     get(m_pTbxAdjust, "adjust");
     nAdjustMirrorId = m_pTbxAdjust->GetItemId(0);
     m_pTbxAdjust->SetItemBits(nAdjustMirrorId, ToolBoxItemBits::AUTOCHECK|ToolBoxItemBits::CHECKABLE);
-    nAdjustLeftId = m_pTbxAdjust->GetItemId(1);
-    m_pTbxAdjust->SetItemBits(nAdjustLeftId, ToolBoxItemBits::AUTOCHECK|ToolBoxItemBits::CHECKABLE);
-    nAdjustCenterId = m_pTbxAdjust->GetItemId(2);
+    // separator is item "1"
+    nAdjustLeftId = m_pTbxAdjust->GetItemId(2);
+    m_pTbxAdjust->SetItemBits(nAdjustLeftId, ToolBoxItemBits::AUTOCHECK|ToolBoxItemBits::RADIOCHECK);
+    nAdjustCenterId = m_pTbxAdjust->GetItemId(3);
     m_pTbxAdjust->SetItemBits(nAdjustCenterId, ToolBoxItemBits::AUTOCHECK|ToolBoxItemBits::RADIOCHECK);
-    nAdjustRightId = m_pTbxAdjust->GetItemId(3);
+    nAdjustRightId = m_pTbxAdjust->GetItemId(4);
     m_pTbxAdjust->SetItemBits(nAdjustRightId, ToolBoxItemBits::AUTOCHECK|ToolBoxItemBits::RADIOCHECK);
-    nAdjustAutoSizeId = m_pTbxAdjust->GetItemId(4);
+    nAdjustAutoSizeId = m_pTbxAdjust->GetItemId(5);
     m_pTbxAdjust->SetItemBits(nAdjustAutoSizeId, ToolBoxItemBits::AUTOCHECK|ToolBoxItemBits::RADIOCHECK);
 
     ApplyImageList();
@@ -253,7 +254,7 @@ SvxFontWorkDialog::SvxFontWorkDialog(SfxBindings *pBindinx,
     m_pTbxShadow->SetSizePixel(aSize);
     m_pTbxShadow->SetSelectHdl( LINK(this, SvxFontWorkDialog, SelectShadowHdl_Impl) );
 
-    Link<> aLink = LINK(this, SvxFontWorkDialog, ModifyInputHdl_Impl);
+    Link<Edit&,void> aLink = LINK(this, SvxFontWorkDialog, ModifyInputHdl_Impl);
     m_pMtrFldDistance->SetModifyHdl( aLink );
     m_pMtrFldTextStart->SetModifyHdl( aLink );
     m_pMtrFldShadowX->SetModifyHdl( aLink );
@@ -375,7 +376,7 @@ void SvxFontWorkDialog::SetStyle_Impl(const XFormTextStyleItem* pItem)
             m_pTbxStyle->CheckItem(nStyleSlantXId, false);
             m_pTbxStyle->CheckItem(nStyleSlantYId, false);
 
-            m_pTbxStyle->CheckItem(nStyleOffId, true);
+            m_pTbxStyle->CheckItem(nStyleOffId);
         }
         else
         {
@@ -737,10 +738,9 @@ IMPL_LINK_NOARG_TYPED(SvxFontWorkDialog, SelectShadowHdl_Impl, ToolBox *, void)
     }
 }
 
-IMPL_LINK_NOARG(SvxFontWorkDialog, ModifyInputHdl_Impl)
+IMPL_LINK_NOARG_TYPED(SvxFontWorkDialog, ModifyInputHdl_Impl, Edit&, void)
 {
     aInputIdle.Start();
-    return 0;
 }
 
 IMPL_LINK_NOARG_TYPED(SvxFontWorkDialog, InputTimoutHdl_Impl, Idle *, void)
@@ -796,11 +796,10 @@ IMPL_LINK_NOARG_TYPED(SvxFontWorkDialog, InputTimoutHdl_Impl, Idle *, void)
                                             &aStartItem, &aShadowXItem, &aShadowYItem, 0L );
 }
 
-IMPL_LINK_NOARG(SvxFontWorkDialog, ColorSelectHdl_Impl)
+IMPL_LINK_NOARG_TYPED(SvxFontWorkDialog, ColorSelectHdl_Impl, ListBox&, void)
 {
     XFormTextShadowColorItem aItem( "", m_pShadowColorLB->GetSelectEntryColor() );
     GetBindings().GetDispatcher()->Execute( SID_FORMTEXT_SHDWCOLOR, SfxCallMode::RECORD, &aItem, 0L );
-    return 0;
 }
 
 void SvxFontWorkDialog::SetColorList(const XColorListRef &pList)
