@@ -20,6 +20,8 @@
 #include <svl/itempool.hxx>
 #include <vcl/dialog.hxx>
 #include <vcl/wrkwin.hxx>
+#include <vcl/settings.hxx>
+#include <vcl/builderfactory.hxx>
 #include <unotools/syslocale.hxx>
 #include <rtl/math.hxx>
 #include <unotools/localedatawrapper.hxx>
@@ -32,8 +34,6 @@
 #include "svx/xoutbmp.hxx"
 #include <svx/svxids.hrc>
 #include <svx/svdpage.hxx>
-
-// #i72889#
 #include "svx/sdrpaintwindow.hxx"
 
 void GraphCtrlUserCall::Changed( const SdrObject& rObj, SdrUserCallType eType, const Rectangle& /*rOldBoundRect*/ )
@@ -54,65 +54,56 @@ void GraphCtrlUserCall::Changed( const SdrObject& rObj, SdrUserCallType eType, c
     }
 }
 
-GraphCtrl::GraphCtrl( Window* pParent, const ResId& rResId ) :
-            Control         ( pParent, rResId ),
-            aMap100         ( MAP_100TH_MM ),
-            nWinStyle       ( 0 ),
-            eObjKind        ( OBJ_NONE ),
-            nPolyEdit       ( 0 ),
-            bEditMode       ( sal_False ),
-            bSdrMode        ( sal_False ),
-            bAnim           ( sal_False ),
-            mpAccContext    ( NULL ),
-            pModel          ( NULL ),
-            pView           ( NULL )
-{
-    pUserCall = new GraphCtrlUserCall( *this );
-    aUpdateTimer.SetTimeout( 500 );
-    aUpdateTimer.SetTimeoutHdl( LINK( this, GraphCtrl, UpdateHdl ) );
-    aUpdateTimer.Start();
-    EnableRTL( sal_False );
-}
-
-GraphCtrl::GraphCtrl( Window* pParent, WinBits nStyle ) :
+GraphCtrl::GraphCtrl( vcl::Window* pParent, WinBits nStyle ) :
             Control         ( pParent, nStyle ),
             aMap100         ( MAP_100TH_MM ),
             nWinStyle       ( 0 ),
             eObjKind        ( OBJ_NONE ),
             nPolyEdit       ( 0 ),
-            bEditMode       ( sal_False ),
-            bSdrMode        ( sal_False ),
-            bAnim           ( sal_False ),
-            mpAccContext    ( NULL ),
-            pModel          ( NULL ),
-            pView           ( NULL )
+            bEditMode       ( false ),
+            bSdrMode        ( false ),
+            bAnim           ( false ),
+            mpAccContext    ( nullptr ),
+            pModel          ( nullptr ),
+            pView           ( nullptr )
 {
     pUserCall = new GraphCtrlUserCall( *this );
-    aUpdateTimer.SetTimeout( 500 );
-    aUpdateTimer.SetTimeoutHdl( LINK( this, GraphCtrl, UpdateHdl ) );
-    aUpdateTimer.Start();
-    EnableRTL( sal_False );
+    aUpdateIdle.SetPriority( SchedulerPriority::LOWEST );
+    aUpdateIdle.SetIdleHdl( LINK( this, GraphCtrl, UpdateHdl ) );
+    aUpdateIdle.Start();
+    EnableRTL( false );
 }
 
-extern "C" SAL_DLLPUBLIC_EXPORT Window* SAL_CALL makeGraphCtrl(Window *pParent, VclBuilder::stringmap &rMap)
+VCL_BUILDER_DECL_FACTORY(GraphCtrl)
 {
     WinBits nWinStyle = 0;
     OString sBorder = VclBuilder::extractCustomProperty(rMap);
     if (!sBorder.isEmpty())
         nWinStyle |= WB_BORDER;
-    return new GraphCtrl(pParent, nWinStyle);
+    rRet = VclPtr<GraphCtrl>::Create(pParent, nWinStyle);
 }
 
 GraphCtrl::~GraphCtrl()
 {
+    disposeOnce();
+}
+
+void GraphCtrl::dispose()
+{
+    aUpdateIdle.Stop();
+
     if( mpAccContext )
     {
         mpAccContext->disposing();
         mpAccContext->release();
     }
     delete pView;
+    pView = nullptr;
     delete pModel;
+    pModel = nullptr;
     delete pUserCall;
+    pUserCall = nullptr;
+    Control::dispose();
 }
 
 void GraphCtrl::SetWinStyle( WinBits nWinBits )
@@ -126,10 +117,10 @@ void GraphCtrl::SetWinStyle( WinBits nWinBits )
     SetMapMode( aMap100 );
 
     delete pView;
-    pView = NULL;
+    pView = nullptr;
 
     delete pModel;
-    pModel = NULL;
+    pModel = nullptr;
 
     if ( bSdrMode )
         InitSdrModel();
@@ -157,28 +148,28 @@ void GraphCtrl::InitSdrModel()
     pPage->SetSize( aGraphSize );
     pPage->SetBorder( 0, 0, 0, 0 );
     pModel->InsertPage( pPage );
-    pModel->SetChanged( sal_False );
+    pModel->SetChanged( false );
 
     // Creating a View
     pView = new GraphCtrlView( pModel, this );
     pView->SetWorkArea( Rectangle( Point(), aGraphSize ) );
-    pView->EnableExtendedMouseEventDispatcher( sal_True );
+    pView->EnableExtendedMouseEventDispatcher( true );
     pView->ShowSdrPage(pView->GetModel()->GetPage(0));
-    pView->SetFrameDragSingles( sal_True );
+    pView->SetFrameDragSingles();
     pView->SetMarkedPointsSmooth( SDRPATHSMOOTH_SYMMETRIC );
-    pView->SetEditMode( sal_True );
+    pView->SetEditMode();
 
-    // #i72889# set neeeded flags
+    // #i72889# set needed flags
     pView->SetPagePaintingAllowed(false);
     pView->SetBufferedOutputAllowed(true);
     pView->SetBufferedOverlayAllowed(true);
 
     // Tell the accessibility object about the changes.
-    if (mpAccContext != NULL)
+    if (mpAccContext != nullptr)
         mpAccContext->setModelAndView (pModel, pView);
 }
 
-void GraphCtrl::SetGraphic( const Graphic& rGraphic, sal_Bool bNewModel )
+void GraphCtrl::SetGraphic( const Graphic& rGraphic, bool bNewModel )
 {
     // If possible we dither bitmaps for the display
     if ( !bAnim && ( rGraphic.GetType() == GRAPHIC_BITMAP )  )
@@ -208,8 +199,7 @@ void GraphCtrl::SetGraphic( const Graphic& rGraphic, sal_Bool bNewModel )
     if ( bSdrMode && bNewModel )
         InitSdrModel();
 
-    if ( aGraphSizeLink.IsSet() )
-        aGraphSizeLink.Call( this );
+    aGraphSizeLink.Call( this );
 
     Resize();
     Invalidate();
@@ -256,19 +246,19 @@ void GraphCtrl::Resize()
     Invalidate();
 }
 
-void GraphCtrl::Paint( const Rectangle& rRect )
+void GraphCtrl::Paint( vcl::RenderContext& rRenderContext, const Rectangle& rRect)
 {
     // #i72889# used splitted repaint to be able to paint an own background
     // even to the buffered view
     const bool bGraphicValid(GRAPHIC_NONE != aGraphic.GetType());
 
-    if(bSdrMode)
+    if (bSdrMode)
     {
-        SdrPaintWindow* pPaintWindow = pView->BeginCompleteRedraw(this);
+        SdrPaintWindow* pPaintWindow = pView->BeginCompleteRedraw(&rRenderContext);
 
-        if(bGraphicValid)
+        if (bGraphicValid)
         {
-            OutputDevice& rTarget = pPaintWindow->GetTargetOutputDevice();
+            vcl::RenderContext& rTarget = pPaintWindow->GetTargetOutputDevice();
 
             rTarget.SetBackground(GetBackground());
             rTarget.Erase();
@@ -276,7 +266,7 @@ void GraphCtrl::Paint( const Rectangle& rRect )
             aGraphic.Draw(&rTarget, Point(), aGraphSize);
         }
 
-        const Region aRepaintRegion(rRect);
+        const vcl::Region aRepaintRegion(rRect);
         pView->DoCompleteRedraw(*pPaintWindow, aRepaintRegion);
         pView->EndCompleteRedraw(*pPaintWindow, true);
     }
@@ -285,7 +275,7 @@ void GraphCtrl::Paint( const Rectangle& rRect )
         // #i73381# in non-SdrMode, paint to local directly
         if(bGraphicValid)
         {
-            aGraphic.Draw(this, Point(), aGraphSize);
+            aGraphic.Draw(&rRenderContext, Point(), aGraphSize);
         }
     }
 }
@@ -300,13 +290,11 @@ void GraphCtrl::SdrObjCreated( const SdrObject& )
 
 void GraphCtrl::MarkListHasChanged()
 {
-    if ( aMarkObjLink.IsSet() )
-        aMarkObjLink.Call( this );
 }
 
 void GraphCtrl::KeyInput( const KeyEvent& rKEvt )
 {
-    KeyCode aCode( rKEvt.GetKeyCode() );
+    vcl::KeyCode aCode( rKEvt.GetKeyCode() );
     bool    bProc = false;
 
     Dialog* pDialog = GetParentDialog();
@@ -376,7 +364,7 @@ void GraphCtrl::KeyInput( const KeyEvent& rKEvt )
                 {
                     // select next handle
                     const SdrHdlList& rHdlList = pView->GetHdlList();
-                    sal_Bool bForward(!aCode.IsShift());
+                    bool bForward(!aCode.IsShift());
 
                     ((SdrHdlList&)rHdlList).TravelFocusHdl(bForward);
 
@@ -393,7 +381,7 @@ void GraphCtrl::KeyInput( const KeyEvent& rKEvt )
             {
                 // mark last object
                 pView->UnmarkAllObj();
-                pView->MarkNextObj(sal_False);
+                pView->MarkNextObj();
 
                 bProc = true;
             }
@@ -405,7 +393,7 @@ void GraphCtrl::KeyInput( const KeyEvent& rKEvt )
             if ( aCode.IsMod1() )
             {
                 pView->UnmarkAllObj();
-                pView->MarkNextObj(sal_True);
+                pView->MarkNextObj(true);
 
                 bProc = true;
             }
@@ -465,7 +453,7 @@ void GraphCtrl::KeyInput( const KeyEvent& rKEvt )
                 const SdrHdlList& rHdlList = pView->GetHdlList();
                 SdrHdl* pHdl = rHdlList.GetFocusHdl();
 
-                if(0L == pHdl)
+                if(nullptr == pHdl)
                 {
                     // restrict movement to WorkArea
                     const Rectangle& rWorkArea = pView->GetWorkArea();
@@ -516,18 +504,18 @@ void GraphCtrl::KeyInput( const KeyEvent& rKEvt )
                         const SdrDragStat& rDragStat = pView->GetDragStat();
 
                         // start dragging
-                        pView->BegDragObj(aStartPoint, 0, pHdl, 0);
+                        pView->BegDragObj(aStartPoint, nullptr, pHdl, 0);
 
                         if(pView->IsDragObj())
                         {
                             bool bWasNoSnap = rDragStat.IsNoSnap();
-                            sal_Bool bWasSnapEnabled = pView->IsSnapEnabled();
+                            bool bWasSnapEnabled = pView->IsSnapEnabled();
 
                             // switch snapping off
                             if(!bWasNoSnap)
-                                ((SdrDragStat&)rDragStat).SetNoSnap(sal_True);
+                                ((SdrDragStat&)rDragStat).SetNoSnap();
                             if(bWasSnapEnabled)
-                                pView->SetSnapEnabled(sal_False);
+                                pView->SetSnapEnabled(false);
 
                             pView->MovAction(aEndPoint);
                             pView->EndDragObj();
@@ -576,12 +564,12 @@ void GraphCtrl::KeyInput( const KeyEvent& rKEvt )
                         pView->MarkPoint(*pHdl);
                     }
 
-                    if(0L == rHdlList.GetFocusHdl())
+                    if(nullptr == rHdlList.GetFocusHdl())
                     {
                         // restore point with focus
-                        SdrHdl* pNewOne = 0L;
+                        SdrHdl* pNewOne = nullptr;
 
-                        for(sal_uInt32 a(0); !pNewOne && a < rHdlList.GetHdlCount(); a++)
+                        for(size_t a = 0; !pNewOne && a < rHdlList.GetHdlCount(); ++a)
                         {
                             SdrHdl* pAct = rHdlList.GetHdl(a);
 
@@ -632,7 +620,7 @@ void GraphCtrl::MouseButtonDown( const MouseEvent& rMEvt )
             if ( nPolyEdit )
             {
                 SdrViewEvent    aVEvt;
-                SdrHitKind      eHit = pView->PickAnything( rMEvt, SDRMOUSEBUTTONDOWN, aVEvt );
+                SdrHitKind      eHit = pView->PickAnything( rMEvt, SdrMouseEventKind::BUTTONDOWN, aVEvt );
 
                 if ( nPolyEdit == SID_BEZIER_INSERT && eHit == SDRHIT_MARKEDOBJECT )
                     pView->BegInsObjPoint( aLogPt, rMEvt.IsMod1());
@@ -649,7 +637,7 @@ void GraphCtrl::MouseButtonDown( const MouseEvent& rMEvt )
         if ( pCreateObj && !pCreateObj->GetUserCall() )
             pCreateObj->SetUserCall( pUserCall );
 
-        SetPointer( pView->GetPreferedPointer( aLogPt, this ) );
+        SetPointer( pView->GetPreferredPointer( aLogPt, this ) );
     }
     else
         Control::MouseButtonDown( rMEvt );
@@ -667,10 +655,10 @@ void GraphCtrl::MouseMove(const MouseEvent& rMEvt)
             !pView->PickHandle( aLogPos ) &&
             !pView->IsInsObjPoint() )
         {
-            SetPointer( POINTER_CROSS );
+            SetPointer( PointerStyle::Cross );
         }
         else
-            SetPointer( pView->GetPreferedPointer( aLogPos, this ) );
+            SetPointer( pView->GetPreferredPointer( aLogPos, this ) );
     }
     else
         Control::MouseButtonUp( rMEvt );
@@ -696,7 +684,7 @@ void GraphCtrl::MouseButtonUp(const MouseEvent& rMEvt)
             pView->MouseButtonUp( rMEvt, this );
 
         ReleaseMouse();
-        SetPointer( pView->GetPreferedPointer( PixelToLogic( rMEvt.GetPosPixel() ), this ) );
+        SetPointer( pView->GetPreferredPointer( PixelToLogic( rMEvt.GetPosPixel() ), this ) );
     }
     else
         Control::MouseButtonUp( rMEvt );
@@ -704,7 +692,7 @@ void GraphCtrl::MouseButtonUp(const MouseEvent& rMEvt)
 
 SdrObject* GraphCtrl::GetSelectedSdrObject() const
 {
-    SdrObject* pSdrObj = NULL;
+    SdrObject* pSdrObj = nullptr;
 
     if ( bSdrMode )
     {
@@ -717,7 +705,7 @@ SdrObject* GraphCtrl::GetSelectedSdrObject() const
     return pSdrObj;
 }
 
-void GraphCtrl::SetEditMode( const sal_Bool _bEditMode )
+void GraphCtrl::SetEditMode( const bool _bEditMode )
 {
     if ( bSdrMode )
     {
@@ -727,7 +715,7 @@ void GraphCtrl::SetEditMode( const sal_Bool _bEditMode )
         pView->SetCurrentObj( sal::static_int_cast< sal_uInt16 >( eObjKind ) );
     }
     else
-        bEditMode = sal_False;
+        bEditMode = false;
 }
 
 void GraphCtrl::SetPolyEditMode( const sal_uInt16 _nPolyEdit )
@@ -745,7 +733,7 @@ void GraphCtrl::SetObjKind( const SdrObjKind _eObjKind )
 {
     if ( bSdrMode )
     {
-        bEditMode = sal_False;
+        bEditMode = false;
         pView->SetEditMode( bEditMode );
         eObjKind = _eObjKind;
         pView->SetCurrentObj( sal::static_int_cast< sal_uInt16 >( eObjKind ) );
@@ -754,28 +742,25 @@ void GraphCtrl::SetObjKind( const SdrObjKind _eObjKind )
         eObjKind = OBJ_NONE;
 }
 
-IMPL_LINK( GraphCtrl, UpdateHdl, Timer*, pTimer )
+IMPL_LINK_TYPED( GraphCtrl, UpdateHdl, Idle*, pTimer, void )
 {
-    if ( aUpdateLink.IsSet() )
-        aUpdateLink.Call( this );
+    aUpdateLink.Call( this );
 
     pTimer->Start();
-
-    return 0L;
 }
 
 
-::com::sun::star::uno::Reference< ::com::sun::star::accessibility::XAccessible > GraphCtrl::CreateAccessible()
+css::uno::Reference< css::accessibility::XAccessible > GraphCtrl::CreateAccessible()
 {
-    if( mpAccContext == NULL )
+    if( mpAccContext == nullptr )
     {
-        Window* pParent = GetParent();
+        vcl::Window* pParent = GetParent();
 
         DBG_ASSERT( pParent, "-GraphCtrl::CreateAccessible(): No Parent!" );
 
         if( pParent )
         {
-            ::com::sun::star::uno::Reference< ::com::sun::star::accessibility::XAccessible > xAccParent( pParent->GetAccessible() );
+            css::uno::Reference< css::accessibility::XAccessible > xAccParent( pParent->GetAccessible() );
 
             // Disable accessibility if no model/view data available
             if( pView &&
