@@ -48,14 +48,16 @@
 #include <svx/svxdlg.hxx>
 #include <basegfx/point/b2dpoint.hxx>
 #include <basegfx/polygon/b2dpolygon.hxx>
+#include <memory>
 
+using namespace com::sun::star;
 using ::com::sun::star::frame::XFrame;
 using ::com::sun::star::uno::Reference;
 
 #define TRANSCOL Color( COL_WHITE )
 
-IMapWindow::IMapWindow( Window* pParent, const ResId& rResId, const Reference< XFrame >& rxDocumentFrame ) :
-            GraphCtrl( pParent, rResId ),
+IMapWindow::IMapWindow( vcl::Window* pParent, WinBits nBits, const Reference< XFrame >& rxDocumentFrame ) :
+            GraphCtrl( pParent, nBits ),
             DropTargetHelper( this ),
             mxDocumentFrame( rxDocumentFrame )
 {
@@ -69,19 +71,30 @@ IMapWindow::IMapWindow( Window* pParent, const ResId& rResId, const Reference< X
 }
 
 IMapWindow::~IMapWindow()
+{
+    disposeOnce();
+}
+
+void IMapWindow::dispose()
 {
     SfxItemPool::Free(pIMapPool);
     delete[] pItemInfo;
+    GraphCtrl::dispose();
+}
+
+Size IMapWindow::GetOptimalSize() const
+{
+    return LogicToPixel(Size(270, 170), MAP_APPFONT);
 }
 
 void IMapWindow::SetImageMap( const ImageMap& rImageMap )
 {
-    ReplaceImageMap( rImageMap, sal_False );
+    ReplaceImageMap( rImageMap, false );
 }
 
-void IMapWindow::ReplaceImageMap( const ImageMap& rImageMap, sal_Bool /*bScaleToGraphic*/ )
+void IMapWindow::ReplaceImageMap( const ImageMap& rImageMap, bool /*bScaleToGraphic*/ )
 {
-    SdrPage* pPage = 0;
+    SdrPage* pPage = nullptr;
     aIMap = rImageMap;
 
     if(GetSdrModel())
@@ -109,28 +122,28 @@ void IMapWindow::ReplaceImageMap( const ImageMap& rImageMap, sal_Bool /*bScaleTo
     {
         SdrObject* pNewObj = CreateObj( rImageMap.GetIMapObject( i - 1 ) );
 
-        if ( pNewObj )
+        if (pNewObj && pPage)
         {
             pPage->InsertObject( pNewObj );
         }
     }
 }
 
-sal_Bool IMapWindow::ReplaceActualIMapInfo( const NotifyInfo& rNewInfo )
+bool IMapWindow::ReplaceActualIMapInfo( const NotifyInfo& rNewInfo )
 {
     const SdrObject*    pSdrObj = GetSelectedSdrObject();
     IMapObject*         pIMapObj;
-    sal_Bool                bRet = sal_False;
+    bool                bRet = false;
 
-    if ( pSdrObj && ( ( pIMapObj = GetIMapObj( pSdrObj ) ) != NULL ) )
+    if ( pSdrObj && ( ( pIMapObj = GetIMapObj( pSdrObj ) ) != nullptr ) )
     {
         pIMapObj->SetURL( rNewInfo.aMarkURL );
         pIMapObj->SetAltText( rNewInfo.aMarkAltText );
         pIMapObj->SetTarget( rNewInfo.aMarkTarget );
-        pModel->SetChanged( sal_True );
-        UpdateInfo( sal_False );
+        pModel->SetChanged();
+        UpdateInfo( false );
 
-        bRet = sal_True;
+        bRet = true;
     }
 
     return bRet;
@@ -140,19 +153,22 @@ const ImageMap& IMapWindow::GetImageMap()
 {
     if ( pModel->IsChanged() )
     {
-        SdrPage* pPage = (SdrPage*) pModel->GetPage( 0 );
+        SdrPage* pPage = pModel->GetPage( 0 );
 
         if ( pPage )
         {
-            const long nCount = pPage->GetObjCount();
+            const size_t nCount = pPage->GetObjCount();
 
             aIMap.ClearImageMap();
 
-            for ( long i = nCount - 1; i > -1; i-- )
-                aIMap.InsertIMapObject( *( ( (IMapUserData*) pPage->GetObj( i )->GetUserData( 0 ) )->GetObject() ) );
+            for ( size_t i = nCount; i; )
+            {
+                --i;
+                aIMap.InsertIMapObject( *( static_cast<IMapUserData*>( pPage->GetObj( i )->GetUserData( 0 ) )->GetObject() ) );
+            }
         }
 
-        pModel->SetChanged( sal_False );
+        pModel->SetChanged( false );
     }
 
     return aIMap;
@@ -167,50 +183,50 @@ void IMapWindow::SetTargetList( TargetList& rTargetList )
     for( size_t i = 0, n = rTargetList.size(); i < n; ++i )
         aTargetList.push_back( rTargetList[ i ] );
 
-    pModel->SetChanged( sal_False );
+    pModel->SetChanged( false );
 }
 
 SdrObject* IMapWindow::CreateObj( const IMapObject* pIMapObj )
 {
     Point       aPoint;
     Rectangle   aClipRect( aPoint, GetGraphicSize() );
-    SdrObject*  pSdrObj = NULL;
+    SdrObject*  pSdrObj = nullptr;
     IMapObjectPtr pCloneIMapObj;
 
     switch( pIMapObj->GetType() )
     {
         case( IMAP_OBJ_RECTANGLE ):
         {
-            IMapRectangleObject*    pIMapRectObj = (IMapRectangleObject*) pIMapObj;
-            Rectangle               aDrawRect( pIMapRectObj->GetRectangle( sal_False ) );
+            const IMapRectangleObject* pIMapRectObj = static_cast<const IMapRectangleObject*>(pIMapObj);
+            Rectangle               aDrawRect( pIMapRectObj->GetRectangle( false ) );
 
             // clipped on CanvasPane
             aDrawRect.Intersection( aClipRect );
 
-            pSdrObj = (SdrObject*) new SdrRectObj( aDrawRect );
-            pCloneIMapObj.reset((IMapObject*) new IMapRectangleObject( *pIMapRectObj ));
+            pSdrObj = static_cast<SdrObject*>(new SdrRectObj( aDrawRect ));
+            pCloneIMapObj.reset(static_cast<IMapObject*>(new IMapRectangleObject( *pIMapRectObj )));
         }
         break;
 
         case( IMAP_OBJ_CIRCLE ):
         {
-            IMapCircleObject*   pIMapCircleObj = (IMapCircleObject*) pIMapObj;
-            const Point         aCenter( pIMapCircleObj->GetCenter( sal_False ) );
-            const long          nRadius = pIMapCircleObj->GetRadius( sal_False );
+            const IMapCircleObject*   pIMapCircleObj = static_cast<const IMapCircleObject*>(pIMapObj);
+            const Point         aCenter( pIMapCircleObj->GetCenter( false ) );
+            const long          nRadius = pIMapCircleObj->GetRadius( false );
             const Point         aOffset( nRadius, nRadius );
             Rectangle           aCircle( aCenter - aOffset, aCenter + aOffset );
 
             // limited to CanvasPane
             aCircle.Intersection( aClipRect );
 
-            pSdrObj = (SdrObject*) new SdrCircObj( OBJ_CIRC, aCircle, 0, 36000 );
-            pCloneIMapObj.reset((IMapObject*) new IMapCircleObject( *pIMapCircleObj ));
+            pSdrObj = static_cast<SdrObject*>(new SdrCircObj( OBJ_CIRC, aCircle, 0, 36000 ));
+            pCloneIMapObj.reset(static_cast<IMapObject*>(new IMapCircleObject( *pIMapCircleObj )));
         }
         break;
 
         case( IMAP_OBJ_POLYGON ):
         {
-            IMapPolygonObject*  pIMapPolyObj = (IMapPolygonObject*) pIMapObj;
+            const IMapPolygonObject*  pIMapPolyObj = static_cast<const IMapPolygonObject*>(pIMapObj);
 
             // If it actually is an ellipse, then another ellipse is created again
             if ( pIMapPolyObj->HasExtraEllipse() )
@@ -220,22 +236,22 @@ SdrObject* IMapWindow::CreateObj( const IMapObject* pIMapObj )
                 // clipped on CanvasPane
                 aDrawRect.Intersection( aClipRect );
 
-                pSdrObj = (SdrObject*) new SdrCircObj( OBJ_CIRC, aDrawRect, 0, 36000 );
+                pSdrObj = static_cast<SdrObject*>(new SdrCircObj( OBJ_CIRC, aDrawRect, 0, 36000 ));
             }
             else
             {
-                const Polygon&  rPoly = pIMapPolyObj->GetPolygon( sal_False );
-                Polygon         aDrawPoly( rPoly );
+                const tools::Polygon& rPoly = pIMapPolyObj->GetPolygon( false );
+                tools::Polygon aDrawPoly( rPoly );
 
                 // clipped on CanvasPane
                 aDrawPoly.Clip( aClipRect );
 
                 basegfx::B2DPolygon aPolygon;
                 aPolygon.append(aDrawPoly.getB2DPolygon());
-                pSdrObj = (SdrObject*)new SdrPathObj(OBJ_POLY, basegfx::B2DPolyPolygon(aPolygon));
+                pSdrObj = static_cast<SdrObject*>(new SdrPathObj(OBJ_POLY, basegfx::B2DPolyPolygon(aPolygon)));
             }
 
-            pCloneIMapObj.reset((IMapObject*) new IMapPolygonObject( *pIMapPolyObj ));
+            pCloneIMapObj.reset(static_cast<IMapObject*>(new IMapPolygonObject( *pIMapPolyObj )));
         }
         break;
 
@@ -247,7 +263,7 @@ SdrObject* IMapWindow::CreateObj( const IMapObject* pIMapObj )
     {
         SfxItemSet aSet( pModel->GetItemPool() );
 
-        aSet.Put( XFillStyleItem( XFILL_SOLID ) );
+        aSet.Put( XFillStyleItem( drawing::FillStyle_SOLID ) );
         aSet.Put( XFillColorItem( "", TRANSCOL ) );
 
         if ( !pIMapObj->IsActive() )
@@ -279,7 +295,7 @@ void IMapWindow::InitSdrModel()
     aSet.Put( XFillColorItem( "", TRANSCOL ) );
     aSet.Put( XFillTransparenceItem( 50 ) );
     pView->SetAttributes( aSet );
-    pView->SetFrameDragSingles( sal_True );
+    pView->SetFrameDragSingles();
 }
 
 void IMapWindow::SdrObjCreated( const SdrObject& rObj )
@@ -288,8 +304,8 @@ void IMapWindow::SdrObjCreated( const SdrObject& rObj )
     {
         case( OBJ_RECT ):
         {
-            SdrRectObj*          pRectObj = (SdrRectObj*) &rObj;
-            IMapRectangleObject* pObj = new IMapRectangleObject( pRectObj->GetLogicRect(), "", "", "", "", "", sal_True, sal_False );
+            SdrRectObj*    pRectObj = const_cast<SdrRectObj*>(static_cast<const SdrRectObj*>(&rObj));
+            IMapRectangleObject* pObj = new IMapRectangleObject( pRectObj->GetLogicRect(), "", "", "", "", "", true, false );
 
             pRectObj->AppendUserData( new IMapUserData( IMapObjectPtr(pObj) ) );
         }
@@ -297,12 +313,12 @@ void IMapWindow::SdrObjCreated( const SdrObject& rObj )
 
         case( OBJ_CIRC ):
         {
-            SdrCircObj* pCircObj = (SdrCircObj*) &rObj;
-            SdrPathObj* pPathObj = (SdrPathObj*) pCircObj->ConvertToPolyObj( sal_False, sal_False );
-            Polygon aPoly(pPathObj->GetPathPoly().getB2DPolygon(0L));
+            SdrCircObj* pCircObj = const_cast<SdrCircObj*>( static_cast<const SdrCircObj*>(&rObj) );
+            SdrPathObj* pPathObj = static_cast<SdrPathObj*>( pCircObj->ConvertToPolyObj( false, false ) );
+            tools::Polygon aPoly(pPathObj->GetPathPoly().getB2DPolygon(0L));
             delete pPathObj;
 
-            IMapPolygonObject* pObj = new IMapPolygonObject( Polygon(aPoly), "", "", "", "", "", sal_True, sal_False );
+            IMapPolygonObject* pObj = new IMapPolygonObject( tools::Polygon(aPoly), "", "", "", "", "", true, false );
             pObj->SetExtraEllipse( aPoly.GetBoundRect() );
             pCircObj->AppendUserData( new IMapUserData( IMapObjectPtr(pObj) ) );
         }
@@ -313,13 +329,13 @@ void IMapWindow::SdrObjCreated( const SdrObject& rObj )
         case( OBJ_PATHPOLY ):
         case( OBJ_PATHFILL ):
         {
-            SdrPathObj* pPathObj = (SdrPathObj*) &rObj;
+            SdrPathObj* pPathObj = const_cast<SdrPathObj*>( static_cast<const SdrPathObj*>(&rObj) );
             const basegfx::B2DPolyPolygon& rXPolyPoly = pPathObj->GetPathPoly();
 
             if ( rXPolyPoly.count() )
             {
-                Polygon aPoly(rXPolyPoly.getB2DPolygon(0L));
-                IMapPolygonObject* pObj = new IMapPolygonObject( aPoly, "", "", "", "", "", sal_True, sal_False );
+                tools::Polygon aPoly(rXPolyPoly.getB2DPolygon(0L));
+                IMapPolygonObject* pObj = new IMapPolygonObject( aPoly, "", "", "", "", "", true, false );
                 pPathObj->AppendUserData( new IMapUserData( IMapObjectPtr(pObj) ) );
             }
         }
@@ -332,7 +348,7 @@ void IMapWindow::SdrObjCreated( const SdrObject& rObj )
 
 void IMapWindow::SdrObjChanged( const SdrObject& rObj )
 {
-    IMapUserData* pUserData = (IMapUserData*) rObj.GetUserData( 0 );
+    IMapUserData* pUserData = static_cast<IMapUserData*>( rObj.GetUserData( 0 ) );
 
     if ( pUserData )
     {
@@ -341,7 +357,7 @@ void IMapWindow::SdrObjChanged( const SdrObject& rObj )
         OUString        aDesc;
         OUString        aTarget;
         IMapObjectPtr   pIMapObj = pUserData->GetObject();
-        sal_Bool        bActive = sal_True;
+        bool        bActive = true;
 
         if ( pIMapObj.get() )
         {
@@ -356,18 +372,18 @@ void IMapWindow::SdrObjChanged( const SdrObject& rObj )
         {
             case( OBJ_RECT ):
             {
-                pUserData->ReplaceObject( IMapObjectPtr(new IMapRectangleObject( ( (const SdrRectObj&) rObj ).GetLogicRect(),
-                          aURL, aAltText, aDesc, aTarget, "", bActive, sal_False ) ) );
+                pUserData->ReplaceObject( IMapObjectPtr(new IMapRectangleObject( static_cast<const SdrRectObj&>(rObj).GetLogicRect(),
+                          aURL, aAltText, aDesc, aTarget, "", bActive, false ) ) );
             }
             break;
 
             case( OBJ_CIRC ):
             {
-                const SdrCircObj& rCircObj = (const SdrCircObj&) rObj;
-                SdrPathObj* pPathObj = (SdrPathObj*) rCircObj.ConvertToPolyObj( sal_False, sal_False );
-                Polygon aPoly(pPathObj->GetPathPoly().getB2DPolygon(0L));
+                const SdrCircObj& rCircObj = static_cast<const SdrCircObj&>(rObj);
+                SdrPathObj* pPathObj = static_cast<SdrPathObj*>( rCircObj.ConvertToPolyObj( false, false ) );
+                tools::Polygon aPoly(pPathObj->GetPathPoly().getB2DPolygon(0L));
 
-                IMapPolygonObject* pObj = new IMapPolygonObject( aPoly, aURL, aAltText, aDesc, aTarget, "", bActive, sal_False );
+                IMapPolygonObject* pObj = new IMapPolygonObject( aPoly, aURL, aAltText, aDesc, aTarget, "", bActive, false );
                 pObj->SetExtraEllipse( aPoly.GetBoundRect() );
 
                 // was only created by us temporarily
@@ -381,13 +397,13 @@ void IMapWindow::SdrObjChanged( const SdrObject& rObj )
             case( OBJ_PATHPOLY ):
             case( OBJ_PATHFILL ):
             {
-                const SdrPathObj& rPathObj = (const SdrPathObj&) rObj;
+                const SdrPathObj& rPathObj = static_cast<const SdrPathObj&>(rObj);
                 const basegfx::B2DPolyPolygon& rXPolyPoly = rPathObj.GetPathPoly();
 
                 if ( rXPolyPoly.count() )
                 {
-                    Polygon aPoly(rPathObj.GetPathPoly().getB2DPolygon(0L));
-                    IMapPolygonObject*  pObj = new IMapPolygonObject( aPoly, aURL, aAltText, aDesc, aTarget, "", bActive, sal_False );
+                    tools::Polygon aPoly(rPathObj.GetPathPoly().getB2DPolygon(0L));
+                    IMapPolygonObject*  pObj = new IMapPolygonObject( aPoly, aURL, aAltText, aDesc, aTarget, "", bActive, false );
                     pUserData->ReplaceObject( IMapObjectPtr(pObj) );
                 }
             }
@@ -402,29 +418,28 @@ void IMapWindow::SdrObjChanged( const SdrObject& rObj )
 void IMapWindow::MouseButtonUp(const MouseEvent& rMEvt)
 {
     GraphCtrl::MouseButtonUp( rMEvt );
-    UpdateInfo( sal_True );
+    UpdateInfo( true );
 }
 
 void IMapWindow::MarkListHasChanged()
 {
     GraphCtrl::MarkListHasChanged();
-    UpdateInfo( sal_False );
+    UpdateInfo( false );
 }
 
 SdrObject* IMapWindow::GetHitSdrObj( const Point& rPosPixel ) const
 {
-    SdrObject*  pObj = NULL;
+    SdrObject*  pObj = nullptr;
     Point       aPt = PixelToLogic( rPosPixel );
 
     if ( Rectangle( Point(), GetGraphicSize() ).IsInside( aPt ) )
     {
-        SdrPage* pPage = (SdrPage*) pModel->GetPage( 0 );
-        sal_uIntPtr  nCount;
-
-        if ( pPage && ( ( nCount = pPage->GetObjCount() ) > 0 ) )
+        SdrPage* pPage = pModel->GetPage( 0 );
+        if ( pPage )
         {
-            for ( long i = nCount - 1; i >= 0; i-- )
+            for ( size_t i = pPage->GetObjCount(); i > 0; )
             {
+                --i;
                 SdrObject*  pTestObj = pPage->GetObj( i );
                 IMapObject* pIMapObj = GetIMapObj( pTestObj );
 
@@ -440,13 +455,13 @@ SdrObject* IMapWindow::GetHitSdrObj( const Point& rPosPixel ) const
     return pObj;
 }
 
-IMapObject* IMapWindow::GetIMapObj( const SdrObject* pSdrObj ) const
+IMapObject* IMapWindow::GetIMapObj( const SdrObject* pSdrObj )
 {
-    IMapObject* pIMapObj = NULL;
+    IMapObject* pIMapObj = nullptr;
 
     if ( pSdrObj )
     {
-        IMapUserData* pUserData = (IMapUserData*) pSdrObj->GetUserData( 0 );
+        IMapUserData* pUserData = static_cast<IMapUserData*>( pSdrObj->GetUserData( 0 ) );
 
         if ( pUserData )
             pIMapObj = pUserData->GetObject().get();
@@ -457,27 +472,27 @@ IMapObject* IMapWindow::GetIMapObj( const SdrObject* pSdrObj ) const
 
 void IMapWindow::Command(const CommandEvent& rCEvt)
 {
-    Region  aRegion;
+    vcl::Region  aRegion;
 
-    if ( rCEvt.GetCommand() == COMMAND_CONTEXTMENU )
+    if ( rCEvt.GetCommand() == CommandEventId::ContextMenu )
     {
         PopupMenu           aMenu( SVX_RES( RID_SVXMN_IMAP ) );
         const SdrMarkList&  rMarkList = pView->GetMarkedObjectList();
-        sal_uIntPtr             nMarked = rMarkList.GetMarkCount();
+        const size_t nMarked = rMarkList.GetMarkCount();
 
-        aMenu.EnableItem( MN_URL, sal_False );
-        aMenu.EnableItem( MN_ACTIVATE, sal_False );
-        aMenu.EnableItem( MN_MACRO, sal_False );
+        aMenu.EnableItem( MN_URL, false );
+        aMenu.EnableItem( MN_ACTIVATE, false );
+        aMenu.EnableItem( MN_MACRO, false );
         aMenu.EnableItem( MN_MARK_ALL, pModel->GetPage( 0 )->GetObjCount() != pView->GetMarkedObjectCount() );
 
         if ( !nMarked )
         {
-            aMenu.EnableItem( MN_POSITION, sal_False );
-            aMenu.EnableItem( MN_FRAME_TO_TOP, sal_False );
-            aMenu.EnableItem( MN_MOREFRONT, sal_False );
-            aMenu.EnableItem( MN_MOREBACK, sal_False );
-            aMenu.EnableItem( MN_FRAME_TO_BOTTOM, sal_False );
-            aMenu.EnableItem( MN_DELETE1, sal_False );
+            aMenu.EnableItem( MN_POSITION, false );
+            aMenu.EnableItem( MN_FRAME_TO_TOP, false );
+            aMenu.EnableItem( MN_MOREFRONT, false );
+            aMenu.EnableItem( MN_MOREBACK, false );
+            aMenu.EnableItem( MN_FRAME_TO_BOTTOM, false );
+            aMenu.EnableItem( MN_DELETE1, false );
         }
         else
         {
@@ -485,18 +500,18 @@ void IMapWindow::Command(const CommandEvent& rCEvt)
             {
                 SdrObject*  pSdrObj = GetSelectedSdrObject();
 
-                aMenu.EnableItem( MN_URL, sal_True );
-                aMenu.EnableItem( MN_ACTIVATE, sal_True );
-                aMenu.EnableItem( MN_MACRO, sal_True );
+                aMenu.EnableItem( MN_URL );
+                aMenu.EnableItem( MN_ACTIVATE );
+                aMenu.EnableItem( MN_MACRO );
                 aMenu.CheckItem( MN_ACTIVATE, GetIMapObj( pSdrObj )->IsActive() );
             }
 
-            aMenu.EnableItem( MN_POSITION, sal_True );
-            aMenu.EnableItem( MN_FRAME_TO_TOP, sal_True );
-            aMenu.EnableItem( MN_MOREFRONT, sal_True );
-            aMenu.EnableItem( MN_MOREBACK, sal_True );
-            aMenu.EnableItem( MN_FRAME_TO_BOTTOM, sal_True );
-            aMenu.EnableItem( MN_DELETE1, sal_True );
+            aMenu.EnableItem( MN_POSITION );
+            aMenu.EnableItem( MN_FRAME_TO_TOP );
+            aMenu.EnableItem( MN_MOREFRONT );
+            aMenu.EnableItem( MN_MOREBACK );
+            aMenu.EnableItem( MN_FRAME_TO_BOTTOM );
+            aMenu.EnableItem( MN_DELETE1 );
         }
 
         aMenu.SetSelectHdl( LINK( this, IMapWindow, MenuSelectHdl ) );
@@ -508,29 +523,29 @@ void IMapWindow::Command(const CommandEvent& rCEvt)
 
 sal_Int8 IMapWindow::AcceptDrop( const AcceptDropEvent& rEvt )
 {
-    return( ( GetHitSdrObj( rEvt.maPosPixel ) != NULL ) ? rEvt.mnAction : DND_ACTION_NONE );
+    return( ( GetHitSdrObj( rEvt.maPosPixel ) != nullptr ) ? rEvt.mnAction : DND_ACTION_NONE );
 }
 
 sal_Int8 IMapWindow::ExecuteDrop( const ExecuteDropEvent& rEvt )
 {
     sal_Int8 nRet = DND_ACTION_NONE;
 
-    if( IsDropFormatSupported( SOT_FORMATSTR_ID_NETSCAPE_BOOKMARK ) )
+    if( IsDropFormatSupported( SotClipboardFormatId::NETSCAPE_BOOKMARK ) )
     {
         const OUString  aString;
         INetBookmark    aBookMark( aString, aString );
         SdrObject*      pSdrObj = GetHitSdrObj( rEvt.maPosPixel );
 
-        if( pSdrObj && TransferableDataHelper( rEvt.maDropEvent.Transferable ).GetINetBookmark( SOT_FORMATSTR_ID_NETSCAPE_BOOKMARK, aBookMark ) )
+        if( pSdrObj && TransferableDataHelper( rEvt.maDropEvent.Transferable ).GetINetBookmark( SotClipboardFormatId::NETSCAPE_BOOKMARK, aBookMark ) )
         {
             IMapObject* pIMapObj = GetIMapObj( pSdrObj );
 
             pIMapObj->SetURL( aBookMark.GetURL() );
             pIMapObj->SetAltText( aBookMark.GetDescription() );
-            pModel->SetChanged( sal_True );
+            pModel->SetChanged();
             pView->UnmarkAll();
             pView->MarkObj( pSdrObj, pView->GetSdrPageView() );
-            UpdateInfo( sal_True );
+            UpdateInfo( true );
             nRet =  rEvt.mnAction;
         }
     }
@@ -544,8 +559,8 @@ void IMapWindow::RequestHelp( const HelpEvent& rHEvt )
 
     if ( Help::IsBalloonHelpEnabled() || Help::IsQuickHelpEnabled() )
     {
-        SdrObject*          pSdrObj = NULL;
-        SdrPageView*        pPageView = NULL;
+        SdrObject*          pSdrObj = nullptr;
+        SdrPageView*        pPageView = nullptr;
         if ( pView->PickObj( aPos, pView->getHitTolLog(), pSdrObj, pPageView ) )
         {
             const IMapObject*   pIMapObj = GetIMapObj( pSdrObj );
@@ -568,7 +583,7 @@ void IMapWindow::RequestHelp( const HelpEvent& rHEvt )
     }
 }
 
-void IMapWindow::SetCurrentObjState( sal_Bool bActive )
+void IMapWindow::SetCurrentObjState( bool bActive )
 {
     SdrObject* pObj = GetSelectedSdrObject();
 
@@ -591,36 +606,38 @@ void IMapWindow::SetCurrentObjState( sal_Bool bActive )
             aSet.Put( XLineColorItem( "", Color( COL_BLACK ) ) );
         }
 
-        pView->SetAttributes( aSet, sal_False );
+        pView->SetAttributes( aSet );
     }
 }
 
-void IMapWindow::UpdateInfo( sal_Bool bNewObj )
+void IMapWindow::UpdateInfo( bool bNewObj )
 {
     if ( aInfoLink.IsSet() )
     {
         const SdrObject*    pSdrObj = GetSelectedSdrObject();
-        const IMapObject*   pIMapObj = pSdrObj ? GetIMapObj( pSdrObj ) : NULL;
+        const IMapObject*   pIMapObj = pSdrObj ? GetIMapObj( pSdrObj ) : nullptr;
 
         aInfo.bNewObj = bNewObj;
 
         if ( pIMapObj )
         {
-            aInfo.bOneMarked = sal_True;
+            aInfo.bOneMarked = true;
             aInfo.aMarkURL = pIMapObj->GetURL();
             aInfo.aMarkAltText = pIMapObj->GetAltText();
             aInfo.aMarkTarget = pIMapObj->GetTarget();
             aInfo.bActivated = pIMapObj->IsActive();
-            aInfoLink.Call( this );
+            aInfoLink.Call( *this );
         }
         else
         {
-            aInfo.aMarkURL = aInfo.aMarkAltText = aInfo.aMarkTarget = "";
-            aInfo.bOneMarked = sal_False;
-            aInfo.bActivated = sal_False;
+            aInfo.aMarkURL.clear();
+            aInfo.aMarkAltText.clear();
+            aInfo.aMarkTarget.clear();
+            aInfo.bOneMarked = false;
+            aInfo.bActivated = false;
         }
 
-        aInfoLink.Call( this );
+        aInfoLink.Call( *this );
     }
 }
 
@@ -643,17 +660,15 @@ void IMapWindow::DoMacroAssign()
         aSet.Put( aMacroItem, SID_ATTR_MACROITEM );
 
         SvxAbstractDialogFactory* pFact = SvxAbstractDialogFactory::Create();
-        SfxAbstractDialog* pMacroDlg = pFact->CreateSfxDialog( this, aSet, mxDocumentFrame, SID_EVENTCONFIG );
+        std::unique_ptr<SfxAbstractDialog> pMacroDlg(pFact->CreateSfxDialog( this, aSet, mxDocumentFrame, SID_EVENTCONFIG ));
 
         if ( pMacroDlg && pMacroDlg->Execute() == RET_OK )
         {
             const SfxItemSet* pOutSet = pMacroDlg->GetOutputItemSet();
-            pIMapObj->SetMacroTable( ((const SvxMacroItem& )pOutSet->Get( SID_ATTR_MACROITEM )).GetMacroTable() );
-            pModel->SetChanged( sal_True );
-            UpdateInfo( sal_False );
+            pIMapObj->SetMacroTable( static_cast<const SvxMacroItem& >(pOutSet->Get( SID_ATTR_MACROITEM )).GetMacroTable() );
+            pModel->SetChanged();
+            UpdateInfo( false );
         }
-
-        delete pMacroDlg;
     }
 }
 
@@ -667,17 +682,17 @@ void IMapWindow::DoPropertyDialog()
         SvxAbstractDialogFactory* pFact = SvxAbstractDialogFactory::Create();
         if(pFact)
         {
-            AbstractURLDlg* aDlg = pFact->CreateURLDialog( this, pIMapObj->GetURL(), pIMapObj->GetAltText(), pIMapObj->GetDesc(),
-                                            pIMapObj->GetTarget(), pIMapObj->GetName(), aTargetList );
-            DBG_ASSERT(aDlg, "Dialogdiet fail!");
+            std::unique_ptr<AbstractURLDlg> aDlg(pFact->CreateURLDialog( this, pIMapObj->GetURL(), pIMapObj->GetAltText(), pIMapObj->GetDesc(),
+                                            pIMapObj->GetTarget(), pIMapObj->GetName(), aTargetList ));
+            DBG_ASSERT(aDlg, "Dialog creation failed!");
             if ( aDlg->Execute() == RET_OK )
             {
                 const OUString aURLText( aDlg->GetURL() );
 
                 if ( !aURLText.isEmpty() )
                 {
-                    INetURLObject aObj( aURLText, INET_PROT_FILE );
-                    DBG_ASSERT( aObj.GetProtocol() != INET_PROT_NOT_VALID, "Invalid URL" );
+                    INetURLObject aObj( aURLText, INetProtocol::File );
+                    DBG_ASSERT( aObj.GetProtocol() != INetProtocol::NotValid, "Invalid URL" );
                     pIMapObj->SetURL( aObj.GetMainURL( INetURLObject::NO_DECODE ) );
                 }
                 else
@@ -687,68 +702,68 @@ void IMapWindow::DoPropertyDialog()
                 pIMapObj->SetDesc( aDlg->GetDesc() );
                 pIMapObj->SetTarget( aDlg->GetTarget() );
                 pIMapObj->SetName( aDlg->GetName() );
-                pModel->SetChanged( sal_True );
-                UpdateInfo( sal_True );
+                pModel->SetChanged();
+                UpdateInfo( true );
             }
-            delete aDlg;
         }
     }
 }
 
-IMPL_LINK( IMapWindow, MenuSelectHdl, Menu*, pMenu )
+IMPL_LINK_TYPED( IMapWindow, MenuSelectHdl, Menu*, pMenu, bool )
 {
-    if (pMenu)
+    if (!pMenu)
+        return false;
+
+    sal_uInt16  nId = pMenu->GetCurItemId();
+
+    switch(nId)
     {
-        sal_uInt16  nId = pMenu->GetCurItemId();
+        case( MN_URL ):
+            DoPropertyDialog();
+        break;
 
-        switch(nId)
+        case( MN_MACRO ):
+            DoMacroAssign();
+        break;
+
+        case( MN_ACTIVATE ):
         {
-            case( MN_URL ):
-                DoPropertyDialog();
-            break;
+            const bool bNewState = !pMenu->IsItemChecked( MN_ACTIVATE );
 
-            case( MN_MACRO ):
-                DoMacroAssign();
-            break;
-
-            case( MN_ACTIVATE ):
-            {
-                const sal_Bool bNewState = !pMenu->IsItemChecked( MN_ACTIVATE );
-
-                pMenu->CheckItem( MN_ACTIVATE, bNewState );
-                SetCurrentObjState( bNewState );
-                UpdateInfo( sal_False );
-            }
-
-            case( MN_FRAME_TO_TOP ):
-                pView->PutMarkedToTop();
-            break;
-
-            case( MN_MOREFRONT ):
-                pView->MovMarkedToTop();
-            break;
-
-            case( MN_MOREBACK ):
-                pView->MovMarkedToBtm();
-            break;
-
-            case( MN_FRAME_TO_BOTTOM ):
-                pView->PutMarkedToBtm();
-            break;
-
-            case( MN_MARK_ALL ):
-                pView->MarkAll();
-            break;
-
-            case( MN_DELETE1 ):
-                pView->DeleteMarked();
-
-            default :
-            break;
+            pMenu->CheckItem( MN_ACTIVATE, bNewState );
+            SetCurrentObjState( bNewState );
+            UpdateInfo( false );
         }
+        break;
+
+        case( MN_FRAME_TO_TOP ):
+            pView->PutMarkedToTop();
+        break;
+
+        case( MN_MOREFRONT ):
+            pView->MovMarkedToTop();
+        break;
+
+        case( MN_MOREBACK ):
+            pView->MovMarkedToBtm();
+        break;
+
+        case( MN_FRAME_TO_BOTTOM ):
+            pView->PutMarkedToBtm();
+        break;
+
+        case( MN_MARK_ALL ):
+            pView->MarkAll();
+        break;
+
+        case( MN_DELETE1 ):
+            pView->DeleteMarked();
+
+        default :
+        break;
     }
 
-    return 0;
+    return false;
 }
 
 void IMapWindow::CreateDefaultObject()
@@ -766,7 +781,7 @@ void IMapWindow::CreateDefaultObject()
         aPagePos.Y() += (aPageSize.Height() / 2) - (nDefaultObjectSizeHeight / 2);
         Rectangle aNewObjectRectangle(aPagePos, Size(nDefaultObjectSizeWidth, nDefaultObjectSizeHeight));
 
-        SdrObject* pObj = SdrObjFactory::MakeNewObject( pView->GetCurrentObjInventor(), pView->GetCurrentObjIdentifier(), 0L, pModel);
+        SdrObject* pObj = SdrObjFactory::MakeNewObject( pView->GetCurrentObjInventor(), pView->GetCurrentObjIdentifier(), nullptr, pModel);
         pObj->SetLogicRect(aNewObjectRectangle);
 
         switch( pObj->GetObjIdentifier() )
@@ -782,7 +797,7 @@ void IMapWindow::CreateDefaultObject()
                 aInnerPoly.append(basegfx::B2DPoint(aNewObjectRectangle.RightCenter().X(), aNewObjectRectangle.RightCenter().Y()));
                 aInnerPoly.append(basegfx::B2DPoint(aNewObjectRectangle.BottomRight().X(), aNewObjectRectangle.BottomRight().Y()));
                 aInnerPoly.setClosed(true);
-                ((SdrPathObj*)pObj)->SetPathPoly(basegfx::B2DPolyPolygon(aInnerPoly));
+                static_cast<SdrPathObj*>(pObj)->SetPathPoly(basegfx::B2DPolyPolygon(aInnerPoly));
                 break;
             }
         case OBJ_FREEFILL:
@@ -791,7 +806,7 @@ void IMapWindow::CreateDefaultObject()
                 sal_Int32 nWdt(aNewObjectRectangle.GetWidth() / 2);
                 sal_Int32 nHgt(aNewObjectRectangle.GetHeight() / 2);
                 basegfx::B2DPolygon aInnerPoly(XPolygon(aNewObjectRectangle.Center(), nWdt, nHgt).getB2DPolygon());
-                ((SdrPathObj*)pObj)->SetPathPoly(basegfx::B2DPolyPolygon(aInnerPoly));
+                static_cast<SdrPathObj*>(pObj)->SetPathPoly(basegfx::B2DPolyPolygon(aInnerPoly));
                 break;
             }
 
@@ -811,12 +826,12 @@ void IMapWindow::KeyInput( const KeyEvent& rKEvt )
 
 void IMapWindow::SelectFirstObject()
 {
-    SdrPage*    pPage = (SdrPage*) pModel->GetPage( 0 );
+    SdrPage*    pPage = pModel->GetPage( 0 );
     if( pPage->GetObjCount() != 0 )
     {
         GrabFocus();
         pView->UnmarkAllObj();
-        pView->MarkNextObj(sal_True);
+        pView->MarkNextObj(true);
     }
 }
 
@@ -825,7 +840,7 @@ void IMapWindow::StartPolyEdit()
     GrabFocus();
 
     if( !pView->AreObjectsMarked() )
-        pView->MarkNextObj(sal_True);
+        pView->MarkNextObj(true);
 
     const SdrHdlList& rHdlList = pView->GetHdlList();
     SdrHdl* pHdl = rHdlList.GetFocusHdl();
