@@ -26,6 +26,7 @@
 #include <com/sun/star/awt/XTextComponent.hpp>
 #include <com/sun/star/awt/XListBox.hpp>
 #include <tools/debug.hxx>
+#include <osl/diagnose.h>
 
 
 namespace svxform
@@ -83,10 +84,6 @@ namespace svxform
         _rxPeer->setProperty( FM_PROP_BORDERCOLOR, makeAny( _rBoder.nBorderColor ) );
     }
 
-
-    //= ControlBorderManager
-
-
     ControlBorderManager::ControlBorderManager()
         :m_nFocusColor    ( 0x000000FF )
         ,m_nMouseHoveColor( 0x007098BE )
@@ -136,7 +133,7 @@ namespace svxform
     }
 
 
-    ControlStatus ControlBorderManager::getControlStatus( const Reference< XControl >& _rxControl ) SAL_THROW(())
+    ControlStatus ControlBorderManager::getControlStatus( const Reference< XControl >& _rxControl )
     {
         ControlStatus nStatus = CONTROL_STATUS_NONE;
 
@@ -172,7 +169,7 @@ namespace svxform
     }
 
 
-    void ControlBorderManager::updateBorderStyle( const Reference< XControl >& _rxControl, const Reference< XVclWindowPeer >& _rxPeer, const BorderDescriptor& _rFallback ) SAL_THROW(())
+    void ControlBorderManager::updateBorderStyle( const Reference< XControl >& _rxControl, const Reference< XVclWindowPeer >& _rxPeer, const BorderDescriptor& _rFallback )
     {
         OSL_PRECOND( _rxControl.is() && _rxPeer.is(), "ControlBorderManager::updateBorderStyle: invalid parameters!" );
 
@@ -215,7 +212,7 @@ namespace svxform
     }
 
 
-    void ControlBorderManager::controlStatusGained( const Reference< XInterface >& _rxControl, ControlData& _rControlData ) SAL_THROW(())
+    void ControlBorderManager::controlStatusGained( const Reference< XInterface >& _rxControl, ControlData& _rControlData )
     {
         if ( _rxControl == _rControlData.xControl )
             // nothing to do - though suspicious
@@ -248,7 +245,7 @@ namespace svxform
     }
 
 
-    void ControlBorderManager::controlStatusLost( const Reference< XInterface >& _rxControl, ControlData& _rControlData ) SAL_THROW(())
+    void ControlBorderManager::controlStatusLost( const Reference< XInterface >& _rxControl, ControlData& _rControlData )
     {
         if ( _rxControl != _rControlData.xControl )
             // nothing to do
@@ -330,35 +327,35 @@ namespace svxform
     }
 
 
-    void ControlBorderManager::focusGained( const Reference< XInterface >& _rxControl ) SAL_THROW(())
+    void ControlBorderManager::focusGained( const Reference< XInterface >& _rxControl )
     {
         if ( m_bDynamicBorderColors )
             controlStatusGained( _rxControl, m_aFocusControl );
     }
 
 
-    void ControlBorderManager::focusLost( const Reference< XInterface >& _rxControl ) SAL_THROW(())
+    void ControlBorderManager::focusLost( const Reference< XInterface >& _rxControl )
     {
         if ( m_bDynamicBorderColors )
             controlStatusLost( _rxControl, m_aFocusControl );
     }
 
 
-    void ControlBorderManager::mouseEntered( const Reference< XInterface >& _rxControl ) SAL_THROW(())
+    void ControlBorderManager::mouseEntered( const Reference< XInterface >& _rxControl )
     {
         if ( m_bDynamicBorderColors )
             controlStatusGained( _rxControl, m_aMouseHoverControl );
     }
 
 
-    void ControlBorderManager::mouseExited( const Reference< XInterface >& _rxControl ) SAL_THROW(())
+    void ControlBorderManager::mouseExited( const Reference< XInterface >& _rxControl )
     {
         if ( m_bDynamicBorderColors )
             controlStatusLost( _rxControl, m_aMouseHoverControl );
     }
 
 
-    void ControlBorderManager::validityChanged( const Reference< XControl >& _rxControl, const Reference< XValidatableFormComponent >& _rxValidatable ) SAL_THROW(())
+    void ControlBorderManager::validityChanged( const Reference< XControl >& _rxControl, const Reference< XValidatableFormComponent >& _rxValidatable )
     {
         try
         {
@@ -407,7 +404,7 @@ namespace svxform
                 else
                 {
                     // and also the new font
-                    setUnderline( xPeer, UnderlineDescriptor( com::sun::star::awt::FontUnderline::WAVE, m_nInvalidColor ) );
+                    setUnderline( xPeer, UnderlineDescriptor( css::awt::FontUnderline::WAVE, m_nInvalidColor ) );
                 }
             }
 
@@ -424,7 +421,7 @@ namespace svxform
     }
 
 
-} // namespace svxform
+}
 
 
 /* vim:set shiftwidth=4 softtabstop=4 expandtab: */
