@@ -39,10 +39,10 @@
 #include <functional>
 #include <algorithm>
 
-//........................................................................
+
 namespace svx
 {
-//........................................................................
+
 
     using ::com::sun::star::uno::Reference;
     using ::com::sun::star::uno::XComponentContext;
@@ -65,9 +65,9 @@ namespace svx
 
     namespace FormFeature = ::com::sun::star::form::runtime::FormFeature;
 
-    //====================================================================
+
     //= FeatureSlotTranslation
-    //====================================================================
+
     namespace
     {
         struct FeatureDescription
@@ -78,7 +78,7 @@ namespace svx
         };
         typedef ::std::vector< FeatureDescription > FeatureDescriptions;
 
-        //................................................................
+
         const FeatureDescriptions& getFeatureDescriptions()
         {
             static FeatureDescriptions s_aFeatureDescriptions;
@@ -88,26 +88,26 @@ namespace svx
                 if ( s_aFeatureDescriptions.empty() )
                 {
                     FeatureDescription aDescriptions[] = {
-                        { FMURL_FORM_POSITION,        SID_FM_RECORD_ABSOLUTE,     FormFeature::MoveAbsolute },
-                        { FMURL_FORM_RECORDCOUNT,     SID_FM_RECORD_TOTAL,        FormFeature::TotalRecords },
-                        { FMURL_RECORD_MOVEFIRST,     SID_FM_RECORD_FIRST,        FormFeature::MoveToFirst },
-                        { FMURL_RECORD_MOVEPREV,      SID_FM_RECORD_PREV,         FormFeature::MoveToPrevious },
-                        { FMURL_RECORD_MOVENEXT,      SID_FM_RECORD_NEXT,         FormFeature::MoveToNext },
-                        { FMURL_RECORD_MOVELAST,      SID_FM_RECORD_LAST,         FormFeature::MoveToLast },
-                        { FMURL_RECORD_MOVETONEW,     SID_FM_RECORD_NEW,          FormFeature::MoveToInsertRow },
-                        { FMURL_RECORD_SAVE,          SID_FM_RECORD_SAVE,         FormFeature::SaveRecordChanges },
-                        { FMURL_RECORD_DELETE,        SID_FM_RECORD_DELETE,       FormFeature::DeleteRecord },
-                        { FMURL_FORM_REFRESH,         SID_FM_REFRESH,             FormFeature::ReloadForm },
-                        { FMURL_FORM_REFRESH_CURRENT_CONTROL,
+                        { OUString(FMURL_FORM_POSITION),        SID_FM_RECORD_ABSOLUTE,     FormFeature::MoveAbsolute },
+                        { OUString(FMURL_FORM_RECORDCOUNT),     SID_FM_RECORD_TOTAL,        FormFeature::TotalRecords },
+                        { OUString(FMURL_RECORD_MOVEFIRST),     SID_FM_RECORD_FIRST,        FormFeature::MoveToFirst },
+                        { OUString(FMURL_RECORD_MOVEPREV),      SID_FM_RECORD_PREV,         FormFeature::MoveToPrevious },
+                        { OUString(FMURL_RECORD_MOVENEXT),      SID_FM_RECORD_NEXT,         FormFeature::MoveToNext },
+                        { OUString(FMURL_RECORD_MOVELAST),      SID_FM_RECORD_LAST,         FormFeature::MoveToLast },
+                        { OUString(FMURL_RECORD_MOVETONEW),     SID_FM_RECORD_NEW,          FormFeature::MoveToInsertRow },
+                        { OUString(FMURL_RECORD_SAVE),          SID_FM_RECORD_SAVE,         FormFeature::SaveRecordChanges },
+                        { OUString(FMURL_RECORD_DELETE),        SID_FM_RECORD_DELETE,       FormFeature::DeleteRecord },
+                        { OUString(FMURL_FORM_REFRESH),         SID_FM_REFRESH,             FormFeature::ReloadForm },
+                        { OUString(FMURL_FORM_REFRESH_CURRENT_CONTROL),
                                                       SID_FM_REFRESH_FORM_CONTROL,FormFeature::RefreshCurrentControl },
-                        { FMURL_RECORD_UNDO,          SID_FM_RECORD_UNDO,         FormFeature::UndoRecordChanges },
-                        { FMURL_FORM_SORT_UP,         SID_FM_SORTUP,              FormFeature::SortAscending },
-                        { FMURL_FORM_SORT_DOWN,       SID_FM_SORTDOWN,            FormFeature::SortDescending },
-                        { FMURL_FORM_SORT,            SID_FM_ORDERCRIT,           FormFeature::InteractiveSort },
-                        { FMURL_FORM_AUTO_FILTER,     SID_FM_AUTOFILTER,          FormFeature::AutoFilter },
-                        { FMURL_FORM_FILTER,          SID_FM_FILTERCRIT,          FormFeature::InteractiveFilter },
-                        { FMURL_FORM_APPLY_FILTER,    SID_FM_FORM_FILTERED,       FormFeature::ToggleApplyFilter },
-                        { FMURL_FORM_REMOVE_FILTER,   SID_FM_REMOVE_FILTER_SORT,  FormFeature::RemoveFilterAndSort }
+                        { OUString(FMURL_RECORD_UNDO),          SID_FM_RECORD_UNDO,         FormFeature::UndoRecordChanges },
+                        { OUString(FMURL_FORM_SORT_UP),         SID_FM_SORTUP,              FormFeature::SortAscending },
+                        { OUString(FMURL_FORM_SORT_DOWN),       SID_FM_SORTDOWN,            FormFeature::SortDescending },
+                        { OUString(FMURL_FORM_SORT),            SID_FM_ORDERCRIT,           FormFeature::InteractiveSort },
+                        { OUString(FMURL_FORM_AUTO_FILTER),     SID_FM_AUTOFILTER,          FormFeature::AutoFilter },
+                        { OUString(FMURL_FORM_FILTER),          SID_FM_FILTERCRIT,          FormFeature::InteractiveFilter },
+                        { OUString(FMURL_FORM_APPLY_FILTER),    SID_FM_FORM_FILTERED,       FormFeature::ToggleApplyFilter },
+                        { OUString(FMURL_FORM_REMOVE_FILTER),   SID_FM_REMOVE_FILTER_SORT,  FormFeature::RemoveFilterAndSort }
                     };
                     for ( size_t i=0; i<sizeof(aDescriptions)/sizeof(aDescriptions[0]); ++i )
                         s_aFeatureDescriptions.push_back( aDescriptions[i] );
@@ -117,14 +117,14 @@ namespace svx
         }
     }
 
-    //--------------------------------------------------------------------
+
     namespace
     {
-        //................................................................
+
         struct MatchFeatureDescriptionByURL : public ::std::unary_function< FeatureDescription, bool >
         {
             const OUString&  m_rURL;
-            MatchFeatureDescriptionByURL( const OUString& _rURL ) :m_rURL( _rURL ) { }
+            explicit MatchFeatureDescriptionByURL( const OUString& _rURL ) :m_rURL( _rURL ) { }
 
             bool operator()( const FeatureDescription& _compare )
             {
@@ -132,11 +132,11 @@ namespace svx
             }
         };
 
-        //................................................................
+
         struct MatchFeatureDescriptionBySlotId : public ::std::unary_function< FeatureDescription, bool >
         {
             sal_Int32   m_nSlotId;
-            MatchFeatureDescriptionBySlotId( sal_Int32 _nSlotId ) :m_nSlotId( _nSlotId ) { }
+            explicit MatchFeatureDescriptionBySlotId( sal_Int32 _nSlotId ) :m_nSlotId( _nSlotId ) { }
 
             bool operator()( const FeatureDescription& _compare )
             {
@@ -144,11 +144,11 @@ namespace svx
             }
         };
 
-        //................................................................
+
         struct MatchFeatureDescriptionByFormFeature : public ::std::unary_function< FeatureDescription, bool >
         {
             sal_Int32   m_nFormFeature;
-            MatchFeatureDescriptionByFormFeature( sal_Int32 _nFormFeature ) :m_nFormFeature( _nFormFeature ) { }
+            explicit MatchFeatureDescriptionByFormFeature( sal_Int32 _nFormFeature ) :m_nFormFeature( _nFormFeature ) { }
 
             bool operator()( const FeatureDescription& _compare )
             {
@@ -156,7 +156,7 @@ namespace svx
             }
         };
 
-        //................................................................
+
         struct FormFeatureToSlotId : public ::std::unary_function< sal_Int16, sal_Int32 >
         {
             sal_Int32 operator()( sal_Int16 _FormFeature )
@@ -166,7 +166,7 @@ namespace svx
         };
     }
 
-    //--------------------------------------------------------------------
+
     sal_Int32 FeatureSlotTranslation::getControllerFeatureSlotIdForURL( const OUString& _rMainURL )
     {
         const FeatureDescriptions& rDescriptions( getFeatureDescriptions() );
@@ -174,7 +174,7 @@ namespace svx
         return ( pos != rDescriptions.end() ) ? pos->nSlotId : -1;
     }
 
-    //--------------------------------------------------------------------
+
     sal_Int16 FeatureSlotTranslation::getFormFeatureForSlotId( sal_Int32 _nSlotId )
     {
         const FeatureDescriptions& rDescriptions( getFeatureDescriptions() );
@@ -183,7 +183,7 @@ namespace svx
         return ( pos != rDescriptions.end() ) ? pos->nFormFeature : -1;
     }
 
-    //--------------------------------------------------------------------
+
     sal_Int32 FeatureSlotTranslation::getSlotIdForFormFeature( sal_Int16 _nFormFeature )
     {
         const FeatureDescriptions& rDescriptions( getFeatureDescriptions() );
@@ -192,25 +192,21 @@ namespace svx
         return ( pos != rDescriptions.end() ) ? pos->nSlotId : -1;
     }
 
-    //====================================================================
-    //= ControllerFeatures
-    //====================================================================
-    //--------------------------------------------------------------------
     ControllerFeatures::ControllerFeatures( IControllerFeatureInvalidation* _pInvalidationCallback )
         :m_pInvalidationCallback( _pInvalidationCallback )
-        ,m_pImpl( NULL )
+        ,m_pImpl( nullptr )
     {
     }
 
-    //--------------------------------------------------------------------
+
     ControllerFeatures::ControllerFeatures( const Reference< XFormController >& _rxController, IControllerFeatureInvalidation* _pInvalidationCallback )
         :m_pInvalidationCallback( _pInvalidationCallback )
-        ,m_pImpl( NULL )
+        ,m_pImpl( nullptr )
     {
         assign( _rxController );
     }
 
-    //--------------------------------------------------------------------
+
     void ControllerFeatures::assign( const Reference< XFormController >& _rxController )
     {
         dispose();
@@ -218,27 +214,23 @@ namespace svx
         m_pImpl->acquire();
     }
 
-    //--------------------------------------------------------------------
+
     ControllerFeatures::~ControllerFeatures()
     {
         dispose();
     }
 
-    //--------------------------------------------------------------------
+
     void ControllerFeatures::dispose()
     {
         if ( m_pImpl )
         {
             m_pImpl->dispose();
             m_pImpl->release();
-            m_pImpl = NULL;
+            m_pImpl = nullptr;
         }
     }
 
-    //====================================================================
-    //= FormControllerHelper
-    //====================================================================
-    //--------------------------------------------------------------------
     FormControllerHelper::FormControllerHelper( const Reference< XFormController >& _rxController, IControllerFeatureInvalidation* _pInvalidationCallback )
         :m_pInvalidationCallback( _pInvalidationCallback )
     {
@@ -248,11 +240,6 @@ namespace svx
             m_xFormOperations = FormOperations::createWithFormController( comphelper::getProcessComponentContext(), _rxController );
             if ( m_xFormOperations.is() )
                 m_xFormOperations->setFeatureInvalidation( this );
-
-            // to prevent the controller from displaying any error messages which happen while we operate on it,
-            // we add ourself as XSQLErrorListener. By contract, a FormController displays errors if and only if
-            // no SQLErrorListeners are registered.
-            _rxController->addSQLErrorListener( this );
         }
         catch( const Exception& )
         {
@@ -261,7 +248,7 @@ namespace svx
         osl_atomic_decrement( &m_refCount );
     }
 
-    //--------------------------------------------------------------------
+
     FormControllerHelper::~FormControllerHelper( )
     {
         try
@@ -275,7 +262,7 @@ namespace svx
         }
     }
 
-    //--------------------------------------------------------------------
+
     void FormControllerHelper::dispose()
     {
         if ( m_xFormOperations.is() )
@@ -283,15 +270,15 @@ namespace svx
         m_xFormOperations.clear();
     }
 
-    //--------------------------------------------------------------------
-    sal_Bool FormControllerHelper::isEnabled( sal_Int32 _nSlotId ) const
+
+    bool FormControllerHelper::isEnabled( sal_Int32 _nSlotId ) const
     {
         if ( !m_xFormOperations.is() )
-            return sal_False;
+            return false;
         return m_xFormOperations->isEnabled( FeatureSlotTranslation::getFormFeatureForSlotId( _nSlotId ) );
     }
 
-    //--------------------------------------------------------------------
+
     Reference< XRowSet > FormControllerHelper::getCursor() const
     {
         Reference< XRowSet > xCursor;
@@ -300,36 +287,33 @@ namespace svx
         return xCursor;
     }
 
-    //--------------------------------------------------------------------
+
     void FormControllerHelper::getState( sal_Int32 _nSlotId, FeatureState& _rState ) const
     {
         if ( m_xFormOperations.is() )
             _rState = m_xFormOperations->getState( FeatureSlotTranslation::getFormFeatureForSlotId( _nSlotId ) );
     }
 
-    //--------------------------------------------------------------------
-    sal_Bool FormControllerHelper::commitCurrentControl( ) const
+
+    bool FormControllerHelper::commitCurrentControl( ) const
     {
         return impl_operateForm_nothrow( COMMIT_CONTROL );
     }
 
-    //--------------------------------------------------------------------
-    sal_Bool FormControllerHelper::commitCurrentRecord() const
+
+    bool FormControllerHelper::commitCurrentRecord() const
     {
         return impl_operateForm_nothrow( COMMIT_RECORD );
     }
 
-    //--------------------------------------------------------------------
+
     void FormControllerHelper::execute( sal_Int32 _nSlotId, const OUString& _rParamName, const Any& _rParamValue ) const
     {
-        Sequence< NamedValue > aArguments(1);
-        aArguments[0].Name = _rParamName;
-        aArguments[0].Value = _rParamValue;
-
+        Sequence< NamedValue > aArguments { { _rParamName, _rParamValue } };
         impl_operateForm_nothrow( EXECUTE_ARGS, FeatureSlotTranslation::getFormFeatureForSlotId( _nSlotId ), aArguments );
     }
 
-    //--------------------------------------------------------------------
+
     bool FormControllerHelper::impl_operateForm_nothrow( const FormOperation _eWhat, const sal_Int16 _nFeature,
             const Sequence< NamedValue >& _rArguments ) const
     {
@@ -341,6 +325,11 @@ namespace svx
         const_cast< FormControllerHelper* >( this )->m_aOperationError.clear();
         try
         {
+            // to prevent the controller from displaying any error messages which happen while we operate on it,
+            // we add ourself as XSQLErrorListener. By contract, a FormController displays errors if and only if
+            // no SQLErrorListeners are registered.
+            m_xFormOperations->getController()->addSQLErrorListener( const_cast< FormControllerHelper* >(this) );
+
             switch ( _eWhat )
             {
             case COMMIT_CONTROL:
@@ -349,7 +338,7 @@ namespace svx
 
             case COMMIT_RECORD:
             {
-                sal_Bool bDummy( sal_False );
+                sal_Bool bDummy( false );
                 bSuccess = m_xFormOperations->commitCurrentRecord( bDummy );
             }
             break;
@@ -367,10 +356,12 @@ namespace svx
         }
         catch ( const SQLException& )
         {
+            m_xFormOperations->getController()->removeSQLErrorListener( const_cast< FormControllerHelper* >(this) );
             aError = ::cppu::getCaughtException();
         }
         catch( const Exception& )
         {
+            m_xFormOperations->getController()->removeSQLErrorListener( const_cast< FormControllerHelper* >(this) );
             SQLException aFallbackError;
             aFallbackError.Message = ::comphelper::anyToString( ::cppu::getCaughtException() );
             aError <<= aFallbackError;
@@ -390,15 +381,15 @@ namespace svx
         return false;
     }
 
-    //--------------------------------------------------------------------
+
     void FormControllerHelper::execute( sal_Int32 _nSlotId ) const
     {
         impl_operateForm_nothrow( EXECUTE, FeatureSlotTranslation::getFormFeatureForSlotId( _nSlotId ),
             Sequence< NamedValue >() );
     }
 
-    //--------------------------------------------------------------------
-    void SAL_CALL FormControllerHelper::invalidateFeatures( const Sequence< ::sal_Int16 >& _Features ) throw (RuntimeException)
+
+    void SAL_CALL FormControllerHelper::invalidateFeatures( const Sequence< ::sal_Int16 >& _Features ) throw (RuntimeException, std::exception)
     {
         if ( !m_pInvalidationCallback )
             // nobody's interested in ...
@@ -415,8 +406,8 @@ namespace svx
         m_pInvalidationCallback->invalidateFeatures( aFeatures );
     }
 
-    //--------------------------------------------------------------------
-    void SAL_CALL FormControllerHelper::invalidateAllFeatures() throw (RuntimeException)
+
+    void SAL_CALL FormControllerHelper::invalidateAllFeatures() throw (RuntimeException, std::exception)
     {
         if ( !m_pInvalidationCallback )
             // nobody's interested in ...
@@ -458,37 +449,37 @@ namespace svx
         m_pInvalidationCallback->invalidateFeatures( aSupportedFeatures );
     }
 
-    //--------------------------------------------------------------------
-    void SAL_CALL FormControllerHelper::errorOccured( const SQLErrorEvent& _Event ) throw (RuntimeException)
+
+    void SAL_CALL FormControllerHelper::errorOccured( const SQLErrorEvent& _Event ) throw (RuntimeException, std::exception)
     {
         OSL_ENSURE( !m_aOperationError.hasValue(), "FormControllerHelper::errorOccurred: two errors during one operation?" );
         m_aOperationError = _Event.Reason;
     }
 
-    //--------------------------------------------------------------------
-    void SAL_CALL FormControllerHelper::disposing( const EventObject& /*_Source*/ ) throw (RuntimeException)
+
+    void SAL_CALL FormControllerHelper::disposing( const EventObject& /*_Source*/ ) throw (RuntimeException, std::exception)
     {
         // not interested in
     }
 
-    //--------------------------------------------------------------------
-    sal_Bool FormControllerHelper::isInsertionRow() const
+
+    bool FormControllerHelper::isInsertionRow() const
     {
-        sal_Bool bIs = sal_False;
+        bool bIs = false;
         if ( m_xFormOperations.is() )
             bIs = m_xFormOperations->isInsertionRow();
         return bIs;
     }
 
-    //--------------------------------------------------------------------
-    sal_Bool FormControllerHelper::isModifiedRow() const
+
+    bool FormControllerHelper::isModifiedRow() const
     {
-        sal_Bool bIs = sal_False;
+        bool bIs = false;
         if ( m_xFormOperations.is() )
             bIs = m_xFormOperations->isModifiedRow();
         return bIs;
     }
-    //--------------------------------------------------------------------
+
     bool FormControllerHelper::canDoFormFilter() const
     {
         if ( !m_xFormOperations.is() )
@@ -517,8 +508,8 @@ namespace svx
         return bCanDo;
     }
 
-//........................................................................
-}   // namespace svx
-//........................................................................
+
+}
+
 
 /* vim:set shiftwidth=4 softtabstop=4 expandtab: */
