@@ -17,6 +17,15 @@
  *   the License at http://www.apache.org/licenses/LICENSE-2.0 .
  */
 
+#include <config_features.h>
+
+#if defined(MACOSX) && HAVE_FEATURE_READONLY_INSTALLSET
+#define __ASSERT_MACROS_DEFINE_VERSIONS_WITHOUT_UNDERSCORES 0
+#include <premac.h>
+#include <Foundation/Foundation.h>
+#include <postmac.h>
+#endif
+
 #include "sal/config.h"
 
 #include <comphelper/processfactory.hxx>
@@ -34,10 +43,10 @@
 #include "svx/gallery1.hxx"
 #include <com/sun/star/sdbc/XResultSet.hpp>
 #include <com/sun/star/ucb/XContentAccess.hpp>
+#include <memory>
 
 // - Namespaces -
 
-using namespace ::rtl;
 using namespace ::com::sun::star;
 
 // - GalleryThemeEntry -
@@ -51,14 +60,14 @@ static bool FileExists( const INetURLObject &rURL, const rtl::OUString &rExt )
 
 GalleryThemeEntry::GalleryThemeEntry( bool bCreateUniqueURL,
                                       const INetURLObject& rBaseURL, const OUString& rName,
-                                      sal_Bool _bReadOnly, sal_Bool _bNewFile,
-                                      sal_uInt32 _nId, sal_Bool _bThemeNameFromResource ) :
-        nId                                     ( _nId ),
-        bReadOnly                               ( _bReadOnly ),
+                                      bool _bReadOnly, bool _bNewFile,
+                                      sal_uInt32 _nId, bool _bThemeNameFromResource ) :
+        nId                     ( _nId ),
+        bReadOnly               ( _bReadOnly ),
         bThemeNameFromResource  ( _bThemeNameFromResource )
 {
     INetURLObject aURL( rBaseURL );
-    DBG_ASSERT( aURL.GetProtocol() != INET_PROT_NOT_VALID, "invalid URL" );
+    DBG_ASSERT( aURL.GetProtocol() != INetProtocol::NotValid, "invalid URL" );
 
     if (bCreateUniqueURL)
     {
@@ -98,7 +107,7 @@ GalleryThemeEntry::GalleryThemeEntry( bool bCreateUniqueURL,
         aName = rName;
 }
 
-INetURLObject GalleryThemeEntry::ImplGetURLIgnoreCase( const INetURLObject& rURL ) const
+INetURLObject GalleryThemeEntry::ImplGetURLIgnoreCase( const INetURLObject& rURL )
 {
     INetURLObject   aURL( rURL );
 
@@ -123,15 +132,15 @@ void GalleryThemeEntry::SetName( const OUString& rNewName )
     if( aName != rNewName )
     {
         aName = rNewName;
-        SetModified( sal_True );
-        bThemeNameFromResource = sal_False;
+        SetModified( true );
+        bThemeNameFromResource = false;
     }
 }
 
-void GalleryThemeEntry::SetId( sal_uInt32 nNewId, sal_Bool bResetThemeName )
+void GalleryThemeEntry::SetId( sal_uInt32 nNewId, bool bResetThemeName )
 {
     nId = nNewId;
-    SetModified( sal_True );
+    SetModified( true );
     bThemeNameFromResource = ( nId && bResetThemeName );
 }
 
@@ -157,8 +166,7 @@ public:
 // - Gallery -
 
 Gallery::Gallery( const OUString& rMultiPath )
-:       nReadTextEncoding   ( osl_getThreadTextEncoding() )
-,       bMultiPath          ( sal_False )
+:       bMultiPath          ( false )
 {
     ImplLoad( rMultiPath );
 }
@@ -173,24 +181,24 @@ Gallery::~Gallery()
 
 Gallery* Gallery::GetGalleryInstance()
 {
-    static Gallery* pGallery = NULL;
+    static Gallery* s_pGallery = nullptr;
 
-    if( !pGallery )
+    if (!s_pGallery)
     {
         ::osl::MutexGuard aGuard( ::osl::Mutex::getGlobalMutex() );
-        if( !pGallery )
+        if (!s_pGallery)
         {
-            pGallery = new Gallery( SvtPathOptions().GetGalleryPath() );
+            s_pGallery = new Gallery( SvtPathOptions().GetGalleryPath() );
         }
     }
 
-    return pGallery;
+    return s_pGallery;
 }
 
 void Gallery::ImplLoad( const OUString& rMultiPath )
 {
     const sal_Int32 nTokenCount = comphelper::string::getTokenCount(rMultiPath, ';');
-    sal_Bool        bIsReadOnlyDir;
+    bool            bIsReadOnlyDir;
 
     bMultiPath = ( nTokenCount > 0 );
 
@@ -202,11 +210,11 @@ void Gallery::ImplLoad( const OUString& rMultiPath )
 
     if( bMultiPath )
     {
-        aRelURL = INetURLObject( comphelper::string::getToken(rMultiPath, 0, ';') );
+        aRelURL = INetURLObject( rMultiPath.getToken(0, ';') );
 
         for( sal_Int32 i = 0; i < nTokenCount; ++i )
         {
-            aCurURL = INetURLObject(comphelper::string::getToken(rMultiPath, i, ';'));
+            aCurURL = INetURLObject(rMultiPath.getToken(i, ';'));
 
             ImplLoadSubDirs( aCurURL, bIsReadOnlyDir );
 
@@ -217,24 +225,32 @@ void Gallery::ImplLoad( const OUString& rMultiPath )
     else
         aRelURL = INetURLObject( rMultiPath );
 
-    DBG_ASSERT( aUserURL.GetProtocol() != INET_PROT_NOT_VALID, "no writable Gallery user directory available" );
-    DBG_ASSERT( aRelURL.GetProtocol() != INET_PROT_NOT_VALID, "invalid URL" );
+    DBG_ASSERT( aUserURL.GetProtocol() != INetProtocol::NotValid, "no writable Gallery user directory available" );
+    DBG_ASSERT( aRelURL.GetProtocol() != INetProtocol::NotValid, "invalid URL" );
 }
 
-void Gallery::ImplLoadSubDirs( const INetURLObject& rBaseURL, sal_Bool& rbDirIsReadOnly )
+void Gallery::ImplLoadSubDirs( const INetURLObject& rBaseURL, bool& rbDirIsReadOnly )
 {
-    rbDirIsReadOnly = sal_False;
+    rbDirIsReadOnly = false;
 
     try
     {
         uno::Reference< ucb::XCommandEnvironment > xEnv;
         ::ucbhelper::Content                       aCnt( rBaseURL.GetMainURL( INetURLObject::NO_DECODE ), xEnv, comphelper::getProcessComponentContext() );
 
-        uno::Sequence< OUString > aProps( 1 );
-        aProps.getArray()[ 0 ] = "Url";
+        uno::Sequence<OUString> aProps { "Url" };
 
         uno::Reference< sdbc::XResultSet > xResultSet( aCnt.createCursor( aProps, ::ucbhelper::INCLUDE_DOCUMENTS_ONLY ) );
 
+#if defined(MACOSX) && HAVE_FEATURE_READONLY_INSTALLSET
+        if( rBaseURL.GetProtocol() == INetProtocol::File )
+        {
+            const char *appBundle = [[[NSBundle mainBundle] bundlePath] UTF8String];
+            OUString path = rBaseURL.GetURLPath();
+            if( path.startsWith( OUString( appBundle, strlen( appBundle ), RTL_TEXTENCODING_UTF8 ) + "/" ) )
+                rbDirIsReadOnly = true;
+        }
+#else
         try
         {
             // check readonlyness the very hard way
@@ -242,20 +258,20 @@ void Gallery::ImplLoadSubDirs( const INetURLObject& rBaseURL, sal_Bool& rbDirIsR
             OUString        aTestFile( "cdefghij.klm" );
 
             aTestURL.Append( aTestFile );
-            SvStream* pTestStm = ::utl::UcbStreamHelper::CreateStream( aTestURL.GetMainURL( INetURLObject::NO_DECODE ), STREAM_WRITE );
+            std::unique_ptr<SvStream> pTestStm(::utl::UcbStreamHelper::CreateStream( aTestURL.GetMainURL( INetURLObject::NO_DECODE ), StreamMode::WRITE ));
 
             if( pTestStm )
             {
-                *pTestStm << sal_Int32(1);
+                pTestStm->WriteInt32( sal_Int32(1) );
 
                 if( pTestStm->GetError() )
-                    rbDirIsReadOnly = sal_True;
+                    rbDirIsReadOnly = true;
 
-                delete pTestStm;
+                pTestStm.reset();
                 KillFile( aTestURL );
             }
             else
-                rbDirIsReadOnly = sal_True;
+                rbDirIsReadOnly = true;
         }
         catch( const ucb::ContentCreationException& )
         {
@@ -266,17 +282,17 @@ void Gallery::ImplLoadSubDirs( const INetURLObject& rBaseURL, sal_Bool& rbDirIsR
         catch( const uno::Exception& )
         {
         }
-
+#endif
         if( xResultSet.is() )
         {
             uno::Reference< ucb::XContentAccess > xContentAccess( xResultSet, uno::UNO_QUERY );
 
             if( xContentAccess.is() )
             {
-                static const OUString s_sTitle("Title");
-                static const OUString s_sIsReadOnly("IsReadOnly");
-                static const OUString s_sSDG_EXT("sdg");
-                static const OUString s_sSDV_EXT("sdv");
+                static const char s_sTitle[] = "Title";
+                static const char s_sIsReadOnly[] = "IsReadOnly";
+                static const char s_sSDG_EXT[] = "sdg";
+                static const char s_sSDV_EXT[] = "sdv";
 
                 while( xResultSet->next() )
                 {
@@ -287,7 +303,6 @@ void Gallery::ImplLoadSubDirs( const INetURLObject& rBaseURL, sal_Bool& rbDirIsR
                         INetURLObject   aSdgURL( aThmURL); aSdgURL.SetExtension( s_sSDG_EXT );
                         INetURLObject   aSdvURL( aThmURL ); aSdvURL.SetExtension( s_sSDV_EXT );
                         OUString        aTitle;
-                        sal_Bool        bReadOnly = sal_False;
 
                         try
                         {
@@ -308,6 +323,8 @@ void Gallery::ImplLoadSubDirs( const INetURLObject& rBaseURL, sal_Bool& rbDirIsR
 
                             if( !aTitle.isEmpty() )
                             {
+                                bool bReadOnly = false;
+
                                 try
                                 {
                                     aThmCnt.getPropertyValue( s_sIsReadOnly ) >>= bReadOnly;
@@ -325,10 +342,10 @@ void Gallery::ImplLoadSubDirs( const INetURLObject& rBaseURL, sal_Bool& rbDirIsR
                                     {
                                         aSdgCnt.getPropertyValue( s_sTitle ) >>= aTitle;
                                     }
-                                    catch( const ::com::sun::star::uno::RuntimeException& )
+                                    catch( const css::uno::RuntimeException& )
                                     {
                                     }
-                                    catch( const ::com::sun::star::uno::Exception& )
+                                    catch( const css::uno::Exception& )
                                     {
                                     }
 
@@ -353,10 +370,10 @@ void Gallery::ImplLoadSubDirs( const INetURLObject& rBaseURL, sal_Bool& rbDirIsR
                                     {
                                         aSdvCnt.getPropertyValue( s_sTitle ) >>= aTitle;
                                     }
-                                    catch( const ::com::sun::star::uno::RuntimeException& )
+                                    catch( const css::uno::RuntimeException& )
                                     {
                                     }
-                                    catch( const ::com::sun::star::uno::Exception& )
+                                    catch( const css::uno::Exception& )
                                     {
                                     }
 
@@ -408,7 +425,7 @@ void Gallery::ImplLoadSubDirs( const INetURLObject& rBaseURL, sal_Bool& rbDirIsR
 
 GalleryThemeEntry* Gallery::ImplGetThemeEntry( const OUString& rThemeName )
 {
-    GalleryThemeEntry* pFound = NULL;
+    GalleryThemeEntry* pFound = nullptr;
 
     if( !rThemeName.isEmpty() )
     {
@@ -422,7 +439,7 @@ GalleryThemeEntry* Gallery::ImplGetThemeEntry( const OUString& rThemeName )
 
 OUString Gallery::GetThemeName( sal_uIntPtr nThemeId ) const
 {
-    GalleryThemeEntry* pFound = NULL;
+    GalleryThemeEntry* pFound = nullptr;
 
     for ( size_t i = 0, n = aThemeList.size(); i < n && !pFound; ++i )
     {
@@ -481,36 +498,36 @@ OUString Gallery::GetThemeName( sal_uIntPtr nThemeId ) const
     return( pFound ? pFound->GetThemeName() : OUString() );
 }
 
-sal_Bool Gallery::HasTheme( const OUString& rThemeName )
+bool Gallery::HasTheme( const OUString& rThemeName )
 {
-    return( ImplGetThemeEntry( rThemeName ) != NULL );
+    return( ImplGetThemeEntry( rThemeName ) != nullptr );
 }
 
-sal_Bool Gallery::CreateTheme( const OUString& rThemeName )
+bool Gallery::CreateTheme( const OUString& rThemeName )
 {
-    sal_Bool bRet = sal_False;
+    bool bRet = false;
 
-    if( !HasTheme( rThemeName ) && ( GetUserURL().GetProtocol() != INET_PROT_NOT_VALID ) )
+    if( !HasTheme( rThemeName ) && ( GetUserURL().GetProtocol() != INetProtocol::NotValid ) )
     {
         INetURLObject aURL( GetUserURL() );
         aURL.Append( rThemeName );
         GalleryThemeEntry* pNewEntry = new GalleryThemeEntry(
                 true, aURL, rThemeName,
-                sal_False, sal_True, 0, sal_False );
+                false, true, 0, false );
 
         aThemeList.push_back( pNewEntry );
         delete( new GalleryTheme( this, pNewEntry ) );
-        Broadcast( GalleryHint( GALLERY_HINT_THEME_CREATED, rThemeName ) );
-        bRet = sal_True;
+        Broadcast( GalleryHint( GalleryHintType::THEME_CREATED, rThemeName ) );
+        bRet = true;
     }
 
     return bRet;
 }
 
-sal_Bool Gallery::RenameTheme( const OUString& rOldName, const OUString& rNewName )
+bool Gallery::RenameTheme( const OUString& rOldName, const OUString& rNewName )
 {
     GalleryThemeEntry*      pThemeEntry = ImplGetThemeEntry( rOldName );
-    sal_Bool                            bRet = sal_False;
+    bool                    bRet = false;
 
     // check if the new theme name is already present
     if( pThemeEntry && !HasTheme( rNewName ) && !pThemeEntry->IsReadOnly() )
@@ -525,23 +542,23 @@ sal_Bool Gallery::RenameTheme( const OUString& rOldName, const OUString& rNewNam
             pThemeEntry->SetName( rNewName );
             pThm->ImplWrite();
 
-            Broadcast( GalleryHint( GALLERY_HINT_THEME_RENAMED, aOldName, pThm->GetName() ) );
+            Broadcast( GalleryHint( GalleryHintType::THEME_RENAMED, aOldName, pThm->GetName() ) );
             ReleaseTheme( pThm, aListener );
-            bRet = sal_True;
+            bRet = true;
         }
     }
 
     return bRet;
 }
 
-sal_Bool Gallery::RemoveTheme( const OUString& rThemeName )
+bool Gallery::RemoveTheme( const OUString& rThemeName )
 {
     GalleryThemeEntry*  pThemeEntry = ImplGetThemeEntry( rThemeName );
-    sal_Bool                bRet = sal_False;
+    bool                bRet = false;
 
     if( pThemeEntry && !pThemeEntry->IsReadOnly() )
     {
-        Broadcast( GalleryHint( GALLERY_HINT_CLOSE_THEME, rThemeName ) );
+        Broadcast( GalleryHint( GalleryHintType::CLOSE_THEME, rThemeName ) );
 
         SfxListener     aListener;
         GalleryTheme*   pThm = AcquireTheme( rThemeName, aListener );
@@ -570,17 +587,17 @@ sal_Bool Gallery::RemoveTheme( const OUString& rThemeName )
             }
         }
 
-        Broadcast( GalleryHint( GALLERY_HINT_THEME_REMOVED, rThemeName ) );
+        Broadcast( GalleryHint( GalleryHintType::THEME_REMOVED, rThemeName ) );
 
-        bRet = sal_True;
+        bRet = true;
     }
 
     return bRet;
 }
 
-GalleryTheme* Gallery::ImplGetCachedTheme( const GalleryThemeEntry* pThemeEntry )
+GalleryTheme* Gallery::ImplGetCachedTheme(const GalleryThemeEntry* pThemeEntry)
 {
-    GalleryTheme* pTheme = NULL;
+    GalleryTheme* pTheme = nullptr;
 
     if( pThemeEntry )
     {
@@ -597,23 +614,27 @@ GalleryTheme* Gallery::ImplGetCachedTheme( const GalleryThemeEntry* pThemeEntry
         {
             INetURLObject aURL = pThemeEntry->GetThmURL();
 
-            DBG_ASSERT( aURL.GetProtocol() != INET_PROT_NOT_VALID, "invalid URL" );
+            DBG_ASSERT( aURL.GetProtocol() != INetProtocol::NotValid, "invalid URL" );
 
             if( FileExists( aURL ) )
             {
-                SvStream* pIStm = ::utl::UcbStreamHelper::CreateStream( aURL.GetMainURL( INetURLObject::NO_DECODE ), STREAM_READ );
+                std::unique_ptr<SvStream> pIStm(::utl::UcbStreamHelper::CreateStream( aURL.GetMainURL( INetURLObject::NO_DECODE ), StreamMode::READ ));
 
                 if( pIStm )
                 {
-                    pTheme = new GalleryTheme( this, (GalleryThemeEntry*) pThemeEntry );
-                    *pIStm >> *pTheme;
-
-                    if( pIStm->GetError() )
+                    try
                     {
-                        delete pTheme, pTheme = NULL;
-                    }
+                        pTheme = new GalleryTheme( this, const_cast<GalleryThemeEntry*>(pThemeEntry) );
+                        ReadGalleryTheme( *pIStm, *pTheme );
 
-                    delete pIStm;
+                        if( pIStm->GetError() )
+                        {
+                            delete pTheme, pTheme = nullptr;
+                        }
+                    }
+                    catch (const css::ucb::ContentCreationException&)
+                    {
+                    }
                 }
             }
 
@@ -640,10 +661,10 @@ void Gallery::ImplDeleteCachedTheme( GalleryTheme* pTheme )
 
 GalleryTheme* Gallery::AcquireTheme( const OUString& rThemeName, SfxListener& rListener )
 {
-    GalleryTheme*           pTheme = NULL;
+    GalleryTheme*           pTheme = nullptr;
     GalleryThemeEntry*      pThemeEntry = ImplGetThemeEntry( rThemeName );
 
-    if( pThemeEntry && ( ( pTheme = ImplGetCachedTheme( pThemeEntry ) ) != NULL ) )
+    if( pThemeEntry && ( ( pTheme = ImplGetCachedTheme( pThemeEntry ) ) != nullptr ) )
         rListener.StartListening( *pTheme );
 
     return pTheme;
@@ -660,7 +681,9 @@ void Gallery::ReleaseTheme( GalleryTheme* pTheme, SfxListener& rListener )
     }
 }
 
-sal_Bool GalleryThemeEntry::IsDefault() const
-{ return( ( nId > 0 ) && ( nId != ( RID_GALLERYSTR_THEME_MYTHEME - RID_GALLERYSTR_THEME_START ) ) ); }
+bool GalleryThemeEntry::IsDefault() const
+{
+    return ( nId > 0 ) && ( nId != ( RID_GALLERYSTR_THEME_MYTHEME - RID_GALLERYSTR_THEME_START ) );
+}
 
 /* vim:set shiftwidth=4 softtabstop=4 expandtab: */
