@@ -17,10 +17,10 @@
  *   the License at http://www.apache.org/licenses/LICENSE-2.0 .
  */
 
-#include <svx/sdr/primitive2d/sdrmeasureprimitive2d.hxx>
+#include <sdr/primitive2d/sdrmeasureprimitive2d.hxx>
 #include <svx/sdr/primitive2d/sdrdecompositiontools.hxx>
 #include <basegfx/matrix/b2dhommatrix.hxx>
-#include <svx/sdr/primitive2d/sdrtextprimitive2d.hxx>
+#include <sdr/primitive2d/sdrtextprimitive2d.hxx>
 #include <svx/sdr/attribute/sdrtextattribute.hxx>
 #include <basegfx/polygon/b2dpolypolygontools.hxx>
 #include <basegfx/tools/canvastools.hxx>
@@ -29,11 +29,10 @@
 #include <basegfx/matrix/b2dhommatrixtools.hxx>
 #include <drawinglayer/primitive2d/hiddengeometryprimitive2d.hxx>
 
-//////////////////////////////////////////////////////////////////////////////
 
 using namespace com::sun::star;
 
-//////////////////////////////////////////////////////////////////////////////
+
 
 namespace drawinglayer
 {
@@ -52,12 +51,12 @@ namespace drawinglayer
 
             aPolygon.append(rStart);
             aPolygon.append(rEnd);
+            aPolygon.transform(rObjectMatrix);
 
             if(rLineStartEnd.isDefault() || (!bLeftActive && !bRightActive))
             {
                 return createPolygonLinePrimitive(
                     aPolygon,
-                    rObjectMatrix,
                     rLineAttribute,
                     attribute::SdrLineStartEndAttribute());
             }
@@ -66,7 +65,6 @@ namespace drawinglayer
             {
                 return createPolygonLinePrimitive(
                     aPolygon,
-                    rObjectMatrix,
                     rLineAttribute,
                     rLineStartEnd);
             }
@@ -75,19 +73,20 @@ namespace drawinglayer
             const attribute::SdrLineStartEndAttribute aLineStartEnd(
                 bLeftActive ? rLineStartEnd.getStartPolyPolygon() : aEmpty, bRightActive ? rLineStartEnd.getEndPolyPolygon() : aEmpty,
                 bLeftActive ? rLineStartEnd.getStartWidth() : 0.0, bRightActive ? rLineStartEnd.getEndWidth() : 0.0,
-                bLeftActive ? rLineStartEnd.isStartActive() : false, bRightActive ? rLineStartEnd.isEndActive() : false,
-                bLeftActive ? rLineStartEnd.isStartCentered() : false, bRightActive? rLineStartEnd.isEndCentered() : false);
+                bLeftActive && rLineStartEnd.isStartActive(), bRightActive && rLineStartEnd.isEndActive(),
+                bLeftActive && rLineStartEnd.isStartCentered(), bRightActive && rLineStartEnd.isEndCentered());
 
-            return createPolygonLinePrimitive(aPolygon, rObjectMatrix, rLineAttribute, aLineStartEnd);
+            return createPolygonLinePrimitive(
+                aPolygon,
+                rLineAttribute,
+                aLineStartEnd);
         }
 
         Primitive2DSequence SdrMeasurePrimitive2D::create2DDecomposition(const geometry::ViewInformation2D& aViewInformation) const
         {
             Primitive2DSequence aRetval;
-            SdrBlockTextPrimitive2D* pBlockText = 0;
+            css::uno::Reference<SdrBlockTextPrimitive2D> xBlockText;
             basegfx::B2DRange aTextRange;
-            double fTextX((getStart().getX() + getEnd().getX()) * 0.5);
-            double fTextY((getStart().getX() + getEnd().getX()) * 0.5);
             const basegfx::B2DVector aLine(getEnd() - getStart());
             const double fDistance(aLine.getLength());
             const double fAngle(atan2(aLine.getY(), aLine.getX()));
@@ -123,7 +122,7 @@ namespace drawinglayer
                 }
 
                 // create primitive and get text range
-                pBlockText = new SdrBlockTextPrimitive2D(
+                xBlockText = new SdrBlockTextPrimitive2D(
                     &rTextAttribute.getSdrText(),
                     rTextAttribute.getOutlinerParaObject(),
                     aTextMatrix,
@@ -135,10 +134,12 @@ namespace drawinglayer
                     false,
                     false);
 
-                aTextRange = pBlockText->getB2DRange(aViewInformation);
+                aTextRange = xBlockText->getB2DRange(aViewInformation);
             }
 
             // prepare line attribute and result
+            double fTextX;
+            double fTextY;
             {
                 const attribute::SdrLineAttribute rLineAttribute(getSdrLSTAttribute().getLine());
                 bool bArrowsOutside(false);
@@ -399,7 +400,7 @@ namespace drawinglayer
                 aRetval = Primitive2DSequence(&xHiddenLines, 1);
             }
 
-            if(pBlockText)
+            if(xBlockText.is())
             {
                 // create transformation to text primitive end position
                 basegfx::B2DHomMatrix aChange;
@@ -417,9 +418,9 @@ namespace drawinglayer
                 aChange *= aObjectMatrix;
 
                 // apply to existing text primitive
-                SdrTextPrimitive2D* pNewBlockText = pBlockText->createTransformedClone(aChange);
+                SdrTextPrimitive2D* pNewBlockText = xBlockText->createTransformedClone(aChange);
                 OSL_ENSURE(pNewBlockText, "SdrMeasurePrimitive2D::create2DDecomposition: Could not create transformed clone of text primitive (!)");
-                delete pBlockText;
+                xBlockText.clear();
 
                 // add to local primitives
                 appendPrimitive2DReferenceToPrimitive2DSequence(aRetval, Primitive2DReference(pNewBlockText));
@@ -471,7 +472,7 @@ namespace drawinglayer
         {
             if(BufferedDecompositionPrimitive2D::operator==(rPrimitive))
             {
-                const SdrMeasurePrimitive2D& rCompare = (SdrMeasurePrimitive2D&)rPrimitive;
+                const SdrMeasurePrimitive2D& rCompare = static_cast<const SdrMeasurePrimitive2D&>(rPrimitive);
 
                 return (getStart() == rCompare.getStart()
                     && getEnd() == rCompare.getEnd()
