@@ -17,7 +17,6 @@
  *   the License at http://www.apache.org/licenses/LICENSE-2.0 .
  */
 #include "InsertPropertyPanel.hxx"
-#include "sfx2/sidebar/CommandInfoProvider.hxx"
 
 #include <sfx2/sidebar/Theme.hxx>
 #include <sfx2/sidebar/Tools.hxx>
@@ -32,7 +31,6 @@
 #include <framework/sfxhelperfunctions.hxx>
 #include <framework/imageproducer.hxx>
 #include <comphelper/processfactory.hxx>
-#include <cppuhelper/compbase1.hxx>
 #include <cppuhelper/basemutex.hxx>
 
 #include <com/sun/star/frame/XStatusListener.hpp>
@@ -67,7 +65,7 @@ InsertPropertyPanel::InsertPropertyPanel (
     // In other words, we should find the underlying problem, and remove the
     // WindowEventListener for good.
     vcl::Window* pTopWindow = pParent;
-    while (pTopWindow->GetParent() != NULL)
+    while (pTopWindow->GetParent() != nullptr)
         pTopWindow = pTopWindow->GetParent();
     pTopWindow->AddChildEventListener(LINK(this, InsertPropertyPanel, WindowEventListener));
 }
@@ -81,7 +79,7 @@ void InsertPropertyPanel::dispose()
 {
     // Remove window child listener.
     vcl::Window* pTopWindow = this;
-    while (pTopWindow->GetParent() != NULL)
+    while (pTopWindow->GetParent() != nullptr)
         pTopWindow = pTopWindow->GetParent();
     pTopWindow->RemoveChildEventListener(LINK(this, InsertPropertyPanel, WindowEventListener));
     mpStandardShapesToolBox.clear();
@@ -92,59 +90,52 @@ void InsertPropertyPanel::dispose()
 
 
 
-IMPL_LINK(InsertPropertyPanel, WindowEventListener, VclSimpleEvent*, pEvent)
+IMPL_LINK_TYPED(InsertPropertyPanel, WindowEventListener, VclWindowEvent&, rEvent, void)
 {
     // We will be getting a lot of window events (well, basically all
     // of them), so reject early everything that is not connected to
     // toolbox selection.
-    if (pEvent == NULL)
-        return 1;
-    if ( ! pEvent->ISA(VclWindowEvent))
-        return 1;
-    if (pEvent->GetId() != VCLEVENT_TOOLBOX_SELECT)
-        return 1;
+    if (rEvent.GetId() != VCLEVENT_TOOLBOX_SELECT)
+        return;
 
-    VclWindowEvent* pWindowEvent = dynamic_cast<VclWindowEvent*>(pEvent);
-    vcl::Window* pWindow = pWindowEvent ? pWindowEvent->GetWindow() : NULL;
+    vcl::Window* pWindow = rEvent.GetWindow();
     ToolBox* pToolBox = dynamic_cast<ToolBox*>(pWindow);
-    if (pToolBox == NULL)
-        return 1;
+    if (pToolBox == nullptr)
+        return;
 
     // Extract name of (sub)toolbar from help id.
     OUString sToolbarName (rtl::OStringToOUString(pToolBox->GetHelpId(), RTL_TEXTENCODING_UTF8));
     if (sToolbarName.getLength() == 0)
-        return 1;
+        return;
     const util::URL aURL (sfx2::sidebar::Tools::GetURL(sToolbarName));
     if (aURL.Path.getLength() == 0)
-        return 1;
+        return;
 
     // Get item id.
     sal_uInt16 nId = pToolBox->GetCurItemId();
     if (nId == 0)
-        return 1;
+        return;
 
     SidebarToolBox* pSidebarToolBox = dynamic_cast<SidebarToolBox*>(mpStandardShapesToolBox.get());
-    if (pSidebarToolBox == NULL)
-        return 1;
+    if (pSidebarToolBox == nullptr)
+        return;
     sal_uInt16 nItemId (pSidebarToolBox->GetItemIdForSubToolbarName(aURL.Path));
     if (nItemId == 0)
     {
         pSidebarToolBox = dynamic_cast<SidebarToolBox*>(mpCustomShapesToolBox.get());
-        if (pSidebarToolBox == NULL)
-            return 1;
+        if (pSidebarToolBox == nullptr)
+            return;
         nItemId = pSidebarToolBox->GetItemIdForSubToolbarName(aURL.Path);
         if (nItemId == 0)
-            return 1;
+            return;
     }
 
-    Reference<frame::XSubToolbarController> xController (pSidebarToolBox->GetControllerForItemId(nItemId), UNO_QUERY);
+    Reference<css::frame::XSubToolbarController> xController (pSidebarToolBox->GetControllerForItemId(nItemId), UNO_QUERY);
     if ( ! xController.is() )
-        return 1;
+        return;
 
     const OUString sCommand (pToolBox->GetItemCommand(nId));
     xController->functionSelected(sCommand);
-
-    return 1;
 }
 
 
