@@ -25,7 +25,7 @@
 #include <svx/svdopath.hxx>
 #include <svx/svdundo.hxx>
 #include "svx/svdstr.hrc"
-#include "svx/svdglob.hxx"
+#include "svdglob.hxx"
 #include <svx/svdtrans.hxx>
 #include <basegfx/polygon/b2dpolygon.hxx>
 #include <basegfx/polygon/b2dpolygontools.hxx>
@@ -35,14 +35,14 @@
 
 using namespace sdr;
 
-////////////////////////////////////////////////////////////////////////////////////////////////////
+
 
 void SdrPolyEditView::ImpResetPolyPossibilityFlags()
 {
     eMarkedPointsSmooth=SDRPATHSMOOTH_DONTCARE;
     eMarkedSegmentsKind=SDRPATHSEGMENT_DONTCARE;
-    bSetMarkedPointsSmoothPossible=sal_False;
-    bSetMarkedSegmentsKindPossible=sal_False;
+    bSetMarkedPointsSmoothPossible=false;
+    bSetMarkedSegmentsKindPossible=false;
 }
 
 void SdrPolyEditView::ImpClearVars()
@@ -63,18 +63,18 @@ SdrPolyEditView::~SdrPolyEditView()
 void SdrPolyEditView::ImpCheckPolyPossibilities()
 {
     ImpResetPolyPossibilityFlags();
-    const sal_uIntPtr nMarkAnz(GetMarkedObjectCount());
+    const size_t nMarkCount(GetMarkedObjectCount());
 
-    if(nMarkAnz && !ImpIsFrameHandles())
+    if(nMarkCount && !ImpIsFrameHandles())
     {
         bool b1stSmooth(true);
         bool b1stSegm(true);
         bool bCurve(false);
         bool bSmoothFuz(false);
         bool bSegmFuz(false);
-        basegfx::B2VectorContinuity eSmooth = basegfx::CONTINUITY_NONE;
+        basegfx::B2VectorContinuity eSmooth = basegfx::B2VectorContinuity::NONE;
 
-        for(sal_uIntPtr nMarkNum(0L); nMarkNum < nMarkAnz; nMarkNum++)
+        for(size_t nMarkNum = 0; nMarkNum < nMarkCount; ++nMarkNum)
         {
             SdrMark* pM = GetSdrMarkByIndex(nMarkNum);
             CheckPolyPossibilitiesHelper( pM, b1stSmooth, b1stSegm, bCurve, bSmoothFuz, bSegmFuz, eSmooth );
@@ -86,7 +86,7 @@ void SdrPolyEditView::CheckPolyPossibilitiesHelper( SdrMark* pM, bool& b1stSmoot
 {
     SdrObject* pObj = pM->GetMarkedSdrObj();
     SdrUShortCont* pPts = pM->GetMarkedPoints();
-    SdrPathObj* pPath = PTR_CAST(SdrPathObj,pObj);
+    SdrPathObj* pPath = dynamic_cast<SdrPathObj*>( pObj );
 
     if(pPath && pPts)
     {
@@ -152,17 +152,17 @@ void SdrPolyEditView::CheckPolyPossibilitiesHelper( SdrMark* pM, bool& b1stSmoot
 
             if(!b1stSmooth && !bSmoothFuz)
             {
-                if(basegfx::CONTINUITY_NONE == eSmooth)
+                if(basegfx::B2VectorContinuity::NONE == eSmooth)
                 {
                     eMarkedPointsSmooth = SDRPATHSMOOTH_ANGULAR;
                 }
 
-                if(basegfx::CONTINUITY_C1 == eSmooth)
+                if(basegfx::B2VectorContinuity::C1 == eSmooth)
                 {
                     eMarkedPointsSmooth = SDRPATHSMOOTH_ASYMMETRIC;
                 }
 
-                if(basegfx::CONTINUITY_C2 == eSmooth)
+                if(basegfx::B2VectorContinuity::C2 == eSmooth)
                 {
                     eMarkedPointsSmooth = SDRPATHSMOOTH_SYMMETRIC;
                 }
@@ -182,15 +182,15 @@ void SdrPolyEditView::SetMarkedPointsSmooth(SdrPathSmoothKind eKind)
 
     if(SDRPATHSMOOTH_ANGULAR == eKind)
     {
-        eFlags = basegfx::CONTINUITY_NONE;
+        eFlags = basegfx::B2VectorContinuity::NONE;
     }
     else if(SDRPATHSMOOTH_ASYMMETRIC == eKind)
     {
-        eFlags = basegfx::CONTINUITY_C1;
+        eFlags = basegfx::B2VectorContinuity::C1;
     }
     else if(SDRPATHSMOOTH_SYMMETRIC == eKind)
     {
-        eFlags = basegfx::CONTINUITY_C2;
+        eFlags = basegfx::B2VectorContinuity::C2;
     }
     else
     {
@@ -204,11 +204,11 @@ void SdrPolyEditView::SetMarkedPointsSmooth(SdrPathSmoothKind eKind)
         const bool bUndo = IsUndoEnabled();
         if( bUndo )
             BegUndo(ImpGetResStr(STR_EditSetPointsSmooth), GetDescriptionOfMarkedPoints());
-        sal_uIntPtr nMarkAnz(GetMarkedObjectCount());
+        const size_t nMarkCount(GetMarkedObjectCount());
 
-        for(sal_uIntPtr nMarkNum(nMarkAnz); nMarkNum > 0L;)
+        for(size_t nMarkNum(nMarkCount); nMarkNum > 0;)
         {
-            nMarkNum--;
+            --nMarkNum;
             SdrMark* pM = GetSdrMarkByIndex(nMarkNum);
             SdrUShortCont* pPts = pM->GetMarkedPoints();
             SdrPathObj* pPath = dynamic_cast< SdrPathObj* >( pM->GetMarkedSdrObj() );
@@ -239,11 +239,11 @@ void SdrPolyEditView::SetMarkedSegmentsKind(SdrPathSegmentKind eKind)
         const bool bUndo = IsUndoEnabled();
         if( bUndo )
             BegUndo(ImpGetResStr(STR_EditSetSegmentsKind), GetDescriptionOfMarkedPoints());
-        sal_uIntPtr nMarkAnz(GetMarkedObjectCount());
+        const size_t nMarkCount(GetMarkedObjectCount());
 
-        for(sal_uIntPtr nMarkNum(nMarkAnz); nMarkNum > 0L;)
+        for(size_t nMarkNum=nMarkCount; nMarkNum > 0;)
         {
-            nMarkNum--;
+            --nMarkNum;
             SdrMark* pM = GetSdrMarkByIndex(nMarkNum);
             SdrUShortCont* pPts = pM->GetMarkedPoints();
             SdrPathObj* pPath = dynamic_cast< SdrPathObj* >( pM->GetMarkedSdrObj() );
@@ -265,7 +265,7 @@ void SdrPolyEditView::SetMarkedSegmentsKind(SdrPathSegmentKind eKind)
     }
 }
 
-sal_Bool SdrPolyEditView::IsSetMarkedPointsSmoothPossible() const
+bool SdrPolyEditView::IsSetMarkedPointsSmoothPossible() const
 {
     ForcePossibilities();
     return bSetMarkedPointsSmoothPossible;
@@ -277,7 +277,7 @@ SdrPathSmoothKind SdrPolyEditView::GetMarkedPointsSmooth() const
     return eMarkedPointsSmooth;
 }
 
-sal_Bool SdrPolyEditView::IsSetMarkedSegmentsKindPossible() const
+bool SdrPolyEditView::IsSetMarkedSegmentsKindPossible() const
 {
     ForcePossibilities();
     return bSetMarkedSegmentsKindPossible;
@@ -289,7 +289,7 @@ SdrPathSegmentKind SdrPolyEditView::GetMarkedSegmentsKind() const
     return eMarkedSegmentsKind;
 }
 
-sal_Bool SdrPolyEditView::IsDeleteMarkedPointsPossible() const
+bool SdrPolyEditView::IsDeleteMarkedPointsPossible() const
 {
     return HasMarkedPoints();
 }
@@ -300,7 +300,7 @@ void SdrPolyEditView::DeleteMarkedPoints()
     {
         BrkAction();
         SortMarkedObjects();
-        sal_uIntPtr nMarkAnz=GetMarkedObjectCount();
+        const size_t nMarkCount=GetMarkedObjectCount();
 
         const bool bUndo = IsUndoEnabled();
         if( bUndo )
@@ -309,9 +309,9 @@ void SdrPolyEditView::DeleteMarkedPoints()
             BegUndo(ImpGetResStr(STR_EditDelete),GetDescriptionOfMarkedPoints(),SDRREPFUNC_OBJ_DELETE);
         }
 
-        for (sal_uIntPtr nMarkNum=nMarkAnz; nMarkNum>0;)
+        for (size_t nMarkNum=nMarkCount; nMarkNum>0;)
         {
-            nMarkNum--;
+            --nMarkNum;
             SdrMark* pM=GetSdrMarkByIndex(nMarkNum);
             SdrUShortCont* pPts=pM->GetMarkedPoints();
             SdrPathObj* pPath = dynamic_cast< SdrPathObj* >( pM->GetMarkedSdrObj() );
@@ -354,18 +354,18 @@ void SdrPolyEditView::RipUpAtMarkedPoints()
     if(HasMarkedPoints())
     {
         SortMarkedObjects();
-        sal_uInt32 nMarkAnz(GetMarkedObjectCount());
+        const size_t nMarkCount(GetMarkedObjectCount());
 
         const bool bUndo = IsUndoEnabled();
         if( bUndo )
             BegUndo(ImpGetResStr(STR_EditRipUp), GetDescriptionOfMarkedPoints());
 
-        for(sal_uInt32 nMarkNum(nMarkAnz); nMarkNum > 0L;)
+        for(size_t nMarkNum = nMarkCount; nMarkNum > 0;)
         {
-            nMarkNum--;
+            --nMarkNum;
             SdrMark* pM = GetSdrMarkByIndex(nMarkNum);
             SdrUShortCont* pPts = pM->GetMarkedPoints();
-            SdrPathObj* pObj = PTR_CAST(SdrPathObj, pM->GetMarkedSdrObj());
+            SdrPathObj* pObj = dynamic_cast<SdrPathObj*>( pM->GetMarkedSdrObj() );
 
             if(pPts && pObj)
             {
@@ -381,17 +381,17 @@ void SdrPolyEditView::RipUpAtMarkedPoints()
 
                     if(pNeuObj)
                     {
-                        SdrInsertReason aReason(SDRREASON_VIEWCALL, pObj);
+                        SdrInsertReason aReason(SDRREASON_VIEWCALL);
                         pM->GetPageView()->GetObjList()->InsertObject(pNeuObj, pObj->GetOrdNum() + 1, &aReason);
                         if( bUndo )
                             AddUndo(GetModel()->GetSdrUndoFactory().CreateUndoNewObject(*pNeuObj));
-                        MarkObj(pNeuObj, pM->GetPageView(), sal_False, sal_True);
+                        MarkObj(pNeuObj, pM->GetPageView(), false, true);
                     }
 
                     if(nNewPt0Idx)
                     {
                         // correction necessary?
-                        DBG_ASSERT(bKorregFlag==false,"Multiple index corrections at SdrPolyEditView::RipUp().");
+                        DBG_ASSERT(!bKorregFlag,"Multiple index corrections at SdrPolyEditView::RipUp().");
                         if(!bKorregFlag)
                         {
                             bKorregFlag = true;
@@ -428,9 +428,9 @@ void SdrPolyEditView::RipUpAtMarkedPoints()
 bool SdrPolyEditView::IsRipUpAtMarkedPointsPossible() const
 {
     bool bRetval(false);
-    const sal_uInt32 nMarkCount(GetMarkedObjectCount());
+    const size_t nMarkCount(GetMarkedObjectCount());
 
-    for(sal_uInt32 a(0); a < nMarkCount; a++)
+    for(size_t a = 0; a < nMarkCount; ++a)
     {
         const SdrMark* pMark = GetSdrMarkByIndex(a);
         const SdrPathObj* pMarkedPathObject = dynamic_cast< const SdrPathObj* >(pMark->GetMarkedSdrObj());
@@ -447,7 +447,7 @@ bool SdrPolyEditView::IsRipUpAtMarkedPointsPossible() const
                 {
                     // #i76617# Do not yet use basegfx::B2DPolygon since curve definitions
                     // are different and methods need to be changed thoroughly with interaction rework
-                    const Polygon aPathPolygon(rPathPolyPolygon.getB2DPolygon(0));
+                    const tools::Polygon aPathPolygon(rPathPolyPolygon.getB2DPolygon(0));
                     const sal_uInt16 nPointCount(aPathPolygon.GetSize());
 
                     if(nPointCount >= 3)
@@ -473,9 +473,9 @@ bool SdrPolyEditView::IsRipUpAtMarkedPointsPossible() const
 bool SdrPolyEditView::IsOpenCloseMarkedObjectsPossible() const
 {
     bool bRetval(false);
-    const sal_uInt32 nMarkCount(GetMarkedObjectCount());
+    const size_t nMarkCount(GetMarkedObjectCount());
 
-    for(sal_uInt32 a(0); a < nMarkCount; a++)
+    for(size_t a = 0; a < nMarkCount; ++a)
     {
         const SdrMark* pMark = GetSdrMarkByIndex(a);
         const SdrPathObj* pMarkedPathObject = dynamic_cast< const SdrPathObj* >(pMark->GetMarkedSdrObj());
@@ -484,12 +484,12 @@ bool SdrPolyEditView::IsOpenCloseMarkedObjectsPossible() const
         {
             // #i76617# Do not yet use basegfx::B2DPolygon since curve definitions
             // are different and methods need to be changed thoroughly with interaction rework
-            const PolyPolygon aPathPolyPolygon(pMarkedPathObject->GetPathPoly());
+            const tools::PolyPolygon aPathPolyPolygon(pMarkedPathObject->GetPathPoly());
             const sal_uInt16 nPolygonCount(aPathPolyPolygon.Count());
 
             for(sal_uInt16 b(0); !bRetval && b < nPolygonCount; b++)
             {
-                const Polygon& rPathPolygon = aPathPolyPolygon[b];
+                const tools::Polygon& rPathPolygon = aPathPolyPolygon[b];
                 const sal_uInt16 nPointCount(rPathPolygon.GetSize());
 
                 bRetval = (nPointCount >= 3);
@@ -504,9 +504,9 @@ SdrObjClosedKind SdrPolyEditView::GetMarkedObjectsClosedState() const
 {
     bool bOpen(false);
     bool bClosed(false);
-    const sal_uInt32 nMarkCount(GetMarkedObjectCount());
+    const size_t nMarkCount(GetMarkedObjectCount());
 
-    for(sal_uInt32 a(0); !(bOpen && bClosed) && a < nMarkCount; a++)
+    for(size_t a = 0; !(bOpen && bClosed) && a < nMarkCount; ++a)
     {
         const SdrMark* pMark = GetSdrMarkByIndex(a);
         const SdrPathObj* pMarkedPathObject = dynamic_cast< const SdrPathObj* >(pMark->GetMarkedSdrObj());
@@ -538,59 +538,19 @@ SdrObjClosedKind SdrPolyEditView::GetMarkedObjectsClosedState() const
     }
 }
 
-void SdrPolyEditView::CloseMarkedObjects(sal_Bool bToggle, sal_Bool bOpen)
-{
-    if (AreObjectsMarked())
-    {
-        const bool bUndo = IsUndoEnabled();
-        if( bUndo )
-            BegUndo(ImpGetResStr(STR_EditShut),GetDescriptionOfMarkedPoints());
-
-        bool bChg=false;
-        sal_uIntPtr nMarkAnz=GetMarkedObjectCount();
-        for (sal_uIntPtr nm=0; nm<nMarkAnz; nm++)
-        {
-            SdrMark* pM=GetSdrMarkByIndex(nm);
-            SdrObject* pO=pM->GetMarkedSdrObj();
-            sal_Bool bClosed=pO->IsClosedObj();
-            if ((pO->IsPolyObj() && (bClosed==bOpen)) || bToggle)
-            {
-                if( bUndo )
-                    AddUndo(GetModel()->GetSdrUndoFactory().CreateUndoGeoObject(*pO));
-
-                SdrPathObj* pPathObj = dynamic_cast< SdrPathObj* >( pO );
-                if(pPathObj)
-                    pPathObj->ToggleClosed();
-                bChg=true;
-            }
-        }
-
-        if( bUndo )
-            EndUndo();
-
-        if (bChg)
-        {
-            UnmarkAllPoints();
-            MarkListHasChanged();
-        }
-    }
-}
-
-////////////////////////////////////////////////////////////////////////////////////////////////////
-
 void SdrPolyEditView::ImpTransformMarkedPoints(PPolyTrFunc pTrFunc, const void* p1, const void* p2, const void* p3, const void* p4, const void* p5)
 {
     const bool bUndo = IsUndoEnabled();
 
-    sal_uIntPtr nMarkAnz=GetMarkedObjectCount();
-    for (sal_uIntPtr nm=0; nm<nMarkAnz; nm++)
+    const size_t nMarkCount=GetMarkedObjectCount();
+    for (size_t nm=0; nm<nMarkCount; ++nm)
     {
         SdrMark* pM=GetSdrMarkByIndex(nm);
         SdrObject* pObj=pM->GetMarkedSdrObj();
         const SdrUShortCont* pPts=pM->GetMarkedPoints();
-        sal_uIntPtr nPtAnz=pPts==NULL ? 0 : pPts->size();
-        SdrPathObj* pPath=PTR_CAST(SdrPathObj,pObj);
-        if (nPtAnz!=0 && pPath!=NULL)
+        sal_uIntPtr nPointCount=pPts==nullptr ? 0 : pPts->size();
+        SdrPathObj* pPath=dynamic_cast<SdrPathObj*>( pObj );
+        if (nPointCount!=0 && pPath!=nullptr)
         {
             if( bUndo )
                 AddUndo(GetModel()->GetSdrUndoFactory().CreateUndoGeoObject(*pObj));
@@ -651,67 +611,57 @@ void SdrPolyEditView::ImpTransformMarkedPoints(PPolyTrFunc pTrFunc, const void*
     }
 }
 
-////////////////////////////////////////////////////////////////////////////////////////////////////
+
 
 static void ImpMove(Point& rPt, Point* pC1, Point* pC2, const void* p1, const void* /*p2*/, const void* /*p3*/, const void* /*p4*/, const void* /*p5*/)
 {
-    MovePoint(rPt,*(const Size*)p1);
-    if (pC1!=NULL) MovePoint(*pC1,*(const Size*)p1);
-    if (pC2!=NULL) MovePoint(*pC2,*(const Size*)p1);
+    MovePoint(rPt,*static_cast<const Size*>(p1));
+    if (pC1!=nullptr) MovePoint(*pC1,*static_cast<const Size*>(p1));
+    if (pC2!=nullptr) MovePoint(*pC2,*static_cast<const Size*>(p1));
 }
 
-void SdrPolyEditView::MoveMarkedPoints(const Size& rSiz, bool bCopy)
+void SdrPolyEditView::MoveMarkedPoints(const Size& rSiz)
 {
-    bCopy=sal_False; // TODO: not yet implemented
     ForceUndirtyMrkPnt();
     OUString aStr(ImpGetResStr(STR_EditMove));
-    if (bCopy) aStr+=ImpGetResStr(STR_EditWithCopy);
     BegUndo(aStr,GetDescriptionOfMarkedPoints(),SDRREPFUNC_OBJ_MOVE);
     ImpTransformMarkedPoints(ImpMove,&rSiz);
     EndUndo();
     AdjustMarkHdl();
 }
 
-////////////////////////////////////////////////////////////////////////////////////////////////////
-
 static void ImpResize(Point& rPt, Point* pC1, Point* pC2, const void* p1, const void* p2, const void* p3, const void* /*p4*/, const void* /*p5*/)
 {
-    ResizePoint(rPt,*(const Point*)p1,*(const Fraction*)p2,*(const Fraction*)p3);
-    if (pC1!=NULL) ResizePoint(*pC1,*(const Point*)p1,*(const Fraction*)p2,*(const Fraction*)p3);
-    if (pC2!=NULL) ResizePoint(*pC2,*(const Point*)p1,*(const Fraction*)p2,*(const Fraction*)p3);
+    ResizePoint(rPt,*static_cast<const Point*>(p1),*static_cast<const Fraction*>(p2),*static_cast<const Fraction*>(p3));
+    if (pC1!=nullptr) ResizePoint(*pC1,*static_cast<const Point*>(p1),*static_cast<const Fraction*>(p2),*static_cast<const Fraction*>(p3));
+    if (pC2!=nullptr) ResizePoint(*pC2,*static_cast<const Point*>(p1),*static_cast<const Fraction*>(p2),*static_cast<const Fraction*>(p3));
 }
 
-void SdrPolyEditView::ResizeMarkedPoints(const Point& rRef, const Fraction& xFact, const Fraction& yFact, bool bCopy)
+void SdrPolyEditView::ResizeMarkedPoints(const Point& rRef, const Fraction& xFact, const Fraction& yFact)
 {
-    bCopy=sal_False; // TODO: not yet implemented
     ForceUndirtyMrkPnt();
     OUString aStr(ImpGetResStr(STR_EditResize));
-    if (bCopy) aStr+=ImpGetResStr(STR_EditWithCopy);
     BegUndo(aStr,GetDescriptionOfMarkedPoints(),SDRREPFUNC_OBJ_RESIZE);
     ImpTransformMarkedPoints(ImpResize,&rRef,&xFact,&yFact);
     EndUndo();
     AdjustMarkHdl();
 }
 
-////////////////////////////////////////////////////////////////////////////////////////////////////
-
 static void ImpRotate(Point& rPt, Point* pC1, Point* pC2, const void* p1, const void* /*p2*/, const void* p3, const void* p4, const void* /*p5*/)
 {
-    RotatePoint(rPt,*(const Point*)p1,*(const double*)p3,*(const double*)p4);
-    if (pC1!=NULL) RotatePoint(*pC1,*(const Point*)p1,*(const double*)p3,*(const double*)p4);
-    if (pC2!=NULL) RotatePoint(*pC2,*(const Point*)p1,*(const double*)p3,*(const double*)p4);
+    RotatePoint(rPt,*static_cast<const Point*>(p1),*static_cast<const double*>(p3),*static_cast<const double*>(p4));
+    if (pC1!=nullptr) RotatePoint(*pC1,*static_cast<const Point*>(p1),*static_cast<const double*>(p3),*static_cast<const double*>(p4));
+    if (pC2!=nullptr) RotatePoint(*pC2,*static_cast<const Point*>(p1),*static_cast<const double*>(p3),*static_cast<const double*>(p4));
 }
 
-void SdrPolyEditView::RotateMarkedPoints(const Point& rRef, long nWink, bool bCopy)
+void SdrPolyEditView::RotateMarkedPoints(const Point& rRef, long nAngle)
 {
-    bCopy=sal_False; // TODO: not yet implemented
     ForceUndirtyMrkPnt();
     OUString aStr(ImpGetResStr(STR_EditResize));
-    if (bCopy) aStr+=ImpGetResStr(STR_EditWithCopy);
     BegUndo(aStr,GetDescriptionOfMarkedPoints(),SDRREPFUNC_OBJ_ROTATE);
-    double nSin=sin(nWink*nPi180);
-    double nCos=cos(nWink*nPi180);
-    ImpTransformMarkedPoints(ImpRotate,&rRef,&nWink,&nSin,&nCos);
+    double nSin=sin(nAngle*nPi180);
+    double nCos=cos(nAngle*nPi180);
+    ImpTransformMarkedPoints(ImpRotate,&rRef,&nAngle,&nSin,&nCos);
     EndUndo();
     AdjustMarkHdl();
 }
