@@ -37,76 +37,64 @@ void ResizeRect(Rectangle& rRect, const Point& rRef, const Fraction& rxFact, con
     Fraction xFact(rxFact);
     Fraction yFact(ryFact);
 
-    {
-        if (xFact.GetDenominator()==0) {
-            long nWdt=rRect.Right()-rRect.Left();
-            if (xFact.GetNumerator()>=0) { // catch divisions by zero
-                xFact=Fraction(xFact.GetNumerator(),1);
-                if (nWdt==0) rRect.Right()++;
-            } else {
-                xFact=Fraction(xFact.GetNumerator(),-1);
-                if (nWdt==0) rRect.Left()--;
-            }
-        }
-        rRect.Left()  =rRef.X()+Round(((double)(rRect.Left()  -rRef.X())*xFact.GetNumerator())/xFact.GetDenominator());
-        rRect.Right() =rRef.X()+Round(((double)(rRect.Right() -rRef.X())*xFact.GetNumerator())/xFact.GetDenominator());
+    if (!xFact.IsValid()) {
+        SAL_WARN( "svx.svdraw", "invalid fraction xFract, using Fraction(1,1)" );
+        xFact = Fraction(1,1);
+        long nWdt = rRect.Right() - rRect.Left();
+        if (nWdt == 0) rRect.Right()++;
     }
-    {
-        if (yFact.GetDenominator()==0) {
-            long nHgt=rRect.Bottom()-rRect.Top();
-            if (yFact.GetNumerator()>=0) { // catch divisions by zero
-                yFact=Fraction(yFact.GetNumerator(),1);
-                if (nHgt==0) rRect.Bottom()++;
-            } else {
-                yFact=Fraction(yFact.GetNumerator(),-1);
-                if (nHgt==0) rRect.Top()--;
-            }
+    rRect.Left()  = rRef.X() + svx::Round( (rRect.Left()  - rRef.X()) * double(xFact) );
+    rRect.Right() = rRef.X() + svx::Round( (rRect.Right() - rRef.X()) * double(xFact) );
 
-            yFact=Fraction(yFact.GetNumerator(),1); // catch divisions by zero
-        }
-        rRect.Top()   =rRef.Y()+Round(((double)(rRect.Top()   -rRef.Y())*yFact.GetNumerator())/yFact.GetDenominator());
-        rRect.Bottom()=rRef.Y()+Round(((double)(rRect.Bottom()-rRef.Y())*yFact.GetNumerator())/yFact.GetDenominator());
+    if (!yFact.IsValid()) {
+        SAL_WARN( "svx.svdraw", "invalid fraction yFract, using Fraction(1,1)" );
+        yFact = Fraction(1,1);
+        long nHgt = rRect.Bottom() - rRect.Top();
+        if (nHgt == 0) rRect.Bottom()++;
     }
+    rRect.Top()    = rRef.Y() + svx::Round( (rRect.Top()    - rRef.Y()) * double(yFact) );
+    rRect.Bottom() = rRef.Y() + svx::Round( (rRect.Bottom() - rRef.Y()) * double(yFact) );
+
     if (!bNoJustify) rRect.Justify();
 }
 
 
-void ResizePoly(Polygon& rPoly, const Point& rRef, const Fraction& xFact, const Fraction& yFact)
+void ResizePoly(tools::Polygon& rPoly, const Point& rRef, const Fraction& xFact, const Fraction& yFact)
 {
-    sal_uInt16 nAnz=rPoly.GetSize();
-    for (sal_uInt16 i=0; i<nAnz; i++) {
+    sal_uInt16 nCount=rPoly.GetSize();
+    for (sal_uInt16 i=0; i<nCount; i++) {
         ResizePoint(rPoly[i],rRef,xFact,yFact);
     }
 }
 
 void ResizeXPoly(XPolygon& rPoly, const Point& rRef, const Fraction& xFact, const Fraction& yFact)
 {
-    sal_uInt16 nAnz=rPoly.GetPointCount();
-    for (sal_uInt16 i=0; i<nAnz; i++) {
+    sal_uInt16 nCount=rPoly.GetPointCount();
+    for (sal_uInt16 i=0; i<nCount; i++) {
         ResizePoint(rPoly[i],rRef,xFact,yFact);
     }
 }
 
-void RotatePoly(Polygon& rPoly, const Point& rRef, double sn, double cs)
+void RotatePoly(tools::Polygon& rPoly, const Point& rRef, double sn, double cs)
 {
-    sal_uInt16 nAnz=rPoly.GetSize();
-    for (sal_uInt16 i=0; i<nAnz; i++) {
+    sal_uInt16 nCount=rPoly.GetSize();
+    for (sal_uInt16 i=0; i<nCount; i++) {
         RotatePoint(rPoly[i],rRef,sn,cs);
     }
 }
 
 void RotateXPoly(XPolygon& rPoly, const Point& rRef, double sn, double cs)
 {
-    sal_uInt16 nAnz=rPoly.GetPointCount();
-    for (sal_uInt16 i=0; i<nAnz; i++) {
+    sal_uInt16 nCount=rPoly.GetPointCount();
+    for (sal_uInt16 i=0; i<nCount; i++) {
         RotatePoint(rPoly[i],rRef,sn,cs);
     }
 }
 
 void RotateXPoly(XPolyPolygon& rPoly, const Point& rRef, double sn, double cs)
 {
-    sal_uInt16 nAnz=rPoly.Count();
-    for (sal_uInt16 i=0; i<nAnz; i++) {
+    sal_uInt16 nCount=rPoly.Count();
+    for (sal_uInt16 i=0; i<nCount; i++) {
         RotateXPoly(rPoly[i],rRef,sn,cs);
     }
 }
@@ -145,34 +133,26 @@ void MirrorPoint(Point& rPnt, const Point& rRef1, const Point& rRef2)
     }
 }
 
-void MirrorPoly(Polygon& rPoly, const Point& rRef1, const Point& rRef2)
-{
-    sal_uInt16 nAnz=rPoly.GetSize();
-    for (sal_uInt16 i=0; i<nAnz; i++) {
-        MirrorPoint(rPoly[i],rRef1,rRef2);
-    }
-}
-
 void MirrorXPoly(XPolygon& rPoly, const Point& rRef1, const Point& rRef2)
 {
-    sal_uInt16 nAnz=rPoly.GetPointCount();
-    for (sal_uInt16 i=0; i<nAnz; i++) {
+    sal_uInt16 nCount=rPoly.GetPointCount();
+    for (sal_uInt16 i=0; i<nCount; i++) {
         MirrorPoint(rPoly[i],rRef1,rRef2);
     }
 }
 
-void ShearPoly(Polygon& rPoly, const Point& rRef, double tn, bool bVShear)
+void ShearPoly(tools::Polygon& rPoly, const Point& rRef, double tn, bool bVShear)
 {
-    sal_uInt16 nAnz=rPoly.GetSize();
-    for (sal_uInt16 i=0; i<nAnz; i++) {
+    sal_uInt16 nCount=rPoly.GetSize();
+    for (sal_uInt16 i=0; i<nCount; i++) {
         ShearPoint(rPoly[i],rRef,tn,bVShear);
     }
 }
 
 void ShearXPoly(XPolygon& rPoly, const Point& rRef, double tn, bool bVShear)
 {
-    sal_uInt16 nAnz=rPoly.GetPointCount();
-    for (sal_uInt16 i=0; i<nAnz; i++) {
+    sal_uInt16 nCount=rPoly.GetPointCount();
+    for (sal_uInt16 i=0; i<nCount; i++) {
         ShearPoint(rPoly[i],rRef,tn,bVShear);
     }
 }
@@ -180,8 +160,8 @@ void ShearXPoly(XPolygon& rPoly, const Point& rRef, double tn, bool bVShear)
 double CrookRotateXPoint(Point& rPnt, Point* pC1, Point* pC2, const Point& rCenter,
                          const Point& rRad, double& rSin, double& rCos, bool bVert)
 {
-    bool bC1=pC1!=NULL;
-    bool bC2=pC2!=NULL;
+    bool bC1=pC1!=nullptr;
+    bool bC2=pC2!=nullptr;
     long x0=rPnt.X();
     long y0=rPnt.Y();
     long cx=rCenter.X();
@@ -195,7 +175,7 @@ double CrookRotateXPoint(Point& rPnt, Point* pC1, Point* pC2, const Point& rCent
             // move into the direction of the center, as a basic position for the rotation
             pC1->Y()-=y0;
             // resize, account for the distance from the center
-            pC1->Y()=Round(((double)pC1->Y()) /rRad.X()*(cx-pC1->X()));
+            pC1->Y()=svx::Round(((double)pC1->Y()) /rRad.X()*(cx-pC1->X()));
             pC1->Y()+=cy;
         } else {
             // move into the direction of the center, as a basic position for the rotation
@@ -203,7 +183,7 @@ double CrookRotateXPoint(Point& rPnt, Point* pC1, Point* pC2, const Point& rCent
             // resize, account for the distance from the center
             long nPntRad=cy-pC1->Y();
             double nFact=(double)nPntRad/(double)rRad.Y();
-            pC1->X()=Round((double)pC1->X()*nFact);
+            pC1->X()=svx::Round((double)pC1->X()*nFact);
             pC1->X()+=cx;
         }
         RotatePoint(*pC1,rCenter,sn,cs);
@@ -213,7 +193,7 @@ double CrookRotateXPoint(Point& rPnt, Point* pC1, Point* pC2, const Point& rCent
             // move into the direction of the center, as a basic position for the rotation
             pC2->Y()-=y0;
             // resize, account for the distance from the center
-            pC2->Y()=Round(((double)pC2->Y()) /rRad.X()*(rCenter.X()-pC2->X()));
+            pC2->Y()=svx::Round(((double)pC2->Y()) /rRad.X()*(rCenter.X()-pC2->X()));
             pC2->Y()+=cy;
         } else {
             // move into the direction of the center, as a basic position for the rotation
@@ -221,7 +201,7 @@ double CrookRotateXPoint(Point& rPnt, Point* pC1, Point* pC2, const Point& rCent
             // resize, account for the distance from the center
             long nPntRad=rCenter.Y()-pC2->Y();
             double nFact=(double)nPntRad/(double)rRad.Y();
-            pC2->X()=Round((double)pC2->X()*nFact);
+            pC2->X()=svx::Round((double)pC2->X()*nFact);
             pC2->X()+=cx;
         }
         RotatePoint(*pC2,rCenter,sn,cs);
@@ -234,8 +214,8 @@ double CrookRotateXPoint(Point& rPnt, Point* pC1, Point* pC2, const Point& rCent
 double CrookSlantXPoint(Point& rPnt, Point* pC1, Point* pC2, const Point& rCenter,
                         const Point& rRad, double& rSin, double& rCos, bool bVert)
 {
-    bool bC1=pC1!=NULL;
-    bool bC2=pC2!=NULL;
+    bool bC1=pC1!=nullptr;
+    bool bC2=pC2!=nullptr;
     long x0=rPnt.X();
     long y0=rPnt.Y();
     long dx1=0,dy1=0;
@@ -288,7 +268,7 @@ double CrookSlantXPoint(Point& rPnt, Point* pC1, Point* pC2, const Point& rCente
 
 double CrookStretchXPoint(Point& rPnt, Point* pC1, Point* pC2, const Point& rCenter,
                           const Point& rRad, double& rSin, double& rCos, bool bVert,
-                          const Rectangle rRefRect)
+                          const Rectangle& rRefRect)
 {
     long y0=rPnt.Y();
     CrookSlantXPoint(rPnt,pC1,pC2,rCenter,rRad,rSin,rCos,bVert);
@@ -300,7 +280,7 @@ double CrookStretchXPoint(Point& rPnt, Point* pC1, Point* pC2, const Point& rCen
         long dy=rPnt.Y()-y0;
         double a=((double)(y0-nTop))/nHgt;
         a*=dy;
-        rPnt.Y()=y0+Round(a);
+        rPnt.Y()=y0+svx::Round(a);
     } return 0.0;
 }
 
@@ -313,8 +293,8 @@ void CrookRotatePoly(XPolygon& rPoly, const Point& rCenter, const Point& rRad, b
     sal_uInt16 i=0;
     while (i<nPointAnz) {
         Point* pPnt=&rPoly[i];
-        Point* pC1=NULL;
-        Point* pC2=NULL;
+        Point* pC1=nullptr;
+        Point* pC2=nullptr;
         if (i+1<nPointAnz && rPoly.IsControl(i)) { // control point to the left
             pC1=pPnt;
             i++;
@@ -336,8 +316,8 @@ void CrookSlantPoly(XPolygon& rPoly, const Point& rCenter, const Point& rRad, bo
     sal_uInt16 i=0;
     while (i<nPointAnz) {
         Point* pPnt=&rPoly[i];
-        Point* pC1=NULL;
-        Point* pC2=NULL;
+        Point* pC1=nullptr;
+        Point* pC2=nullptr;
         if (i+1<nPointAnz && rPoly.IsControl(i)) { // control point to the left
             pC1=pPnt;
             i++;
@@ -352,15 +332,15 @@ void CrookSlantPoly(XPolygon& rPoly, const Point& rCenter, const Point& rRad, bo
     }
 }
 
-void CrookStretchPoly(XPolygon& rPoly, const Point& rCenter, const Point& rRad, bool bVert, const Rectangle rRefRect)
+void CrookStretchPoly(XPolygon& rPoly, const Point& rCenter, const Point& rRad, bool bVert, const Rectangle& rRefRect)
 {
     double nSin,nCos;
     sal_uInt16 nPointAnz=rPoly.GetPointCount();
     sal_uInt16 i=0;
     while (i<nPointAnz) {
         Point* pPnt=&rPoly[i];
-        Point* pC1=NULL;
-        Point* pC2=NULL;
+        Point* pC1=nullptr;
+        Point* pC2=nullptr;
         if (i+1<nPointAnz && rPoly.IsControl(i)) { //  control point to the left
             pC1=pPnt;
             i++;
@@ -379,24 +359,24 @@ void CrookStretchPoly(XPolygon& rPoly, const Point& rCenter, const Point& rRad,
 
 void CrookRotatePoly(XPolyPolygon& rPoly, const Point& rCenter, const Point& rRad, bool bVert)
 {
-    sal_uInt16 nPolyAnz=rPoly.Count();
-    for (sal_uInt16 nPolyNum=0; nPolyNum<nPolyAnz; nPolyNum++) {
+    sal_uInt16 nPolyCount=rPoly.Count();
+    for (sal_uInt16 nPolyNum=0; nPolyNum<nPolyCount; nPolyNum++) {
         CrookRotatePoly(rPoly[nPolyNum],rCenter,rRad,bVert);
     }
 }
 
 void CrookSlantPoly(XPolyPolygon& rPoly, const Point& rCenter, const Point& rRad, bool bVert)
 {
-    sal_uInt16 nPolyAnz=rPoly.Count();
-    for (sal_uInt16 nPolyNum=0; nPolyNum<nPolyAnz; nPolyNum++) {
+    sal_uInt16 nPolyCount=rPoly.Count();
+    for (sal_uInt16 nPolyNum=0; nPolyNum<nPolyCount; nPolyNum++) {
         CrookSlantPoly(rPoly[nPolyNum],rCenter,rRad,bVert);
     }
 }
 
-void CrookStretchPoly(XPolyPolygon& rPoly, const Point& rCenter, const Point& rRad, bool bVert, const Rectangle rRefRect)
+void CrookStretchPoly(XPolyPolygon& rPoly, const Point& rCenter, const Point& rRad, bool bVert, const Rectangle& rRefRect)
 {
-    sal_uInt16 nPolyAnz=rPoly.Count();
-    for (sal_uInt16 nPolyNum=0; nPolyNum<nPolyAnz; nPolyNum++) {
+    sal_uInt16 nPolyCount=rPoly.Count();
+    for (sal_uInt16 nPolyNum=0; nPolyNum<nPolyCount; nPolyNum++) {
         CrookStretchPoly(rPoly[nPolyNum],rCenter,rRad,bVert,rRefRect);
     }
 }
@@ -412,7 +392,7 @@ long GetAngle(const Point& rPnt)
         if (rPnt.Y()>0) a=-9000;
         else a=9000;
     } else {
-        a=Round((atan2((double)-rPnt.Y(),(double)rPnt.X())/nPi180));
+        a=svx::Round((atan2((double)-rPnt.Y(),(double)rPnt.X())/nPi180));
     }
     return a;
 }
@@ -449,7 +429,7 @@ long GetLen(const Point& rPnt)
         x*=x;
         y*=y;
         x+=y;
-        x=Round(sqrt((double)x));
+        x=svx::Round(sqrt((double)x));
         return x;
     } else {
         double nx=x;
@@ -461,7 +441,7 @@ long GetLen(const Point& rPnt)
         if (nx>0x7FFFFFFF) {
             return 0x7FFFFFFF; // we can't go any further, for fear of an overrun!
         } else {
-            return Round(nx);
+            return svx::Round(nx);
         }
     }
 }
@@ -492,9 +472,9 @@ void GeoStat::RecalcTan()
 
 
 
-Polygon Rect2Poly(const Rectangle& rRect, const GeoStat& rGeo)
+tools::Polygon Rect2Poly(const Rectangle& rRect, const GeoStat& rGeo)
 {
-    Polygon aPol(5);
+    tools::Polygon aPol(5);
     aPol[0]=rRect.TopLeft();
     aPol[1]=rRect.TopRight();
     aPol[2]=rRect.BottomRight();
@@ -505,7 +485,7 @@ Polygon Rect2Poly(const Rectangle& rRect, const GeoStat& rGeo)
     return aPol;
 }
 
-void Poly2Rect(const Polygon& rPol, Rectangle& rRect, GeoStat& rGeo)
+void Poly2Rect(const tools::Polygon& rPol, Rectangle& rRect, GeoStat& rGeo)
 {
     rGeo.nRotationAngle=GetAngle(rPol[1]-rPol[0]);
     rGeo.nRotationAngle=NormAngle360(rGeo.nRotationAngle);
@@ -596,39 +576,6 @@ long BigMulDiv(long nVal, long nMul, long nDiv)
     return 0x7fffffff;
 }
 
-void Kuerzen(Fraction& rF, unsigned nDigits)
-{
-    sal_Int32 nMul=rF.GetNumerator();
-    sal_Int32 nDiv=rF.GetDenominator();
-    bool bNeg = false;
-    if (nMul<0) { nMul=-nMul; bNeg=!bNeg; }
-    if (nDiv<0) { nDiv=-nDiv; bNeg=!bNeg; }
-    if (nMul==0 || nDiv==0) return;
-    sal_uInt32 a;
-    a=sal_uInt32(nMul); unsigned nMulZ=0; // count leading zeros
-    while (a<0x00800000) { nMulZ+=8; a<<=8; }
-    while (a<0x80000000) { nMulZ++; a<<=1; }
-    a=sal_uInt32(nDiv); unsigned nDivZ=0; // count leading zeros
-    while (a<0x00800000) { nDivZ+=8; a<<=8; }
-    while (a<0x80000000) { nDivZ++; a<<=1; }
-    // count the number of digits
-    int nMulDigits=32-nMulZ;
-    int nDivDigits=32-nDivZ;
-    // count how many decimal places can be removed
-    int nMulWeg=nMulDigits-nDigits; if (nMulWeg<0) nMulWeg=0;
-    int nDivWeg=nDivDigits-nDigits; if (nDivWeg<0) nDivWeg=0;
-    int nWeg=std::min(nMulWeg,nDivWeg);
-    nMul>>=nWeg;
-    nDiv>>=nWeg;
-    if (nMul==0 || nDiv==0) {
-        DBG_WARNING("Math error after canceling decimal places.");
-        return;
-    }
-    if (bNeg) nMul=-nMul;
-    rF=Fraction(nMul,nDiv);
-}
-
-
 // How many eU units fit into a mm, respectively an inch?
 // Or: How many mm, respectively inches, are there in an eU (and then give me the inverse)
 
@@ -646,17 +593,17 @@ FrPair GetInchOrMM(MapUnit eU)
         case MAP_MM         : return FrPair(   1,1);
         case MAP_CM         : return FrPair(   1,10);
         case MAP_PIXEL      : {
-            VirtualDevice aVD;
-            aVD.SetMapMode(MapMode(MAP_100TH_MM));
-            Point aP(aVD.PixelToLogic(Point(64,64))); // 64 pixels for more accuracy
+            ScopedVclPtrInstance< VirtualDevice > pVD;
+            pVD->SetMapMode(MapMode(MAP_100TH_MM));
+            Point aP(pVD->PixelToLogic(Point(64,64))); // 64 pixels for more accuracy
             return FrPair(6400,aP.X(),6400,aP.Y());
         }
         case MAP_APPFONT: case MAP_SYSFONT: {
-            VirtualDevice aVD;
-            aVD.SetMapMode(MapMode(eU));
-            Point aP(aVD.LogicToPixel(Point(32,32))); // 32 units for more accuracy
-            aVD.SetMapMode(MapMode(MAP_100TH_MM));
-            aP=aVD.PixelToLogic(aP);
+            ScopedVclPtrInstance< VirtualDevice > pVD;
+            pVD->SetMapMode(MapMode(eU));
+            Point aP(pVD->LogicToPixel(Point(32,32))); // 32 units for more accuracy
+            pVD->SetMapMode(MapMode(MAP_100TH_MM));
+            aP=pVD->PixelToLogic(aP);
             return FrPair(3200,aP.X(),3200,aP.Y());
         }
         default: break;
@@ -870,16 +817,16 @@ void SdrFormatter::TakeStr(long nVal, OUString& rStr) const
     if(nC > 0 && aStr.getLength() <= nC )
     {
         // decimal separator necessary
-        sal_Int32 nAnz(nC - aStr.getLength());
+        sal_Int32 nCount(nC - aStr.getLength());
 
-        if(nAnz >= 0 && rLoc.isNumLeadingZero())
-            nAnz++;
+        if(nCount >= 0 && LocaleDataWrapper::isNumLeadingZero())
+            nCount++;
 
-        for(sal_Int32  i=0; i<nAnz; i++)
+        for(sal_Int32  i=0; i<nCount; i++)
             aStr.insert(0, aNullCode);
 
         // remove superfluous decimal points
-        sal_Int32 nNumDigits(rLoc.getNumDigits());
+        sal_Int32 nNumDigits(LocaleDataWrapper::getNumDigits());
         sal_Int32 nWeg(nC - nNumDigits);
 
         if(nWeg > 0)
