@@ -205,6 +205,8 @@ public:
     CellPos maEditPos;
     TableStyleSettings maTableStyle;
     Reference< XIndexAccess > mxTableStyle;
+    std::vector<std::unique_ptr<SdrUndoAction>> maUndos;
+    bool mbSkipChangeLayout;
 
     void SetModel(SdrModel* pOldModel, SdrModel* pNewModel);
 
@@ -261,6 +263,7 @@ sal_Int32 SdrTableObjImpl::lastColCount;
 SdrTableObjImpl::SdrTableObjImpl()
 : mpTableObj( nullptr )
 , mpLayouter( nullptr )
+, mbSkipChangeLayout(false)
 {
 }
 
@@ -1860,7 +1863,14 @@ void SdrTableObj::EndTextEdit(SdrOutliner& rOutl)
     if(rOutl.IsModified())
     {
         if( GetModel() && GetModel()->IsUndoEnabled() )
+        {
+            // These actions should be on the undo stack after text edit.
+            for (std::unique_ptr<SdrUndoAction>& pAction : mpImpl->maUndos)
+                GetModel()->AddUndo(pAction.release());
+            mpImpl->maUndos.clear();
+
             GetModel()->AddUndo( GetModel()->GetSdrUndoFactory().CreateUndoGeoObject(*this) );
+        }
 
         OutlinerParaObject* pNewText = nullptr;
         Paragraph* p1stPara = rOutl.GetParagraph( 0 );
@@ -1942,7 +1952,11 @@ void SdrTableObj::NbcSetLogicRect(const Rectangle& rRect)
     const bool bWidth = maLogicRect.getWidth() != maRect.getWidth();
     const bool bHeight = maLogicRect.getHeight() != maRect.getHeight();
     maRect = maLogicRect;
-    NbcAdjustTextFrameWidthAndHeight( !bHeight, !bWidth );
+    if (mpImpl->mbSkipChangeLayout)
+        // Avoid distributing newly available space between existing cells.
+        NbcAdjustTextFrameWidthAndHeight();
+    else
+        NbcAdjustTextFrameWidthAndHeight(!bHeight, !bWidth);
     SetRectsDirty();
 }
 
@@ -2085,6 +2099,15 @@ WritingMode SdrTableObj::GetWritingMode() const
     return eWritingMode;
 }
 
+void SdrTableObj::AddUndo(SdrUndoAction* pUndo)
+{
+    mpImpl->maUndos.push_back(std::unique_ptr<SdrUndoAction>(pUndo));
+}
+
+void SdrTableObj::SetSkipChangeLayout(bool bSkipChangeLayout)
+{
+    mpImpl->mbSkipChangeLayout = bSkipChangeLayout;
+}
 
 
 // gets base transformation and rectangle of object. If it's an SdrPathObj it fills the PolyPolygon
@@ -2329,6 +2352,7 @@ bool SdrTableObj::applySpecialDrag(SdrDragStat& rDrag)
                 if( GetModel() && IsInserted() )
                 {
                     rDrag.SetEndDragChangesAttributes(true);
+                    rDrag.SetEndDragChangesLayout(true);
                 }
 
                 mpImpl->DragEdge( pEdgeHdl->IsHorizontalEdge(), pEdgeHdl->GetPointNum(), pEdgeHdl->GetValidDragOffset( rDrag ) );
