@@ -18,7 +18,7 @@
  */
 
 
-#include "svx/sdr/properties/textproperties.hxx"
+#include "sdr/properties/textproperties.hxx"
 #include "editeng/outlobj.hxx"
 
 #include "cell.hxx"
@@ -28,12 +28,12 @@
 #include "tablecolumn.hxx"
 
 
-// -----------------------------------------------------------------------------
+
 
 using namespace ::com::sun::star::uno;
 using namespace ::com::sun::star::table;
 
-// -----------------------------------------------------------------------------
+
 
 namespace sdr { namespace table {
 
@@ -61,13 +61,13 @@ void CellUndo::dispose()
 {
     mxCell.clear();
     delete maUndoData.mpProperties;
-    maUndoData.mpProperties = 0;
+    maUndoData.mpProperties = nullptr;
     delete maRedoData.mpProperties;
-    maRedoData.mpProperties = 0;
+    maRedoData.mpProperties = nullptr;
     delete maUndoData.mpOutlinerParaObject;
-    maUndoData.mpOutlinerParaObject = 0;
+    maUndoData.mpOutlinerParaObject = nullptr;
     delete maRedoData.mpOutlinerParaObject;
-    maRedoData.mpOutlinerParaObject = 0;
+    maRedoData.mpOutlinerParaObject = nullptr;
 }
 
 void CellUndo::ObjectInDestruction(const SdrObject& )
@@ -79,7 +79,7 @@ void CellUndo::Undo()
 {
     if( mxCell.is() && mbUndo )
     {
-        if( maRedoData.mpProperties == 0 )
+        if( maRedoData.mpProperties == nullptr )
             getDataFromCell( maRedoData );
 
         setDataToCell( maUndoData );
@@ -115,7 +115,7 @@ void CellUndo::setDataToCell( const Data& rData )
     if( rData.mpProperties )
         mxCell->mpProperties = Cell::CloneProperties( rData.mpProperties, *mxObjRef.get(), *mxCell.get() );
     else
-        mxCell->mpProperties = 0;
+        mxCell->mpProperties = nullptr;
 
     if( rData.mpOutlinerParaObject )
         mxCell->SetOutlinerParaObject( new OutlinerParaObject(*rData.mpOutlinerParaObject) );
@@ -129,8 +129,13 @@ void CellUndo::setDataToCell( const Data& rData )
     mxCell->mnRowSpan = rData.mnRowSpan;
     mxCell->mnColSpan = rData.mnColSpan;
 
-    if( mxObjRef.is() )
+    if(mxObjRef.is())
+    {
+        // #i120201# ActionChanged is not enough, we need to trigger TableLayouter::UpdateBorderLayout()
+        // and this is done best using ReformatText() for table objects
         mxObjRef->ActionChanged();
+        mxObjRef->NbcReformatText();
+    }
 }
 
 void CellUndo::getDataFromCell( Data& rData )
@@ -143,7 +148,7 @@ void CellUndo::getDataFromCell( Data& rData )
         if( mxCell->GetOutlinerParaObject() )
             rData.mpOutlinerParaObject = new OutlinerParaObject(*mxCell->GetOutlinerParaObject());
         else
-            rData.mpOutlinerParaObject =  0;
+            rData.mpOutlinerParaObject =  nullptr;
 
         rData.mnCellContentType = mxCell->mnCellContentType;
 
@@ -156,9 +161,9 @@ void CellUndo::getDataFromCell( Data& rData )
     }
 }
 
-// -----------------------------------------------------------------------------
+
 // class InsertRowUndo : public SdrUndoAction
-// -----------------------------------------------------------------------------
+
 
 static void Dispose( RowVector& rRows )
 {
@@ -167,7 +172,7 @@ static void Dispose( RowVector& rRows )
         (*aIter++)->dispose();
 }
 
-// -----------------------------------------------------------------------------
+
 
 InsertRowUndo::InsertRowUndo( const TableModelRef& xTable, sal_Int32 nIndex, RowVector& aNewRows )
     : SdrUndoAction( *xTable->getSdrTableObj()->GetModel() )
@@ -178,7 +183,7 @@ InsertRowUndo::InsertRowUndo( const TableModelRef& xTable, sal_Int32 nIndex, Row
     maRows.swap( aNewRows );
 }
 
-// -----------------------------------------------------------------------------
+
 
 InsertRowUndo::~InsertRowUndo()
 {
@@ -186,7 +191,7 @@ InsertRowUndo::~InsertRowUndo()
         Dispose( maRows );
 }
 
-// -----------------------------------------------------------------------------
+
 
 void InsertRowUndo::Undo()
 {
@@ -197,7 +202,7 @@ void InsertRowUndo::Undo()
     }
 }
 
-// -----------------------------------------------------------------------------
+
 
 void InsertRowUndo::Redo()
 {
@@ -208,9 +213,9 @@ void InsertRowUndo::Redo()
     }
 }
 
-// -----------------------------------------------------------------------------
+
 // class RemoveRowUndo : public SdrUndoAction
-// -----------------------------------------------------------------------------
+
 
 RemoveRowUndo::RemoveRowUndo( const TableModelRef& xTable, sal_Int32 nIndex, RowVector& aRemovedRows )
     : SdrUndoAction( *xTable->getSdrTableObj()->GetModel() )
@@ -221,7 +226,7 @@ RemoveRowUndo::RemoveRowUndo( const TableModelRef& xTable, sal_Int32 nIndex, Row
     maRows.swap( aRemovedRows );
 }
 
-// -----------------------------------------------------------------------------
+
 
 RemoveRowUndo::~RemoveRowUndo()
 {
@@ -229,7 +234,7 @@ RemoveRowUndo::~RemoveRowUndo()
         Dispose( maRows );
 }
 
-// -----------------------------------------------------------------------------
+
 
 void RemoveRowUndo::Undo()
 {
@@ -240,7 +245,7 @@ void RemoveRowUndo::Undo()
     }
 }
 
-// -----------------------------------------------------------------------------
+
 
 void RemoveRowUndo::Redo()
 {
@@ -251,9 +256,9 @@ void RemoveRowUndo::Redo()
     }
 }
 
-// -----------------------------------------------------------------------------
+
 // class InsertColUndo : public SdrUndoAction
-// -----------------------------------------------------------------------------
+
 
 static void Dispose( ColumnVector& rCols )
 {
@@ -262,7 +267,7 @@ static void Dispose( ColumnVector& rCols )
         (*aIter++)->dispose();
 }
 
-// -----------------------------------------------------------------------------
+
 
 static void Dispose( CellVector& rCells )
 {
@@ -271,7 +276,7 @@ static void Dispose( CellVector& rCells )
         (*aIter++)->dispose();
 }
 
-// -----------------------------------------------------------------------------
+
 
 InsertColUndo::InsertColUndo( const TableModelRef& xTable, sal_Int32 nIndex, ColumnVector& aNewCols, CellVector& aCells  )
     : SdrUndoAction( *xTable->getSdrTableObj()->GetModel() )
@@ -283,7 +288,7 @@ InsertColUndo::InsertColUndo( const TableModelRef& xTable, sal_Int32 nIndex, Col
     maCells.swap( aCells );
 }
 
-// -----------------------------------------------------------------------------
+
 
 InsertColUndo::~InsertColUndo()
 {
@@ -294,7 +299,7 @@ InsertColUndo::~InsertColUndo()
     }
 }
 
-// -----------------------------------------------------------------------------
+
 
 void InsertColUndo::Undo()
 {
@@ -305,7 +310,7 @@ void InsertColUndo::Undo()
     }
 }
 
-// -----------------------------------------------------------------------------
+
 
 void InsertColUndo::Redo()
 {
@@ -316,9 +321,9 @@ void InsertColUndo::Redo()
     }
 }
 
-// -----------------------------------------------------------------------------
+
 // class RemoveColUndo : public SdrUndoAction
-// -----------------------------------------------------------------------------
+
 
 RemoveColUndo::RemoveColUndo( const TableModelRef& xTable, sal_Int32 nIndex, ColumnVector& aNewCols, CellVector& aCells )
     : SdrUndoAction( *xTable->getSdrTableObj()->GetModel() )
@@ -330,7 +335,7 @@ RemoveColUndo::RemoveColUndo( const TableModelRef& xTable, sal_Int32 nIndex, Col
     maCells.swap( aCells );
 }
 
-// -----------------------------------------------------------------------------
+
 
 RemoveColUndo::~RemoveColUndo()
 {
@@ -341,7 +346,7 @@ RemoveColUndo::~RemoveColUndo()
     }
 }
 
-// -----------------------------------------------------------------------------
+
 
 void RemoveColUndo::Undo()
 {
@@ -352,7 +357,7 @@ void RemoveColUndo::Undo()
     }
 }
 
-// -----------------------------------------------------------------------------
+
 
 void RemoveColUndo::Redo()
 {
@@ -363,9 +368,9 @@ void RemoveColUndo::Redo()
     }
 }
 
-// -----------------------------------------------------------------------------
+
 // class TableColumnUndo : public SdrUndoAction
-// -----------------------------------------------------------------------------
+
 
 TableColumnUndo::TableColumnUndo( const TableColumnRef& xCol )
     : SdrUndoAction( *xCol->mxTableModel->getSdrTableObj()->GetModel() )
@@ -375,13 +380,13 @@ TableColumnUndo::TableColumnUndo( const TableColumnRef& xCol )
     getData( maUndoData );
 }
 
-// -----------------------------------------------------------------------------
+
 
 TableColumnUndo::~TableColumnUndo()
 {
 }
 
-// -----------------------------------------------------------------------------
+
 
 void TableColumnUndo::Undo()
 {
@@ -393,14 +398,14 @@ void TableColumnUndo::Undo()
     setData( maUndoData );
 }
 
-// -----------------------------------------------------------------------------
+
 
 void TableColumnUndo::Redo()
 {
     setData( maRedoData );
 }
 
-// -----------------------------------------------------------------------------
+
 
 bool TableColumnUndo::Merge( SfxUndoAction *pNextAction )
 {
@@ -408,7 +413,7 @@ bool TableColumnUndo::Merge( SfxUndoAction *pNextAction )
     return pNext && pNext->mxCol == mxCol;
 }
 
-// -----------------------------------------------------------------------------
+
 
 void TableColumnUndo::setData( const Data& rData )
 {
@@ -420,7 +425,7 @@ void TableColumnUndo::setData( const Data& rData )
     mxCol->maName = rData.maName;
 }
 
-// -----------------------------------------------------------------------------
+
 
 void TableColumnUndo::getData( Data& rData )
 {
@@ -432,9 +437,9 @@ void TableColumnUndo::getData( Data& rData )
     rData.maName = mxCol->maName;
 }
 
-// -----------------------------------------------------------------------------
+
 // class TableRowUndo : public SdrUndoAction
-// -----------------------------------------------------------------------------
+
 
 TableRowUndo::TableRowUndo( const TableRowRef& xRow )
     : SdrUndoAction( *xRow->mxTableModel->getSdrTableObj()->GetModel() )
@@ -444,13 +449,13 @@ TableRowUndo::TableRowUndo( const TableRowRef& xRow )
     getData( maUndoData );
 }
 
-// -----------------------------------------------------------------------------
+
 
 TableRowUndo::~TableRowUndo()
 {
 }
 
-// -----------------------------------------------------------------------------
+
 
 void TableRowUndo::Undo()
 {
@@ -462,14 +467,14 @@ void TableRowUndo::Undo()
     setData( maUndoData );
 }
 
-// -----------------------------------------------------------------------------
+
 
 void TableRowUndo::Redo()
 {
     setData( maRedoData );
 }
 
-// -----------------------------------------------------------------------------
+
 
 bool TableRowUndo::Merge( SfxUndoAction *pNextAction )
 {
@@ -477,7 +482,7 @@ bool TableRowUndo::Merge( SfxUndoAction *pNextAction )
     return pNext && pNext->mxRow == mxRow;
 }
 
-// -----------------------------------------------------------------------------
+
 
 void TableRowUndo::setData( const Data& rData )
 {
@@ -487,9 +492,12 @@ void TableRowUndo::setData( const Data& rData )
     mxRow->mbIsVisible = rData.mbIsVisible;
     mxRow->mbIsStartOfNewPage = rData.mbIsStartOfNewPage;
     mxRow->maName = rData.maName;
+
+    // Trigger re-layout of the table.
+    mxRow->getModel()->setModified(true);
  }
 
-// -----------------------------------------------------------------------------
+
 
 void TableRowUndo::getData( Data& rData )
 {
@@ -501,7 +509,7 @@ void TableRowUndo::getData( Data& rData )
     rData.maName = mxRow->maName;
 }
 
-// -----------------------------------------------------------------------------
+
 
 TableStyleUndo::TableStyleUndo( const SdrTableObj& rTableObj )
     : SdrUndoAction( *rTableObj.GetModel() )
