@@ -24,7 +24,8 @@
 #include <com/sun/star/drawing/PointSequence.hpp>
 #include <svl/style.hxx>
 
-#include <cppuhelper/implbase2.hxx>
+#include <comphelper/sequence.hxx>
+#include <cppuhelper/implbase.hxx>
 #include <cppuhelper/supportsservice.hxx>
 #include <svl/itempool.hxx>
 #include <svl/itemset.hxx>
@@ -49,7 +50,7 @@ using namespace ::cppu;
 
 typedef std::vector< SfxItemSet* > ItemPoolVector;
 
-class SvxUnoMarkerTable : public WeakImplHelper2< container::XNameContainer, lang::XServiceInfo >,
+class SvxUnoMarkerTable : public WeakImplHelper< container::XNameContainer, lang::XServiceInfo >,
                           public SfxListener
 {
 private:
@@ -59,41 +60,41 @@ private:
     ItemPoolVector maItemSetVector;
 
 public:
-    SvxUnoMarkerTable( SdrModel* pModel ) throw();
+    explicit SvxUnoMarkerTable( SdrModel* pModel ) throw();
     virtual ~SvxUnoMarkerTable() throw();
 
     void dispose();
 
     // SfxListener
-    virtual void Notify( SfxBroadcaster& rBC, const SfxHint& rHint ) throw () SAL_OVERRIDE;
+    virtual void Notify( SfxBroadcaster& rBC, const SfxHint& rHint ) throw () override;
 
     void SAL_CALL ImplInsertByName( const OUString& aName, const uno::Any& aElement );
 
     // XServiceInfo
-    virtual OUString SAL_CALL getImplementationName(  ) throw( uno::RuntimeException, std::exception ) SAL_OVERRIDE;
-    virtual sal_Bool SAL_CALL supportsService( const  OUString& ServiceName ) throw( uno::RuntimeException, std::exception) SAL_OVERRIDE;
-    virtual uno::Sequence<  OUString > SAL_CALL getSupportedServiceNames(  ) throw( uno::RuntimeException, std::exception) SAL_OVERRIDE;
+    virtual OUString SAL_CALL getImplementationName(  ) throw( uno::RuntimeException, std::exception ) override;
+    virtual sal_Bool SAL_CALL supportsService( const  OUString& ServiceName ) throw( uno::RuntimeException, std::exception) override;
+    virtual uno::Sequence<  OUString > SAL_CALL getSupportedServiceNames(  ) throw( uno::RuntimeException, std::exception) override;
 
     // XNameContainer
-    virtual void SAL_CALL insertByName( const  OUString& aName, const  uno::Any& aElement ) throw( lang::IllegalArgumentException, container::ElementExistException, lang::WrappedTargetException, uno::RuntimeException, std::exception) SAL_OVERRIDE;
-    virtual void SAL_CALL removeByName( const  OUString& Name ) throw( container::NoSuchElementException, lang::WrappedTargetException, uno::RuntimeException, std::exception) SAL_OVERRIDE;
+    virtual void SAL_CALL insertByName( const  OUString& aName, const  uno::Any& aElement ) throw( lang::IllegalArgumentException, container::ElementExistException, lang::WrappedTargetException, uno::RuntimeException, std::exception) override;
+    virtual void SAL_CALL removeByName( const  OUString& Name ) throw( container::NoSuchElementException, lang::WrappedTargetException, uno::RuntimeException, std::exception) override;
 
     // XNameReplace
-    virtual void SAL_CALL replaceByName( const  OUString& aName, const  uno::Any& aElement ) throw( lang::IllegalArgumentException, container::NoSuchElementException, lang::WrappedTargetException, uno::RuntimeException, std::exception) SAL_OVERRIDE;
+    virtual void SAL_CALL replaceByName( const  OUString& aName, const  uno::Any& aElement ) throw( lang::IllegalArgumentException, container::NoSuchElementException, lang::WrappedTargetException, uno::RuntimeException, std::exception) override;
 
     // XNameAccess
-    virtual uno::Any SAL_CALL getByName( const  OUString& aName ) throw( container::NoSuchElementException, lang::WrappedTargetException, uno::RuntimeException, std::exception) SAL_OVERRIDE;
-    virtual uno::Sequence<  OUString > SAL_CALL getElementNames(  ) throw( uno::RuntimeException, std::exception) SAL_OVERRIDE;
-    virtual sal_Bool SAL_CALL hasByName( const  OUString& aName ) throw( uno::RuntimeException, std::exception) SAL_OVERRIDE;
+    virtual uno::Any SAL_CALL getByName( const  OUString& aName ) throw( container::NoSuchElementException, lang::WrappedTargetException, uno::RuntimeException, std::exception) override;
+    virtual uno::Sequence<  OUString > SAL_CALL getElementNames(  ) throw( uno::RuntimeException, std::exception) override;
+    virtual sal_Bool SAL_CALL hasByName( const  OUString& aName ) throw( uno::RuntimeException, std::exception) override;
 
     // XElementAccess
-    virtual uno::Type SAL_CALL getElementType(  ) throw( uno::RuntimeException, std::exception) SAL_OVERRIDE;
-    virtual sal_Bool SAL_CALL hasElements(  ) throw( uno::RuntimeException, std::exception) SAL_OVERRIDE;
+    virtual uno::Type SAL_CALL getElementType(  ) throw( uno::RuntimeException, std::exception) override;
+    virtual sal_Bool SAL_CALL hasElements(  ) throw( uno::RuntimeException, std::exception) override;
 };
 
 SvxUnoMarkerTable::SvxUnoMarkerTable( SdrModel* pModel ) throw()
 : mpModel( pModel ),
-  mpModelPool( pModel ? &pModel->GetItemPool() : (SfxItemPool*)NULL )
+  mpModelPool( pModel ? &pModel->GetItemPool() : nullptr )
 {
     if( pModel )
         StartListening( *pModel );
@@ -141,8 +142,7 @@ OUString SAL_CALL SvxUnoMarkerTable::getImplementationName() throw( uno::Runtime
 uno::Sequence< OUString > SAL_CALL SvxUnoMarkerTable::getSupportedServiceNames(  )
     throw( uno::RuntimeException, std::exception )
 {
-    uno::Sequence< OUString > aSNS( 1 );
-    aSNS.getArray()[0] = "com.sun.star.drawing.MarkerTable";
+    uno::Sequence<OUString> aSNS { "com.sun.star.drawing.MarkerTable" };
     return aSNS;
 }
 
@@ -153,13 +153,13 @@ void SAL_CALL SvxUnoMarkerTable::ImplInsertByName( const OUString& aName, const
 
     XLineEndItem aEndMarker;
     aEndMarker.SetName( aName );
-    aEndMarker.PutValue( aElement );
+    aEndMarker.PutValue( aElement, 0 );
 
     mpInSet->Put( aEndMarker, XATTR_LINEEND );
 
     XLineStartItem aStartMarker;
     aStartMarker.SetName( aName );
-    aStartMarker.PutValue( aElement );
+    aStartMarker.PutValue( aElement, 0 );
 
     mpInSet->Put( aStartMarker, XATTR_LINESTART );
 }
@@ -196,12 +196,11 @@ void SAL_CALL SvxUnoMarkerTable::removeByName( const OUString& aApiName )
     ItemPoolVector::iterator aIter = maItemSetVector.begin();
     const ItemPoolVector::iterator aEnd = maItemSetVector.end();
 
-    const NameOrIndex *pItem;
     const OUString aSearchName( Name );
 
     while( aIter != aEnd )
     {
-        pItem = static_cast<const NameOrIndex *>(&((*aIter)->Get( XATTR_LINEEND ) ));
+        const NameOrIndex *pItem = static_cast<const NameOrIndex *>(&((*aIter)->Get( XATTR_LINEEND ) ));
         if( pItem->GetName() == aSearchName )
         {
             delete (*aIter);
@@ -235,14 +234,14 @@ void SAL_CALL SvxUnoMarkerTable::replaceByName( const OUString& aApiName, const
         {
             XLineEndItem aEndMarker;
             aEndMarker.SetName( aSearchName );
-            if( !aEndMarker.PutValue( aElement ) )
+            if( !aEndMarker.PutValue( aElement, 0 ) )
                 throw lang::IllegalArgumentException();
 
             (*aIter)->Put( aEndMarker, XATTR_LINEEND );
 
             XLineStartItem aStartMarker;
             aStartMarker.SetName( aSearchName );
-            aStartMarker.PutValue( aElement );
+            aStartMarker.PutValue( aElement, 0 );
 
             (*aIter)->Put( aStartMarker, XATTR_LINESTART );
             return;
@@ -260,7 +259,7 @@ void SAL_CALL SvxUnoMarkerTable::replaceByName( const OUString& aApiName, const
         NameOrIndex *pItem = const_cast<NameOrIndex*>(static_cast<const NameOrIndex*>(mpModelPool->GetItem2( XATTR_LINESTART, nSurrogate)));
         if( pItem && pItem->GetName() == aSearchName )
         {
-            pItem->PutValue( aElement );
+            pItem->PutValue( aElement, 0 );
             bFound = true;
             break;
         }
@@ -272,7 +271,7 @@ void SAL_CALL SvxUnoMarkerTable::replaceByName( const OUString& aApiName, const
         NameOrIndex *pItem = const_cast<NameOrIndex*>(static_cast<const NameOrIndex*>(mpModelPool->GetItem2( XATTR_LINEEND, nSurrogate)));
         if( pItem && pItem->GetName() == aSearchName )
         {
-            pItem->PutValue( aElement );
+            pItem->PutValue( aElement, 0 );
             bFound = true;
             break;
         }
@@ -286,15 +285,14 @@ void SAL_CALL SvxUnoMarkerTable::replaceByName( const OUString& aApiName, const
 
 static bool getByNameFromPool( const OUString& rSearchName, SfxItemPool* pPool, sal_uInt16 nWhich, uno::Any& rAny )
 {
-    const NameOrIndex *pItem;
     const sal_uInt32 nSurrogateCount = pPool ? pPool->GetItemCount2( nWhich ) : 0;
     for( sal_uInt32 nSurrogate = 0; nSurrogate < nSurrogateCount; nSurrogate++ )
     {
-        pItem = static_cast<const NameOrIndex*>(pPool->GetItem2( nWhich, nSurrogate ));
+        const NameOrIndex *pItem = static_cast<const NameOrIndex*>(pPool->GetItem2( nWhich, nSurrogate ));
 
         if( pItem && pItem->GetName() == rSearchName )
         {
-            pItem->QueryValue( rAny, 0 );
+            pItem->QueryValue( rAny );
             return true;
         }
     }
@@ -338,7 +336,7 @@ static void createNamesForPool( SfxItemPool* pPool, sal_uInt16 nWhich, std::set<
     {
         const NameOrIndex* pItem = static_cast<const NameOrIndex*>(pPool->GetItem2( nWhich, nSurrogate ));
 
-        if( pItem == NULL || pItem->GetName().isEmpty() )
+        if( pItem == nullptr || pItem->GetName().isEmpty() )
             continue;
 
         OUString aName = SvxUnogetApiNameForItem(XATTR_LINEEND, pItem->GetName());
@@ -359,18 +357,7 @@ uno::Sequence< OUString > SAL_CALL SvxUnoMarkerTable::getElementNames()
     // search model pool for line ends
     createNamesForPool( mpModelPool, XATTR_LINEEND, aNameSet );
 
-    uno::Sequence< OUString > aSeq( aNameSet.size() );
-    OUString* pNames = aSeq.getArray();
-
-    std::set< OUString >::iterator aIter( aNameSet.begin() );
-    const std::set< OUString >::iterator aEnd( aNameSet.end() );
-
-    while( aIter != aEnd )
-    {
-        *pNames++ = *aIter++;
-    }
-
-    return aSeq;
+    return comphelper::containerToSequence<OUString>(aNameSet);
 }
 
 sal_Bool SAL_CALL SvxUnoMarkerTable::hasByName( const OUString& aName )
@@ -411,7 +398,7 @@ sal_Bool SAL_CALL SvxUnoMarkerTable::hasByName( const OUString& aName )
 uno::Type SAL_CALL SvxUnoMarkerTable::getElementType(  )
     throw( uno::RuntimeException, std::exception )
 {
-    return ::getCppuType((const drawing::PointSequence*)0);
+    return cppu::UnoType<drawing::PointSequence>::get();
 }
 
 sal_Bool SAL_CALL SvxUnoMarkerTable::hasElements(  )
