@@ -28,13 +28,12 @@
 #include <com/sun/star/drawing/PointSequence.hpp>
 #include <com/sun/star/graphic/XGraphic.hpp>
 #include <tools/urlobj.hxx>
-#include <unotools/localfilehelper.hxx>
 #include <vcl/svapp.hxx>
+#include <osl/file.hxx>
 #include <osl/mutex.hxx>
 #include <vcl/fltcall.hxx>
 #include <vcl/graphicfilter.hxx>
 
-#include <boost/scoped_ptr.hpp>
 #include <svx/svdpool.hxx>
 
 #include <editeng/unoprnms.hxx>
@@ -58,6 +57,8 @@
 #include <comphelper/servicehelper.hxx>
 #include <vcl/wmf.hxx>
 
+#include <memory>
+
 using namespace ::osl;
 using namespace ::cppu;
 using namespace ::com::sun::star;
@@ -66,7 +67,7 @@ using namespace ::com::sun::star::lang;
 using namespace ::com::sun::star::container;
 
 #define QUERYINT( xint ) \
-    if( rType == ::getCppuType((const Reference< xint >*)0) ) \
+    if( rType == cppu::UnoType<xint>::get() ) \
         aAny <<= Reference< xint >(this)
 
 SvxShapeGroup::SvxShapeGroup( SdrObject* pObj, SvxDrawPage* pDrawPage  )  throw() :
@@ -131,7 +132,7 @@ uno::Sequence< sal_Int8 > SAL_CALL SvxShapeGroup::getImplementationId()
     return css::uno::Sequence<sal_Int8>();
 }
 
-// ::com::sun::star::drawing::XShape
+// css::drawing::XShape
 
 
 OUString SAL_CALL SvxShapeGroup::getShapeType()
@@ -197,7 +198,7 @@ void SvxShapeGroup::addUnoShape( const uno::Reference< drawing::XShape >& xShape
     }
 
     SdrObject* pSdrShape = pShape->GetSdrObject();
-    if( pSdrShape == NULL )
+    if( pSdrShape == nullptr )
         pSdrShape = mxPage->_CreateSdrObject( xShape );
 
     if( pSdrShape->IsInserted() )
@@ -239,13 +240,13 @@ void SAL_CALL SvxShapeGroup::remove( const uno::Reference< drawing::XShape >& xS
 {
     ::SolarMutexGuard aGuard;
 
-    SdrObject* pSdrShape = NULL;
+    SdrObject* pSdrShape = nullptr;
     SvxShape* pShape = SvxShape::getImplementation( xShape );
 
     if( pShape )
         pSdrShape = pShape->GetSdrObject();
 
-    if( !mpObj.is() || pSdrShape == NULL || pSdrShape->GetObjList()->GetOwnerObj() != mpObj.get() )
+    if( !mpObj.is() || pSdrShape == nullptr || pSdrShape->GetObjList()->GetOwnerObj() != mpObj.get() )
         throw uno::RuntimeException();
 
     SdrObjList& rList = *pSdrShape->GetObjList();
@@ -270,7 +271,7 @@ void SAL_CALL SvxShapeGroup::remove( const uno::Reference< drawing::XShape >& xS
         {
             if(SAL_MAX_SIZE != pView->TryToFindMarkedObject(pSdrShape))
             {
-                pView->MarkObj(pSdrShape, pView->GetSdrPageView(), true, false);
+                pView->MarkObj(pSdrShape, pView->GetSdrPageView(), true);
             }
         }
 
@@ -327,7 +328,7 @@ uno::Any SAL_CALL SvxShapeGroup::getByIndex( sal_Int32 Index )
 {
     ::SolarMutexGuard aGuard;
 
-    if( !mpObj.is() || mpObj->GetSubList() == NULL )
+    if( !mpObj.is() || mpObj->GetSubList() == nullptr )
         throw uno::RuntimeException();
 
     if( Index<0 || mpObj->GetSubList()->GetObjCount() <= static_cast<size_t>(Index) )
@@ -335,14 +336,14 @@ uno::Any SAL_CALL SvxShapeGroup::getByIndex( sal_Int32 Index )
 
     SdrObject* pDestObj = mpObj->GetSubList()->GetObj( Index );
 
-    if(pDestObj == NULL)
+    if(pDestObj == nullptr)
         throw lang::IndexOutOfBoundsException();
 
     Reference< drawing::XShape > xShape( pDestObj->getUnoShape(), uno::UNO_QUERY );
     return uno::makeAny( xShape );
 }
 
-// ::com::sun::star::container::XElementAccess
+// css::container::XElementAccess
 
 
 uno::Type SAL_CALL SvxShapeGroup::getElementType() throw( uno::RuntimeException, std::exception )
@@ -359,7 +360,7 @@ sal_Bool SAL_CALL SvxShapeGroup::hasElements() throw( uno::RuntimeException, std
 }
 
 
-// ::com::sun::star::lang::XServiceInfo
+// css::lang::XServiceInfo
 
 uno::Sequence< OUString > SAL_CALL SvxShapeGroup::getSupportedServiceNames()
     throw(uno::RuntimeException, std::exception)
@@ -419,7 +420,7 @@ uno::Sequence< sal_Int8 > SAL_CALL SvxShapeConnector::getImplementationId()
     return css::uno::Sequence<sal_Int8>();
 }
 
-// ::com::sun::star::drawing::XShape
+// css::drawing::XShape
 
 
 OUString SAL_CALL SvxShapeConnector::getShapeType()
@@ -514,7 +515,7 @@ void SAL_CALL SvxShapeConnector::disconnectEnd( const uno::Reference< drawing::X
 }
 
 
-// ::com::sun::star::lang::XServiceInfo
+// css::lang::XServiceInfo
 
 uno::Sequence< OUString > SAL_CALL SvxShapeConnector::getSupportedServiceNames() throw( uno::RuntimeException, std::exception )
 {
@@ -573,7 +574,7 @@ uno::Sequence< sal_Int8 > SAL_CALL SvxShapeControl::getImplementationId()
     return css::uno::Sequence<sal_Int8>();
 }
 
-// ::com::sun::star::drawing::XShape
+// css::drawing::XShape
 
 
 OUString SAL_CALL SvxShapeControl::getShapeType()
@@ -655,7 +656,7 @@ static struct
 SvxShapeControlPropertyMapping[] =
 {
     // Warning: The first entry must be FontSlant because the any needs to be converted
-    { RTL_CONSTASCII_STRINGPARAM(UNO_NAME_EDIT_CHAR_POSTURE), RTL_CONSTASCII_STRINGPARAM("FontSlant")  }, //  const sal_Int16 => ::com::sun::star::awt::FontSlant
+    { RTL_CONSTASCII_STRINGPARAM(UNO_NAME_EDIT_CHAR_POSTURE), RTL_CONSTASCII_STRINGPARAM("FontSlant")  }, //  const sal_Int16 => css::awt::FontSlant
     { RTL_CONSTASCII_STRINGPARAM(UNO_NAME_EDIT_CHAR_FONTNAME), RTL_CONSTASCII_STRINGPARAM("FontName") },
     { RTL_CONSTASCII_STRINGPARAM(UNO_NAME_EDIT_CHAR_FONTSTYLENAME), RTL_CONSTASCII_STRINGPARAM("FontStyleName") },
     { RTL_CONSTASCII_STRINGPARAM(UNO_NAME_EDIT_CHAR_FONTFAMILY), RTL_CONSTASCII_STRINGPARAM("FontFamily") },
@@ -669,6 +670,8 @@ SvxShapeControlPropertyMapping[] =
     { RTL_CONSTASCII_STRINGPARAM("CharWordMode"), RTL_CONSTASCII_STRINGPARAM("FontWordLineMode" ) },
     { RTL_CONSTASCII_STRINGPARAM(UNO_NAME_EDIT_CHAR_COLOR),   RTL_CONSTASCII_STRINGPARAM("TextColor") },
     { RTL_CONSTASCII_STRINGPARAM("CharBackColor"), RTL_CONSTASCII_STRINGPARAM("CharBackColor") },
+    { RTL_CONSTASCII_STRINGPARAM("CharBackTransparent"), RTL_CONSTASCII_STRINGPARAM("CharBackTransparent") },
+    { RTL_CONSTASCII_STRINGPARAM(UNO_NAME_TEXT_CHAINNEXTNAME), RTL_CONSTASCII_STRINGPARAM(UNO_NAME_TEXT_CHAINNEXTNAME) },
     { RTL_CONSTASCII_STRINGPARAM("CharRelief"),   RTL_CONSTASCII_STRINGPARAM("FontRelief") },
     { RTL_CONSTASCII_STRINGPARAM("CharUnderlineColor"),   RTL_CONSTASCII_STRINGPARAM("TextLineColor") },
     { RTL_CONSTASCII_STRINGPARAM(UNO_NAME_EDIT_PARA_ADJUST), RTL_CONSTASCII_STRINGPARAM("Align") },
@@ -684,7 +687,7 @@ SvxShapeControlPropertyMapping[] =
     { RTL_CONSTASCII_STRINGPARAM("ControlTypeinMSO"), RTL_CONSTASCII_STRINGPARAM("ControlTypeinMSO") },
     { RTL_CONSTASCII_STRINGPARAM("ObjIDinMSO"), RTL_CONSTASCII_STRINGPARAM("ObjIDinMSO") },
     { RTL_CONSTASCII_STRINGPARAM("CharCaseMap"), RTL_CONSTASCII_STRINGPARAM("CharCaseMap") },
-    { NULL,0, NULL, 0 }
+    { nullptr,0, nullptr, 0 }
 };
 
 namespace
@@ -802,7 +805,7 @@ namespace
 }
 
 void SAL_CALL SvxShapeControl::setPropertyValue( const OUString& aPropertyName, const uno::Any& aValue )
-    throw( beans::UnknownPropertyException, lang::WrappedTargetException, uno::RuntimeException, com::sun::star::beans::PropertyVetoException, com::sun::star::lang::IllegalArgumentException, std::exception)
+    throw( beans::UnknownPropertyException, lang::WrappedTargetException, uno::RuntimeException, css::beans::PropertyVetoException, css::lang::IllegalArgumentException, std::exception)
 {
     OUString aFormsName;
     if ( lcl_convertPropertyName( aPropertyName, aFormsName ) )
@@ -984,7 +987,7 @@ SvxShapeDimensioning::~SvxShapeDimensioning() throw()
 {
 }
 
-// ::com::sun::star::lang::XServiceInfo
+// css::lang::XServiceInfo
 uno::Sequence< OUString > SAL_CALL SvxShapeDimensioning::getSupportedServiceNames() throw( uno::RuntimeException, std::exception )
 {
     return SvxShapeText::getSupportedServiceNames();
@@ -999,7 +1002,7 @@ SvxShapeCircle::~SvxShapeCircle() throw()
 {
 }
 
-// ::com::sun::star::lang::XServiceInfo
+// css::lang::XServiceInfo
 // XServiceInfo
 uno::Sequence< OUString > SAL_CALL SvxShapeCircle::getSupportedServiceNames() throw( uno::RuntimeException, std::exception )
 {
@@ -1009,7 +1012,7 @@ uno::Sequence< OUString > SAL_CALL SvxShapeCircle::getSupportedServiceNames() th
 
 
 SvxShapePolyPolygon::SvxShapePolyPolygon( SdrObject* pObj , drawing::PolygonKind eNew )
- throw( com::sun::star::beans::PropertyVetoException, com::sun::star::lang::IllegalArgumentException)
+ throw( css::beans::PropertyVetoException, css::lang::IllegalArgumentException)
 : SvxShapeText( pObj, getSvxMapProvider().GetMap(SVXMAP_POLYPOLYGON), getSvxMapProvider().GetPropertySet(SVXMAP_POLYPOLYGON, SdrObject::GetGlobalDrawObjectItemPool()) )
 , mePolygonKind( eNew )
 {
@@ -1024,16 +1027,16 @@ basegfx::B2DPolyPolygon SAL_CALL ImplSvxPointSequenceSequenceToB2DPolyPolygon( c
 {
     basegfx::B2DPolyPolygon aRetval;
 
-    // Zeiger auf innere sequences holen
+    // get pointer to internal sequences
     const drawing::PointSequence* pInnerSequence = pOuterSequence->getConstArray();
     const drawing::PointSequence* pInnerSeqEnd   = pInnerSequence + pOuterSequence->getLength();
 
     for(;pInnerSequence != pInnerSeqEnd; ++pInnerSequence)
     {
-        // Neues Polygon vorbereiten
+        // prepare new polygon
         basegfx::B2DPolygon aNewPolygon;
 
-        // Zeiger auf Arrays holen
+        // get pointer to arrays
         const awt::Point* pArray    = pInnerSequence->getConstArray();
         const awt::Point* pArrayEnd = pArray + pInnerSequence->getLength();
 
@@ -1045,7 +1048,7 @@ basegfx::B2DPolyPolygon SAL_CALL ImplSvxPointSequenceSequenceToB2DPolyPolygon( c
         // check for closed state flag
         basegfx::tools::checkClosed(aNewPolygon);
 
-        // Neues Teilpolygon einfuegen
+        // add new subpolygon
         aRetval.append(aNewPolygon);
     }
 
@@ -1054,15 +1057,15 @@ basegfx::B2DPolyPolygon SAL_CALL ImplSvxPointSequenceSequenceToB2DPolyPolygon( c
 
 
 
-bool SvxShapePolyPolygon::setPropertyValueImpl( const OUString& rName, const SfxItemPropertySimpleEntry* pProperty, const ::com::sun::star::uno::Any& rValue ) throw(::com::sun::star::beans::UnknownPropertyException, ::com::sun::star::beans::PropertyVetoException, ::com::sun::star::lang::IllegalArgumentException, ::com::sun::star::lang::WrappedTargetException, ::com::sun::star::uno::RuntimeException)
+bool SvxShapePolyPolygon::setPropertyValueImpl( const OUString& rName, const SfxItemPropertySimpleEntry* pProperty, const css::uno::Any& rValue ) throw(css::beans::UnknownPropertyException, css::beans::PropertyVetoException, css::lang::IllegalArgumentException, css::lang::WrappedTargetException, css::uno::RuntimeException)
 {
     switch( pProperty->nWID )
     {
     case OWN_ATTR_VALUE_POLYPOLYGON:
     {
-        if( rValue.getValue() && (rValue.getValueType() == ::getCppuType(( const drawing::PointSequenceSequence*)0) ) )
+        if( rValue.getValue() && (rValue.getValueType() == cppu::UnoType<drawing::PointSequenceSequence>::get() ) )
         {
-            basegfx::B2DPolyPolygon aNewPolyPolygon(ImplSvxPointSequenceSequenceToB2DPolyPolygon( (drawing::PointSequenceSequence*)rValue.getValue()));
+            basegfx::B2DPolyPolygon aNewPolyPolygon(ImplSvxPointSequenceSequenceToB2DPolyPolygon( static_cast<drawing::PointSequenceSequence const *>(rValue.getValue())));
             SetPolygon(aNewPolyPolygon);
             return true;
         }
@@ -1070,7 +1073,7 @@ bool SvxShapePolyPolygon::setPropertyValueImpl( const OUString& rName, const Sfx
     }
     case OWN_ATTR_BASE_GEOMETRY:
     {
-        if( rValue.getValue() && (rValue.getValueType() == ::getCppuType(( const drawing::PointSequenceSequence*)0)))
+        if( rValue.getValue() && (rValue.getValueType() == cppu::UnoType<drawing::PointSequenceSequence>::get()))
         {
             if( mpObj.is() )
             {
@@ -1078,7 +1081,7 @@ bool SvxShapePolyPolygon::setPropertyValueImpl( const OUString& rName, const Sfx
                 basegfx::B2DHomMatrix aNewHomogenMatrix;
 
                 mpObj->TRGetBaseGeometry(aNewHomogenMatrix, aNewPolyPolygon);
-                aNewPolyPolygon = ImplSvxPointSequenceSequenceToB2DPolyPolygon((drawing::PointSequenceSequence*)rValue.getValue());
+                aNewPolyPolygon = ImplSvxPointSequenceSequenceToB2DPolyPolygon(static_cast<drawing::PointSequenceSequence const *>(rValue.getValue()));
                 mpObj->TRSetBaseGeometry(aNewHomogenMatrix, aNewPolyPolygon);
             }
             return true;
@@ -1087,15 +1090,14 @@ bool SvxShapePolyPolygon::setPropertyValueImpl( const OUString& rName, const Sfx
     }
     case OWN_ATTR_VALUE_POLYGON:
     {
-        if( rValue.getValue() && (rValue.getValueType() == ::getCppuType(( const drawing::PointSequenceSequence*)0) ))
+        if( rValue.getValue() && (rValue.getValueType() == cppu::UnoType<drawing::PointSequenceSequence>::get() ))
         {
-            drawing::PointSequence* pSequence = (drawing::PointSequence*)rValue.getValue();
+            drawing::PointSequence const * pSequence = static_cast<drawing::PointSequence const *>(rValue.getValue());
 
-            // Neues Polygon vorbereiten
+            // prepare new polygon
             basegfx::B2DPolygon aNewPolygon;
 
-            // Zeiger auf Arrays holen
-            // Zeiger auf Arrays holen
+            // get pointer to arrays
             const awt::Point* pArray    = pSequence->getConstArray();
             const awt::Point* pArrayEnd = pArray + pSequence->getLength();
 
@@ -1107,7 +1109,7 @@ bool SvxShapePolyPolygon::setPropertyValueImpl( const OUString& rName, const Sfx
             // check for closed state flag
             basegfx::tools::checkClosed(aNewPolygon);
 
-            // Polygon setzen
+            // set polygon
             SetPolygon(basegfx::B2DPolyPolygon(aNewPolygon));
             return true;
         }
@@ -1125,24 +1127,24 @@ void SAL_CALL B2DPolyPolygonToSvxPointSequenceSequence( const basegfx::B2DPolyPo
     if( (sal_uInt32)rRetval.getLength() != rPolyPoly.count() )
         rRetval.realloc( rPolyPoly.count() );
 
-    // Zeiger auf aeussere Arrays holen
+    // get pointer to external arrays
     drawing::PointSequence* pOuterSequence = rRetval.getArray();
 
     for(sal_uInt32 a(0L); a < rPolyPoly.count(); a++)
     {
-        // Einzelpolygon holen
+        // get single polygon
         const basegfx::B2DPolygon aPoly(rPolyPoly.getB2DPolygon(a));
 
-        // #i75974# take closed stae into account, the API polygon still uses the old closed definition
+        // #i75974# take closed state into account, the API polygon still uses the old closed definition
         // with last/first point are identical (cannot hold information about open polygons with identical
         // first and last point, though)
         const sal_uInt32 nPointCount(aPoly.count());
         const bool bIsClosed(aPoly.isClosed());
 
-        // Platz in Arrays schaffen
+        // create space in arrays
         pOuterSequence->realloc(bIsClosed ? nPointCount + 1 : nPointCount);
 
-        // Pointer auf arrays holen
+        // get pointer to arrays
         awt::Point* pInnerSequence = pOuterSequence->getArray();
 
         for(sal_uInt32 b(0L); b < nPointCount; b++)
@@ -1164,13 +1166,17 @@ void SAL_CALL B2DPolyPolygonToSvxPointSequenceSequence( const basegfx::B2DPolyPo
 
 
 
-bool SvxShapePolyPolygon::getPropertyValueImpl( const OUString& rName, const SfxItemPropertySimpleEntry* pProperty, ::com::sun::star::uno::Any& rValue ) throw(::com::sun::star::beans::UnknownPropertyException, ::com::sun::star::lang::WrappedTargetException, ::com::sun::star::uno::RuntimeException)
+bool SvxShapePolyPolygon::getPropertyValueImpl( const OUString& rName, const SfxItemPropertySimpleEntry* pProperty,
+                                                css::uno::Any& rValue )
+    throw(css::beans::UnknownPropertyException,
+          css::lang::WrappedTargetException,
+          css::uno::RuntimeException)
 {
     switch( pProperty->nWID )
     {
     case OWN_ATTR_VALUE_POLYPOLYGON:
     {
-        // tools::PolyPolygon in eine struct tools::PolyPolygon packen
+        // pack a tools::PolyPolygon in a struct tools::PolyPolygon
         const basegfx::B2DPolyPolygon& rPolyPoly = GetPolygon();
         drawing::PointSequenceSequence aRetval( rPolyPoly.count() );
 
@@ -1195,7 +1201,7 @@ bool SvxShapePolyPolygon::getPropertyValueImpl( const OUString& rName, const Sfx
     }
     case OWN_ATTR_VALUE_POLYGON:
     {
-        // tools::PolyPolygon in eine struct tools::PolyPolygon packen
+        // pack a tools::PolyPolygon in a struct tools::PolyPolygon
         const basegfx::B2DPolyPolygon& rPolyPoly = GetPolygon();
 
         sal_Int32 nCount = 0;
@@ -1206,10 +1212,10 @@ bool SvxShapePolyPolygon::getPropertyValueImpl( const OUString& rName, const Sfx
 
         if( nCount > 0 )
         {
-            // Einzelpolygon holen
+            // get single polygon
             const basegfx::B2DPolygon aPoly(rPolyPoly.getB2DPolygon(0L));
 
-            // Pointer auf arrays holen
+            // get pointer to arrays
             awt::Point* pSequence = aRetval.getArray();
 
             for(sal_Int32 b=0;b<nCount;b++)
@@ -1260,7 +1266,7 @@ basegfx::B2DPolyPolygon SvxShapePolyPolygon::GetPolygon() const throw()
     }
 }
 
-// ::com::sun::star::lang::XServiceInfo
+// css::lang::XServiceInfo
 uno::Sequence< OUString > SAL_CALL SvxShapePolyPolygon::getSupportedServiceNames() throw( uno::RuntimeException, std::exception )
 {
     return SvxShapeText::getSupportedServiceNames();
@@ -1282,7 +1288,7 @@ SvxShapePolyPolygonBezier::~SvxShapePolyPolygonBezier() throw()
 
 
 
-bool SvxShapePolyPolygonBezier::setPropertyValueImpl( const OUString& rName, const SfxItemPropertySimpleEntry* pProperty, const ::com::sun::star::uno::Any& rValue ) throw(::com::sun::star::beans::UnknownPropertyException, ::com::sun::star::beans::PropertyVetoException, ::com::sun::star::lang::IllegalArgumentException, ::com::sun::star::lang::WrappedTargetException, ::com::sun::star::uno::RuntimeException)
+bool SvxShapePolyPolygonBezier::setPropertyValueImpl( const OUString& rName, const SfxItemPropertySimpleEntry* pProperty, const css::uno::Any& rValue ) throw(css::beans::UnknownPropertyException, css::beans::PropertyVetoException, css::lang::IllegalArgumentException, css::lang::WrappedTargetException, css::uno::RuntimeException)
 {
     switch( pProperty->nWID )
     {
@@ -1292,7 +1298,7 @@ bool SvxShapePolyPolygonBezier::setPropertyValueImpl( const OUString& rName, con
         {
             basegfx::B2DPolyPolygon aNewPolyPolygon(
                 basegfx::unotools::polyPolygonBezierToB2DPolyPolygon(
-                    *(drawing::PolyPolygonBezierCoords*)rValue.getValue()));
+                    *static_cast<drawing::PolyPolygonBezierCoords const *>(rValue.getValue())));
             SetPolygon(aNewPolyPolygon);
             return true;
         }
@@ -1309,7 +1315,7 @@ bool SvxShapePolyPolygonBezier::setPropertyValueImpl( const OUString& rName, con
 
                 mpObj->TRGetBaseGeometry(aNewHomogenMatrix, aNewPolyPolygon);
                 aNewPolyPolygon = basegfx::unotools::polyPolygonBezierToB2DPolyPolygon(
-                    *(drawing::PolyPolygonBezierCoords*)rValue.getValue());
+                    *static_cast<drawing::PolyPolygonBezierCoords const *>(rValue.getValue()));
                 mpObj->TRSetBaseGeometry(aNewHomogenMatrix, aNewPolyPolygon);
             }
             return true;
@@ -1325,13 +1331,13 @@ bool SvxShapePolyPolygonBezier::setPropertyValueImpl( const OUString& rName, con
 
 
 
-bool SvxShapePolyPolygonBezier::getPropertyValueImpl( const OUString& rName, const SfxItemPropertySimpleEntry* pProperty, ::com::sun::star::uno::Any& rValue ) throw(::com::sun::star::beans::UnknownPropertyException, ::com::sun::star::lang::WrappedTargetException, ::com::sun::star::uno::RuntimeException)
+bool SvxShapePolyPolygonBezier::getPropertyValueImpl( const OUString& rName, const SfxItemPropertySimpleEntry* pProperty, css::uno::Any& rValue ) throw(css::beans::UnknownPropertyException, css::lang::WrappedTargetException, css::uno::RuntimeException)
 {
     switch( pProperty->nWID )
     {
     case OWN_ATTR_VALUE_POLYPOLYGONBEZIER:
     {
-        // tools::PolyPolygon in eine struct tools::PolyPolygon packen
+        // pack a tools::PolyPolygon in a struct tools::PolyPolygon
         const basegfx::B2DPolyPolygon& rPolyPoly = GetPolygon();
         drawing::PolyPolygonBezierCoords aRetval;
         basegfx::unotools::b2DPolyPolygonToPolyPolygonBezier(rPolyPoly, aRetval);
@@ -1341,7 +1347,7 @@ bool SvxShapePolyPolygonBezier::getPropertyValueImpl( const OUString& rName, con
     }
     case OWN_ATTR_BASE_GEOMETRY:
     {
-        // tools::PolyPolygon in eine struct tools::PolyPolygon packen
+        // pack a tools::PolyPolygon in a struct tools::PolyPolygon
         basegfx::B2DPolyPolygon aNewPolyPolygon;
         basegfx::B2DHomMatrix aNewHomogenMatrix;
         mpObj.get()->TRGetBaseGeometry(aNewHomogenMatrix, aNewPolyPolygon);
@@ -1389,7 +1395,7 @@ basegfx::B2DPolyPolygon SvxShapePolyPolygonBezier::GetPolygon() const throw()
 }
 
 
-// ::com::sun::star::lang::XServiceInfo
+// css::lang::XServiceInfo
 uno::Sequence< OUString > SAL_CALL SvxShapePolyPolygonBezier::getSupportedServiceNames() throw( uno::RuntimeException, std::exception )
 {
     return SvxShapeText::getSupportedServiceNames();
@@ -1414,7 +1420,7 @@ SvxGraphicObject::~SvxGraphicObject() throw()
 {
 }
 
-bool SvxGraphicObject::setPropertyValueImpl( const OUString& rName, const SfxItemPropertySimpleEntry* pProperty, const ::com::sun::star::uno::Any& rValue ) throw(::com::sun::star::beans::UnknownPropertyException, ::com::sun::star::beans::PropertyVetoException, ::com::sun::star::lang::IllegalArgumentException, ::com::sun::star::lang::WrappedTargetException, ::com::sun::star::uno::RuntimeException, std::exception)
+bool SvxGraphicObject::setPropertyValueImpl( const OUString& rName, const SfxItemPropertySimpleEntry* pProperty, const css::uno::Any& rValue ) throw(css::beans::UnknownPropertyException, css::beans::PropertyVetoException, css::lang::IllegalArgumentException, css::lang::WrappedTargetException, css::uno::RuntimeException, std::exception)
 {
     bool bOk = false;
     switch( pProperty->nWID )
@@ -1423,13 +1429,13 @@ bool SvxGraphicObject::setPropertyValueImpl( const OUString& rName, const SfxIte
     {
         if( rValue.getValue() )
         {
-            if( rValue.getValueType() == ::getCppuType(( const uno::Sequence< sal_Int8 >*)0) )
+            if( rValue.getValueType() == cppu::UnoType<uno::Sequence< sal_Int8 >>::get() )
             {
-                uno::Sequence<sal_Int8>* pSeq( (uno::Sequence<sal_Int8>*)rValue.getValue() );
+                uno::Sequence<sal_Int8> const * pSeq( static_cast<uno::Sequence<sal_Int8> const *>(rValue.getValue()) );
                 SvMemoryStream  aMemStm;
                 Graphic         aGraphic;
 
-                aMemStm.SetBuffer( (char*)pSeq->getConstArray(), pSeq->getLength(), false, pSeq->getLength() );
+                aMemStm.SetBuffer( const_cast<css::uno::Sequence<sal_Int8> *>(pSeq)->getArray(), pSeq->getLength(), false, pSeq->getLength() );
 
                 if( GraphicConverter::Import( aMemStm, aGraphic ) == ERRCODE_NONE )
                 {
@@ -1448,11 +1454,11 @@ bool SvxGraphicObject::setPropertyValueImpl( const OUString& rName, const SfxIte
             }
             else
             {
-                // Bitmap in das Objekt packen
+                // pack bitmap in the object
                 Reference< awt::XBitmap > xBmp( rValue, UNO_QUERY );
                 if( xBmp.is() )
                 {
-                    // Bitmap einsetzen
+                    // apply bitmap
                     Graphic aGraphic(VCLUnoHelper::GetBitmap( xBmp ));
                     static_cast<SdrGrafObj*>(mpObj.get())->SetGraphic(aGraphic);
                     bOk = true;
@@ -1487,24 +1493,24 @@ bool SvxGraphicObject::setPropertyValueImpl( const OUString& rName, const SfxIte
             {
                 // normal link
                 OUString            aFilterName;
-                const SfxFilter*    pSfxFilter = NULL;
-                SfxMedium           aSfxMedium( aURL, referer_, STREAM_READ | STREAM_SHARE_DENYNONE );
+                const SfxFilter*    pSfxFilter = nullptr;
+                SfxMedium           aSfxMedium( aURL, referer_, StreamMode::READ | StreamMode::SHARE_DENYNONE );
 
-                SfxGetpApp()->GetFilterMatcher().GuessFilter( aSfxMedium, &pSfxFilter, SFX_FILTER_IMPORT, SFX_FILTER_NOTINSTALLED | SFX_FILTER_EXECUTABLE );
+                SfxGetpApp()->GetFilterMatcher().GuessFilter( aSfxMedium, &pSfxFilter );
 
                 if( !pSfxFilter )
                 {
                     INetURLObject aURLObj( aURL );
 
-                    if( aURLObj.GetProtocol() == INET_PROT_NOT_VALID )
+                    if( aURLObj.GetProtocol() == INetProtocol::NotValid )
                     {
                         OUString aValidURL;
 
-                        if( ::utl::LocalFileHelper::ConvertPhysicalNameToURL( aURL, aValidURL ) )
+                        if( osl::FileBase::getFileURLFromSystemPath( aURL, aValidURL ) == osl::FileBase::E_None )
                             aURLObj = INetURLObject( aValidURL );
                     }
 
-                    if( aURLObj.GetProtocol() != INET_PROT_NOT_VALID )
+                    if( aURLObj.GetProtocol() != INetProtocol::NotValid )
                     {
                         GraphicFilter &rGrfFilter = GraphicFilter::GetGraphicFilter();
                         aFilterName = rGrfFilter.GetImportFormatName( rGrfFilter.GetImportFormatNumberForShortName( aURLObj.getExtension() ) );
@@ -1566,9 +1572,7 @@ bool SvxGraphicObject::setPropertyValueImpl( const OUString& rName, const SfxIte
     return true;
 }
 
-
-
-bool SvxGraphicObject::getPropertyValueImpl( const OUString& rName, const SfxItemPropertySimpleEntry* pProperty, ::com::sun::star::uno::Any& rValue ) throw(::com::sun::star::beans::UnknownPropertyException, ::com::sun::star::lang::WrappedTargetException, ::com::sun::star::uno::RuntimeException)
+bool SvxGraphicObject::getPropertyValueImpl( const OUString& rName, const SfxItemPropertySimpleEntry* pProperty, css::uno::Any& rValue ) throw(css::beans::UnknownPropertyException, css::lang::WrappedTargetException, css::uno::RuntimeException, std::exception)
 {
     switch( pProperty->nWID )
     {
@@ -1578,15 +1582,15 @@ bool SvxGraphicObject::getPropertyValueImpl( const OUString& rName, const SfxIte
 
         if(rGraphic.GetType() != GRAPHIC_GDIMETAFILE)
         {
-            // Objekt in eine Bitmap packen
-            Reference< ::com::sun::star::awt::XBitmap >  xBitmap( VCLUnoHelper::CreateBitmap(static_cast< SdrGrafObj*>( mpObj.get() )->GetGraphic().GetBitmapEx()) );
+            // pack object in a bitmap
+            Reference< css::awt::XBitmap >  xBitmap( VCLUnoHelper::CreateBitmap(static_cast< SdrGrafObj*>( mpObj.get() )->GetGraphic().GetBitmapEx()) );
             rValue <<= xBitmap;
         }
         else
         {
             SvMemoryStream aDestStrm( 65535, 65535 );
 
-            ConvertGDIMetaFileToWMF( rGraphic.GetGDIMetaFile(), aDestStrm, NULL, false );
+            ConvertGDIMetaFileToWMF( rGraphic.GetGDIMetaFile(), aDestStrm, nullptr, false );
             const uno::Sequence<sal_Int8> aSeq(
                 static_cast< const sal_Int8* >(aDestStrm.GetData()),
                 aDestStrm.GetEndOfData());
@@ -1691,7 +1695,7 @@ uno::Any SAL_CALL SvxCustomShape::queryInterface( const uno::Type & rType )
 uno::Any SAL_CALL SvxCustomShape::queryAggregation( const uno::Type & rType )
     throw(uno::RuntimeException, std::exception)
 {
-    ::com::sun::star::uno::Any aReturn = SvxShapeText::queryAggregation( rType );
+    css::uno::Any aReturn = SvxShapeText::queryAggregation( rType );
     if ( !aReturn.hasValue() )
         aReturn = ::cppu::queryInterface(rType, static_cast<drawing::XEnhancedCustomShapeDefaulter*>(this) );
     return aReturn;
@@ -1721,7 +1725,7 @@ uno::Sequence< sal_Int8 > SAL_CALL SvxCustomShape::getImplementationId()
     return css::uno::Sequence<sal_Int8>();
 }
 
-// ::com::sun::star::drawing::XShape
+// css::drawing::XShape
 
 
 OUString SAL_CALL SvxCustomShape::getShapeType()
@@ -1756,19 +1760,19 @@ awt::Point SAL_CALL SvxCustomShape::getPosition() throw(uno::RuntimeException, s
             GeoStat aNewGeo( aCustomShapeGeoData.aGeo );
             if ( bMirroredX )
             {
-                Polygon aPol( Rect2Poly( aRect, aNewGeo ) );
+                tools::Polygon aPol( Rect2Poly( aRect, aNewGeo ) );
                 Rectangle aBoundRect( aPol.GetBoundRect() );
 
                 Point aRef1( ( aBoundRect.Left() + aBoundRect.Right() ) >> 1, aBoundRect.Top() );
                 Point aRef2( aRef1.X(), aRef1.Y() + 1000 );
                 sal_uInt16 i;
-                sal_uInt16 nPntAnz=aPol.GetSize();
-                for (i=0; i<nPntAnz; i++)
+                sal_uInt16 nPointCount=aPol.GetSize();
+                for (i=0; i<nPointCount; i++)
                 {
                     MirrorPoint(aPol[i],aRef1,aRef2);
                 }
-                // Polygon wenden und etwas schieben
-                Polygon aPol0(aPol);
+                // turn and move polygon
+                tools::Polygon aPol0(aPol);
                 aPol[0]=aPol0[1];
                 aPol[1]=aPol0[0];
                 aPol[2]=aPol0[3];
@@ -1778,19 +1782,19 @@ awt::Point SAL_CALL SvxCustomShape::getPosition() throw(uno::RuntimeException, s
             }
             if ( bMirroredY )
             {
-                Polygon aPol( Rect2Poly( aRectangle, aNewGeo ) );
+                tools::Polygon aPol( Rect2Poly( aRectangle, aNewGeo ) );
                 Rectangle aBoundRect( aPol.GetBoundRect() );
 
                 Point aRef1( aBoundRect.Left(), ( aBoundRect.Top() + aBoundRect.Bottom() ) >> 1 );
                 Point aRef2( aRef1.X() + 1000, aRef1.Y() );
                 sal_uInt16 i;
-                sal_uInt16 nPntAnz=aPol.GetSize();
-                for (i=0; i<nPntAnz; i++)
+                sal_uInt16 nPointCount=aPol.GetSize();
+                for (i=0; i<nPointCount; i++)
                 {
                     MirrorPoint(aPol[i],aRef1,aRef2);
                 }
-                // Polygon wenden und etwas schieben
-                Polygon aPol0(aPol);
+                // turn and move polygon
+                tools::Polygon aPol0(aPol);
                 aPol[0]=aPol0[1];
                 aPol[1]=aPol0[0];
                 aPol[2]=aPol0[3];
@@ -1805,7 +1809,7 @@ awt::Point SAL_CALL SvxCustomShape::getPosition() throw(uno::RuntimeException, s
             aPt -= mpObj->GetAnchorPos();
 
         ForceMetricTo100th_mm(aPt);
-        return ::com::sun::star::awt::Point( aPt.X(), aPt.Y() );
+        return css::awt::Point( aPt.X(), aPt.Y() );
     }
     else
         return SvxShape::getPosition();
@@ -1835,11 +1839,29 @@ void SAL_CALL SvxCustomShape::setSize( const awt::Size& rSize )
 
 
 void SAL_CALL SvxCustomShape::setPropertyValue( const OUString& aPropertyName, const uno::Any& aValue )
-    throw( beans::UnknownPropertyException, lang::WrappedTargetException, uno::RuntimeException, com::sun::star::beans::PropertyVetoException, com::sun::star::lang::IllegalArgumentException, std::exception)
+    throw( beans::UnknownPropertyException, lang::WrappedTargetException, uno::RuntimeException, css::beans::PropertyVetoException, css::lang::IllegalArgumentException, std::exception)
 {
     ::SolarMutexGuard aGuard;
+
     SdrObject* pObject = mpObj.get();
 
+    // tdf#98163 Use a custom slot to have filter code flush the UNO
+    // API implementations of SdrObjCustomShape. Used e.g. by
+    // ~SdXMLCustomShapeContext, see there for more information
+    const OUString sFlushCustomShapeUnoApiObjects("FlushCustomShapeUnoApiObjects");
+    if(sFlushCustomShapeUnoApiObjects == aPropertyName)
+    {
+        SdrObjCustomShape* pTarget = dynamic_cast< SdrObjCustomShape* >(pObject);
+        if(pTarget)
+        {
+            // Luckily, the object causing problems in tdf#93994 is not the
+            // UNO API object, but the XCustomShapeEngine involved. This
+            // object is on-demand replacable and can be reset here. This
+            // will free the involved EditEngine and VirtualDevice.
+            pTarget->mxCustomShapeEngine.set(nullptr);
+        }
+    }
+
     bool bCustomShapeGeometry = pObject && aPropertyName == "CustomShapeGeometry";
 
     bool bMirroredX = false;
@@ -1855,14 +1877,14 @@ void SAL_CALL SvxCustomShape::setPropertyValue( const OUString& aPropertyName, c
 
     if ( bCustomShapeGeometry )
     {
-        static_cast<SdrObjCustomShape*>(pObject)->MergeDefaultAttributes(0);
+        static_cast<SdrObjCustomShape*>(pObject)->MergeDefaultAttributes();
         Rectangle aRect( pObject->GetSnapRect() );
 
         // #i38892#
         bool bNeedsMirrorX = static_cast<SdrObjCustomShape*>(pObject)->IsMirroredX() != bMirroredX;
         bool bNeedsMirrorY = static_cast<SdrObjCustomShape*>(pObject)->IsMirroredY() != bMirroredY;
 
-        boost::scoped_ptr< SdrGluePointList > pListCopy;
+        std::unique_ptr< SdrGluePointList > pListCopy;
         if( bNeedsMirrorX || bNeedsMirrorY )
         {
             const SdrGluePointList* pList = pObject->GetGluePointList();
@@ -1877,7 +1899,7 @@ void SAL_CALL SvxCustomShape::setPropertyValue( const OUString& aPropertyName, c
             pObject->NbcMirror( aTop, aBottom );
             // NbcMirroring is flipping the current mirror state,
             // so we have to set the correct state again
-            static_cast<SdrObjCustomShape*>(pObject)->SetMirroredX( bMirroredX ? sal_False : sal_True );
+            static_cast<SdrObjCustomShape*>(pObject)->SetMirroredX( !bMirroredX );
         }
         if ( bNeedsMirrorY )
         {
@@ -1886,7 +1908,7 @@ void SAL_CALL SvxCustomShape::setPropertyValue( const OUString& aPropertyName, c
             pObject->NbcMirror( aLeft, aRight );
             // NbcMirroring is flipping the current mirror state,
             // so we have to set the correct state again
-            static_cast<SdrObjCustomShape*>(pObject)->SetMirroredY( bMirroredY ? sal_False : sal_True );
+            static_cast<SdrObjCustomShape*>(pObject)->SetMirroredY( !bMirroredY );
         }
 
         if( pListCopy )
@@ -1898,7 +1920,7 @@ void SAL_CALL SvxCustomShape::setPropertyValue( const OUString& aPropertyName, c
     }
 }
 
-bool SvxCustomShape::getPropertyValueImpl( const OUString& rName, const SfxItemPropertySimpleEntry* pProperty, ::com::sun::star::uno::Any& rValue ) throw(css::beans::UnknownPropertyException, css::lang::WrappedTargetException, css::uno::RuntimeException, std::exception)
+bool SvxCustomShape::getPropertyValueImpl( const OUString& rName, const SfxItemPropertySimpleEntry* pProperty, css::uno::Any& rValue ) throw(css::beans::UnknownPropertyException, css::lang::WrappedTargetException, css::uno::RuntimeException, std::exception)
 {
     switch( pProperty->nWID )
     {
@@ -1915,7 +1937,7 @@ bool SvxCustomShape::getPropertyValueImpl( const OUString& rName, const SfxItemP
 }
 
 
-void SvxCustomShape::createCustomShapeDefaults( const OUString& rValueType ) throw (::com::sun::star::uno::RuntimeException, std::exception)
+void SvxCustomShape::createCustomShapeDefaults( const OUString& rValueType ) throw (css::uno::RuntimeException, std::exception)
 {
     static_cast<SdrObjCustomShape*>(mpObj.get())->MergeDefaultAttributes( &rValueType );
 }
