@@ -67,6 +67,14 @@
 using namespace ::editeng;
 using namespace ::com::sun::star;
 
+bool IsConditionalByPoolId(sal_uInt16 nId)
+{
+    // TODO: why is this style conditional?
+    // If it is changed to no longer be conditional, then a style "Text Body"
+    // will be imported without its conditions from ODF.
+    return RES_POOLCOLL_TEXT == nId;
+}
+
 namespace
 {
     static const sal_uInt16 PT_3   =  3 * 20;      //  3 pt
@@ -98,7 +106,7 @@ namespace
         const SvxLRSpaceItem& rLR = rPgDscFormat.GetLRSpace();
         const long nLeft = rLR.GetLeft();
         const long nRight = rLR.GetRight();
-        const long nWidth = rPgDscFormat.GetFrmSize().GetWidth();
+        const long nWidth = rPgDscFormat.GetFrameSize().GetWidth();
         return nWidth - nLeft - nRight;
     }
 
@@ -176,40 +184,40 @@ namespace
                                 DefaultFontType::CTL_TEXT, rSet );
         }
 
-        if( pColl )
+        if( !pColl )
+            return;
+
+        if( !( nOutLvlBits & ( 1 << nLevel )) )
         {
-            if( !( nOutLvlBits & ( 1 << nLevel )) )
+            pColl->AssignToListLevelOfOutlineStyle(nLevel);
+            if( !bHTMLMode )
             {
-                pColl->AssignToListLevelOfOutlineStyle(nLevel);
-                if( !bHTMLMode )
+                SwNumRule * pOutlineRule = pDoc->GetOutlineNumRule();
+                const SwNumFormat& rNFormat = pOutlineRule->Get( nLevel );
+
+                SvxLRSpaceItem aLR( static_cast<const SvxLRSpaceItem&>(pColl->GetFormatAttr( RES_LR_SPACE )) );
+                if ( rNFormat.GetPositionAndSpaceMode() == SvxNumberFormat::LABEL_WIDTH_AND_POSITION &&
+                        ( rNFormat.GetAbsLSpace() || rNFormat.GetFirstLineOffset() ) )
                 {
-                    SwNumRule * pOutlineRule = pDoc->GetOutlineNumRule();
-                    const SwNumFormat& rNFormat = pOutlineRule->Get( nLevel );
-
-                    if ( rNFormat.GetPositionAndSpaceMode() ==
-                                        SvxNumberFormat::LABEL_WIDTH_AND_POSITION &&
-                         ( rNFormat.GetAbsLSpace() || rNFormat.GetFirstLineOffset() ) )
-                    {
-                        SvxLRSpaceItem aLR( static_cast<const SvxLRSpaceItem&>(pColl->GetFormatAttr( RES_LR_SPACE )) );
-                        aLR.SetTextFirstLineOfstValue( rNFormat.GetFirstLineOffset() );
-                        aLR.SetTextLeft( rNFormat.GetAbsLSpace() );
-                        pColl->SetFormatAttr( aLR );
-                    }
-
-                    // #i71764#
-                    // Check on document setting OUTLINE_LEVEL_YIELDS_OUTLINE_RULE no longer needed.
-                    // All paragraph styles, which are assigned to a level of the
-                    // outline style has to have the outline style set as its list style.
-                    {
-                        SwNumRuleItem aItem(pOutlineRule->GetName());
-
-                        pColl->SetFormatAttr(aItem);
-                    }
+                    aLR.SetTextFirstLineOfstValue( rNFormat.GetFirstLineOffset() );
+                    aLR.SetTextLeft( rNFormat.GetAbsLSpace() );
                 }
+                else
+                {
+                    // tdf#93970 The indent set at the associated outline style also affects this paragraph.
+                    // We don't want this here, so override it. This doesn't affect the outline style properties.
+                    aLR.SetTextFirstLineOfstValue( 0 );
+                    aLR.SetTextLeft( 0 );
+                }
+                pColl->SetFormatAttr( aLR );
+
+                // All paragraph styles, which are assigned to a level of the
+                // outline style has to have the outline style set as its list style.
+                SwNumRuleItem aItem(pOutlineRule->GetName());
+                pColl->SetFormatAttr(aItem);
             }
-            pColl->SetNextTextFormatColl( *pDoc->getIDocumentStylePoolAccess().GetTextCollFromPool(
-                                            RES_POOLCOLL_TEXT ));
         }
+        pColl->SetNextTextFormatColl( *pDoc->getIDocumentStylePoolAccess().GetTextCollFromPool( RES_POOLCOLL_TEXT ));
     }
 
     static void lcl_SetRegister( SwDoc* pDoc, SfxItemSet& rSet, sal_uInt16 nFact,
@@ -242,9 +250,12 @@ namespace
                             SwTwips nUpper, SwTwips nLower )
     {
 
-        SvxLRSpaceItem aLR( RES_LR_SPACE ); SvxULSpaceItem aUL( RES_UL_SPACE );
-        aLR.SetTextFirstLineOfst( sal_uInt16(nEZ) ); aLR.SetTextLeft( sal_uInt16(nLeft) );
-        aUL.SetUpper( sal_uInt16(nUpper) ); aUL.SetLower( sal_uInt16(nLower) );
+        SvxLRSpaceItem aLR( RES_LR_SPACE );
+        SvxULSpaceItem aUL( RES_UL_SPACE );
+        aLR.SetTextFirstLineOfst( sal_uInt16(nEZ) );
+        aLR.SetTextLeft( sal_uInt16(nLeft) );
+        aUL.SetUpper( sal_uInt16(nUpper) );
+        aUL.SetLower( sal_uInt16(nLower) );
         rSet.Put( aLR );
         rSet.Put( aUL );
 
@@ -255,14 +266,14 @@ namespace
     static void lcl_PutStdPageSizeIntoItemSet( SwDoc* pDoc, SfxItemSet& rSet )
     {
         SwPageDesc* pStdPgDsc = pDoc->getIDocumentStylePoolAccess().GetPageDescFromPool( RES_POOLPAGE_STANDARD );
-        SwFormatFrmSize aFrmSz( pStdPgDsc->GetMaster().GetFrmSize() );
+        SwFormatFrameSize aFrameSz( pStdPgDsc->GetMaster().GetFrameSize() );
         if( pStdPgDsc->GetLandscape() )
         {
-            SwTwips nTmp = aFrmSz.GetHeight();
-            aFrmSz.SetHeight( aFrmSz.GetWidth() );
-            aFrmSz.SetWidth( nTmp );
+            SwTwips nTmp = aFrameSz.GetHeight();
+            aFrameSz.SetHeight( aFrameSz.GetWidth() );
+            aFrameSz.SetWidth( nTmp );
         }
-        rSet.Put( aFrmSz );
+        rSet.Put( aFrameSz );
     }
 }
 
@@ -287,7 +298,7 @@ SwTextFormatColl* DocumentStylePoolManager::GetTextCollFromPool( sal_uInt16 nId,
 
     SwTextFormatColl* pNewColl;
     sal_uInt16 nOutLvlBits = 0;
-    for( sal_uInt16 n = 0; n < m_rDoc.GetTextFormatColls()->size(); ++n )
+    for( size_t n = 0; n < m_rDoc.GetTextFormatColls()->size(); ++n )
     {
         if( nId == ( pNewColl = (*m_rDoc.GetTextFormatColls())[ n ] )->GetPoolFormatId() )
         {
@@ -367,8 +378,7 @@ SwTextFormatColl* DocumentStylePoolManager::GetTextCollFromPool( sal_uInt16 nId,
 
         case RES_POOLCOLL_TEXT:                 // Text body
             {
-                SvxLineSpacingItem aLSpc( LINE_SPACE_DEFAULT_HEIGHT,
-                                        RES_PARATR_LINESPACING );
+                SvxLineSpacingItem aLSpc( LINE_SPACE_DEFAULT_HEIGHT, RES_PARATR_LINESPACING );
                 SvxULSpaceItem aUL( 0, PT_7, RES_UL_SPACE );
                 aLSpc.SetPropLineSpace( (const sal_uInt8) 120 );
                 if( m_rDoc.GetDocumentSettingManager().get(DocumentSettingId::HTML_MODE) ) aUL.SetLower( HTML_PARSPACE );
@@ -388,7 +398,8 @@ SwTextFormatColl* DocumentStylePoolManager::GetTextCollFromPool( sal_uInt16 nId,
                 SvxLRSpaceItem aLR( RES_LR_SPACE );
                 aLR.SetTextFirstLineOfst( -(short)GetMetricVal( CM_05 ));
                 aLR.SetTextLeft( GetMetricVal( CM_1 ));
-                SvxTabStopItem aTStops(RES_PARATR_TABSTOP);    aTStops.Insert( SvxTabStop( 0 ));
+                SvxTabStopItem aTStops(RES_PARATR_TABSTOP);
+                aTStops.Insert( SvxTabStop( 0 ));
 
                 aSet.Put( aLR );
                 aSet.Put( aTStops );
@@ -408,7 +419,8 @@ SwTextFormatColl* DocumentStylePoolManager::GetTextCollFromPool( sal_uInt16 nId,
                 aLR.SetTextFirstLineOfst( - short( GetMetricVal( CM_1 ) * 4 +
                                                   GetMetricVal( CM_05)) );
                 aLR.SetTextLeft( GetMetricVal( CM_1 ) * 5 );
-                SvxTabStopItem aTStops( RES_PARATR_TABSTOP );    aTStops.Insert( SvxTabStop( 0 ));
+                SvxTabStopItem aTStops( RES_PARATR_TABSTOP );
+                aTStops.Insert( SvxTabStop( 0 ));
 
                 aSet.Put( aLR );
                 aSet.Put( aTStops );
@@ -483,7 +495,8 @@ SwTextFormatColl* DocumentStylePoolManager::GetTextCollFromPool( sal_uInt16 nId,
         case RES_POOLCOLL_SIGNATURE:            // Signatures
         case RES_POOLCOLL_TABLE:                // Tabele content
             {
-                SwFormatLineNumber aLN; aLN.SetCountLines( false );
+                SwFormatLineNumber aLN;
+                aLN.SetCountLines( false );
                 aSet.Put( aLN );
             }
             break;
@@ -569,7 +582,8 @@ SwTextFormatColl* DocumentStylePoolManager::GetTextCollFromPool( sal_uInt16 nId,
         case RES_POOLCOLL_FOOTERL:
         case RES_POOLCOLL_FOOTERR:
             {
-                SwFormatLineNumber aLN; aLN.SetCountLines( false );
+                SwFormatLineNumber aLN;
+                aLN.SetCountLines( false );
                 aSet.Put( aLN );
 
                 long nRightMargin = lcl_GetRightMargin( m_rDoc );
@@ -586,7 +600,8 @@ SwTextFormatColl* DocumentStylePoolManager::GetTextCollFromPool( sal_uInt16 nId,
             {
                 SetAllScriptItem( aSet, SvxWeightItem( WEIGHT_BOLD, RES_CHRATR_WEIGHT ) );
                 aSet.Put( SvxAdjustItem( SVX_ADJUST_CENTER, RES_PARATR_ADJUST ) );
-                SwFormatLineNumber aLN; aLN.SetCountLines( false );
+                SwFormatLineNumber aLN;
+                aLN.SetCountLines( false );
                 aSet.Put( aLN );
             }
             break;
@@ -599,18 +614,22 @@ SwTextFormatColl* DocumentStylePoolManager::GetTextCollFromPool( sal_uInt16 nId,
                 aLR.SetTextLeft( GetMetricVal( CM_05 ) + GetMetricVal( CM_01 ) );
                 SetAllScriptItem( aSet, SvxFontHeightItem( PT_10, 100, RES_CHRATR_FONTSIZE ) );
                 aSet.Put( aLR );
-                SwFormatLineNumber aLN; aLN.SetCountLines( false );
+                SwFormatLineNumber aLN;
+                aLN.SetCountLines( false );
                 aSet.Put( aLN );
             }
             break;
 
         case RES_POOLCOLL_LABEL:                // basic caption
             {
-                SvxULSpaceItem aUL( RES_UL_SPACE ); aUL.SetUpper( PT_6 ); aUL.SetLower( PT_6 );
+                SvxULSpaceItem aUL( RES_UL_SPACE );
+                aUL.SetUpper( PT_6 );
+                aUL.SetLower( PT_6 );
                 aSet.Put( aUL );
                 SetAllScriptItem( aSet, SvxPostureItem( ITALIC_NORMAL, RES_CHRATR_POSTURE ) );
                 SetAllScriptItem( aSet, SvxFontHeightItem( PT_10, 100, RES_CHRATR_FONTSIZE ) );
-                SwFormatLineNumber aLN; aLN.SetCountLines( false );
+                SwFormatLineNumber aLN;
+                aLN.SetCountLines( false );
                 aSet.Put( aLN );
             }
             break;
@@ -624,9 +643,11 @@ SwTextFormatColl* DocumentStylePoolManager::GetTextCollFromPool( sal_uInt16 nId,
 
         case RES_POOLCOLL_JAKETADRESS:          // envelope address
             {
-                SvxULSpaceItem aUL( RES_UL_SPACE ); aUL.SetLower( PT_3 );
+                SvxULSpaceItem aUL( RES_UL_SPACE );
+                aUL.SetLower( PT_3 );
                 aSet.Put( aUL );
-                SwFormatLineNumber aLN; aLN.SetCountLines( false );
+                SwFormatLineNumber aLN;
+                aLN.SetCountLines( false );
                 aSet.Put( aLN );
             }
             break;
@@ -640,7 +661,8 @@ SwTextFormatColl* DocumentStylePoolManager::GetTextCollFromPool( sal_uInt16 nId,
                     SvxULSpaceItem aUL( RES_UL_SPACE ); aUL.SetLower( PT_3 );
                     aSet.Put( aUL );
                 }
-                SwFormatLineNumber aLN; aLN.SetCountLines( false );
+                SwFormatLineNumber aLN;
+                aLN.SetCountLines( false );
                 aSet.Put( aLN );
             }
             break;
@@ -649,7 +671,8 @@ SwTextFormatColl* DocumentStylePoolManager::GetTextCollFromPool( sal_uInt16 nId,
         case RES_POOLCOLL_TOX_USERH:            // Header
             lcl_SetRegister( &m_rDoc, aSet, 0, true, false );
             {
-                SwFormatLineNumber aLN; aLN.SetCountLines( false );
+                SwFormatLineNumber aLN;
+                aLN.SetCountLines( false );
                 aSet.Put( aLN );
             }
             break;
@@ -688,7 +711,8 @@ SwTextFormatColl* DocumentStylePoolManager::GetTextCollFromPool( sal_uInt16 nId,
         case RES_POOLCOLL_TOX_IDXH:         // Header
             lcl_SetRegister( &m_rDoc, aSet, 0, true, false );
             {
-                SwFormatLineNumber aLN; aLN.SetCountLines( false );
+                SwFormatLineNumber aLN;
+                aLN.SetCountLines( false );
                 aSet.Put( aLN );
             }
             break;
@@ -709,7 +733,8 @@ SwTextFormatColl* DocumentStylePoolManager::GetTextCollFromPool( sal_uInt16 nId,
         case RES_POOLCOLL_TOX_CNTNTH:       // Header
             lcl_SetRegister( &m_rDoc, aSet, 0, true, false );
             {
-                SwFormatLineNumber aLN; aLN.SetCountLines( false );
+                SwFormatLineNumber aLN;
+                aLN.SetCountLines( false );
                 aSet.Put( aLN );
             }
             break;
@@ -750,7 +775,8 @@ SwTextFormatColl* DocumentStylePoolManager::GetTextCollFromPool( sal_uInt16 nId,
         case RES_POOLCOLL_TOX_AUTHORITIESH:
             lcl_SetRegister( &m_rDoc, aSet, 0, true, false );
             {
-                SwFormatLineNumber aLN; aLN.SetCountLines( false );
+                SwFormatLineNumber aLN;
+                aLN.SetCountLines( false );
                 aSet.Put( aLN );
             }
             break;
@@ -972,8 +998,7 @@ SwTextFormatColl* DocumentStylePoolManager::GetTextCollFromPool( sal_uInt16 nId,
 
                 aSet.Put( SvxAdjustItem( SVX_ADJUST_CENTER, RES_PARATR_ADJUST ));
 
-                pNewColl->SetNextTextFormatColl( *GetTextCollFromPool(
-                                                    RES_POOLCOLL_TEXT ));
+                pNewColl->SetNextTextFormatColl( *GetTextCollFromPool( RES_POOLCOLL_TEXT ));
             }
             break;
 
@@ -1019,13 +1044,13 @@ SwTextFormatColl* DocumentStylePoolManager::GetTextCollFromPool( sal_uInt16 nId,
 
                 SvxULSpaceItem aUL( RES_UL_SPACE );
                 {
-                    pNewColl->SetNextTextFormatColl( *GetTextCollFromPool(
-                                                    RES_POOLCOLL_TEXT ));
+                    pNewColl->SetNextTextFormatColl( *GetTextCollFromPool( RES_POOLCOLL_TEXT ));
                     aUL = pNewColl->GetULSpace();
                 }
                 aUL.SetLower( HTML_PARSPACE );
                 aSet.Put( aUL);
-                SwFormatLineNumber aLN; aLN.SetCountLines( false );
+                SwFormatLineNumber aLN;
+                aLN.SetCountLines( false );
                 aSet.Put( aLN );
             }
             break;
@@ -1043,8 +1068,7 @@ SwTextFormatColl* DocumentStylePoolManager::GetTextCollFromPool( sal_uInt16 nId,
             {
                 SvxLRSpaceItem aLR( RES_LR_SPACE );
                 {
-                    pNewColl->SetNextTextFormatColl( *GetTextCollFromPool(
-                                                        RES_POOLCOLL_HTML_DD ));
+                    pNewColl->SetNextTextFormatColl( *GetTextCollFromPool( RES_POOLCOLL_HTML_DD ));
                     aLR = pNewColl->GetLRSpace();
                 }
                 // We indent by 0 cm. The IDs are always 2 away from each other!
@@ -1056,11 +1080,7 @@ SwTextFormatColl* DocumentStylePoolManager::GetTextCollFromPool( sal_uInt16 nId,
     }
 
     if( aSet.Count() )
-    {
-        {
-            pNewColl->SetFormatAttr( aSet );
-        }
-    }
+        pNewColl->SetFormatAttr( aSet );
     return pNewColl;
 }
 
@@ -1068,12 +1088,12 @@ SwTextFormatColl* DocumentStylePoolManager::GetTextCollFromPool( sal_uInt16 nId,
 /// exist, create it.
 SwFormat* DocumentStylePoolManager::GetFormatFromPool( sal_uInt16 nId )
 {
-    SwFormat *pNewFormat = 0;
-    SwFormat *pDeriveFormat = 0;
+    SwFormat *pNewFormat = nullptr;
+    SwFormat *pDeriveFormat = nullptr;
 
     SwFormatsBase* pArray[ 2 ];
     sal_uInt16 nArrCnt = 1, nRCId = 0;
-    sal_uInt16* pWhichRange = 0;
+    sal_uInt16* pWhichRange = nullptr;
 
     switch( nId & (COLL_GET_RANGE_BITS + POOLGRP_NOCOLLID) )
     {
@@ -1119,7 +1139,7 @@ SwFormat* DocumentStylePoolManager::GetFormatFromPool( sal_uInt16 nId )
     default:
         // Fault, unknown Format
         OSL_ENSURE( nId, "invalid Id" );
-        return 0;
+        return nullptr;
     }
     OSL_ENSURE( nRCId, "invalid Id" );
 
@@ -1156,7 +1176,7 @@ SwFormat* DocumentStylePoolManager::GetFormatFromPool( sal_uInt16 nId )
         if( !bIsModified )
             m_rDoc.getIDocumentState().ResetModified();
         pNewFormat->SetPoolFormatId( nId );
-        pNewFormat->SetAuto( false );      // no AutoFormat
+        pNewFormat->SetAuto(false);      // no AutoFormat
     }
 
     switch( nId )
@@ -1308,7 +1328,7 @@ SwFormat* DocumentStylePoolManager::GetFormatFromPool( sal_uInt16 nId )
             aSet.Put( SwFormatVertOrient( 0, text::VertOrientation::TOP, text::RelOrientation::FRAME ));
             aSet.Put( SwFormatSurround( SURROUND_PARALLEL ));
             // Set the default width to 3.5 cm, use the minimum value for the height
-            aSet.Put( SwFormatFrmSize( ATT_MIN_SIZE,
+            aSet.Put( SwFormatFrameSize( ATT_MIN_SIZE,
                     GetMetricVal( CM_1 ) * 3 + GetMetricVal( CM_05 ),
                     MM50 ));
         }
@@ -1333,7 +1353,7 @@ SwFormat* DocumentStylePoolManager::GetFormatFromPool( sal_uInt16 nId )
             aProtect.SetPosProtect( true );
             aSet.Put( aProtect );
 
-            pNewFormat->SetAutoUpdateFormat( true );
+            pNewFormat->SetAutoUpdateFormat();
         }
         break;
     }
@@ -1376,7 +1396,7 @@ SwPageDesc* DocumentStylePoolManager::GetPageDescFromPool( sal_uInt16 nId, bool
         nId = RES_POOLPAGE_BEGIN;
     }
 
-    SwPageDesc* pNewPgDsc = 0;
+    SwPageDesc* pNewPgDsc = nullptr;
     {
         const ResId aResId( sal_uInt32(RC_POOLPAGEDESC_BEGIN + nId - RES_POOLPAGE_BEGIN), *pSwResMgr );
         const OUString aNm( aResId );
@@ -1384,7 +1404,7 @@ SwPageDesc* DocumentStylePoolManager::GetPageDescFromPool( sal_uInt16 nId, bool
 
         {
             ::sw::UndoGuard const undoGuard(m_rDoc.GetIDocumentUndoRedo());
-            pNewPgDsc = m_rDoc.MakePageDesc(aNm, 0, bRegardLanguage);
+            pNewPgDsc = m_rDoc.MakePageDesc(aNm, nullptr, bRegardLanguage);
         }
 
         pNewPgDsc->SetPoolFormatId( nId );
@@ -1457,7 +1477,7 @@ SwPageDesc* DocumentStylePoolManager::GetPageDescFromPool( sal_uInt16 nId, bool
         {
             Size aPSize( SvxPaperInfo::GetPaperSize( PAPER_ENV_C65 ) );
             LandscapeSwap( aPSize );
-            aSet.Put( SwFormatFrmSize( ATT_FIX_SIZE, aPSize.Width(), aPSize.Height() ));
+            aSet.Put( SwFormatFrameSize( ATT_FIX_SIZE, aPSize.Width(), aPSize.Height() ));
             aLR.SetLeft( 0 ); aLR.SetRight( 0 );
             aUL.SetUpper( 0 ); aUL.SetLower( 0 );
             aSet.Put( aLR );
@@ -1499,14 +1519,14 @@ SwPageDesc* DocumentStylePoolManager::GetPageDescFromPool( sal_uInt16 nId, bool
     case RES_POOLPAGE_LANDSCAPE:    // "Landscape"
         {
             SwPageDesc* pStdPgDsc = GetPageDescFromPool( RES_POOLPAGE_STANDARD );
-            SwFormatFrmSize aFrmSz( pStdPgDsc->GetMaster().GetFrmSize() );
+            SwFormatFrameSize aFrameSz( pStdPgDsc->GetMaster().GetFrameSize() );
             if ( !pStdPgDsc->GetLandscape() )
             {
-                const SwTwips nTmp = aFrmSz.GetHeight();
-                aFrmSz.SetHeight( aFrmSz.GetWidth() );
-                aFrmSz.SetWidth( nTmp );
+                const SwTwips nTmp = aFrameSz.GetHeight();
+                aFrameSz.SetHeight( aFrameSz.GetWidth() );
+                aFrameSz.SetWidth( nTmp );
             }
-            aSet.Put( aFrmSz );
+            aSet.Put( aFrameSz );
             aSet.Put( aLR );
             aSet.Put( aUL );
             pNewPgDsc->SetUseOn( nsUseOnPage::PD_ALL );
@@ -1554,14 +1574,14 @@ SwNumRule* DocumentStylePoolManager::GetNumRuleFromPool( sal_uInt16 nId )
     ResId aResId( sal_uInt32(RC_POOLNUMRULE_BEGIN + nId - RES_POOLNUMRULE_BEGIN), *pSwResMgr );
     OUString aNm( aResId );
 
-    SwCharFormat *pNumCFormat = 0, *pBullCFormat = 0;
+    SwCharFormat *pNumCFormat = nullptr, *pBullCFormat = nullptr;
 
     const SvxNumberFormat::SvxNumPositionAndSpaceMode eNumberFormatPositionAndSpaceMode
                                   = numfunc::GetDefaultPositionAndSpaceMode(); //#i89178#
     {
         bool bIsModified = m_rDoc.getIDocumentState().IsModified();
 
-        sal_uInt16 n = m_rDoc.MakeNumRule( aNm, 0, false, eNumberFormatPositionAndSpaceMode );
+        sal_uInt16 n = m_rDoc.MakeNumRule( aNm, nullptr, false, eNumberFormatPositionAndSpaceMode );
 
         pNewRule = m_rDoc.GetNumRuleTable()[ n ];
         pNewRule->SetPoolFormatId( nId );
@@ -2109,7 +2129,7 @@ bool DocumentStylePoolManager::IsPoolTextCollUsed( sal_uInt16 nId ) const
         (RES_POOLCOLL_HTML_BEGIN <= nId && nId < RES_POOLCOLL_HTML_END),
             "Wrong AutoFormat Id" );
 
-    SwTextFormatColl* pNewColl = 0;
+    SwTextFormatColl* pNewColl = nullptr;
     bool bFnd = false;
     for( sal_uInt16 n = 0; !bFnd && n < m_rDoc.GetTextFormatColls()->size(); ++n )
     {
@@ -2128,7 +2148,7 @@ bool DocumentStylePoolManager::IsPoolTextCollUsed( sal_uInt16 nId ) const
 /// Check if this AutoCollection is already/still in use
 bool DocumentStylePoolManager::IsPoolFormatUsed( sal_uInt16 nId ) const
 {
-    const SwFormat *pNewFormat = 0;
+    const SwFormat *pNewFormat = nullptr;
     const SwFormatsBase* pArray[ 2 ];
     sal_uInt16 nArrCnt = 1;
     bool bFnd = true;
@@ -2180,7 +2200,7 @@ bool DocumentStylePoolManager::IsPoolPageDescUsed( sal_uInt16 nId ) const
 {
     OSL_ENSURE( RES_POOLPAGE_BEGIN <= nId && nId < RES_POOLPAGE_END,
             "Wrong AutoFormat Id" );
-    SwPageDesc *pNewPgDsc = 0;
+    SwPageDesc *pNewPgDsc = nullptr;
     bool bFnd = false;
     for( size_t n = 0; !bFnd && n < m_rDoc.GetPageDescCnt(); ++n )
     {
