@@ -17,8 +17,6 @@
  *   the License at http://www.apache.org/licenses/LICENSE-2.0 .
  */
 
-#include <boost/ptr_container/ptr_set.hpp>
-
 #include <hintids.hxx>
 #include <rtl/math.hxx>
 #include <unotools/collatorwrapper.hxx>
@@ -50,21 +48,23 @@
 #include <node2lay.hxx>
 #include <unochart.hxx>
 
+#include <set>
+
 using namespace ::com::sun::star::lang;
 using namespace ::com::sun::star;
 
-SwSortOptions*      SwSortElement::pOptions = 0;
-SwDoc*              SwSortElement::pDoc = 0;
-const FlatFndBox*   SwSortElement::pBox = 0;
-CollatorWrapper*    SwSortElement::pSortCollator = 0;
-lang::Locale*       SwSortElement::pLocale = 0;
-OUString*           SwSortElement::pLastAlgorithm = 0;
-LocaleDataWrapper*  SwSortElement::pLclData = 0;
+SwSortOptions*      SwSortElement::pOptions = nullptr;
+SwDoc*              SwSortElement::pDoc = nullptr;
+const FlatFndBox*   SwSortElement::pBox = nullptr;
+CollatorWrapper*    SwSortElement::pSortCollator = nullptr;
+lang::Locale*       SwSortElement::pLocale = nullptr;
+OUString*           SwSortElement::pLastAlgorithm = nullptr;
+LocaleDataWrapper*  SwSortElement::pLclData = nullptr;
 
 // List of all sorted elements
 
-typedef ::boost::ptr_multiset<SwSortTextElement> SwSortTextElements;
-typedef ::boost::ptr_multiset<SwSortBoxElement> SwSortBoxElements;
+typedef ::std::multiset<SwSortTextElement> SwSortTextElements;
+typedef ::std::multiset<SwSortBoxElement> SwSortBoxElements;
 
 /// Construct a SortElement for the Sort
 void SwSortElement::Init( SwDoc* pD, const SwSortOptions& rOpt,
@@ -90,13 +90,13 @@ void SwSortElement::Init( SwDoc* pD, const SwSortOptions& rOpt,
 
 void SwSortElement::Finit()
 {
-    delete pOptions, pOptions = 0;
-    delete pLocale, pLocale = 0;
-    delete pLastAlgorithm, pLastAlgorithm = 0;
-    delete pSortCollator, pSortCollator = 0;
-    delete pLclData, pLclData = 0;
-    pDoc = 0;
-    pBox = 0;
+    delete pOptions, pOptions = nullptr;
+    delete pLocale, pLocale = nullptr;
+    delete pLastAlgorithm, pLastAlgorithm = nullptr;
+    delete pSortCollator, pSortCollator = nullptr;
+    delete pLclData, pLclData = nullptr;
+    pDoc = nullptr;
+    pBox = nullptr;
 }
 
 SwSortElement::~SwSortElement()
@@ -166,7 +166,7 @@ bool SwSortElement::operator==(const SwSortElement& ) const
 bool SwSortElement::operator<(const SwSortElement& rCmp) const
 {
     // The actual comparison
-    for(sal_uInt16 nKey = 0; nKey < pOptions->aKeys.size(); ++nKey)
+    for(size_t nKey = 0; nKey < pOptions->aKeys.size(); ++nKey)
     {
         int nCmp = keycompare(rCmp, nKey);
 
@@ -254,7 +254,7 @@ OUString SwSortBoxElement::GetKey(sal_uInt16 nKey) const
         if( pMyBox->GetSttNd() )
         {
             // Iterate over all the Box's TextNodes
-            const SwNode *pNd = 0, *pEndNd = pMyBox->GetSttNd()->EndOfSectionNode();
+            const SwNode *pNd = nullptr, *pEndNd = pMyBox->GetSttNd()->EndOfSectionNode();
             for( sal_uLong nIdx = pMyBox->GetSttIdx() + 1; pNd != pEndNd; ++nIdx )
                 if( ( pNd = pDoc->GetNodes()[ nIdx ])->IsTextNode() )
                     aRetStr += pNd->GetTextNode()->GetText();
@@ -318,12 +318,12 @@ bool SwDoc::SortText(const SwPaM& rPaM, const SwSortOptions& rOpt)
     bool const bUndo = GetIDocumentUndoRedo().DoesUndo();
     if( bUndo )
     {
-        GetIDocumentUndoRedo().StartUndo( UNDO_START, NULL );
+        GetIDocumentUndoRedo().StartUndo( UNDO_START, nullptr );
     }
 
-    SwPaM* pRedlPam = 0;
-    SwUndoRedlineSort* pRedlUndo = 0;
-    SwUndoSort* pUndoSort = 0;
+    SwPaM* pRedlPam = nullptr;
+    SwUndoRedlineSort* pRedlUndo = nullptr;
+    SwUndoSort* pUndoSort = nullptr;
 
     // To-Do - add 'SwExtraRedlineTable' also ?
     if( getIDocumentRedlineAccess().IsRedlineOn() || (!getIDocumentRedlineAccess().IsIgnoreRedline() && !getIDocumentRedlineAccess().GetRedlineTable().empty() ))
@@ -353,10 +353,10 @@ bool SwDoc::SortText(const SwPaM& rPaM, const SwSortOptions& rOpt)
             pRedlPam->GetMark()->nContent.Assign( pCNd, 0 );
 
             pRedlPam->GetPoint()->nNode.Assign( aEndIdx.GetNode() );
-            pCNd = pRedlPam->GetContentNode( true );
+            pCNd = pRedlPam->GetContentNode();
             sal_Int32 nCLen = 0;
             if( !pCNd &&
-                0 != (pCNd = GetNodes()[ aEndIdx.GetIndex()-1 ]->GetContentNode()))
+                nullptr != (pCNd = GetNodes()[ aEndIdx.GetIndex()-1 ]->GetContentNode()))
             {
                 nCLen = pCNd->Len();
                 pRedlPam->GetPoint()->nNode.Assign( *pCNd );
@@ -369,7 +369,7 @@ bool SwDoc::SortText(const SwPaM& rPaM, const SwSortOptions& rOpt)
         else
         {
             getIDocumentRedlineAccess().DeleteRedline( *pRedlPam, true, USHRT_MAX );
-            delete pRedlPam, pRedlPam = 0;
+            delete pRedlPam, pRedlPam = nullptr;
         }
     }
 
@@ -379,8 +379,7 @@ bool SwDoc::SortText(const SwPaM& rPaM, const SwSortOptions& rOpt)
     while( aStart <= pEnd->nNode )
     {
         // Iterate over a selected range
-        SwSortTextElement* pSE = new SwSortTextElement( aStart );
-        aSortSet.insert(pSE);
+        aSortSet.insert(SwSortTextElement(aStart));
         ++aStart;
     }
 
@@ -461,12 +460,12 @@ bool SwDoc::SortText(const SwPaM& rPaM, const SwSortOptions& rOpt)
         if( pRedlUndo )
             pRedlUndo->SetOffset( aSttIdx );
 
-        delete pRedlPam, pRedlPam = 0;
+        delete pRedlPam, pRedlPam = nullptr;
     }
     GetIDocumentUndoRedo().DoUndo( bUndo );
     if( bUndo )
     {
-        GetIDocumentUndoRedo().EndUndo( UNDO_END, NULL );
+        GetIDocumentUndoRedo().EndUndo( UNDO_END, nullptr );
     }
 
     return true;
@@ -483,7 +482,7 @@ bool SwDoc::SortTable(const SwSelBoxes& rBoxes, const SwSortOptions& rOpt)
 
     // We begin sorting
     // Find all Boxes/Lines
-    _FndBox aFndBox( 0, 0 );
+    _FndBox aFndBox( nullptr, nullptr );
     {
         _FndPara aPara( rBoxes, &aFndBox );
         ForEach_FndLineCopyCol( pTableNd->GetTable().GetTabLines(), &aPara );
@@ -495,17 +494,17 @@ bool SwDoc::SortTable(const SwSelBoxes& rBoxes, const SwSortOptions& rOpt)
     if( !getIDocumentRedlineAccess().IsIgnoreRedline() && !getIDocumentRedlineAccess().GetRedlineTable().empty() )
         getIDocumentRedlineAccess().DeleteRedline( *pTableNd, true, USHRT_MAX );
 
-    _FndLines::size_type nStart = 0;
+    FndLines_t::size_type nStart = 0;
     if( pTableNd->GetTable().GetRowsToRepeat() > 0 && rOpt.eDirection == SRT_ROWS )
     {
         // Uppermost selected Cell
-        _FndLines& rLines = aFndBox.GetLines();
+        FndLines_t& rLines = aFndBox.GetLines();
 
         while( nStart < rLines.size() )
         {
             // Respect Split Merge nesting,
             // extract the upper most
-            SwTableLine* pLine = rLines[nStart].GetLine();
+            SwTableLine* pLine = rLines[nStart]->GetLine();
             while ( pLine->GetUpper() )
                 pLine = pLine->GetUpper()->GetUpper();
 
@@ -521,7 +520,7 @@ bool SwDoc::SortTable(const SwSelBoxes& rBoxes, const SwSortOptions& rOpt)
 
     // Switch to relative Formulas
     SwTableFormulaUpdate aMsgHint( &pTableNd->GetTable() );
-    aMsgHint.eFlags = TBL_RELBOXNAME;
+    aMsgHint.m_eFlags = TBL_RELBOXNAME;
     getIDocumentFieldsAccess().UpdateTableFields( &aMsgHint );
 
     // Table as a flat array structure
@@ -531,17 +530,17 @@ bool SwDoc::SortTable(const SwSelBoxes& rBoxes, const SwSortOptions& rOpt)
         return false;
 
     // Delete HTML layout
-    pTableNd->GetTable().SetHTMLTableLayout( 0 );
+    pTableNd->GetTable().SetHTMLTableLayout( nullptr );
 
-    // #i37739# A simple 'MakeFrms' after the node sorting
+    // #i37739# A simple 'MakeFrames' after the node sorting
     // does not work if the table is inside a frame and has no prev/next.
     SwNode2Layout aNode2Layout( *pTableNd );
 
     // Delete the Table's Frames
-    pTableNd->DelFrms();
+    pTableNd->DelFrames();
     // ? TL_CHART2: ?
 
-    SwUndoSort* pUndoSort = 0;
+    SwUndoSort* pUndoSort = nullptr;
     if (GetIDocumentUndoRedo().DoesUndo())
     {
         pUndoSort = new SwUndoSort( rBoxes[0]->GetSttIdx(),
@@ -562,8 +561,7 @@ bool SwDoc::SortTable(const SwSelBoxes& rBoxes, const SwSortOptions& rOpt)
     // When sorting, do not include the first row if the HeaderLine is repeated
     for( sal_uInt16 i = static_cast<sal_uInt16>(nStart); i < nCount; ++i)
     {
-        SwSortBoxElement* pEle = new SwSortBoxElement( i );
-        aSortList.insert(pEle);
+        aSortList.insert(SwSortBoxElement(i));
     }
 
     // Move after Sorting
@@ -583,10 +581,10 @@ bool SwDoc::SortTable(const SwSelBoxes& rBoxes, const SwSortOptions& rOpt)
     }
 
     // Restore table frames:
-    // #i37739# A simple 'MakeFrms' after the node sorting
+    // #i37739# A simple 'MakeFrames' after the node sorting
     // does not work if the table is inside a frame and has no prev/next.
     const sal_uLong nIdx = pTableNd->GetIndex();
-    aNode2Layout.RestoreUpperFrms( GetNodes(), nIdx, nIdx + 1 );
+    aNode2Layout.RestoreUpperFrames( GetNodes(), nIdx, nIdx + 1 );
 
     // TL_CHART2: need to inform chart of probably changed cell names
     UpdateCharts( pTableNd->GetTable().GetFrameFormat()->GetName() );
@@ -737,15 +735,15 @@ void MoveCell(SwDoc* pDoc, const SwTableBox* pSource, const SwTableBox* pTar,
 
     // If first Node is empty -> delete it
     if(bDelFirst)
-        pDoc->GetNodes().Delete( aTar, 1 );
+        pDoc->GetNodes().Delete( aTar );
 }
 
 /// Generate two-dimensional array of FndBoxes
 FlatFndBox::FlatFndBox(SwDoc* pDocPtr, const _FndBox& rBox) :
     pDoc(pDocPtr),
     rBoxRef(rBox),
-    pArr(0),
-    ppItemSets(0),
+    pArr(nullptr),
+    ppItemSets(nullptr),
     nRow(0),
     nCol(0)
 { // If the array is symmetric
@@ -758,7 +756,7 @@ FlatFndBox::FlatFndBox(SwDoc* pDocPtr, const _FndBox& rBox) :
         // Create linear array
         size_t nCount = static_cast<size_t>(nRows) * nCols;
         pArr = new const _FndBox*[nCount];
-        _FndBox** ppTmp = (_FndBox**)pArr;
+        _FndBox** ppTmp = const_cast<_FndBox**>(pArr);
         memset(ppTmp, 0, sizeof(const _FndBox*) * nCount);
 
         FillFlat( rBoxRef );
@@ -767,7 +765,7 @@ FlatFndBox::FlatFndBox(SwDoc* pDocPtr, const _FndBox& rBox) :
 
 FlatFndBox::~FlatFndBox()
 {
-    _FndBox** ppTmp = (_FndBox**)pArr;
+    _FndBox** ppTmp = const_cast<_FndBox**>(pArr);
     delete [] ppTmp;
 
     if( ppItemSets )
@@ -777,13 +775,13 @@ FlatFndBox::~FlatFndBox()
 /// All Lines of a Box need to have same number of Boxes
 bool FlatFndBox::CheckLineSymmetry(const _FndBox& rBox)
 {
-    const _FndLines &rLines = rBox.GetLines();
-    _FndBoxes::size_type nBoxes {0};
+    const FndLines_t &rLines = rBox.GetLines();
+    FndBoxes_t::size_type nBoxes {0};
 
-    for(_FndLines::size_type i=0; i < rLines.size(); ++i)
+    for (FndLines_t::size_type i=0; i < rLines.size(); ++i)
     {
-        const _FndLine* pLn = &rLines[i];
-        const _FndBoxes& rBoxes = pLn->GetBoxes();
+        const _FndLine* pLn = rLines[i].get();
+        const FndBoxes_t& rBoxes = pLn->GetBoxes();
 
         // Number of Boxes of all Lines is unequal -> no symmetry
         if( i  && nBoxes != rBoxes.size())
@@ -799,13 +797,13 @@ bool FlatFndBox::CheckLineSymmetry(const _FndBox& rBox)
 /// Check Box for symmetry (All Boxes of a Line need to have same number of Lines)
 bool FlatFndBox::CheckBoxSymmetry(const _FndLine& rLn)
 {
-    const _FndBoxes &rBoxes = rLn.GetBoxes();
-    _FndLines::size_type nLines {0};
+    const FndBoxes_t &rBoxes = rLn.GetBoxes();
+    FndLines_t::size_type nLines {0};
 
-    for(_FndBoxes::size_type i=0; i < rBoxes.size(); ++i)
+    for (FndBoxes_t::size_type i = 0; i < rBoxes.size(); ++i)
     {
-        _FndBox const*const pBox = &rBoxes[i];
-        const _FndLines& rLines = pBox->GetLines();
+        _FndBox const*const pBox = rBoxes[i].get();
+        const FndLines_t& rLines = pBox->GetLines();
 
         // Number of Lines of all Boxes is unequal -> no symmetry
         if( i && nLines != rLines.size() )
@@ -821,20 +819,21 @@ bool FlatFndBox::CheckBoxSymmetry(const _FndLine& rLn)
 /// Maximum count of Columns (Boxes)
 sal_uInt16 FlatFndBox::GetColCount(const _FndBox& rBox)
 {
-    const _FndLines& rLines = rBox.GetLines();
+    const FndLines_t& rLines = rBox.GetLines();
     // Iterate over Lines
     if( rLines.empty() )
         return 1;
 
     sal_uInt16 nSum = 0;
-    for( const auto &rLine : rLines )
+    for (const auto & pLine : rLines)
     {
         // The Boxes of a Line
         sal_uInt16 nCount = 0;
-        const _FndBoxes& rBoxes = rLine.GetBoxes();
-        for( const auto &rB : rBoxes )
-            // Iterate recursively over the Lines
-            nCount += rB.GetLines().empty() ? 1 : GetColCount(rB);
+        const FndBoxes_t& rBoxes = pLine->GetBoxes();
+        for (const auto &rpB : rBoxes)
+        {   // Iterate recursively over the Lines
+            nCount += rpB->GetLines().empty() ? 1 : GetColCount(*rpB);
+        }
 
         if( nSum < nCount )
             nSum = nCount;
@@ -845,42 +844,45 @@ sal_uInt16 FlatFndBox::GetColCount(const _FndBox& rBox)
 /// Maximum count of Rows (Lines)
 sal_uInt16 FlatFndBox::GetRowCount(const _FndBox& rBox)
 {
-    const _FndLines& rLines = rBox.GetLines();
+    const FndLines_t& rLines = rBox.GetLines();
     if( rLines.empty() )
         return 1;
 
     sal_uInt16 nLines = 0;
-    for(const auto &rLine : rLines )
+    for (const auto & pLine : rLines)
     {   // The Boxes of a Line
-        const _FndBoxes& rBoxes = rLine.GetBoxes();
+        const FndBoxes_t& rBoxes = pLine->GetBoxes();
         sal_uInt16 nLn = 1;
-        for(const auto &rB : rBoxes)
-            if (rB.GetLines().size())
-                // Iterate recursively over the Lines
-                nLn = std::max(GetRowCount(rB), nLn);
+        for (const auto &rpB : rBoxes)
+        {
+            if (rpB->GetLines().size())
+            {   // Iterate recursively over the Lines
+                nLn = std::max(GetRowCount(*rpB), nLn);
+            }
+        }
 
         nLines = nLines + nLn;
     }
     return nLines;
 }
 
-/// Create a linear array of atmoic FndBoxes
+/// Create a linear array of atomic FndBoxes
 void FlatFndBox::FillFlat(const _FndBox& rBox, bool bLastBox)
 {
     bool bModRow = false;
-    const _FndLines& rLines = rBox.GetLines();
+    const FndLines_t& rLines = rBox.GetLines();
 
     // Iterate over Lines
     sal_uInt16 nOldRow = nRow;
-    for( const auto &rLine : rLines )
+    for (const auto & pLine : rLines)
     {
         // The Boxes of a Line
-        const _FndBoxes& rBoxes = rLine.GetBoxes();
+        const FndBoxes_t& rBoxes = pLine->GetBoxes();
         sal_uInt16 nOldCol = nCol;
-        for( _FndBoxes::size_type j = 0; j < rBoxes.size(); ++j )
+        for( FndBoxes_t::size_type j = 0; j < rBoxes.size(); ++j )
         {
             // Check the Box if it's an atomic one
-            const _FndBox *const pBox = &rBoxes[j];
+            const _FndBox *const pBox = rBoxes[j].get();
 
             if( pBox->GetLines().empty() )
             {
@@ -938,7 +940,7 @@ const SfxItemSet* FlatFndBox::GetItemSet(sal_uInt16 n_Col, sal_uInt16 n_Row) con
 {
     OSL_ENSURE( !ppItemSets || ( n_Col < nCols && n_Row < nRows), "invalid array access");
 
-    return ppItemSets ? *(ppItemSets + (n_Row * nCols + n_Col )) : 0;
+    return ppItemSets ? *(ppItemSets + (n_Row * nCols + n_Col )) : nullptr;
 }
 
 sal_uInt16 SwMovedBoxes::GetPos(const SwTableBox* pTableBox) const
