@@ -22,7 +22,6 @@
 #include <tblrwcl.hxx>
 #include <swtblfmt.hxx>
 #include <algorithm>
-#include <boost/foreach.hpp>
 
 using namespace ::editeng;
 
@@ -31,12 +30,12 @@ inline const SvxBorderLine* GetLineTB( const SvxBoxItem* pBox, bool bTop )
     return bTop ? pBox->GetTop() : pBox->GetBottom();
 }
 
-bool _SwGCBorder_BoxBrd::CheckLeftBorderOfFormat( const SwFrmFmt& rFmt )
+bool _SwGCBorder_BoxBrd::CheckLeftBorderOfFormat( const SwFrameFormat& rFormat )
 {
     const SvxBorderLine* pBrd;
     const SfxPoolItem* pItem;
-    if( SFX_ITEM_SET == rFmt.GetItemState( RES_BOX, true, &pItem ) &&
-        0 != ( pBrd = ((SvxBoxItem*)pItem)->GetLeft() ) )
+    if( SfxItemState::SET == rFormat.GetItemState( RES_BOX, true, &pItem ) &&
+        nullptr != ( pBrd = static_cast<const SvxBoxItem*>(pItem)->GetLeft() ) )
     {
         if( *pBrdLn == *pBrd )
             bAnyBorderFnd = true;
@@ -55,21 +54,19 @@ static bool lcl_GCBorder_ChkBoxBrd_L( const SwTableLine* pLine, _SwGCBorder_BoxB
 
 static bool lcl_GCBorder_ChkBoxBrd_B( const SwTableBox* pBox, _SwGCBorder_BoxBrd* pPara )
 {
-    bool bRet = true;
     if( !pBox->GetTabLines().empty() )
     {
-        for( sal_uInt16 n = 0, nLines = pBox->GetTabLines().size();
-                n < nLines && bRet; ++n )
+        for( auto pLine : pBox->GetTabLines() )
         {
-            const SwTableLine* pLine = pBox->GetTabLines()[ n ];
-            bRet = lcl_GCBorder_ChkBoxBrd_L( pLine, pPara );
+            if (!lcl_GCBorder_ChkBoxBrd_L( pLine, pPara ))
+            {
+                return false;
+            }
         }
+        return true;
     }
-    else
-    {
-        bRet = pPara->CheckLeftBorderOfFormat( *pBox->GetFrmFmt() );
-    }
-    return bRet;
+
+    return pPara->CheckLeftBorderOfFormat( *pBox->GetFrameFormat() );
 }
 
 static void lcl_GCBorder_GetLastBox_B( const SwTableBox* pBox, SwTableBoxes* pPara );
@@ -86,26 +83,26 @@ static void lcl_GCBorder_GetLastBox_B( const SwTableBox* pBox, SwTableBoxes* pPa
     const SwTableLines& rLines = pBox->GetTabLines();
     if( !rLines.empty() )
     {
-        BOOST_FOREACH( const SwTableLine* pLine, rLines )
+        for( const SwTableLine* pLine : rLines )
             lcl_GCBorder_GetLastBox_L( pLine, pPara );
     }
     else
-        pPara->push_back( (SwTableBox*)pBox );
+        pPara->push_back( const_cast<SwTableBox*>(pBox) );
 }
 
 // Find the "end" of the passed BorderLine. Returns the "Layout"Pos!
-static sal_uInt16 lcl_FindEndPosOfBorder( const SwCollectTblLineBoxes& rCollTLB,
-                        const SvxBorderLine& rBrdLn, sal_uInt16& rStt, bool bTop )
+static sal_uInt16 lcl_FindEndPosOfBorder( const SwCollectTableLineBoxes& rCollTLB,
+                        const SvxBorderLine& rBrdLn, size_t& rStt, bool bTop )
 {
     sal_uInt16 nPos, nLastPos = 0;
-    for( sal_uInt16 nEnd = rCollTLB.Count(); rStt < nEnd; ++rStt )
+    for( size_t nEnd = rCollTLB.Count(); rStt < nEnd; ++rStt )
     {
         const SfxPoolItem* pItem;
         const SvxBorderLine* pBrd;
         const SwTableBox& rBox = rCollTLB.GetBox( rStt, &nPos );
 
-        if( SFX_ITEM_SET != rBox.GetFrmFmt()->GetItemState(RES_BOX,true, &pItem )
-            || 0 == ( pBrd = GetLineTB( (SvxBoxItem*)pItem, bTop ))
+        if( SfxItemState::SET != rBox.GetFrameFormat()->GetItemState(RES_BOX,true, &pItem )
+            || nullptr == ( pBrd = GetLineTB( static_cast<const SvxBoxItem*>(pItem), bTop ))
             || !( *pBrd == rBrdLn ))
             break;
         nLastPos = nPos;
@@ -117,41 +114,41 @@ static inline const SvxBorderLine* lcl_GCBorder_GetBorder( const SwTableBox& rBo
                                                 bool bTop,
                                                 const SfxPoolItem** ppItem )
 {
-    return SFX_ITEM_SET == rBox.GetFrmFmt()->GetItemState( RES_BOX, true, ppItem )
-            ? GetLineTB( (SvxBoxItem*)*ppItem, bTop )
-            : 0;
+    return SfxItemState::SET == rBox.GetFrameFormat()->GetItemState( RES_BOX, true, ppItem )
+            ? GetLineTB( static_cast<const SvxBoxItem*>(*ppItem), bTop )
+            : nullptr;
 }
 
-static void lcl_GCBorder_DelBorder( const SwCollectTblLineBoxes& rCollTLB,
-                                sal_uInt16& rStt, bool bTop,
+static void lcl_GCBorder_DelBorder( const SwCollectTableLineBoxes& rCollTLB,
+                                size_t& rStt, bool bTop,
                                 const SvxBorderLine& rLine,
                                 const SfxPoolItem* pItem,
                                 sal_uInt16 nEndPos,
-                                SwShareBoxFmts* pShareFmts )
+                                SwShareBoxFormats* pShareFormats )
 {
-    SwTableBox* pBox = (SwTableBox*)&rCollTLB.GetBox( rStt );
+    SwTableBox* pBox = const_cast<SwTableBox*>(&rCollTLB.GetBox( rStt ));
     sal_uInt16 nNextPos;
     const SvxBorderLine* pLn = &rLine;
 
     do {
         if( pLn && *pLn == rLine )
         {
-            SvxBoxItem aBox( *(SvxBoxItem*)pItem );
+            SvxBoxItem aBox( *static_cast<const SvxBoxItem*>(pItem) );
             if( bTop )
-                aBox.SetLine( 0, BOX_LINE_TOP );
+                aBox.SetLine( nullptr, SvxBoxItemLine::TOP );
             else
-                aBox.SetLine( 0, BOX_LINE_BOTTOM );
+                aBox.SetLine( nullptr, SvxBoxItemLine::BOTTOM );
 
-            if( pShareFmts )
-                pShareFmts->SetAttr( *pBox, aBox );
+            if( pShareFormats )
+                pShareFormats->SetAttr( *pBox, aBox );
             else
-                pBox->ClaimFrmFmt()->SetFmtAttr( aBox );
+                pBox->ClaimFrameFormat()->SetFormatAttr( aBox );
         }
 
         if( ++rStt >= rCollTLB.Count() )
             break;
 
-        pBox = (SwTableBox*)&rCollTLB.GetBox( rStt, &nNextPos );
+        pBox = const_cast<SwTableBox*>(&rCollTLB.GetBox( rStt, &nNextPos ));
         if( nNextPos > nEndPos )
             break;
 
@@ -170,7 +167,7 @@ void sw_GC_Line_Border( const SwTableLine* pLine, _SwGCLineBorder* pGCPara )
         const SvxBorderLine* pBrd;
         const SfxPoolItem* pItem;
         const SwTableBoxes& rBoxes = pLine->GetTabBoxes();
-        for( sal_uInt16 n = 0, nBoxes = rBoxes.size() - 1; n < nBoxes; ++n )
+        for( SwTableBoxes::size_type n = 0, nBoxes = rBoxes.size() - 1; n < nBoxes; ++n )
         {
             SwTableBoxes aBoxes;
             {
@@ -181,25 +178,27 @@ void sw_GC_Line_Border( const SwTableLine* pLine, _SwGCLineBorder* pGCPara )
                     lcl_GCBorder_GetLastBox_B( pBox, &aBoxes );
             }
 
-            SwTableBox* pBox;
-            for( sal_uInt16 i = aBoxes.size(); i; )
-                if( SFX_ITEM_SET == (pBox = aBoxes[ --i ])->GetFrmFmt()->
+            for( SwTableBoxes::size_type i = aBoxes.size(); i; )
+            {
+                SwTableBox* pBox;
+                if( SfxItemState::SET == (pBox = aBoxes[ --i ])->GetFrameFormat()->
                     GetItemState( RES_BOX, true, &pItem ) &&
-                    0 != ( pBrd = ((SvxBoxItem*)pItem)->GetRight() ) )
+                    nullptr != ( pBrd = static_cast<const SvxBoxItem*>(pItem)->GetRight() ) )
                 {
                     aBPara.SetBorder( *pBrd );
                     const SwTableBox* pNextBox = rBoxes[n+1];
                     if( lcl_GCBorder_ChkBoxBrd_B( pNextBox, &aBPara ) &&
                         aBPara.IsAnyBorderFound() )
                     {
-                        SvxBoxItem aBox( *(SvxBoxItem*)pItem );
-                        aBox.SetLine( 0, BOX_LINE_RIGHT );
-                        if( pGCPara->pShareFmts )
-                            pGCPara->pShareFmts->SetAttr( *pBox, aBox );
+                        SvxBoxItem aBox( *static_cast<const SvxBoxItem*>(pItem) );
+                        aBox.SetLine( nullptr, SvxBoxItemLine::RIGHT );
+                        if( pGCPara->pShareFormats )
+                            pGCPara->pShareFormats->SetAttr( *pBox, aBox );
                         else
-                            pBox->ClaimFrmFmt()->SetFmtAttr( aBox );
+                            pBox->ClaimFrameFormat()->SetFormatAttr( aBox );
                     }
                 }
+            }
 
             aBoxes.clear();
         }
@@ -208,8 +207,8 @@ void sw_GC_Line_Border( const SwTableLine* pLine, _SwGCLineBorder* pGCPara )
     // And now the own bottom edge with the succeeding top edge
     if( !pGCPara->IsLastLine() )
     {
-        SwCollectTblLineBoxes aBottom( false );
-        SwCollectTblLineBoxes aTop( true );
+        SwCollectTableLineBoxes aBottom( false );
+        SwCollectTableLineBoxes aTop( true );
 
         sw_Line_CollectBox( pLine, &aBottom );
 
@@ -217,14 +216,17 @@ void sw_GC_Line_Border( const SwTableLine* pLine, _SwGCLineBorder* pGCPara )
         sw_Line_CollectBox( pNextLine, &aTop );
 
         // remove all "duplicated" Lines that are the same
-        sal_uInt16 nBtmPos, nTopPos,
-                nSttBtm = 0, nSttTop = 0,
-                nEndBtm = aBottom.Count(), nEndTop = aTop.Count();
+        sal_uInt16 nBtmPos, nTopPos;
 
-        const SwTableBox *pBtmBox = &aBottom.GetBox( nSttBtm++, &nBtmPos ),
-                         *pTopBox = &aTop.GetBox( nSttTop++, &nTopPos );
-        const SfxPoolItem *pBtmItem = 0, *pTopItem = 0;
-        const SvxBorderLine *pBtmLine(0), *pTopLine(0);
+        size_t nSttBtm {0};
+        size_t nSttTop {0};
+        const size_t nEndBtm {aBottom.Count()};
+        const size_t nEndTop {aTop.Count()};
+
+        const SwTableBox *pBtmBox = &aBottom.GetBox( nSttBtm++, &nBtmPos );
+        const SwTableBox *pTopBox = &aTop.GetBox( nSttTop++, &nTopPos );
+        const SfxPoolItem *pBtmItem = nullptr, *pTopItem = nullptr;
+        const SvxBorderLine *pBtmLine(nullptr), *pTopLine(nullptr);
         bool bGetTopItem = true, bGetBtmItem = true;
 
         do {
@@ -236,7 +238,8 @@ void sw_GC_Line_Border( const SwTableLine* pLine, _SwGCLineBorder* pGCPara )
             if( pTopLine && pBtmLine && *pTopLine == *pBtmLine )
             {
                 // We can remove one, but which one?
-                sal_uInt16 nSavSttBtm = nSttBtm, nSavSttTop = nSttTop;
+                const size_t nSavSttBtm {nSttBtm};
+                const size_t nSavSttTop {nSttTop};
                 sal_uInt16 nBtmEndPos = ::lcl_FindEndPosOfBorder( aBottom,
                                                 *pTopLine, nSttBtm, false );
                 if( !nBtmEndPos ) nBtmEndPos = nBtmPos;
@@ -251,7 +254,7 @@ void sw_GC_Line_Border( const SwTableLine* pLine, _SwGCLineBorder* pGCPara )
                     if( nTopPos <= nBtmEndPos )
                         lcl_GCBorder_DelBorder( aTop, --nSttTop, true,
                                             *pBtmLine, pTopItem, nBtmEndPos,
-                                            pGCPara->pShareFmts );
+                                            pGCPara->pShareFormats );
                     else
                         nSttBtm = nSavSttBtm;
                 }
@@ -262,7 +265,7 @@ void sw_GC_Line_Border( const SwTableLine* pLine, _SwGCLineBorder* pGCPara )
                     if( nBtmPos <= nTopEndPos )
                         lcl_GCBorder_DelBorder( aBottom, --nSttBtm, false,
                                             *pTopLine, pBtmItem, nTopEndPos,
-                                            pGCPara->pShareFmts );
+                                            pGCPara->pShareFormats );
                     else
                         nSttTop = nSavSttTop;
                 }
@@ -310,8 +313,8 @@ static void lcl_GC_Box_Border( const SwTableBox* pBox, _SwGCLineBorder* pPara )
     if( !pBox->GetTabLines().empty() )
     {
         _SwGCLineBorder aPara( *pBox );
-        aPara.pShareFmts = pPara->pShareFmts;
-        BOOST_FOREACH( const SwTableLine* pLine, pBox->GetTabLines() )
+        aPara.pShareFormats = pPara->pShareFormats;
+        for( const SwTableLine* pLine : pBox->GetTabLines() )
             sw_GC_Line_Border( pLine, &aPara );
     }
 }
@@ -319,35 +322,34 @@ static void lcl_GC_Box_Border( const SwTableBox* pBox, _SwGCLineBorder* pPara )
 struct _GCLinePara
 {
     SwTableLines* pLns;
-    SwShareBoxFmts* pShareFmts;
+    SwShareBoxFormats* pShareFormats;
 
-    _GCLinePara( SwTableLines& rLns, _GCLinePara* pPara = 0 )
-        : pLns( &rLns ), pShareFmts( pPara ? pPara->pShareFmts : 0 )
+    _GCLinePara( SwTableLines& rLns, _GCLinePara* pPara = nullptr )
+        : pLns( &rLns ), pShareFormats( pPara ? pPara->pShareFormats : nullptr )
     {}
 };
 
 static bool lcl_MergeGCLine(SwTableLine* pLine, _GCLinePara* pPara);
 
-static bool lcl_MergeGCBox(SwTableBox* pTblBox, _GCLinePara* pPara)
+static bool lcl_MergeGCBox(SwTableBox* pTableBox, _GCLinePara* pPara)
 {
-    sal_uInt16 n, nLen = pTblBox->GetTabLines().size();
-    if( nLen )
+    if( !pTableBox->GetTabLines().empty() )
     {
         // ATTENTION: The Line count can change!
-        _GCLinePara aPara( pTblBox->GetTabLines(), pPara );
-        for( n = 0; n < pTblBox->GetTabLines().size() &&
-            lcl_MergeGCLine( pTblBox->GetTabLines()[n], &aPara );
+        _GCLinePara aPara( pTableBox->GetTabLines(), pPara );
+        for( SwTableLines::size_type n = 0;
+            n < pTableBox->GetTabLines().size() && lcl_MergeGCLine( pTableBox->GetTabLines()[n], &aPara );
             ++n )
             ;
 
-        if( 1 == pTblBox->GetTabLines().size() )
+        if( 1 == pTableBox->GetTabLines().size() )
         {
             // we have a box with a single line, so we just replace it by the line's boxes
-            SwTableLine* pInsLine = pTblBox->GetUpper();
-            SwTableLine* pCpyLine = pTblBox->GetTabLines()[0];
-            SwTableBoxes::iterator it = std::find( pInsLine->GetTabBoxes().begin(), pInsLine->GetTabBoxes().end(), pTblBox );
-            for( n = 0; n < pCpyLine->GetTabBoxes().size(); ++n )
-                pCpyLine->GetTabBoxes()[n]->SetUpper( pInsLine );
+            SwTableLine* pInsLine = pTableBox->GetUpper();
+            SwTableLine* pCpyLine = pTableBox->GetTabLines()[0];
+            SwTableBoxes::iterator it = std::find( pInsLine->GetTabBoxes().begin(), pInsLine->GetTabBoxes().end(), pTableBox );
+            for( auto pTabBox : pCpyLine->GetTabBoxes() )
+                pTabBox->SetUpper( pInsLine );
 
             // remove the old box from its parent line
             it = pInsLine->GetTabBoxes().erase( it );
@@ -355,7 +357,7 @@ static bool lcl_MergeGCBox(SwTableBox* pTblBox, _GCLinePara* pPara)
             pInsLine->GetTabBoxes().insert( it, pCpyLine->GetTabBoxes().begin(), pCpyLine->GetTabBoxes().end());
             pCpyLine->GetTabBoxes().clear();
             // destroy the removed box
-            delete pTblBox;
+            delete pTableBox;
 
             return false; // set up anew
         }
@@ -365,10 +367,10 @@ static bool lcl_MergeGCBox(SwTableBox* pTblBox, _GCLinePara* pPara)
 
 static bool lcl_MergeGCLine(SwTableLine* pLn, _GCLinePara* pGCPara)
 {
-    sal_uInt16 nLen = pLn->GetTabBoxes().size();
-    if( nLen )
+    SwTableBoxes::size_type nBoxes = pLn->GetTabBoxes().size();
+    if( nBoxes )
     {
-        while( 1 == nLen )
+        while( 1 == nBoxes )
         {
             // We have a Box with Lines
             SwTableBox* pBox = pLn->GetTabBoxes().front();
@@ -380,7 +382,7 @@ static bool lcl_MergeGCLine(SwTableLine* pLn, _GCLinePara* pGCPara)
             // pLine turns into the current Line (that is rpLine), the rest is moved
             // into the LinesArray past the current one.
             // The LinesArray is in pPara!
-            nLen = pBox->GetTabLines().size();
+            SwTableLines::size_type nLines = pBox->GetTabLines().size();
 
             SwTableLines& rLns = *pGCPara->pLns;
             sal_uInt16 nInsPos = rLns.GetPos( pLn );
@@ -394,30 +396,30 @@ static bool lcl_MergeGCLine(SwTableLine* pLn, _GCLinePara* pGCPara)
             // JP 31.03.99: Bug 60000
             // Pass the attributes of the to-be-deleted Lines to the "inserted" one
             const SfxPoolItem* pItem;
-            if( SFX_ITEM_SET == pLn->GetFrmFmt()->GetItemState(
+            if( SfxItemState::SET == pLn->GetFrameFormat()->GetItemState(
                                     RES_BACKGROUND, true, &pItem ))
             {
                 SwTableLines& rBoxLns = pBox->GetTabLines();
-                for( sal_uInt16 nLns = 0; nLns < nLen; ++nLns )
-                    if( SFX_ITEM_SET != rBoxLns[ nLns ]->GetFrmFmt()->
-                            GetItemState( RES_BACKGROUND, true ))
-                        pGCPara->pShareFmts->SetAttr( *rBoxLns[ nLns ], *pItem );
+                for( auto pBoxLine : rBoxLns )
+                    if( SfxItemState::SET != pBoxLine->GetFrameFormat()->
+                            GetItemState( RES_BACKGROUND ))
+                        pGCPara->pShareFormats->SetAttr( *pBoxLine, *pItem );
             }
 
-            pBox->GetTabLines().erase( pBox->GetTabLines().begin(), pBox->GetTabLines().begin() + nLen );  // Remove Lines from the array
+            pBox->GetTabLines().erase( pBox->GetTabLines().begin(), pBox->GetTabLines().begin() + nLines );  // Remove Lines from the array
 
             delete pLn;
 
             // Set the dependency anew
-            while( nLen-- )
+            while( nLines-- )
                 rLns[ nInsPos++ ]->SetUpper( pUpper );
 
             pLn = pLine;                        // and set up anew
-            nLen = pLn->GetTabBoxes().size();
+            nBoxes = pLn->GetTabBoxes().size();
         }
 
         // ATTENTION: The number of boxes can change!
-        for( nLen = 0; nLen < pLn->GetTabBoxes().size(); ++nLen )
+        for( SwTableBoxes::size_type nLen = 0; nLen < pLn->GetTabBoxes().size(); ++nLen )
             if( !lcl_MergeGCBox( pLn->GetTabBoxes()[nLen], pGCPara ))
                 --nLen;
     }
@@ -429,9 +431,9 @@ void SwTable::GCLines()
 {
     // ATTENTION: The Line count can change!
     _GCLinePara aPara( GetTabLines() );
-    SwShareBoxFmts aShareFmts;
-    aPara.pShareFmts = &aShareFmts;
-    for( sal_uInt16 n = 0; n < GetTabLines().size() &&
+    SwShareBoxFormats aShareFormats;
+    aPara.pShareFormats = &aShareFormats;
+    for( SwTableLines::size_type n = 0; n < GetTabLines().size() &&
             lcl_MergeGCLine( GetTabLines()[n], &aPara ); ++n )
         ;
 }
