@@ -24,8 +24,8 @@ CancellableJob::CancellableJob( const rtl::Reference< ObservableThread >& rThrea
 {
 }
 
-// ::com::sun::star::util::XCancellable:
-void SAL_CALL CancellableJob::cancel() throw (com::sun::star::uno::RuntimeException, std::exception)
+// css::util::XCancellable:
+void SAL_CALL CancellableJob::cancel() throw (css::uno::RuntimeException, std::exception)
 {
     mrThread->join();
 }
