@@ -41,7 +41,7 @@ SwCharFormat& SwEditShell::GetCharFormat(sal_uInt16 nFormat) const
 
 SwCharFormat* SwEditShell::GetCurCharFormat() const
 {
-    SwCharFormat *pFormat = 0;
+    SwCharFormat *pFormat = nullptr;
     SfxItemSet aSet( GetDoc()->GetAttrPool(), RES_TXTATR_CHARFMT,
                                                 RES_TXTATR_CHARFMT );
     const SfxPoolItem* pItem;
@@ -59,7 +59,7 @@ void SwEditShell::FillByEx(SwCharFormat* pCharFormat, bool bReset)
         pCharFormat->ResetAllFormatAttr();
     }
 
-    SwPaM* pPam = GetCrsr();
+    SwPaM* pPam = GetCursor();
     const SwContentNode* pCNd = pPam->GetContentNode();
     if( pCNd->IsTextNode() )
     {
