@@ -20,6 +20,9 @@
 #include <osl/thread.h>
 #include <sfx2/linkmgr.hxx>
 #include <doc.hxx>
+#include <IDocumentLinksAdministration.hxx>
+#include <IDocumentState.hxx>
+#include <IDocumentLayoutAccess.hxx>
 #include <editsh.hxx>
 #include <ndtxt.hxx>
 #include <fmtfld.hxx>
@@ -30,6 +33,7 @@
 #include <swddetbl.hxx>
 #include <unofldmid.h>
 #include <hints.hxx>
+#include <calbck.hxx>
 
 using namespace ::com::sun::star;
 
@@ -37,20 +41,20 @@ using namespace ::com::sun::star;
 
 class SwIntrnlRefLink : public SwBaseLink
 {
-    SwDDEFieldType& rFldType;
+    SwDDEFieldType& rFieldType;
 public:
-    SwIntrnlRefLink( SwDDEFieldType& rType, sal_uInt16 nUpdateType, sal_uInt16 nFmt )
-        : SwBaseLink( nUpdateType, nFmt ),
-        rFldType( rType )
+    SwIntrnlRefLink( SwDDEFieldType& rType, SfxLinkUpdateMode nUpdateType, SotClipboardFormatId nFormat )
+        : SwBaseLink( nUpdateType, nFormat ),
+        rFieldType( rType )
     {}
 
-    virtual void Closed();
+    virtual void Closed() override;
     virtual ::sfx2::SvBaseLink::UpdateResult DataChanged(
-        const OUString& rMimeType, const ::com::sun::star::uno::Any & rValue );
+        const OUString& rMimeType, const css::uno::Any & rValue ) override;
 
-    virtual const SwNode* GetAnchor() const;
-    virtual sal_Bool IsInRange( sal_uLong nSttNd, sal_uLong nEndNd, sal_Int32 nStt = 0,
-                            sal_Int32 nEnd = -1 ) const;
+    virtual const SwNode* GetAnchor() const override;
+    virtual bool IsInRange( sal_uLong nSttNd, sal_uLong nEndNd, sal_Int32 nStt = 0,
+                            sal_Int32 nEnd = -1 ) const override;
 };
 
 ::sfx2::SvBaseLink::UpdateResult SwIntrnlRefLink::DataChanged( const OUString& rMimeType,
@@ -58,13 +62,12 @@ public:
 {
     switch( SotExchange::GetFormatIdFromMimeType( rMimeType ) )
     {
-    case FORMAT_STRING:
+    case SotClipboardFormatId::STRING:
         if( !IsNoDataFlag() )
         {
             uno::Sequence< sal_Int8 > aSeq;
             rValue >>= aSeq;
-            OUString sStr( (sal_Char*)aSeq.getConstArray(), static_cast<xub_StrLen>(aSeq.getLength()),
-                               DDE_TXT_ENCODING  );
+            OUString sStr( reinterpret_cast<char const *>(aSeq.getConstArray()), aSeq.getLength(), DDE_TXT_ENCODING );
 
             // remove not needed CR-LF at the end
             sal_Int32 n = sStr.getLength();
@@ -75,13 +78,13 @@ public:
             if( n && 0x0d == sStr[ n-1 ] )
                 --n;
 
-            sal_Bool bDel = n != sStr.getLength();
+            bool bDel = n != sStr.getLength();
             if( bDel )
                 sStr = sStr.copy( 0, n );
 
-            rFldType.SetExpansion( sStr );
+            rFieldType.SetExpansion( sStr );
             // set Expansion first! (otherwise this flag will be deleted)
-            rFldType.SetCRLFDelFlag( bDel );
+            rFieldType.SetCRLFDelFlag( bDel );
         }
         break;
 
@@ -90,40 +93,39 @@ public:
         return SUCCESS;
     }
 
-    OSL_ENSURE( rFldType.GetDoc(), "no pDoc" );
+    OSL_ENSURE( rFieldType.GetDoc(), "no pDoc" );
 
     // no dependencies left?
-    if( rFldType.GetDepends() && !rFldType.IsModifyLocked() && !ChkNoDataFlag() )
+    if( rFieldType.HasWriterListeners() && !rFieldType.IsModifyLocked() && !ChkNoDataFlag() )
     {
-        SwViewShell* pSh;
-        SwEditShell* pESh = rFldType.GetDoc()->GetEditShell( &pSh );
+        SwViewShell* pSh = rFieldType.GetDoc()->getIDocumentLayoutAccess().GetCurrentViewShell();
+        SwEditShell* pESh = rFieldType.GetDoc()->GetEditShell();
 
         // Search for fields. If no valid found, disconnect.
         SwMsgPoolItem aUpdateDDE( RES_UPDATEDDETBL );
-        int bCallModify = sal_False;
-        rFldType.LockModify();
+        bool bCallModify = false;
+        rFieldType.LockModify();
 
-        SwClientIter aIter( rFldType );     // TODO
-        SwClient * pLast = aIter.GoStart();
-        if( pLast )     // Could we jump to beginning?
-            do {
-                // a DDE table or a DDE field attribute in the text
-                if( !pLast->IsA( TYPE( SwFmtFld ) ) ||
-                    ((SwFmtFld*)pLast)->GetTxtFld() )
+        SwIterator<SwClient,SwFieldType> aIter(rFieldType);
+        for(SwClient* pLast = aIter.First(); pLast; pLast = aIter.Next())
+        {
+            // a DDE table or a DDE field attribute in the text
+            if( dynamic_cast<const SwFormatField *>(pLast) == nullptr ||
+                static_cast<SwFormatField*>(pLast)->GetTextField() )
+            {
+                if( !bCallModify )
                 {
-                    if( !bCallModify )
-                    {
-                        if( pESh )
-                            pESh->StartAllAction();
-                        else if( pSh )
-                            pSh->StartAction();
-                    }
-                    pLast->ModifyNotification( 0, &aUpdateDDE );
-                    bCallModify = sal_True;
+                    if( pESh )
+                        pESh->StartAllAction();
+                    else if( pSh )
+                        pSh->StartAction();
                 }
-            } while( 0 != ( pLast = ++aIter ));
+                pLast->ModifyNotification( nullptr, &aUpdateDDE );
+                bCallModify = true;
+            }
+        }
 
-        rFldType.UnlockModify();
+        rFieldType.UnlockModify();
 
         if( bCallModify )
         {
@@ -133,7 +135,7 @@ public:
                 pSh->EndAction();
 
             if( pSh )
-                pSh->GetDoc()->SetModified();
+                pSh->GetDoc()->getIDocumentState().SetModified();
         }
     }
 
@@ -142,15 +144,15 @@ public:
 
 void SwIntrnlRefLink::Closed()
 {
-    if( rFldType.GetDoc() && !rFldType.GetDoc()->IsInDtor() )
+    if( rFieldType.GetDoc() && !rFieldType.GetDoc()->IsInDtor() )
     {
         // advise goes, convert all fields into text?
-        SwViewShell* pSh;
-        SwEditShell* pESh = rFldType.GetDoc()->GetEditShell( &pSh );
+        SwViewShell* pSh = rFieldType.GetDoc()->getIDocumentLayoutAccess().GetCurrentViewShell();
+        SwEditShell* pESh = rFieldType.GetDoc()->GetEditShell();
         if( pESh )
         {
             pESh->StartAllAction();
-            pESh->FieldToText( &rFldType );
+            pESh->FieldToText( &rFieldType );
             pESh->EndAllAction();
         }
         else
@@ -166,82 +168,79 @@ void SwIntrnlRefLink::Closed()
 const SwNode* SwIntrnlRefLink::GetAnchor() const
 {
     // here, any anchor of the normal NodesArray should be sufficient
-    const SwNode* pNd = 0;
-    SwClientIter aIter( rFldType );     // TODO
-    SwClient * pLast = aIter.GoStart();
-    if( pLast )     // Could we jump to beginning?
-        do {
-            // a DDE table or a DDE field attribute in the text
-            if( !pLast->IsA( TYPE( SwFmtFld ) ))
-            {
-                SwDepend* pDep = (SwDepend*)pLast;
-                SwDDETable* pDDETbl = (SwDDETable*)pDep->GetToTell();
-                pNd = pDDETbl->GetTabSortBoxes()[0]->GetSttNd();
-            }
-            else if( ((SwFmtFld*)pLast)->GetTxtFld() )
-                pNd = ((SwFmtFld*)pLast)->GetTxtFld()->GetpTxtNode();
-
-            if( pNd && &rFldType.GetDoc()->GetNodes() == &pNd->GetNodes() )
-                break;
-            pNd = 0;
-        } while( 0 != ( pLast = ++aIter ));
+    const SwNode* pNd = nullptr;
+    SwIterator<SwClient,SwFieldType> aIter(rFieldType);
+    for(SwClient* pLast = aIter.First(); pLast; pLast = aIter.Next())
+    {
+        // a DDE table or a DDE field attribute in the text
+        if( dynamic_cast<const SwFormatField *>(pLast) == nullptr)
+        {
+            SwDepend* pDep = static_cast<SwDepend*>(pLast);
+            SwDDETable* pDDETable = static_cast<SwDDETable*>(pDep->GetToTell());
+            pNd = pDDETable->GetTabSortBoxes()[0]->GetSttNd();
+        }
+        else if( static_cast<SwFormatField*>(pLast)->GetTextField() )
+            pNd = static_cast<SwFormatField*>(pLast)->GetTextField()->GetpTextNode();
 
+        if( pNd && &rFieldType.GetDoc()->GetNodes() == &pNd->GetNodes() )
+            break;
+        pNd = nullptr;
+    }
     return pNd;
 }
 
-sal_Bool SwIntrnlRefLink::IsInRange( sal_uLong nSttNd, sal_uLong nEndNd,
+bool SwIntrnlRefLink::IsInRange( sal_uLong nSttNd, sal_uLong nEndNd,
                                 sal_Int32 nStt, sal_Int32 nEnd ) const
 {
     // here, any anchor of the normal NodesArray should be sufficient
-    SwNodes* pNds = &rFldType.GetDoc()->GetNodes();
-    SwClientIter aIter( rFldType );         // TODO
-    SwClient * pLast = aIter.GoStart();
-    if( pLast )     // Could we jump to beginning?
-        do {
-            // a DDE table or a DDE field attribute in the text
-            if( !pLast->IsA( TYPE( SwFmtFld ) ))
+    SwNodes* pNds = &rFieldType.GetDoc()->GetNodes();
+    SwIterator<SwClient,SwFieldType> aIter(rFieldType);
+    for(SwClient* pLast = aIter.First(); pLast; pLast = aIter.Next())
+    {
+        // a DDE table or a DDE field attribute in the text
+        if( dynamic_cast<const SwFormatField *>(pLast) == nullptr)
+        {
+            SwDepend* pDep = static_cast<SwDepend*>(pLast);
+            SwDDETable* pDDETable = static_cast<SwDDETable*>(pDep->GetToTell());
+            const SwTableNode* pTableNd = pDDETable->GetTabSortBoxes()[0]->
+                            GetSttNd()->FindTableNode();
+            if( pTableNd->GetNodes().IsDocNodes() &&
+                nSttNd < pTableNd->EndOfSectionIndex() &&
+                nEndNd > pTableNd->GetIndex() )
+                return true;
+        }
+        else if( static_cast<SwFormatField*>(pLast)->GetTextField() )
+        {
+            const SwTextField* pTField = static_cast<SwFormatField*>(pLast)->GetTextField();
+            const SwTextNode* pNd = pTField->GetpTextNode();
+            if( pNd && pNds == &pNd->GetNodes() )
             {
-                SwDepend* pDep = (SwDepend*)pLast;
-                SwDDETable* pDDETbl = (SwDDETable*)pDep->GetToTell();
-                const SwTableNode* pTblNd = pDDETbl->GetTabSortBoxes()[0]->
-                                GetSttNd()->FindTableNode();
-                if( pTblNd->GetNodes().IsDocNodes() &&
-                    nSttNd < pTblNd->EndOfSectionIndex() &&
-                    nEndNd > pTblNd->GetIndex() )
-                    return sal_True;
+                sal_uLong nNdPos = pNd->GetIndex();
+                if( nSttNd <= nNdPos && nNdPos <= nEndNd &&
+                    ( nNdPos != nSttNd || pTField->GetStart() >= nStt ) &&
+                    ( nNdPos != nEndNd || pTField->GetStart() < nEnd ))
+                    return true;
             }
-            else if( ((SwFmtFld*)pLast)->GetTxtFld() )
-            {
-                const SwTxtFld* pTFld = ((SwFmtFld*)pLast)->GetTxtFld();
-                const SwTxtNode* pNd = pTFld->GetpTxtNode();
-                if( pNd && pNds == &pNd->GetNodes() )
-                {
-                    sal_uLong nNdPos = pNd->GetIndex();
-                    if( nSttNd <= nNdPos && nNdPos <= nEndNd &&
-                        ( nNdPos != nSttNd || *pTFld->GetStart() >= nStt ) &&
-                        ( nNdPos != nEndNd || *pTFld->GetStart() < nEnd ))
-                        return sal_True;
-                }
-            }
-        } while( 0 != ( pLast = ++aIter ));
+        }
+    }
 
-    return sal_False;
+    return false;
 }
 
 SwDDEFieldType::SwDDEFieldType(const OUString& rName,
-                               const OUString& rCmd, sal_uInt16 nUpdateType )
+                               const OUString& rCmd, SfxLinkUpdateMode nUpdateType )
     : SwFieldType( RES_DDEFLD ),
-    aName( rName ), pDoc( 0 ), nRefCnt( 0 )
+    aName( rName ), pDoc( nullptr ), nRefCnt( 0 )
 {
-    bCRLFFlag = bDeleted = sal_False;
-    refLink = new SwIntrnlRefLink( *this, nUpdateType, FORMAT_STRING );
+    bCRLFFlag = bDeleted = false;
+    refLink = new SwIntrnlRefLink( *this, nUpdateType, SotClipboardFormatId::STRING );
     SetCmd( rCmd );
 }
 
 SwDDEFieldType::~SwDDEFieldType()
 {
     if( pDoc && !pDoc->IsInDtor() )
-        pDoc->GetLinkManager().Remove( refLink );
+        pDoc->getIDocumentLinksAdministration().GetLinkManager().Remove( refLink );
     refLink->Disconnect();
 }
 
@@ -260,8 +259,9 @@ OUString SwDDEFieldType::GetName() const
     return aName;
 }
 
-void SwDDEFieldType::SetCmd( OUString aStr )
+void SwDDEFieldType::SetCmd( const OUString& _aStr )
 {
+    OUString aStr = _aStr;
     sal_Int32 nIndex = 0;
     do
     {
@@ -283,31 +283,30 @@ void SwDDEFieldType::SetDoc( SwDoc* pNewDoc )
     if( pDoc && refLink.Is() )
     {
         OSL_ENSURE( !nRefCnt, "How do we get the references?" );
-        pDoc->GetLinkManager().Remove( refLink );
+        pDoc->getIDocumentLinksAdministration().GetLinkManager().Remove( refLink );
     }
 
     pDoc = pNewDoc;
     if( pDoc && nRefCnt )
     {
-        refLink->SetVisible( pDoc->IsVisibleLinks() );
-        pDoc->GetLinkManager().InsertDDELink( refLink );
+        refLink->SetVisible( pDoc->getIDocumentLinksAdministration().IsVisibleLinks() );
+        pDoc->getIDocumentLinksAdministration().GetLinkManager().InsertDDELink( refLink );
     }
 }
 
-
 void SwDDEFieldType::_RefCntChgd()
 {
     if( nRefCnt )
     {
-        refLink->SetVisible( pDoc->IsVisibleLinks() );
-        pDoc->GetLinkManager().InsertDDELink( refLink );
-        if( pDoc->GetCurrentViewShell() )
+        refLink->SetVisible( pDoc->getIDocumentLinksAdministration().IsVisibleLinks() );
+        pDoc->getIDocumentLinksAdministration().GetLinkManager().InsertDDELink( refLink );
+        if( pDoc->getIDocumentLayoutAccess().GetCurrentViewShell() )
             UpdateNow();
     }
     else
     {
         Disconnect();
-        pDoc->GetLinkManager().Remove( refLink );
+        pDoc->getIDocumentLinksAdministration().GetLinkManager().Remove( refLink );
     }
 }
 
@@ -320,10 +319,7 @@ bool SwDDEFieldType::QueryValue( uno::Any& rVal, sal_uInt16 nWhichId ) const
     case FIELD_PROP_PAR4:      nPart = 1; break;
     case FIELD_PROP_SUBTYPE:   nPart = 0; break;
     case FIELD_PROP_BOOL1:
-        {
-            sal_Bool bSet = GetType() == sfx2::LINKUPDATE_ALWAYS ? sal_True : sal_False;
-            rVal.setValue(&bSet, ::getBooleanCppuType());
-        }
+        rVal <<= GetType() == SfxLinkUpdateMode::ALWAYS;
         break;
     case FIELD_PROP_PAR5:
         rVal <<= aExpansion;
@@ -345,9 +341,9 @@ bool SwDDEFieldType::PutValue( const uno::Any& rVal, sal_uInt16 nWhichId )
     case FIELD_PROP_PAR4:      nPart = 1; break;
     case FIELD_PROP_SUBTYPE:   nPart = 0; break;
     case FIELD_PROP_BOOL1:
-        SetType( static_cast<sal_uInt16>(*(sal_Bool*)rVal.getValue() ?
-                                     sfx2::LINKUPDATE_ALWAYS :
-                                     sfx2::LINKUPDATE_ONCALL ) );
+        SetType( *static_cast<sal_Bool const *>(rVal.getValue()) ?
+                 SfxLinkUpdateMode::ALWAYS :
+                 SfxLinkUpdateMode::ONCALL );
         break;
     case FIELD_PROP_PAR5:
         rVal >>= aExpansion;
@@ -382,14 +378,14 @@ SwDDEField::SwDDEField( SwDDEFieldType* pInitType )
 
 SwDDEField::~SwDDEField()
 {
-    if( GetTyp()->IsLastDepend() )
-        ((SwDDEFieldType*)GetTyp())->Disconnect();
+    if( GetTyp()->HasOnlyOneListener() )
+        static_cast<SwDDEFieldType*>(GetTyp())->Disconnect();
 }
 
 OUString SwDDEField::Expand() const
 {
-    OUString aStr = ((SwDDEFieldType*)GetTyp())->GetExpansion();
-    aStr = aStr.replaceAll("\r", OUString());
+    OUString aStr = static_cast<SwDDEFieldType*>(GetTyp())->GetExpansion();
+    aStr = aStr.replaceAll("\r", "");
     aStr = aStr.replaceAll("\t", " ");
     aStr = aStr.replaceAll("\n", "|");
     if (aStr.endsWith("|"))
@@ -401,25 +397,25 @@ OUString SwDDEField::Expand() const
 
 SwField* SwDDEField::Copy() const
 {
-    return new SwDDEField((SwDDEFieldType*)GetTyp());
+    return new SwDDEField(static_cast<SwDDEFieldType*>(GetTyp()));
 }
 
 /// get field type name
 OUString SwDDEField::GetPar1() const
 {
-    return ((const SwDDEFieldType*)GetTyp())->GetName();
+    return static_cast<const SwDDEFieldType*>(GetTyp())->GetName();
 }
 
 /// get field type command
 OUString SwDDEField::GetPar2() const
 {
-    return ((const SwDDEFieldType*)GetTyp())->GetCmd();
+    return static_cast<const SwDDEFieldType*>(GetTyp())->GetCmd();
 }
 
 /// set field type command
 void SwDDEField::SetPar2(const OUString& rStr)
 {
-    ((SwDDEFieldType*)GetTyp())->SetCmd(rStr);
+    static_cast<SwDDEFieldType*>(GetTyp())->SetCmd(rStr);
 }
 
 /* vim:set shiftwidth=4 softtabstop=4 expandtab: */
