@@ -17,10 +17,7 @@
  *   the License at http://www.apache.org/licenses/LICENSE-2.0 .
  */
 
-
 #include "pagefrm.hxx"
-#include "viewsh.hxx"
-#include "doc.hxx"
 #include <fmtcntnt.hxx>
 #include <fmthdft.hxx>
 #include <fmtfsize.hxx>
@@ -31,20 +28,16 @@
 #include "sectfrm.hxx"
 #include "flyfrm.hxx"
 #include "frmtool.hxx"
-#include "dflyobj.hxx"
-#include "frmfmt.hxx"
-#include "ndindex.hxx"
 #include "hfspacingitem.hxx"
-// OD 2004-05-24 #i28701#
 #include <sortedobjs.hxx>
-// #i43771#
 #include <objectformatter.hxx>
+#include <o3tl/make_unique.hxx>
 
 extern bool bObjsDirect;    //frmtool.cxx
 
-static SwTwips lcl_GetFrmMinHeight(const SwLayoutFrm & rFrm)
+static SwTwips lcl_GetFrameMinHeight(const SwLayoutFrame & rFrame)
 {
-    const SwFmtFrmSize &rSz = rFrm.GetFmt()->GetFrmSize();
+    const SwFormatFrameSize &rSz = rFrame.GetFormat()->GetFrameSize();
     SwTwips nMinHeight;
 
     switch (rSz.GetHeightSizeType())
@@ -58,79 +51,74 @@ static SwTwips lcl_GetFrmMinHeight(const SwLayoutFrm & rFrm)
         nMinHeight = 0;
     }
 
-
     return nMinHeight;
 }
 
-
-static SwTwips lcl_CalcContentHeight(SwLayoutFrm & frm)
+static SwTwips lcl_CalcContentHeight(SwLayoutFrame & frm)
 {
     SwTwips nRemaining = 0;
-    sal_uInt16 nNum = 0;
-    SwFrm* pFrm = frm.Lower();
+    SwFrame* pFrame = frm.Lower();
 
-    while ( pFrm )
+    while ( pFrame )
     {
         SwTwips nTmp;
 
-        nTmp = pFrm->Frm().Height();
+        nTmp = pFrame->Frame().Height();
         nRemaining += nTmp;
-        if( pFrm->IsTxtFrm() && ((SwTxtFrm*)pFrm)->IsUndersized() )
+        if( pFrame->IsTextFrame() && static_cast<SwTextFrame*>(pFrame)->IsUndersized() )
         {
-            nTmp = ((SwTxtFrm*)pFrm)->GetParHeight()
-                - pFrm->Prt().Height();
-            // This TxtFrm would like to be a bit bigger
+            nTmp = static_cast<SwTextFrame*>(pFrame)->GetParHeight()
+                - pFrame->Prt().Height();
+            // This TextFrame would like to be a bit bigger
             nRemaining += nTmp;
         }
-        else if( pFrm->IsSctFrm() && ((SwSectionFrm*)pFrm)->IsUndersized() )
+        else if( pFrame->IsSctFrame() && static_cast<SwSectionFrame*>(pFrame)->IsUndersized() )
         {
-            nTmp = ((SwSectionFrm*)pFrm)->Undersize();
+            nTmp = static_cast<SwSectionFrame*>(pFrame)->Undersize();
             nRemaining += nTmp;
         }
-        pFrm = pFrm->GetNext();
-
-        nNum++;
+        pFrame = pFrame->GetNext();
     }
 
     return nRemaining;
 }
 
-static void lcl_LayoutFrmEnsureMinHeight(SwLayoutFrm & rFrm,
+static void lcl_LayoutFrameEnsureMinHeight(SwLayoutFrame & rFrame,
                                          const SwBorderAttrs * )
 {
-    SwTwips nMinHeight = lcl_GetFrmMinHeight(rFrm);
+    SwTwips nMinHeight = lcl_GetFrameMinHeight(rFrame);
 
-    if (rFrm.Frm().Height() < nMinHeight)
+    if (rFrame.Frame().Height() < nMinHeight)
     {
-        rFrm.Grow(nMinHeight - rFrm.Frm().Height());
+        rFrame.Grow(nMinHeight - rFrame.Frame().Height());
     }
 }
 
-SwHeadFootFrm::SwHeadFootFrm( SwFrmFmt * pFmt, SwFrm* pSib, sal_uInt16 nTypeIn)
-    : SwLayoutFrm( pFmt, pSib )
+SwHeadFootFrame::SwHeadFootFrame( SwFrameFormat * pFormat, SwFrame* pSib, sal_uInt16 nTypeIn)
+    : SwLayoutFrame( pFormat, pSib )
 {
-    mnType = nTypeIn;
-    SetDerivedVert( sal_False );
+    mnFrameType = nTypeIn;
+    SetDerivedVert( false );
 
-    const SwFmtCntnt &rCnt = pFmt->GetCntnt();
+    const SwFormatContent &rCnt = pFormat->GetContent();
 
-    OSL_ENSURE( rCnt.GetCntntIdx(), "No content for Header." );
+    OSL_ENSURE( rCnt.GetContentIdx(), "No content for Header." );
 
     // Have the objects created right now for header and footer
     bool bOld = bObjsDirect;
     bObjsDirect = true;
-    sal_uLong nIndex = rCnt.GetCntntIdx()->GetIndex();
-    ::_InsertCnt( this, pFmt->GetDoc(), ++nIndex );
+    sal_uLong nIndex = rCnt.GetContentIdx()->GetIndex();
+    ::_InsertCnt( this, pFormat->GetDoc(), ++nIndex );
     bObjsDirect = bOld;
 }
 
-void SwHeadFootFrm::FormatPrt(SwTwips & nUL, const SwBorderAttrs * pAttrs)
+void SwHeadFootFrame::FormatPrt(SwTwips & nUL, const SwBorderAttrs * pAttrs)
 {
     if (GetEatSpacing())
     {
         /* The minimal height of the print area is the minimal height of the
            frame without the height needed for borders and shadow. */
-        SwTwips nMinHeight = lcl_GetFrmMinHeight(*this);
+        SwTwips nMinHeight = lcl_GetFrameMinHeight(*this);
 
         nMinHeight -= pAttrs->CalcTop();
         nMinHeight -= pAttrs->CalcBottom();
@@ -159,7 +147,7 @@ void SwHeadFootFrm::FormatPrt(SwTwips & nUL, const SwBorderAttrs * pAttrs)
         /* calculate initial spacing/line space */
         SwTwips nSpace, nLine;
 
-        if (IsHeaderFrm())
+        if (IsHeaderFrame())
         {
             nSpace = pAttrs->CalcBottom();
             nLine = pAttrs->CalcBottomLine();
@@ -178,7 +166,7 @@ void SwHeadFootFrm::FormatPrt(SwTwips & nUL, const SwBorderAttrs * pAttrs)
             nSpace = nLine;
 
         /* calculate real vertical space between frame and print area */
-        if (IsHeaderFrm())
+        if (IsHeaderFrame())
             nUL = pAttrs->CalcTop() + nSpace;
         else
             nUL = pAttrs->CalcBottom() + nSpace;
@@ -189,22 +177,21 @@ void SwHeadFootFrm::FormatPrt(SwTwips & nUL, const SwBorderAttrs * pAttrs)
 
         maPrt.Left(pAttrs->CalcLeft(this));
 
-        if (IsHeaderFrm())
+        if (IsHeaderFrame())
             maPrt.Top(pAttrs->CalcTop());
         else
             maPrt.Top(nSpace);
 
-        maPrt.Width(maFrm.Width() - nLR);
+        maPrt.Width(maFrame.Width() - nLR);
 
         SwTwips nNewHeight;
 
-        if (nUL < maFrm.Height())
-            nNewHeight = maFrm.Height() - nUL;
+        if (nUL < maFrame.Height())
+            nNewHeight = maFrame.Height() - nUL;
         else
             nNewHeight = 0;
 
         maPrt.Height(nNewHeight);
-
     }
     else
     {
@@ -212,28 +199,28 @@ void SwHeadFootFrm::FormatPrt(SwTwips & nUL, const SwBorderAttrs * pAttrs)
         maPrt.Left( pAttrs->CalcLeft( this ) );
         maPrt.Top ( pAttrs->CalcTop()  );
 
-        // Set sizes - the sizes are given by the surrounding Frm, just
+        // Set sizes - the sizes are given by the surrounding Frame, just
         // subtract the borders.
         // OD 23.01.2003 #106895# - add first parameter to <SwBorderAttrs::CalcRight(..)>
         SwTwips nLR = pAttrs->CalcLeft( this ) + pAttrs->CalcRight( this );
-        maPrt.Width ( maFrm.Width() - nLR );
-        maPrt.Height( maFrm.Height()- nUL );
+        maPrt.Width ( maFrame.Width() - nLR );
+        maPrt.Height( maFrame.Height()- nUL );
 
     }
 
-    mbValidPrtArea = sal_True;
+    mbValidPrtArea = true;
 }
 
-void SwHeadFootFrm::FormatSize(SwTwips nUL, const SwBorderAttrs * pAttrs)
+void SwHeadFootFrame::FormatSize(SwTwips nUL, const SwBorderAttrs * pAttrs)
 {
     if ( !HasFixSize() )
     {
         if( !IsColLocked() )
         {
-            mbValidSize = mbValidPrtArea = sal_True;
+            mbValidSize = mbValidPrtArea = true;
 
             const SwTwips nBorder = nUL;
-            SwTwips nMinHeight = lcl_GetFrmMinHeight(*this);
+            SwTwips nMinHeight = lcl_GetFrameMinHeight(*this);
             nMinHeight -= pAttrs->CalcTop();
             nMinHeight -= pAttrs->CalcBottom();
 
@@ -252,54 +239,60 @@ void SwHeadFootFrm::FormatSize(SwTwips nUL, const SwBorderAttrs * pAttrs)
             do
             {
                 nOldHeight = Prt().Height();
-                SwFrm* pFrm = Lower();
+                SwFrame* pFrame = Lower();
                 // #i64301#
-                if ( pFrm &&
-                     aOldFooterPrtPos != ( Frm().Pos() + Prt().Pos() ) )
+                if ( pFrame &&
+                     aOldFooterPrtPos != ( Frame().Pos() + Prt().Pos() ) )
                 {
-                    pFrm->_InvalidatePos();
-                    aOldFooterPrtPos = Frm().Pos() + Prt().Pos();
+                    pFrame->_InvalidatePos();
+                    aOldFooterPrtPos = Frame().Pos() + Prt().Pos();
                 }
-                while( pFrm )
+                int nLoopControl = 0;
+                while( pFrame )
                 {
-                    pFrm->Calc();
+                    pFrame->Calc(getRootFrame()->GetCurrShell()->GetOut());
                     // #i43771# - format also object anchored
                     // at the frame
                     // #i46941# - frame has to be valid.
                     // Note: frame could be invalid after calling its format,
                     //       if it's locked
-                    OSL_ENSURE( StackHack::IsLocked() || !pFrm->IsTxtFrm() ||
-                            pFrm->IsValid() ||
-                            static_cast<SwTxtFrm*>(pFrm)->IsJoinLocked(),
-                            "<SwHeadFootFrm::FormatSize(..)> - text frame invalid and not locked." );
-                    if ( pFrm->IsTxtFrm() && pFrm->IsValid() )
+                    OSL_ENSURE( StackHack::IsLocked() || !pFrame->IsTextFrame() ||
+                            pFrame->IsValid() ||
+                            static_cast<SwTextFrame*>(pFrame)->IsJoinLocked(),
+                            "<SwHeadFootFrame::FormatSize(..)> - text frame invalid and not locked." );
+                    if ( pFrame->IsTextFrame() && pFrame->IsValid() )
                     {
-                        if ( !SwObjectFormatter::FormatObjsAtFrm( *pFrm,
-                                                                  *(pFrm->FindPageFrm()) ) )
+                        if ( !SwObjectFormatter::FormatObjsAtFrame( *pFrame,
+                                                                  *(pFrame->FindPageFrame()) ) )
                         {
-                            // restart format with first content
-                            pFrm = Lower();
-                            continue;
+                            if (nLoopControl++ < 20)
+                            {
+                                // restart format with first content
+                                pFrame = Lower();
+                                continue;
+                            }
+                            else
+                                SAL_WARN("sw", "SwHeadFootFrame::FormatSize: loop detection triggered");
                         }
                     }
-                    pFrm = pFrm->GetNext();
+                    pFrame = pFrame->GetNext();
                 }
                 nRemaining = 0;
-                pFrm = Lower();
+                pFrame = Lower();
 
-                while ( pFrm )
+                while ( pFrame )
                 {
-                    nRemaining += pFrm->Frm().Height();
+                    nRemaining += pFrame->Frame().Height();
 
-                    if( pFrm->IsTxtFrm() &&
-                        ((SwTxtFrm*)pFrm)->IsUndersized() )
-                        // This TxtFrm would like to be a bit bigger
-                        nRemaining += ((SwTxtFrm*)pFrm)->GetParHeight()
-                            - pFrm->Prt().Height();
-                    else if( pFrm->IsSctFrm() &&
-                             ((SwSectionFrm*)pFrm)->IsUndersized() )
-                        nRemaining += ((SwSectionFrm*)pFrm)->Undersize();
-                    pFrm = pFrm->GetNext();
+                    if( pFrame->IsTextFrame() &&
+                        static_cast<SwTextFrame*>(pFrame)->IsUndersized() )
+                        // This TextFrame would like to be a bit bigger
+                        nRemaining += static_cast<SwTextFrame*>(pFrame)->GetParHeight()
+                            - pFrame->Prt().Height();
+                    else if( pFrame->IsSctFrame() &&
+                             static_cast<SwSectionFrame*>(pFrame)->IsUndersized() )
+                        nRemaining += static_cast<SwSectionFrame*>(pFrame)->Undersize();
+                    pFrame = pFrame->GetNext();
                 }
                 if ( nRemaining < nMinHeight )
                     nRemaining = nMinHeight;
@@ -333,32 +326,32 @@ void SwHeadFootFrm::FormatSize(SwTwips nUL, const SwBorderAttrs * pAttrs)
                     {
                         if ( Grow( nDiff ) )
                         {
-                            pFrm = Lower();
+                            pFrame = Lower();
 
-                            while ( pFrm )
+                            while ( pFrame )
                             {
-                                if( pFrm->IsTxtFrm())
+                                if( pFrame->IsTextFrame())
                                 {
-                                    SwTxtFrm * pTmpFrm = (SwTxtFrm*) pFrm;
-                                    if (pTmpFrm->IsUndersized() )
+                                    SwTextFrame * pTmpFrame = static_cast<SwTextFrame*>(pFrame);
+                                    if (pTmpFrame->IsUndersized() )
                                     {
-                                        pTmpFrm->InvalidateSize();
-                                        pTmpFrm->Prepare(PREP_ADJUST_FRM);
+                                        pTmpFrame->InvalidateSize();
+                                        pTmpFrame->Prepare(PREP_ADJUST_FRM);
                                     }
                                 }
                                 /* #i3568# Undersized sections need to be
                                    invalidated too. */
-                                else if (pFrm->IsSctFrm())
+                                else if (pFrame->IsSctFrame())
                                 {
-                                    SwSectionFrm * pTmpFrm =
-                                        (SwSectionFrm*) pFrm;
-                                    if (pTmpFrm->IsUndersized() )
+                                    SwSectionFrame * pTmpFrame =
+                                        static_cast<SwSectionFrame*>(pFrame);
+                                    if (pTmpFrame->IsUndersized() )
                                     {
-                                        pTmpFrm->InvalidateSize();
-                                        pTmpFrm->Prepare(PREP_ADJUST_FRM);
+                                        pTmpFrame->InvalidateSize();
+                                        pTmpFrame->Prepare(PREP_ADJUST_FRM);
                                     }
                                 }
-                                pFrm = pFrm->GetNext();
+                                pFrame = pFrame->GetNext();
                             }
                         }
                     }
@@ -372,49 +365,49 @@ void SwHeadFootFrm::FormatSize(SwTwips nUL, const SwBorderAttrs * pAttrs)
                 else
                     break;
                 // Don't overwrite the lower edge of the upper
-                if ( GetUpper() && Frm().Height() )
+                if ( GetUpper() && Frame().Height() )
                 {
-                    const SwTwips nDeadLine = GetUpper()->Frm().Top() +
+                    const SwTwips nDeadLine = GetUpper()->Frame().Top() +
                         GetUpper()->Prt().Bottom();
-                    const SwTwips nBot = Frm().Bottom();
+                    const SwTwips nBot = Frame().Bottom();
                     if ( nBot > nDeadLine )
                     {
-                        Frm().Bottom( nDeadLine );
-                        Prt().SSize().Height() = Frm().Height() - nBorder;
+                        Frame().Bottom( nDeadLine );
+                        Prt().SSize().Height() = Frame().Height() - nBorder;
                     }
                 }
-                mbValidSize = mbValidPrtArea = sal_True;
+                mbValidSize = mbValidPrtArea = true;
             } while( nRemaining<=nMaxHeight && nOldHeight!=Prt().Height() );
             ColUnlock();
         }
-        mbValidSize = mbValidPrtArea = sal_True;
+        mbValidSize = mbValidPrtArea = true;
     }
-    else //if ( GetType() & 0x0018 )
+    else //if (GetType() & FRM_HEADFOOT)
     {
         do
         {
-            if ( Frm().Height() != pAttrs->GetSize().Height() )
-                ChgSize( Size( Frm().Width(), pAttrs->GetSize().Height()));
-            mbValidSize = sal_True;
+            if ( Frame().Height() != pAttrs->GetSize().Height() )
+                ChgSize( Size( Frame().Width(), pAttrs->GetSize().Height()));
+            mbValidSize = true;
             MakePos();
         } while ( !mbValidSize );
     }
 }
 
-void SwHeadFootFrm::Format(const SwBorderAttrs * pAttrs)
+void SwHeadFootFrame::Format(vcl::RenderContext* pRenderContext, const SwBorderAttrs * pAttrs)
 {
-    OSL_ENSURE( pAttrs, "SwFooterFrm::Format, pAttrs is 0." );
+    OSL_ENSURE( pAttrs, "SwFooterFrame::Format, pAttrs is 0." );
 
     if ( mbValidPrtArea && mbValidSize )
         return;
 
-    if ( ! GetEatSpacing() && IsHeaderFrm())
+    if ( ! GetEatSpacing() && IsHeaderFrame())
     {
-        SwLayoutFrm::Format(pAttrs);
+        SwLayoutFrame::Format(pRenderContext, pAttrs);
     }
     else
     {
-        lcl_LayoutFrmEnsureMinHeight(*this, pAttrs);
+        lcl_LayoutFrameEnsureMinHeight(*this, pAttrs);
 
         long nUL = pAttrs->CalcTop()  + pAttrs->CalcBottom();
 
@@ -426,7 +419,7 @@ void SwHeadFootFrm::Format(const SwBorderAttrs * pAttrs)
     }
 }
 
-SwTwips SwHeadFootFrm::GrowFrm( SwTwips nDist, sal_Bool bTst,  sal_Bool bInfo )
+SwTwips SwHeadFootFrame::GrowFrame( SwTwips nDist, bool bTst, bool bInfo )
 {
     SwTwips nResult;
 
@@ -436,14 +429,13 @@ SwTwips SwHeadFootFrm::GrowFrm( SwTwips nDist, sal_Bool bTst,  sal_Bool bInfo )
     }
     else if (!GetEatSpacing())
     {
-        nResult = SwLayoutFrm::GrowFrm(nDist, bTst, bInfo);
+        nResult = SwLayoutFrame::GrowFrame(nDist, bTst, bInfo);
     }
     else
     {
         nResult = 0;
 
-        SwBorderAttrAccess * pAccess =
-            new SwBorderAttrAccess( SwFrm::GetCache(), this );
+        auto pAccess = o3tl::make_unique<SwBorderAttrAccess>(SwFrame::GetCache(), this);
         OSL_ENSURE(pAccess, "no border attributes");
 
         SwBorderAttrs * pAttrs = pAccess->Get();
@@ -454,20 +446,18 @@ SwTwips SwHeadFootFrm::GrowFrm( SwTwips nDist, sal_Bool bTst,  sal_Bool bInfo )
         SwTwips nMaxEat;
 
         /* calculate maximum eatable spacing */
-        if (IsHeaderFrm())
-            nMaxEat = maFrm.Height() - maPrt.Top() - maPrt.Height() - pAttrs->CalcBottomLine();
+        if (IsHeaderFrame())
+            nMaxEat = maFrame.Height() - maPrt.Top() - maPrt.Height() - pAttrs->CalcBottomLine();
         else
             nMaxEat = maPrt.Top() - pAttrs->CalcTopLine();
 
-        delete pAccess;
-
         if (nMaxEat < 0)
             nMaxEat = 0;
 
         /* If the frame is too small, eat less spacing thus letting the frame
            grow more. */
-        SwTwips nMinHeight = lcl_GetFrmMinHeight(*this);
-        SwTwips nFrameTooSmall = nMinHeight - Frm().Height();
+        SwTwips nMinHeight = lcl_GetFrameMinHeight(*this);
+        SwTwips nFrameTooSmall = nMinHeight - Frame().Height();
 
         if (nFrameTooSmall > 0)
             nEat -= nFrameTooSmall;
@@ -481,12 +471,12 @@ SwTwips SwHeadFootFrm::GrowFrm( SwTwips nDist, sal_Bool bTst,  sal_Bool bInfo )
         // OD 10.04.2003 #108719# - Notify fly frame, if header frame
         // grows. Consider, that 'normal' grow of layout frame already notifys
         // the fly frames.
-        sal_Bool bNotifyFlys = sal_False;
+        bool bNotifyFlys = false;
         if (nEat > 0)
         {
             if ( ! bTst)
             {
-                if (! IsHeaderFrm())
+                if (! IsHeaderFrame())
                 {
                     maPrt.Top(maPrt.Top() - nEat);
                     maPrt.Height(maPrt.Height() - nEat);
@@ -497,21 +487,21 @@ SwTwips SwHeadFootFrm::GrowFrm( SwTwips nDist, sal_Bool bTst,  sal_Bool bInfo )
 
             nResult += nEat;
             // OD 14.04.2003 #108719# - trigger fly frame notify.
-            if ( IsHeaderFrm() )
+            if ( IsHeaderFrame() )
             {
-                bNotifyFlys = sal_True;
+                bNotifyFlys = true;
             }
         }
 
         if (nDist - nEat > 0)
         {
-            SwTwips nFrmGrow =
-                SwLayoutFrm::GrowFrm( nDist - nEat, bTst, bInfo );
+            const SwTwips nFrameGrow =
+                SwLayoutFrame::GrowFrame( nDist - nEat, bTst, bInfo );
 
-            nResult += nFrmGrow;
-            if ( nFrmGrow > 0 )
+            nResult += nFrameGrow;
+            if ( nFrameGrow > 0 )
             {
-                bNotifyFlys = sal_False;
+                bNotifyFlys = false;
             }
         }
 
@@ -528,7 +518,7 @@ SwTwips SwHeadFootFrm::GrowFrm( SwTwips nDist, sal_Bool bTst,  sal_Bool bInfo )
     return nResult;
 }
 
-SwTwips SwHeadFootFrm::ShrinkFrm( SwTwips nDist, sal_Bool bTst, sal_Bool bInfo )
+SwTwips SwHeadFootFrame::ShrinkFrame( SwTwips nDist, bool bTst, bool bInfo )
 {
     SwTwips nResult;
 
@@ -538,14 +528,14 @@ SwTwips SwHeadFootFrm::ShrinkFrm( SwTwips nDist, sal_Bool bTst, sal_Bool bInfo )
     }
     else if (! GetEatSpacing())
     {
-        nResult = SwLayoutFrm::ShrinkFrm(nDist, bTst, bInfo);
+        nResult = SwLayoutFrame::ShrinkFrame(nDist, bTst, bInfo);
     }
     else
     {
         nResult = 0;
 
-        SwTwips nMinHeight = lcl_GetFrmMinHeight(*this);
-        SwTwips nOldHeight = Frm().Height();
+        SwTwips nMinHeight = lcl_GetFrameMinHeight(*this);
+        SwTwips nOldHeight = Frame().Height();
         SwTwips nRest = 0; // Amount to shrink by spitting out spacing
 
         if ( nOldHeight >= nMinHeight )
@@ -571,12 +561,10 @@ SwTwips SwHeadFootFrm::ShrinkFrm( SwTwips nDist, sal_Bool bTst, sal_Bool bInfo )
         // OD 10.04.2003 #108719# - Notify fly frame, if header/footer frame
         // shrinks. Consider, that 'normal' shrink of layout frame already notifys
         // the fly frames.
-        sal_Bool bNotifyFlys = sal_False;
+        bool bNotifyFlys = false;
         if (nRest > 0)
         {
-
-            SwBorderAttrAccess * pAccess =
-                new SwBorderAttrAccess( SwFrm::GetCache(), this );
+            auto pAccess = o3tl::make_unique<SwBorderAttrAccess>(SwFrame::GetCache(), this);
             OSL_ENSURE(pAccess, "no border attributes");
 
             SwBorderAttrs * pAttrs = pAccess->Get();
@@ -589,8 +577,6 @@ SwTwips SwHeadFootFrm::ShrinkFrm( SwTwips nDist, sal_Bool bTst, sal_Bool bInfo )
             if (nMinPrtHeight < 0)
                 nMinPrtHeight = 0;
 
-            delete pAccess;
-
             /* assume all shrinking can be provided */
             SwTwips nShrink = nRest;
 
@@ -606,7 +592,7 @@ SwTwips SwHeadFootFrm::ShrinkFrm( SwTwips nDist, sal_Bool bTst, sal_Bool bInfo )
 
             if (!bTst)
             {
-                if (! IsHeaderFrm() )
+                if (! IsHeaderFrame() )
                 {
                     maPrt.Top(maPrt.Top() + nShrink);
                     maPrt.Height(maPrt.Height() - nShrink);
@@ -616,9 +602,9 @@ SwTwips SwHeadFootFrm::ShrinkFrm( SwTwips nDist, sal_Bool bTst, sal_Bool bInfo )
             }
             nResult += nShrink;
             // OD 14.04.2003 #108719# - trigger fly frame notify.
-            if ( IsHeaderFrm() )
+            if ( IsHeaderFrame() )
             {
-                bNotifyFlys = sal_True;
+                bNotifyFlys = true;
             }
         }
 
@@ -626,11 +612,11 @@ SwTwips SwHeadFootFrm::ShrinkFrm( SwTwips nDist, sal_Bool bTst, sal_Bool bInfo )
            by the frame. */
         if (nDist - nRest > 0)
         {
-            SwTwips nShrinkAmount = SwLayoutFrm::ShrinkFrm( nDist - nRest, bTst, bInfo );
+            SwTwips nShrinkAmount = SwLayoutFrame::ShrinkFrame( nDist - nRest, bTst, bInfo );
             nResult += nShrinkAmount;
             if ( nShrinkAmount > 0 )
             {
-                bNotifyFlys = sal_False;
+                bNotifyFlys = false;
             }
         }
 
@@ -644,137 +630,123 @@ SwTwips SwHeadFootFrm::ShrinkFrm( SwTwips nDist, sal_Bool bTst, sal_Bool bInfo )
     return nResult;
 }
 
-sal_Bool SwHeadFootFrm::GetEatSpacing() const
+bool SwHeadFootFrame::GetEatSpacing() const
 {
-    const SwFrmFmt * pFmt = GetFmt();
-    OSL_ENSURE(pFmt, "SwHeadFootFrm: no format?");
+    const SwFrameFormat * pFormat = GetFormat();
+    OSL_ENSURE(pFormat, "SwHeadFootFrame: no format?");
 
-    if (pFmt->GetHeaderAndFooterEatSpacing().GetValue())
-        return sal_True;
+    if (pFormat->GetHeaderAndFooterEatSpacing().GetValue())
+        return true;
 
-    return sal_False;
+    return false;
 }
 
-
-/*************************************************************************
-|*
-|*  SwPageFrm::PrepareHeader()
-|*
-|*  Description        Creates or removes headers
-|*
-|*************************************************************************/
-
-
-void DelFlys( SwLayoutFrm *pFrm, SwPageFrm *pPage )
+void DelFlys( SwLayoutFrame *pFrame, SwPageFrame *pPage )
 {
-    for ( int i = 0; pPage->GetSortedObjs() &&
-                        pPage->GetSortedObjs()->Count() &&
-                        i < (int)pPage->GetSortedObjs()->Count(); ++i )
+    size_t i = 0;
+    while ( pPage->GetSortedObjs() &&
+            pPage->GetSortedObjs()->size() &&
+            i < pPage->GetSortedObjs()->size() )
     {
         SwAnchoredObject* pObj = (*pPage->GetSortedObjs())[i];
-        if ( pObj->ISA(SwFlyFrm) )
+        if ( dynamic_cast< const SwFlyFrame *>( pObj ) !=  nullptr )
         {
-            SwFlyFrm* pFlyFrm = static_cast<SwFlyFrm*>(pObj);
-            if ( pFrm->IsAnLower( pFlyFrm ) )
+            SwFlyFrame* pFlyFrame = static_cast<SwFlyFrame*>(pObj);
+            if ( pFrame->IsAnLower( pFlyFrame ) )
             {
-                delete pFlyFrm;
-                --i;
+                SwFrame::DestroyFrame(pFlyFrame);
+                // Do not increment index, in this case
+                continue;
             }
         }
+        ++i;
     }
 }
 
-
-
-void SwPageFrm::PrepareHeader()
+/// Creates or removes headers
+void SwPageFrame::PrepareHeader()
 {
-    SwLayoutFrm *pLay = (SwLayoutFrm*)Lower();
+    SwLayoutFrame *pLay = static_cast<SwLayoutFrame*>(Lower());
     if ( !pLay )
         return;
 
-    const SwFmtHeader &rH = ((SwFrmFmt*)GetRegisteredIn())->GetHeader();
+    const SwFormatHeader &rH = static_cast<SwFrameFormat*>(GetRegisteredIn())->GetHeader();
 
-    const SwViewShell *pSh = getRootFrm()->GetCurrShell();
-    const sal_Bool bOn = !(pSh && pSh->GetViewOptions()->getBrowseMode());
+    const SwViewShell *pSh = getRootFrame()->GetCurrShell();
+    const bool bOn = !(pSh && (pSh->GetViewOptions()->getBrowseMode() ||
+                               pSh->GetViewOptions()->IsWhitespaceHidden()));
 
     if ( bOn && rH.IsActive() )
     {   //Implant header, but remove first, if already present
-        OSL_ENSURE( rH.GetHeaderFmt(), "FrmFmt for Header not found." );
+        OSL_ENSURE( rH.GetHeaderFormat(), "FrameFormat for Header not found." );
 
-        if ( pLay->GetFmt() == (SwFrmFmt*)rH.GetHeaderFmt() )
+        if ( pLay->GetFormat() == rH.GetHeaderFormat() )
             return; // Header is already the correct one.
 
-        if ( pLay->IsHeaderFrm() )
-        {   SwLayoutFrm *pDel = pLay;
-            pLay = (SwLayoutFrm*)pLay->GetNext();
+        if ( pLay->IsHeaderFrame() )
+        {   SwLayoutFrame *pDel = pLay;
+            pLay = static_cast<SwLayoutFrame*>(pLay->GetNext());
             ::DelFlys( pDel, this );
             pDel->Cut();
-            delete pDel;
+            SwFrame::DestroyFrame(pDel);
         }
         OSL_ENSURE( pLay, "Where to with the Header?" );
-        SwHeaderFrm *pH = new SwHeaderFrm( (SwFrmFmt*)rH.GetHeaderFmt(), this );
+        SwHeaderFrame *pH = new SwHeaderFrame( const_cast<SwFrameFormat*>(rH.GetHeaderFormat()), this );
         pH->Paste( this, pLay );
         if ( GetUpper() )
             ::RegistFlys( this, pH );
     }
-    else if ( pLay && pLay->IsHeaderFrm() )
+    else if ( pLay && pLay->IsHeaderFrame() )
     {   // Remove header if present.
         ::DelFlys( pLay, this );
         pLay->Cut();
-        delete pLay;
+        SwFrame::DestroyFrame(pLay);
     }
 }
-/*************************************************************************
-|*
-|*  SwPageFrm::PrepareFooter()
-|*
-|*  Description        Creates or removes footer
-|*
-|*************************************************************************/
 
-
-void SwPageFrm::PrepareFooter()
+/// Creates or removes footer
+void SwPageFrame::PrepareFooter()
 {
-    SwLayoutFrm *pLay = (SwLayoutFrm*)Lower();
+    SwLayoutFrame *pLay = static_cast<SwLayoutFrame*>(Lower());
     if ( !pLay )
         return;
 
-    const SwFmtFooter &rF = ((SwFrmFmt*)GetRegisteredIn())->GetFooter();
+    const SwFormatFooter &rF = static_cast<SwFrameFormat*>(GetRegisteredIn())->GetFooter();
     while ( pLay->GetNext() )
-        pLay = (SwLayoutFrm*)pLay->GetNext();
+        pLay = static_cast<SwLayoutFrame*>(pLay->GetNext());
 
-    const SwViewShell *pSh = getRootFrm()->GetCurrShell();
-    const sal_Bool bOn = !(pSh && pSh->GetViewOptions()->getBrowseMode());
+    const SwViewShell *pSh = getRootFrame()->GetCurrShell();
+    const bool bOn = !(pSh && (pSh->GetViewOptions()->getBrowseMode() ||
+                               pSh->GetViewOptions()->IsWhitespaceHidden()));
 
     if ( bOn && rF.IsActive() )
     {   //Implant footer, but remove first, if already present
-        OSL_ENSURE( rF.GetFooterFmt(), "FrmFmt for Footer not found." );
+        OSL_ENSURE( rF.GetFooterFormat(), "FrameFormat for Footer not found." );
 
-        if ( pLay->GetFmt() == (SwFrmFmt*)rF.GetFooterFmt() )
+        if ( pLay->GetFormat() == rF.GetFooterFormat() )
             return;  // Footer is already the correct one.
 
-        if ( pLay->IsFooterFrm() )
-        {   ::DelFlys( pLay, this );
+        if ( pLay->IsFooterFrame() )
+        {
+            ::DelFlys( pLay, this );
             pLay->Cut();
-            delete pLay;
+            SwFrame::DestroyFrame(pLay);
         }
-        SwFooterFrm *pF = new SwFooterFrm( (SwFrmFmt*)rF.GetFooterFmt(), this );
+        SwFooterFrame *pF = new SwFooterFrame( const_cast<SwFrameFormat*>(rF.GetFooterFormat()), this );
         pF->Paste( this );
         if ( GetUpper() )
             ::RegistFlys( this, pF );
     }
-    else if ( pLay && pLay->IsFooterFrm() )
+    else if ( pLay->IsFooterFrame() )
     {   // Remove footer if already present
         ::DelFlys( pLay, this );
         SwViewShell *pShell;
-        if ( pLay->GetPrev() && 0 != (pShell = getRootFrm()->GetCurrShell()) &&
+        if ( pLay->GetPrev() && nullptr != (pShell = getRootFrame()->GetCurrShell()) &&
              pShell->VisArea().HasArea() )
             pShell->InvalidateWindows( pShell->VisArea() );
         pLay->Cut();
-        delete pLay;
+        SwFrame::DestroyFrame(pLay);
     }
 }
 
-
-
 /* vim:set shiftwidth=4 softtabstop=4 expandtab: */
