@@ -45,17 +45,13 @@ using namespace ::sw::mark;
 using namespace ::com::sun::star;
 using namespace ::com::sun::star::i18n::ScriptType;
 
-/*************************************************************************
- *                          lcl_AddSpace
- * Returns for how many characters an extra space has to be added
- * (for justified alignment).
- *************************************************************************/
-
-static sal_Int32 lcl_AddSpace( const SwTxtSizeInfo &rInf, const OUString* pStr,
+// Returns for how many characters an extra space has to be added
+// (for justified alignment).
+static sal_Int32 lcl_AddSpace( const SwTextSizeInfo &rInf, const OUString* pStr,
                                const SwLinePortion& rPor )
 {
     sal_Int32 nPos, nEnd;
-    const SwScriptInfo* pSI = 0;
+    const SwScriptInfo* pSI = nullptr;
 
     if ( pStr )
     {
@@ -67,8 +63,8 @@ static sal_Int32 lcl_AddSpace( const SwTxtSizeInfo &rInf, const OUString* pStr,
     {
         nPos = rInf.GetIdx();
         nEnd = rInf.GetIdx() + rPor.GetLen();
-        pStr = &rInf.GetTxt();
-        pSI = &((SwParaPortion*)rInf.GetParaPortion())->GetScriptInfo();
+        pStr = &rInf.GetText();
+        pSI = &const_cast<SwParaPortion*>(rInf.GetParaPortion())->GetScriptInfo();
     }
 
     sal_Int32 nCnt = 0;
@@ -93,7 +89,7 @@ static sal_Int32 lcl_AddSpace( const SwTxtSizeInfo &rInf, const OUString* pStr,
     if ( nEnd > nPos && ASIAN == nScript )
     {
         LanguageType aLang =
-            rInf.GetTxtFrm()->GetTxtNode()->GetLang( rInf.GetIdx(), 1, nScript );
+            rInf.GetTextFrame()->GetTextNode()->GetLang( rInf.GetIdx(), 1, nScript );
 
         if (!MsLangId::isKorean(aLang))
         {
@@ -118,10 +114,10 @@ static sal_Int32 lcl_AddSpace( const SwTxtSizeInfo &rInf, const OUString* pStr,
     {
         if ( SwScriptInfo::IsArabicText( *pStr, nPos, nEnd - nPos ) && pSI->CountKashida() )
         {
-            const sal_uInt16 nKashRes = pSI->KashidaJustify( 0, 0, nPos, nEnd - nPos );
+            const sal_Int32 nKashRes = pSI->KashidaJustify( nullptr, nullptr, nPos, nEnd - nPos );
             // i60591: need to check result of KashidaJustify
             // determine if kashida justification is applicable
-            if( nKashRes != STRING_LEN )
+            if (nKashRes != -1)
                 return nKashRes;
         }
     }
@@ -130,11 +126,11 @@ static sal_Int32 lcl_AddSpace( const SwTxtSizeInfo &rInf, const OUString* pStr,
     if ( nEnd > nPos && COMPLEX == nScript )
     {
         LanguageType aLang =
-            rInf.GetTxtFrm()->GetTxtNode()->GetLang( rInf.GetIdx(), 1, nScript );
+            rInf.GetTextFrame()->GetTextNode()->GetLang( rInf.GetIdx(), 1, nScript );
 
         if ( LANGUAGE_THAI == aLang )
         {
-            nCnt = SwScriptInfo::ThaiJustify( *pStr, 0, 0, nPos, nEnd - nPos );
+            nCnt = SwScriptInfo::ThaiJustify( *pStr, nullptr, nullptr, nPos, nEnd - nPos );
 
             const SwLinePortion* pPor = rPor.GetPortion();
             if ( pPor && ( pPor->IsKernPortion() ||
@@ -156,13 +152,13 @@ static sal_Int32 lcl_AddSpace( const SwTxtSizeInfo &rInf, const OUString* pStr,
             LATIN == nScript && ( nEnd == nPos + 1 ) && pSI &&
             ( i18n::ScriptType::COMPLEX ==
               pSI->ScriptType( nPos + 1 ) ) &&
-            rInf.GetTxtFrm() && rInf.GetTxtFrm()->IsRightToLeft();
+            rInf.GetTextFrame() && rInf.GetTextFrame()->IsRightToLeft();
 
     if ( bDoNotAddSpace )
         return nCnt;
 
-    sal_Int32 nTxtEnd = std::min(nEnd, pStr->getLength());
-    for ( ; nPos < nTxtEnd; ++nPos )
+    sal_Int32 nTextEnd = std::min(nEnd, pStr->getLength());
+    for ( ; nPos < nTextEnd; ++nPos )
     {
         if( CH_BLANK == (*pStr)[ nPos ] )
             ++nCnt;
@@ -174,7 +170,7 @@ static sal_Int32 lcl_AddSpace( const SwTxtSizeInfo &rInf, const OUString* pStr,
     // nPos referes to the original string, even if a field string has
     // been passed to this function
     nPos = rInf.GetIdx() + rPor.GetLen();
-    if ( nPos < rInf.GetTxt().getLength() )
+    if ( nPos < rInf.GetText().getLength() )
     {
         sal_uInt8 nNextScript = 0;
         const SwLinePortion* pPor = rPor.GetPortion();
@@ -188,21 +184,21 @@ static sal_Int32 lcl_AddSpace( const SwTxtSizeInfo &rInf, const OUString* pStr,
         if ( CH_TXTATR_BREAKWORD == rInf.GetChar( nPos ) && pPor->InExpGrp() )
         {
             bool bOldOnWin = rInf.OnWin();
-            ((SwTxtSizeInfo &)rInf).SetOnWin( false );
+            ((SwTextSizeInfo &)rInf).SetOnWin( false );
 
             OUString aStr;
-            pPor->GetExpTxt( rInf, aStr );
-            ((SwTxtSizeInfo &)rInf).SetOnWin( bOldOnWin );
+            pPor->GetExpText( rInf, aStr );
+            ((SwTextSizeInfo &)rInf).SetOnWin( bOldOnWin );
 
             nNextScript = (sal_uInt8)g_pBreakIt->GetBreakIter()->getScriptType( aStr, 0 );
         }
         else
-            nNextScript = (sal_uInt8)g_pBreakIt->GetBreakIter()->getScriptType( rInf.GetTxt(), nPos );
+            nNextScript = (sal_uInt8)g_pBreakIt->GetBreakIter()->getScriptType( rInf.GetText(), nPos );
 
         if( ASIAN == nNextScript )
         {
             LanguageType aLang =
-                rInf.GetTxtFrm()->GetTxtNode()->GetLang( nPos, 1, nNextScript );
+                rInf.GetTextFrame()->GetTextNode()->GetLang( nPos, 1, nNextScript );
 
             if (!MsLangId::isKorean(aLang))
                 ++nCnt;
@@ -212,28 +208,22 @@ static sal_Int32 lcl_AddSpace( const SwTxtSizeInfo &rInf, const OUString* pStr,
     return nCnt;
 }
 
-/*************************************************************************
- *                      class SwTxtPortion
- *************************************************************************/
-
-SwTxtPortion::SwTxtPortion( const SwLinePortion &rPortion )
-  : SwLinePortion( rPortion )
+SwTextPortion * SwTextPortion::CopyLinePortion(const SwLinePortion &rPortion)
 {
-    SetWhichPor( POR_TXT );
+    SwTextPortion *const pNew(new SwTextPortion);
+    static_cast<SwLinePortion&>(*pNew) = rPortion;
+    pNew->SetWhichPor( POR_TXT ); // overwrite that!
+    return pNew;
 }
 
-/*************************************************************************
- *                      SwTxtPortion::BreakCut()
- *************************************************************************/
-
-void SwTxtPortion::BreakCut( SwTxtFormatInfo &rInf, const SwTxtGuess &rGuess )
+void SwTextPortion::BreakCut( SwTextFormatInfo &rInf, const SwTextGuess &rGuess )
 {
     // The word/char is larger than the line
     // Special case 1: The word is larger than the line
     // We truncate ...
-    const KSHORT nLineWidth = (KSHORT)(rInf.Width() - rInf.X());
-    xub_StrLen nLen = rGuess.CutPos() - rInf.GetIdx();
-    if( nLen )
+    const sal_uInt16 nLineWidth = (sal_uInt16)(rInf.Width() - rInf.X());
+    sal_Int32 nLen = rGuess.CutPos() - rInf.GetIdx();
+    if (nLen > 0)
     {
         // special case: guess does not always provide the correct
         // width, only in common cases.
@@ -241,11 +231,11 @@ void SwTxtPortion::BreakCut( SwTxtFormatInfo &rInf, const SwTxtGuess &rGuess )
         {
             rInf.SetLen( nLen );
             SetLen( nLen );
-            CalcTxtSize( rInf );
+            CalcTextSize( rInf );
 
             // changing these values requires also changing them in
             // guess.cxx
-            KSHORT nItalic = 0;
+            sal_uInt16 nItalic = 0;
             if( ITALIC_NONE != rInf.GetFont()->GetItalic() && !rInf.NotEOL() )
             {
                 nItalic = Height() / 12;
@@ -271,43 +261,35 @@ void SwTxtPortion::BreakCut( SwTxtFormatInfo &rInf, const SwTxtGuess &rGuess )
     }
 }
 
-/*************************************************************************
- *                      SwTxtPortion::BreakUnderflow()
- *************************************************************************/
-
-void SwTxtPortion::BreakUnderflow( SwTxtFormatInfo &rInf )
+void SwTextPortion::BreakUnderflow( SwTextFormatInfo &rInf )
 {
     Truncate();
     Height( 0 );
     Width( 0 );
     SetLen( 0 );
     SetAscent( 0 );
-    rInf.SetUnderFlow( this );
+    rInf.SetUnderflow( this );
 }
 
- /*************************************************************************
- *                      SwTxtPortion::_Format()
- *************************************************************************/
-
-static bool lcl_HasContent( const SwFldPortion& rFld, SwTxtFormatInfo &rInf )
+static bool lcl_HasContent( const SwFieldPortion& rField, SwTextFormatInfo &rInf )
 {
-    OUString aTxt;
-    return rFld.GetExpTxt( rInf, aTxt ) && !aTxt.isEmpty();
+    OUString aText;
+    return rField.GetExpText( rInf, aText ) && !aText.isEmpty();
 }
 
-sal_Bool SwTxtPortion::_Format( SwTxtFormatInfo &rInf )
+bool SwTextPortion::_Format( SwTextFormatInfo &rInf )
 {
-    // 5744: If only the hypen does not fit anymore, we still need to wrap
-    // the word, or else return sal_True!
-    if( rInf.IsUnderFlow() && rInf.GetSoftHyphPos() )
+    // 5744: If only the hyphen does not fit anymore, we still need to wrap
+    // the word, or else return true!
+    if( rInf.IsUnderflow() && rInf.GetSoftHyphPos() )
     {
         // soft hyphen portion has triggered an underflow event because
         // of an alternative spelling position
-        sal_Bool bFull = sal_False;
-        const sal_Bool bHyph = rInf.ChgHyph( sal_True );
+        bool bFull = false;
+        const bool bHyph = rInf.ChgHyph( true );
         if( rInf.IsHyphenate() )
         {
-            SwTxtGuess aGuess;
+            SwTextGuess aGuess;
             // check for alternative spelling left from the soft hyphen
             // this should usually be true but
             aGuess.AlternativeSpelling( rInf, rInf.GetSoftHyphPos() - 1 );
@@ -319,8 +301,8 @@ sal_Bool SwTxtPortion::_Format( SwTxtFormatInfo &rInf )
         return bFull;
     }
 
-    SwTxtGuess aGuess;
-    const sal_Bool bFull = !aGuess.Guess( *this, rInf, Height() );
+    SwTextGuess aGuess;
+    const bool bFull = !aGuess.Guess( *this, rInf, Height() );
 
     // these are the possible cases:
     // A Portion fits to current line
@@ -340,7 +322,7 @@ sal_Bool SwTxtPortion::_Format( SwTxtFormatInfo &rInf )
     {
         Width( aGuess.BreakWidth() );
         // Vorsicht !
-        if( !InExpGrp() || InFldGrp() )
+        if( !InExpGrp() || InFieldGrp() )
             SetLen( rInf.GetLen() );
 
         short nKern = rInf.GetFont()->CheckKerning();
@@ -363,7 +345,7 @@ sal_Bool SwTxtPortion::_Format( SwTxtFormatInfo &rInf )
         aGuess.ClearHangingPortion();
     }
     // breakPos >= index
-    else if ( aGuess.BreakPos() >= rInf.GetIdx() && aGuess.BreakPos() != STRING_LEN )
+    else if ( aGuess.BreakPos() >= rInf.GetIdx() && aGuess.BreakPos() != COMPLETE_STRING )
     {
         // case B1
         if( aGuess.HyphWord().is() && aGuess.BreakPos() > rInf.GetLineStart()
@@ -372,9 +354,9 @@ sal_Bool SwTxtPortion::_Format( SwTxtFormatInfo &rInf )
         {
             CreateHyphen( rInf, aGuess );
             if ( rInf.GetFly() )
-                rInf.GetRoot()->SetMidHyph( sal_True );
+                rInf.GetRoot()->SetMidHyph( true );
             else
-                rInf.GetRoot()->SetEndHyph( sal_True );
+                rInf.GetRoot()->SetEndHyph( true );
         }
         // case C1
         // - Footnote portions with fake line start (i.e., not at beginning of line)
@@ -384,11 +366,11 @@ sal_Bool SwTxtPortion::_Format( SwTxtFormatInfo &rInf )
         //   text portion, if they are not followed by a blank
         //   (work around different definition of tab stop character - breaking or
         //   non breaking character - in compatibility mode)
-        else if ( ( IsFtnPortion() && rInf.IsFakeLineStart() &&
-                    //
-                    rInf.IsOtherThanFtnInside() ) ||
+        else if ( ( IsFootnotePortion() && rInf.IsFakeLineStart() &&
+
+                    rInf.IsOtherThanFootnoteInside() ) ||
                   ( rInf.GetLast() &&
-                    rInf.GetTxtFrm()->GetTxtNode()->getIDocumentSettingAccess()->get(IDocumentSettingAccess::TAB_COMPAT) &&
+                    rInf.GetTextFrame()->GetTextNode()->getIDocumentSettingAccess()->get(DocumentSettingId::TAB_COMPAT) &&
                     rInf.GetLast()->InTabGrp() &&
                     rInf.GetLineStart() + rInf.GetLast()->GetLen() < rInf.GetIdx() &&
                     aGuess.BreakPos() == rInf.GetIdx()  &&
@@ -406,22 +388,22 @@ sal_Bool SwTxtPortion::_Format( SwTxtFormatInfo &rInf )
                  rInf.IsFirstMulti() ||
                  ( rInf.GetLast() &&
                     ( rInf.GetLast()->IsFlyPortion() ||
-                        ( rInf.GetLast()->InFldGrp() &&
+                        ( rInf.GetLast()->InFieldGrp() &&
                           ! rInf.GetLast()->InNumberGrp() &&
                           ! rInf.GetLast()->IsErgoSumPortion() &&
-                          lcl_HasContent(*((SwFldPortion*)rInf.GetLast()),rInf ) ) ) ) )
+                          lcl_HasContent(*static_cast<SwFieldPortion*>(rInf.GetLast()),rInf ) ) ) ) )
         {
             if ( rInf.X() + aGuess.BreakWidth() <= rInf.Width() )
                 Width( aGuess.BreakWidth() );
             else
                 // this actually should not happen
-                Width( KSHORT(rInf.Width() - rInf.X()) );
+                Width( sal_uInt16(rInf.Width() - rInf.X()) );
 
             SetLen( aGuess.BreakPos() - rInf.GetIdx() );
 
             OSL_ENSURE( aGuess.BreakStart() >= aGuess.FieldDiff(),
                     "Trouble with expanded field portions during line break" );
-            const xub_StrLen nRealStart = aGuess.BreakStart() - aGuess.FieldDiff();
+            const sal_Int32 nRealStart = aGuess.BreakStart() - aGuess.FieldDiff();
             if( aGuess.BreakPos() < nRealStart && !InExpGrp() )
             {
                 SwHolePortion *pNew = new SwHolePortion( *this );
@@ -436,12 +418,11 @@ sal_Bool SwTxtPortion::_Format( SwTxtFormatInfo &rInf )
     else
     {
         bool bFirstPor = rInf.GetLineStart() == rInf.GetIdx();
-        if( aGuess.BreakPos() != STRING_LEN &&
+        if( aGuess.BreakPos() != COMPLETE_STRING &&
             aGuess.BreakPos() != rInf.GetLineStart() &&
             ( !bFirstPor || rInf.GetFly() || rInf.GetLast()->IsFlyPortion() ||
               rInf.IsFirstMulti() ) &&
-            ( !rInf.GetLast()->IsBlankPortion() ||  ((SwBlankPortion*)
-              rInf.GetLast())->MayUnderFlow( rInf, rInf.GetIdx()-1, sal_True )))
+            ( !rInf.GetLast()->IsBlankPortion() || SwBlankPortion::MayUnderflow( rInf, rInf.GetIdx()-1, true )))
         {       // case C1 (former BreakUnderflow())
             BreakUnderflow( rInf );
         }
@@ -453,13 +434,7 @@ sal_Bool SwTxtPortion::_Format( SwTxtFormatInfo &rInf )
     return bFull;
 }
 
-/*************************************************************************
- *                 virtual SwTxtPortion::Format()
- *************************************************************************/
-
-
-
-sal_Bool SwTxtPortion::Format( SwTxtFormatInfo &rInf )
+bool SwTextPortion::Format( SwTextFormatInfo &rInf )
 {
     if( rInf.X() > rInf.Width() || (!GetLen() && !InExpGrp()) )
     {
@@ -467,78 +442,66 @@ sal_Bool SwTxtPortion::Format( SwTxtFormatInfo &rInf )
         Width( 0 );
         SetLen( 0 );
         SetAscent( 0 );
-        SetPortion( NULL );  // ????
-        return sal_True;
+        SetPortion( nullptr );  // ????
+        return true;
     }
 
     OSL_ENSURE( rInf.RealWidth() || (rInf.X() == rInf.Width()),
-        "SwTxtPortion::Format: missing real width" );
-    OSL_ENSURE( Height(), "SwTxtPortion::Format: missing height" );
+        "SwTextPortion::Format: missing real width" );
+    OSL_ENSURE( Height(), "SwTextPortion::Format: missing height" );
 
     return _Format( rInf );
 }
 
-/*************************************************************************
- *                 virtual SwTxtPortion::FormatEOL()
- *************************************************************************/
-
 // Format end of line
 // 5083: We can have awkward cases e.g.:
 // "from {Santa}"
 // Santa wraps, "from " turns into "from" and " " in a justified
 // paragraph, in which the glue gets expanded instead of merged
 // with the MarginPortion.
-//
-// rInf.nIdx points to the next word, nIdx-1 is the portion's last char
 
-void SwTxtPortion::FormatEOL( SwTxtFormatInfo &rInf )
+// rInf.nIdx points to the next word, nIdx-1 is the portion's last char
+void SwTextPortion::FormatEOL( SwTextFormatInfo &rInf )
 {
     if( ( !GetPortion() || ( GetPortion()->IsKernPortion() &&
         !GetPortion()->GetPortion() ) ) && GetLen() &&
-        rInf.GetIdx() < rInf.GetTxt().getLength() &&
+        rInf.GetIdx() < rInf.GetText().getLength() &&
         1 < rInf.GetIdx() && ' ' == rInf.GetChar( rInf.GetIdx() - 1 )
         && !rInf.GetLast()->IsHolePortion() )
     {
         // calculate number of blanks
-        xub_StrLen nX = rInf.GetIdx() - 1;
-        sal_uInt16 nHoleLen = 1;
+        sal_Int32 nX = rInf.GetIdx() - 1;
+        sal_Int32 nHoleLen = 1;
         while( nX && nHoleLen < GetLen() && CH_BLANK == rInf.GetChar( --nX ) )
             nHoleLen++;
 
         // First set ourselves and the insert, because there could be
         // a SwLineLayout
-        KSHORT nBlankSize;
+        sal_uInt16 nBlankSize;
         if( nHoleLen == GetLen() )
             nBlankSize = Width();
         else
-            nBlankSize = nHoleLen * rInf.GetTxtSize(OUString(' ')).Width();
+            nBlankSize = nHoleLen * rInf.GetTextSize(OUString(' ')).Width();
         Width( Width() - nBlankSize );
         rInf.X( rInf.X() - nBlankSize );
         SetLen( GetLen() - nHoleLen );
         SwLinePortion *pHole = new SwHolePortion( *this );
-        ( (SwHolePortion *)pHole )->SetBlankWidth( nBlankSize );
-        ( (SwHolePortion *)pHole )->SetLen( nHoleLen );
+        static_cast<SwHolePortion *>( pHole )->SetBlankWidth( nBlankSize );
+        static_cast<SwHolePortion *>( pHole )->SetLen( nHoleLen );
         Insert( pHole );
     }
 }
 
-/*************************************************************************
- *               virtual SwTxtPortion::GetCrsrOfst()
- *************************************************************************/
-xub_StrLen SwTxtPortion::GetCrsrOfst( const KSHORT nOfst ) const
+sal_Int32 SwTextPortion::GetCursorOfst( const sal_uInt16 nOfst ) const
 {
-    OSL_ENSURE( !this, "SwTxtPortion::GetCrsrOfst: don't use this method!" );
-    return SwLinePortion::GetCrsrOfst( nOfst );
+    OSL_ENSURE( false, "SwTextPortion::GetCursorOfst: don't use this method!" );
+    return SwLinePortion::GetCursorOfst( nOfst );
 }
 
-/*************************************************************************
- *                virtual SwTxtPortion::GetTxtSize()
- *************************************************************************/
-// The GetTxtSize() assumes that the own length is correct
-
-SwPosSize SwTxtPortion::GetTxtSize( const SwTxtSizeInfo &rInf ) const
+// The GetTextSize() assumes that the own length is correct
+SwPosSize SwTextPortion::GetTextSize( const SwTextSizeInfo &rInf ) const
 {
-    SwPosSize aSize = rInf.GetTxtSize();
+    SwPosSize aSize = rInf.GetTextSize();
     if( !GetJoinBorderWithPrev() )
         aSize.Width(aSize.Width() + rInf.GetFont()->GetLeftBorderSpace() );
     if( !GetJoinBorderWithNext() )
@@ -551,22 +514,21 @@ SwPosSize SwTxtPortion::GetTxtSize( const SwTxtSizeInfo &rInf ) const
     return aSize;
 }
 
-/*************************************************************************
- *               virtual SwTxtPortion::Paint()
- *************************************************************************/
-void SwTxtPortion::Paint( const SwTxtPaintInfo &rInf ) const
+void SwTextPortion::Paint( const SwTextPaintInfo &rInf ) const
 {
-    if (rInf.OnWin() && 1==rInf.GetLen() && CH_TXT_ATR_FIELDEND==rInf.GetTxt()[rInf.GetIdx()])
+    if (rInf.OnWin() && 1==rInf.GetLen() && CH_TXT_ATR_FIELDEND==rInf.GetText()[rInf.GetIdx()])
     {
+        assert(false); // this is some debugging only code
         rInf.DrawBackBrush( *this );
-        const OUString aTxt(CH_TXT_ATR_SUBST_FIELDEND);
-        rInf.DrawText( aTxt, *this, 0, aTxt.getLength(), false );
+        const OUString aText(CH_TXT_ATR_SUBST_FIELDEND);
+        rInf.DrawText( aText, *this, 0, aText.getLength() );
     }
-    else if (rInf.OnWin() && 1==rInf.GetLen() && CH_TXT_ATR_FIELDSTART==rInf.GetTxt()[rInf.GetIdx()])
+    else if (rInf.OnWin() && 1==rInf.GetLen() && CH_TXT_ATR_FIELDSTART==rInf.GetText()[rInf.GetIdx()])
     {
+        assert(false); // this is some debugging only code
         rInf.DrawBackBrush( *this );
-        const OUString aTxt(CH_TXT_ATR_SUBST_FIELDSTART);
-        rInf.DrawText( aTxt, *this, 0, aTxt.getLength(), false );
+        const OUString aText(CH_TXT_ATR_SUBST_FIELDSTART);
+        rInf.DrawText( aText, *this, 0, aText.getLength() );
     }
     else if( GetLen() )
     {
@@ -579,39 +541,27 @@ void SwTxtPortion::Paint( const SwTxtPaintInfo &rInf ) const
 
         const SwWrongList *pWrongList = rInf.GetpWrongList();
         const SwWrongList *pGrammarCheckList = rInf.GetGrammarCheckList();
-        // SMARTTAGS
         const SwWrongList *pSmarttags = rInf.GetSmartTags();
 
-        const bool bWrong = 0 != pWrongList;
-        const bool bGrammarCheck = 0 != pGrammarCheckList;
-        const bool bSmartTags = 0 != pSmarttags;
+        const bool bWrong = nullptr != pWrongList;
+        const bool bGrammarCheck = nullptr != pGrammarCheckList;
+        const bool bSmartTags = nullptr != pSmarttags;
 
         if ( bWrong || bSmartTags || bGrammarCheck )
-            rInf.DrawMarkedText( *this, rInf.GetLen(), sal_False, bWrong, bSmartTags, bGrammarCheck );
+            rInf.DrawMarkedText( *this, rInf.GetLen(), false, bWrong, bSmartTags, bGrammarCheck );
         else
-            rInf.DrawText( *this, rInf.GetLen(), sal_False );
+            rInf.DrawText( *this, rInf.GetLen() );
     }
 }
 
-/*************************************************************************
- *              virtual SwTxtPortion::GetExpTxt()
- *************************************************************************/
-
-
-
-sal_Bool SwTxtPortion::GetExpTxt( const SwTxtSizeInfo &, OUString & ) const
+bool SwTextPortion::GetExpText( const SwTextSizeInfo &, OUString & ) const
 {
-    return sal_False;
+    return false;
 }
 
-/*************************************************************************
- *        xub_StrLen SwTxtPortion::GetSpaceCnt()
- *              long SwTxtPortion::CalcSpacing()
- * Are responsible for the justified paragraph. They calculate the blank
- * count and the resulting added space.
- *************************************************************************/
-
-sal_Int32 SwTxtPortion::GetSpaceCnt( const SwTxtSizeInfo &rInf,
+// Responsible for the justified paragraph. They calculate the blank
+// count and the resulting added space.
+sal_Int32 SwTextPortion::GetSpaceCnt( const SwTextSizeInfo &rInf,
                                       sal_Int32& rCharCnt ) const
 {
     sal_Int32 nCnt = 0;
@@ -623,11 +573,11 @@ sal_Int32 SwTxtPortion::GetSpaceCnt( const SwTxtSizeInfo &rInf,
             // OnWin() likes to return a blank instead of an empty string from
             // time to time. We cannot use that here at all, however.
             bool bOldOnWin = rInf.OnWin();
-            ((SwTxtSizeInfo &)rInf).SetOnWin( false );
+            ((SwTextSizeInfo &)rInf).SetOnWin( false );
 
             OUString aStr;
-            GetExpTxt( rInf, aStr );
-            ((SwTxtSizeInfo &)rInf).SetOnWin( bOldOnWin );
+            GetExpText( rInf, aStr );
+            ((SwTextSizeInfo &)rInf).SetOnWin( bOldOnWin );
 
             nCnt = nCnt + lcl_AddSpace( rInf, &aStr, *this );
             nPos = aStr.getLength();
@@ -635,16 +585,16 @@ sal_Int32 SwTxtPortion::GetSpaceCnt( const SwTxtSizeInfo &rInf,
     }
     else if( !IsDropPortion() )
     {
-        nCnt = nCnt + lcl_AddSpace( rInf, 0, *this );
+        nCnt = nCnt + lcl_AddSpace( rInf, nullptr, *this );
         nPos = GetLen();
     }
     rCharCnt = rCharCnt + nPos;
     return nCnt;
 }
 
-long SwTxtPortion::CalcSpacing( long nSpaceAdd, const SwTxtSizeInfo &rInf ) const
+long SwTextPortion::CalcSpacing( long nSpaceAdd, const SwTextSizeInfo &rInf ) const
 {
-    xub_StrLen nCnt = 0;
+    sal_Int32 nCnt = 0;
 
     if ( InExpGrp() )
     {
@@ -653,11 +603,11 @@ long SwTxtPortion::CalcSpacing( long nSpaceAdd, const SwTxtSizeInfo &rInf ) cons
             // OnWin() likes to return a blank instead of an empty string from
             // time to time. We cannot use that here at all, however.
             bool bOldOnWin = rInf.OnWin();
-            ((SwTxtSizeInfo &)rInf).SetOnWin( false );
+            ((SwTextSizeInfo &)rInf).SetOnWin( false );
 
             OUString aStr;
-            GetExpTxt( rInf, aStr );
-            ((SwTxtSizeInfo &)rInf).SetOnWin( bOldOnWin );
+            GetExpText( rInf, aStr );
+            ((SwTextSizeInfo &)rInf).SetOnWin( bOldOnWin );
             if( nSpaceAdd > 0 )
                 nCnt = nCnt + lcl_AddSpace( rInf, &aStr, *this );
             else
@@ -670,7 +620,7 @@ long SwTxtPortion::CalcSpacing( long nSpaceAdd, const SwTxtSizeInfo &rInf ) cons
     else if( !IsDropPortion() )
     {
         if( nSpaceAdd > 0 )
-            nCnt = nCnt + lcl_AddSpace( rInf, 0, *this );
+            nCnt = nCnt + lcl_AddSpace( rInf, nullptr, *this );
         else
         {
             nSpaceAdd = -nSpaceAdd;
@@ -692,92 +642,36 @@ long SwTxtPortion::CalcSpacing( long nSpaceAdd, const SwTxtSizeInfo &rInf ) cons
     return nCnt * nSpaceAdd / SPACING_PRECISION_FACTOR;
 }
 
-/*************************************************************************
- *              virtual SwTxtPortion::HandlePortion()
- *************************************************************************/
-
-void SwTxtPortion::HandlePortion( SwPortionHandler& rPH ) const
+void SwTextPortion::HandlePortion( SwPortionHandler& rPH ) const
 {
     rPH.Text( GetLen(), GetWhichPor(), Height(), Width() );
 }
 
-
-SwTxtInputFldPortion::SwTxtInputFldPortion()
-    : SwTxtPortion()
+SwTextInputFieldPortion::SwTextInputFieldPortion()
+    : SwTextPortion()
     , mbContainsInputFieldStart( false )
     , mbContainsInputFieldEnd( false )
 {
     SetWhichPor( POR_INPUTFLD );
 }
 
-
-sal_Bool SwTxtInputFldPortion::Format( SwTxtFormatInfo &rInf )
+bool SwTextInputFieldPortion::Format(SwTextFormatInfo &rTextFormatInfo)
 {
-    mbContainsInputFieldStart =
-        rInf.GetChar( rInf.GetIdx() ) == CH_TXT_ATR_INPUTFIELDSTART;
-    mbContainsInputFieldEnd =
-        rInf.GetChar( rInf.GetIdx() + rInf.GetLen() - 1 ) == CH_TXT_ATR_INPUTFIELDEND;
-
-    sal_Bool bRet = sal_False;
-    if ( rInf.GetLen() == 1
-         && ( mbContainsInputFieldStart || mbContainsInputFieldEnd ) )
-    {
-        Width( 0 );
-    }
-    else
-    {
-        SwTxtSlot aFormatTxt( &rInf, this, true, true, 0 );
-        if ( rInf.GetLen() == 0 )
-        {
-            Width( 0 );
-        }
-        else
-        {
-            const sal_Int32 nFormerLineStart = rInf.GetLineStart();
-            if ( !mbContainsInputFieldStart )
-            {
-                rInf.SetLineStart( 0 );
-            }
-
-            bRet = SwTxtPortion::Format( rInf );
-
-            if ( mbContainsInputFieldEnd )
-            {
-                // adjust portion length accordingly, if complete text fits into the portion
-                if ( GetLen() == rInf.GetLen() )
-                {
-                    SetLen( GetLen() + 1 );
-                }
-            }
-
-            if ( mbContainsInputFieldStart )
-            {
-                // adjust portion length accordingly
-                SetLen( GetLen() + 1 );
-            }
-            else
-            {
-                rInf.SetLineStart( nFormerLineStart );
-            }
-        }
-    }
-
-    return bRet;
+    return SwTextPortion::Format(rTextFormatInfo);
 }
 
-void SwTxtInputFldPortion::Paint( const SwTxtPaintInfo &rInf ) const
+void SwTextInputFieldPortion::Paint( const SwTextPaintInfo &rInf ) const
 {
     if ( Width() )
     {
         rInf.DrawViewOpt( *this, POR_INPUTFLD );
-        static sal_Char sSpace = ' ';
-        SwTxtSlot aPaintTxt( &rInf, this, true, true,
-                            ContainsOnlyDummyChars() ? &sSpace : 0 );
-        SwTxtPortion::Paint( rInf );
+        SwTextSlot aPaintText( &rInf, this, true, true,
+                             ContainsOnlyDummyChars() ? OUString(" ") : OUString() );
+        SwTextPortion::Paint( rInf );
     }
 }
 
-sal_Bool SwTxtInputFldPortion::GetExpTxt( const SwTxtSizeInfo &rInf, OUString &rTxt ) const
+bool SwTextInputFieldPortion::GetExpText( const SwTextSizeInfo &rInf, OUString &rText ) const
 {
     sal_Int32 nIdx = rInf.GetIdx();
     sal_Int32 nLen = rInf.GetLen();
@@ -790,25 +684,23 @@ sal_Bool SwTxtInputFldPortion::GetExpTxt( const SwTxtSizeInfo &rInf, OUString &r
     {
         --nLen;
     }
-    rTxt = rInf.GetTxt().copy( nIdx, std::min( nLen, rInf.GetTxt().getLength() - nIdx ) );
+    rText = rInf.GetText().copy( nIdx, std::min( nLen, rInf.GetText().getLength() - nIdx ) );
 
-    return sal_True;
+    return true;
 }
 
-
-SwPosSize SwTxtInputFldPortion::GetTxtSize( const SwTxtSizeInfo &rInf ) const
+SwPosSize SwTextInputFieldPortion::GetTextSize( const SwTextSizeInfo &rInf ) const
 {
-    SwTxtSlot aFormatTxt( &rInf, this, true, false, 0 );
+    SwTextSlot aFormatText( &rInf, this, true, false );
     if ( rInf.GetLen() == 0 )
     {
         return SwPosSize( 0, 0 );
     }
 
-    return rInf.GetTxtSize();
+    return rInf.GetTextSize();
 }
 
-
-KSHORT SwTxtInputFldPortion::GetViewWidth( const SwTxtSizeInfo &rInf ) const
+sal_uInt16 SwTextInputFieldPortion::GetViewWidth( const SwTextSizeInfo &rInf ) const
 {
     if( !Width()
         && ContainsOnlyDummyChars()
@@ -816,26 +708,20 @@ KSHORT SwTxtInputFldPortion::GetViewWidth( const SwTxtSizeInfo &rInf ) const
         && !rInf.GetOpt().IsReadonly()
         && SwViewOption::IsFieldShadings() )
     {
-        return rInf.GetTxtSize( " " ).Width();
+        return rInf.GetTextSize( " " ).Width();
     }
 
-    return SwTxtPortion::GetViewWidth( rInf );
+    return SwTextPortion::GetViewWidth( rInf );
 }
 
-bool SwTxtInputFldPortion::ContainsOnlyDummyChars() const
+bool SwTextInputFieldPortion::ContainsOnlyDummyChars() const
 {
     return GetLen() <= 2
            && mbContainsInputFieldStart
            && mbContainsInputFieldEnd;
 }
 
-/*************************************************************************
- *                      class SwHolePortion
- *************************************************************************/
-
-
-
-SwHolePortion::SwHolePortion( const SwTxtPortion &rPor )
+SwHolePortion::SwHolePortion( const SwTextPortion &rPor )
     : nBlankWidth( 0 )
 {
     SetLen( 1 );
@@ -846,13 +732,7 @@ SwHolePortion::SwHolePortion( const SwTxtPortion &rPor )
 
 SwLinePortion *SwHolePortion::Compress() { return this; }
 
-/*************************************************************************
- *               virtual SwHolePortion::Paint()
- *************************************************************************/
-
-
-
-void SwHolePortion::Paint( const SwTxtPaintInfo &rInf ) const
+void SwHolePortion::Paint( const SwTextPaintInfo &rInf ) const
 {
     if( !rInf.GetOut() )
         return;
@@ -863,8 +743,8 @@ void SwHolePortion::Paint( const SwTxtPaintInfo &rInf ) const
 
     // #i68503# the hole must have no decoration for a consistent visual appearance
     const SwFont* pOrigFont = rInf.GetFont();
-    SwFont* pHoleFont = NULL;
-    SwFontSave* pFontSave = NULL;
+    SwFont* pHoleFont = nullptr;
+    SwFontSave* pFontSave = nullptr;
     if( pOrigFont->GetUnderline() != UNDERLINE_NONE
     ||  pOrigFont->GetOverline() != UNDERLINE_NONE
     ||  pOrigFont->GetStrikeout() != STRIKEOUT_NONE )
@@ -876,49 +756,38 @@ void SwHolePortion::Paint( const SwTxtPaintInfo &rInf ) const
         pFontSave = new SwFontSave( rInf, pHoleFont );
     }
 
-    const OUString aTxt( ' ' );
-    rInf.DrawText( aTxt, *this, 0, 1, false );
+    const OUString aText( ' ' );
+    rInf.DrawText( aText, *this, 0, 1 );
 
     delete pFontSave;
     delete pHoleFont;
 }
 
-/*************************************************************************
- *                 virtual SwHolePortion::Format()
- *************************************************************************/
-
-
-
-sal_Bool SwHolePortion::Format( SwTxtFormatInfo &rInf )
+bool SwHolePortion::Format( SwTextFormatInfo &rInf )
 {
     return rInf.IsFull() || rInf.X() >= rInf.Width();
 }
 
-/*************************************************************************
- *              virtual SwHolePortion::HandlePortion()
- *************************************************************************/
-
 void SwHolePortion::HandlePortion( SwPortionHandler& rPH ) const
 {
     rPH.Text( GetLen(), GetWhichPor() );
 }
 
-void SwFieldMarkPortion::Paint( const SwTxtPaintInfo & /*rInf*/) const
+void SwFieldMarkPortion::Paint( const SwTextPaintInfo & /*rInf*/) const
 {
     // These shouldn't be painted!
-    // SwTxtPortion::Paint(rInf);
+    //SwTextPortion::Paint(rInf);
 }
 
-sal_Bool SwFieldMarkPortion::Format( SwTxtFormatInfo & )
+bool SwFieldMarkPortion::Format( SwTextFormatInfo & )
 {
-    sal_Bool ret=0;
     Width(0);
-    return ret;
+    return false;
 }
 
-void SwFieldFormCheckboxPortion::Paint( const SwTxtPaintInfo& rInf ) const
+void SwFieldFormCheckboxPortion::Paint( const SwTextPaintInfo& rInf ) const
 {
-    SwTxtNode* pNd = const_cast<SwTxtNode*>(rInf.GetTxtFrm()->GetTxtNode());
+    SwTextNode* pNd = const_cast<SwTextNode*>(rInf.GetTextFrame()->GetTextNode());
     const SwDoc *doc=pNd->GetDoc();
     SwIndex aIndex( pNd, rInf.GetIdx() );
     SwPosition aPosition(*pNd, aIndex);
@@ -936,10 +805,9 @@ void SwFieldFormCheckboxPortion::Paint( const SwTxtPaintInfo& rInf ) const
     }
 }
 
-sal_Bool SwFieldFormCheckboxPortion::Format( SwTxtFormatInfo & rInf )
+bool SwFieldFormCheckboxPortion::Format( SwTextFormatInfo & rInf )
 {
-    sal_Bool ret = 0;
-    SwTxtNode *pNd = const_cast < SwTxtNode * >( rInf.GetTxtFrm(  )->GetTxtNode(  ) );
+    SwTextNode *pNd = rInf.GetTextFrame(  )->GetTextNode(  );
     const SwDoc *doc = pNd->GetDoc(  );
     SwIndex aIndex( pNd, rInf.GetIdx(  ) );
     SwPosition aPosition( *pNd, aIndex );
@@ -947,12 +815,11 @@ sal_Bool SwFieldFormCheckboxPortion::Format( SwTxtFormatInfo & rInf )
     OSL_ENSURE(pBM && pBM->GetFieldname( ) == ODF_FORMCHECKBOX, "Where is my form field bookmark???");
     if (pBM && pBM->GetFieldname( ) == ODF_FORMCHECKBOX)
     {
-        Width( rInf.GetTxtHeight(  ) );
-        Height( rInf.GetTxtHeight(  ) );
+        Width( rInf.GetTextHeight(  ) );
+        Height( rInf.GetTextHeight(  ) );
         SetAscent( rInf.GetAscent(  ) );
     }
-    return ret;
+    return false;
 }
 
-
 /* vim:set shiftwidth=4 softtabstop=4 expandtab: */
