@@ -22,6 +22,7 @@
 #include <anchoredobject.hxx>
 #include <libxml/xmlwriter.h>
 #include <SwPortionHandler.hxx>
+#include <svx/svdobj.hxx>
 
 class XmlPortionDumper:public SwPortionHandler
 {
@@ -29,7 +30,7 @@ class XmlPortionDumper:public SwPortionHandler
     xmlTextWriterPtr writer;
     sal_Int32 ofs;
 
-    const char* getTypeName( sal_uInt16 nType )
+    static const char* getTypeName( sal_uInt16 nType )
     {
         switch ( nType )
         {
@@ -101,7 +102,7 @@ class XmlPortionDumper:public SwPortionHandler
 
   public:
 
-    XmlPortionDumper( xmlTextWriterPtr some_writer ):writer( some_writer ), ofs( 0 )
+    explicit XmlPortionDumper( xmlTextWriterPtr some_writer ):writer( some_writer ), ofs( 0 )
     {
     }
 
@@ -118,7 +119,7 @@ class XmlPortionDumper:public SwPortionHandler
     virtual void Text( sal_Int32 nLength,
                        sal_uInt16 nType,
                        sal_Int32 nHeight,
-                       sal_Int32 nWidth) SAL_OVERRIDE
+                       sal_Int32 nWidth) override
     {
         ofs += nLength;
         xmlTextWriterStartElement( writer, BAD_CAST( "Text" ) );
@@ -151,7 +152,7 @@ class XmlPortionDumper:public SwPortionHandler
                           sal_uInt16 nType,
                           sal_Int32 nHeight,
                           sal_Int32 nWidth,
-                          const SwFont* pFont ) SAL_OVERRIDE
+                          const SwFont* pFont ) override
     {
         xmlTextWriterStartElement( writer, BAD_CAST( "Special" ) );
         xmlTextWriterWriteFormatAttribute( writer,
@@ -179,7 +180,7 @@ class XmlPortionDumper:public SwPortionHandler
         ofs += nLength;
     }
 
-    virtual void LineBreak( sal_Int32 nWidth ) SAL_OVERRIDE
+    virtual void LineBreak( sal_Int32 nWidth ) override
     {
         xmlTextWriterStartElement( writer, BAD_CAST( "LineBreak" ) );
         if (nWidth > 0)
@@ -193,7 +194,7 @@ class XmlPortionDumper:public SwPortionHandler
       * @param nLength
       *         number of 'model string' characters to be skipped
       */
-    virtual void Skip( sal_Int32 nLength ) SAL_OVERRIDE
+    virtual void Skip( sal_Int32 nLength ) override
     {
         xmlTextWriterStartElement( writer, BAD_CAST( "Skip" ) );
         xmlTextWriterWriteFormatAttribute( writer,
@@ -203,7 +204,7 @@ class XmlPortionDumper:public SwPortionHandler
         ofs += nLength;
     }
 
-    virtual void Finish(  ) SAL_OVERRIDE
+    virtual void Finish(  ) override
     {
         xmlTextWriterStartElement( writer, BAD_CAST( "Finish" ) );
         xmlTextWriterEndElement( writer );
@@ -216,7 +217,7 @@ namespace
     xmlTextWriterPtr lcl_createDefaultWriter()
     {
         xmlTextWriterPtr writer = xmlNewTextWriterFilename( "layout.xml", 0 );
-        xmlTextWriterStartDocument( writer, NULL, NULL, NULL );
+        xmlTextWriterStartDocument( writer, nullptr, nullptr, nullptr );
         return writer;
     }
 
@@ -227,13 +228,13 @@ namespace
     }
 }
 
-void SwFrm::dumpAsXml( xmlTextWriterPtr writer ) const
+void SwFrame::dumpAsXml( xmlTextWriterPtr writer ) const
 {
-    bool bCreateWriter = ( NULL == writer );
+    bool bCreateWriter = ( nullptr == writer );
     if ( bCreateWriter )
         writer = lcl_createDefaultWriter();
 
-    const char *name = NULL;
+    const char *name = nullptr;
 
     switch ( GetType(  ) )
     {
@@ -287,31 +288,18 @@ void SwFrm::dumpAsXml( xmlTextWriterPtr writer ) const
         break;
     };
 
-    if ( name != NULL )
+    if ( name != nullptr )
     {
-        xmlTextWriterStartElement( writer, ( const xmlChar * ) name );
+        xmlTextWriterStartElement( writer, reinterpret_cast<const xmlChar *>(name) );
 
         dumpAsXmlAttributes( writer );
 
-        if (IsRootFrm())
+        if (IsRootFrame())
         {
-            // Root frame has access to the edit shell, so dump the current selection ranges here.
-            const SwRootFrm* const pRootFrm = static_cast<const SwRootFrm* const>(this);
-            SwEditShell* pEditShell = pRootFrm->GetCurrShell()->GetDoc()->GetEditShell();
-            xmlTextWriterStartElement(writer, BAD_CAST("shellCrsr"));
-            SwPaM* pPaM = pEditShell->getShellCrsr(false);
-            do
-            {
-                xmlTextWriterStartElement(writer, BAD_CAST("swpam"));
-                xmlTextWriterWriteFormatAttribute(writer, BAD_CAST("pointNodeIndex"), "%ld", pPaM->GetPoint()->nNode.GetIndex());
-                xmlTextWriterWriteFormatAttribute(writer, BAD_CAST("pointContentIndex"), "%" SAL_PRIdINT32, pPaM->GetPoint()->nContent.GetIndex());
-
-                xmlTextWriterWriteFormatAttribute(writer, BAD_CAST("markNodeIndex"), "%ld", pPaM->GetMark()->nNode.GetIndex());
-                xmlTextWriterWriteFormatAttribute(writer, BAD_CAST("markContentIndex"), "%" SAL_PRIdINT32, pPaM->GetMark()->nContent.GetIndex());
-                xmlTextWriterEndElement(writer);
-                pPaM = static_cast<SwPaM*>(pPaM->GetNext());
-            }
-            while (pPaM && pPaM != pEditShell->getShellCrsr(false));
+            const SwRootFrame* pRootFrame = static_cast<const SwRootFrame*>(this);
+            xmlTextWriterStartElement(writer, BAD_CAST("shells"));
+            for (SwViewShell& rViewShell : pRootFrame->GetCurrShell()->GetRingContainer())
+                rViewShell.dumpAsXml(writer);
             xmlTextWriterEndElement(writer);
         }
 
@@ -335,20 +323,20 @@ void SwFrm::dumpAsXml( xmlTextWriterPtr writer ) const
         }
 
         // Dump the children
-        if ( IsTxtFrm(  ) )
+        if ( IsTextFrame(  ) )
         {
-            SwTxtFrm *pTxtFrm = ( SwTxtFrm * ) this;
-            OUString aTxt = pTxtFrm->GetTxt(  );
+            const SwTextFrame *pTextFrame = static_cast<const SwTextFrame *>(this);
+            OUString aText = pTextFrame->GetText(  );
             for ( int i = 0; i < 32; i++ )
             {
-                aTxt = aTxt.replace( i, '*' );
+                aText = aText.replace( i, '*' );
             }
-            OString aTxt8 =OUStringToOString( aTxt,
+            OString aText8 =OUStringToOString( aText,
                                                           RTL_TEXTENCODING_UTF8 );
             xmlTextWriterWriteString( writer,
-                                      ( const xmlChar * ) aTxt8.getStr(  ) );
+                                      reinterpret_cast<const xmlChar *>(aText8.getStr(  )) );
             XmlPortionDumper pdumper( writer );
-            pTxtFrm->VisitPortions( pdumper );
+            pTextFrame->VisitPortions( pdumper );
 
         }
         else
@@ -362,14 +350,22 @@ void SwFrm::dumpAsXml( xmlTextWriterPtr writer ) const
         lcl_freeWriter( writer );
 }
 
-void SwFrm::dumpInfosAsXml( xmlTextWriterPtr writer ) const
+void SwFrame::dumpInfosAsXml( xmlTextWriterPtr writer ) const
 {
-    // output the Frm
+    // output the Frame
     xmlTextWriterStartElement( writer, BAD_CAST( "bounds" ) );
-    xmlTextWriterWriteFormatAttribute( writer, BAD_CAST( "left" ), "%ld", Frm().Left() );
-    xmlTextWriterWriteFormatAttribute( writer, BAD_CAST( "top" ), "%ld", Frm().Top() );
-    xmlTextWriterWriteFormatAttribute( writer, BAD_CAST( "width" ), "%ld", Frm().Width() );
-    xmlTextWriterWriteFormatAttribute( writer, BAD_CAST( "height" ), "%ld", Frm().Height() );
+    xmlTextWriterWriteFormatAttribute( writer, BAD_CAST( "left" ), "%ld", Frame().Left() );
+    xmlTextWriterWriteFormatAttribute( writer, BAD_CAST( "top" ), "%ld", Frame().Top() );
+    xmlTextWriterWriteFormatAttribute( writer, BAD_CAST( "width" ), "%ld", Frame().Width() );
+    xmlTextWriterWriteFormatAttribute( writer, BAD_CAST( "height" ), "%ld", Frame().Height() );
+    xmlTextWriterEndElement( writer );
+
+    // output the Prt
+    xmlTextWriterStartElement( writer, BAD_CAST( "prtBounds" ) );
+    xmlTextWriterWriteFormatAttribute( writer, BAD_CAST( "left" ), "%ld", Prt().Left() );
+    xmlTextWriterWriteFormatAttribute( writer, BAD_CAST( "top" ), "%ld", Prt().Top() );
+    xmlTextWriterWriteFormatAttribute( writer, BAD_CAST( "width" ), "%ld", Prt().Width() );
+    xmlTextWriterWriteFormatAttribute( writer, BAD_CAST( "height" ), "%ld", Prt().Height() );
     xmlTextWriterEndElement( writer );
 }
 
@@ -377,46 +373,46 @@ void SwFrm::dumpInfosAsXml( xmlTextWriterPtr writer ) const
 // bomb on two string litterals in the format.
 static const char* TMP_FORMAT = "%" SAL_PRIuUINTPTR;
 
-void SwFrm::dumpAsXmlAttributes( xmlTextWriterPtr writer ) const
+void SwFrame::dumpAsXmlAttributes( xmlTextWriterPtr writer ) const
 {
     xmlTextWriterWriteFormatAttribute( writer, BAD_CAST( "ptr" ), "%p", this );
-    xmlTextWriterWriteFormatAttribute( writer, BAD_CAST( "id" ), "%" SAL_PRIuUINT32, GetFrmId() );
+    xmlTextWriterWriteFormatAttribute( writer, BAD_CAST( "id" ), "%" SAL_PRIuUINT32, GetFrameId() );
     xmlTextWriterWriteFormatAttribute( writer, BAD_CAST( "symbol" ), "%s", BAD_CAST( typeid( *this ).name( ) ) );
     if ( GetNext( ) )
-        xmlTextWriterWriteFormatAttribute( writer, BAD_CAST( "next" ), "%" SAL_PRIuUINT32, GetNext()->GetFrmId() );
+        xmlTextWriterWriteFormatAttribute( writer, BAD_CAST( "next" ), "%" SAL_PRIuUINT32, GetNext()->GetFrameId() );
     if ( GetPrev( ) )
-        xmlTextWriterWriteFormatAttribute( writer, BAD_CAST( "prev" ), "%" SAL_PRIuUINT32, GetPrev()->GetFrmId() );
+        xmlTextWriterWriteFormatAttribute( writer, BAD_CAST( "prev" ), "%" SAL_PRIuUINT32, GetPrev()->GetFrameId() );
     if ( GetUpper( ) )
-        xmlTextWriterWriteFormatAttribute( writer, BAD_CAST( "upper" ), "%" SAL_PRIuUINT32, GetUpper()->GetFrmId() );
+        xmlTextWriterWriteFormatAttribute( writer, BAD_CAST( "upper" ), "%" SAL_PRIuUINT32, GetUpper()->GetFrameId() );
     if ( GetLower( ) )
-        xmlTextWriterWriteFormatAttribute( writer, BAD_CAST( "lower" ), "%" SAL_PRIuUINT32, GetLower()->GetFrmId() );
-    if ( IsTxtFrm(  ) )
+        xmlTextWriterWriteFormatAttribute( writer, BAD_CAST( "lower" ), "%" SAL_PRIuUINT32, GetLower()->GetFrameId() );
+    if ( IsTextFrame(  ) )
     {
-        SwTxtFrm *pTxtFrm = ( SwTxtFrm * ) this;
-        SwTxtNode *pTxtNode = pTxtFrm->GetTxtNode();
-        xmlTextWriterWriteFormatAttribute( writer, BAD_CAST( "txtNodeIndex" ), TMP_FORMAT, pTxtNode->GetIndex() );
+        const SwTextFrame *pTextFrame = static_cast<const SwTextFrame *>(this);
+        const SwTextNode *pTextNode = pTextFrame->GetTextNode();
+        xmlTextWriterWriteFormatAttribute( writer, BAD_CAST( "txtNodeIndex" ), TMP_FORMAT, pTextNode->GetIndex() );
     }
-    if (IsHeaderFrm() || IsFooterFrm())
+    if (IsHeaderFrame() || IsFooterFrame())
     {
-        SwHeadFootFrm *pHeadFootFrm = (SwHeadFootFrm*)this;
-        OUString aFmtName = pHeadFootFrm->GetFmt()->GetName();
-        xmlTextWriterWriteFormatAttribute( writer, BAD_CAST( "fmtName" ), "%s", BAD_CAST(OUStringToOString(aFmtName, RTL_TEXTENCODING_UTF8).getStr()));
-        xmlTextWriterWriteFormatAttribute( writer, BAD_CAST( "fmtPtr" ), "%p", pHeadFootFrm->GetFmt());
+        const SwHeadFootFrame *pHeadFootFrame = static_cast<const SwHeadFootFrame*>(this);
+        OUString aFormatName = pHeadFootFrame->GetFormat()->GetName();
+        xmlTextWriterWriteFormatAttribute( writer, BAD_CAST( "fmtName" ), "%s", BAD_CAST(OUStringToOString(aFormatName, RTL_TEXTENCODING_UTF8).getStr()));
+        xmlTextWriterWriteFormatAttribute( writer, BAD_CAST( "fmtPtr" ), "%p", pHeadFootFrame->GetFormat());
     }
 }
 
-void SwFrm::dumpChildrenAsXml( xmlTextWriterPtr writer ) const
+void SwFrame::dumpChildrenAsXml( xmlTextWriterPtr writer ) const
 {
-    const SwFrm *pFrm = GetLower(  );
-    for ( ; pFrm != NULL; pFrm = pFrm->GetNext(  ) )
+    const SwFrame *pFrame = GetLower(  );
+    for ( ; pFrame != nullptr; pFrame = pFrame->GetNext(  ) )
     {
-        pFrm->dumpAsXml( writer );
+        pFrame->dumpAsXml( writer );
     }
 }
 
 void SwAnchoredObject::dumpAsXml( xmlTextWriterPtr writer ) const
 {
-    bool bCreateWriter = ( NULL == writer );
+    bool bCreateWriter = ( nullptr == writer );
     if ( bCreateWriter )
         writer = lcl_createDefaultWriter();
 
@@ -430,6 +426,9 @@ void SwAnchoredObject::dumpAsXml( xmlTextWriterPtr writer ) const
     xmlTextWriterWriteFormatAttribute( writer, BAD_CAST( "height" ), "%ld", GetObjBoundRect().Height() );
     xmlTextWriterEndElement( writer );
 
+    if (const SdrObject* pObject = GetDrawObj())
+        pObject->dumpAsXml(writer);
+
     xmlTextWriterEndElement( writer );
 
     if ( bCreateWriter )
@@ -444,34 +443,34 @@ void SwFont::dumpAsXml(xmlTextWriterPtr writer) const
     xmlTextWriterEndElement(writer);
 }
 
-void SwTxtFrm::dumpAsXmlAttributes( xmlTextWriterPtr writer ) const
+void SwTextFrame::dumpAsXmlAttributes( xmlTextWriterPtr writer ) const
 {
-    SwFrm::dumpAsXmlAttributes( writer );
+    SwFrame::dumpAsXmlAttributes( writer );
     if ( HasFollow() )
-        xmlTextWriterWriteFormatAttribute( writer, BAD_CAST( "follow" ), "%" SAL_PRIuUINT32, GetFollow()->GetFrmId() );
+        xmlTextWriterWriteFormatAttribute( writer, BAD_CAST( "follow" ), "%" SAL_PRIuUINT32, GetFollow()->GetFrameId() );
 
-    if (m_pPrecede != NULL)
-        xmlTextWriterWriteFormatAttribute( writer, BAD_CAST( "precede" ), "%" SAL_PRIuUINT32, static_cast<SwTxtFrm*>(m_pPrecede)->GetFrmId() );
+    if (m_pPrecede != nullptr)
+        xmlTextWriterWriteFormatAttribute( writer, BAD_CAST( "precede" ), "%" SAL_PRIuUINT32, static_cast<SwTextFrame*>(m_pPrecede)->GetFrameId() );
 }
 
-void SwSectionFrm::dumpAsXmlAttributes( xmlTextWriterPtr writer ) const
+void SwSectionFrame::dumpAsXmlAttributes( xmlTextWriterPtr writer ) const
 {
-    SwFrm::dumpAsXmlAttributes( writer );
+    SwFrame::dumpAsXmlAttributes( writer );
     if ( HasFollow() )
-        xmlTextWriterWriteFormatAttribute( writer, BAD_CAST( "follow" ), "%" SAL_PRIuUINT32, GetFollow()->GetFrmId() );
+        xmlTextWriterWriteFormatAttribute( writer, BAD_CAST( "follow" ), "%" SAL_PRIuUINT32, GetFollow()->GetFrameId() );
 
-    if (m_pPrecede != NULL)
-        xmlTextWriterWriteFormatAttribute( writer, BAD_CAST( "precede" ), "%" SAL_PRIuUINT32, static_cast<SwSectionFrm*>( m_pPrecede )->GetFrmId() );
+    if (m_pPrecede != nullptr)
+        xmlTextWriterWriteFormatAttribute( writer, BAD_CAST( "precede" ), "%" SAL_PRIuUINT32, static_cast<SwSectionFrame*>( m_pPrecede )->GetFrameId() );
 }
 
-void SwTabFrm::dumpAsXmlAttributes( xmlTextWriterPtr writer ) const
+void SwTabFrame::dumpAsXmlAttributes( xmlTextWriterPtr writer ) const
 {
-    SwFrm::dumpAsXmlAttributes( writer );
+    SwFrame::dumpAsXmlAttributes( writer );
     if ( HasFollow() )
-        xmlTextWriterWriteFormatAttribute( writer, BAD_CAST( "follow" ), "%" SAL_PRIuUINT32, GetFollow()->GetFrmId() );
+        xmlTextWriterWriteFormatAttribute( writer, BAD_CAST( "follow" ), "%" SAL_PRIuUINT32, GetFollow()->GetFrameId() );
 
-    if (m_pPrecede != NULL)
-        xmlTextWriterWriteFormatAttribute( writer, BAD_CAST( "precede" ), "%" SAL_PRIuUINT32, static_cast<SwTabFrm*>( m_pPrecede )->GetFrmId() );
+    if (m_pPrecede != nullptr)
+        xmlTextWriterWriteFormatAttribute( writer, BAD_CAST( "precede" ), "%" SAL_PRIuUINT32, static_cast<SwTabFrame*>( m_pPrecede )->GetFrameId() );
 }
 
 /* vim:set shiftwidth=4 softtabstop=4 expandtab: */
