@@ -28,9 +28,8 @@
 
 using namespace ::com::sun::star;
 
-
 SwScriptIterator::SwScriptIterator(
-            const OUString& rStr, xub_StrLen nStt, bool const bFrwrd)
+            const OUString& rStr, sal_Int32 nStt, bool const bFrwrd)
     : m_rText(rStr)
     , m_nChgPos(rStr.getLength())
     , nCurScript(i18n::ScriptType::WEAK)
@@ -41,15 +40,15 @@ SwScriptIterator::SwScriptIterator(
         if ( ! bFrwrd && nStt )
             --nStt;
 
-        xub_StrLen nPos = nStt;
+        sal_Int32 nPos = nStt;
         nCurScript = g_pBreakIt->GetBreakIter()->getScriptType(m_rText, nPos);
         if( i18n::ScriptType::WEAK == nCurScript )
         {
             if( nPos )
             {
-                nPos = (xub_StrLen)g_pBreakIt->GetBreakIter()->beginOfScript(
+                nPos = g_pBreakIt->GetBreakIter()->beginOfScript(
                                                 m_rText, nPos, nCurScript);
-                if (nPos && nPos < m_rText.getLength())
+                if (nPos > 0 && nPos < m_rText.getLength())
                 {
                     nStt = --nPos;
                     nCurScript =
@@ -71,7 +70,7 @@ bool SwScriptIterator::Next()
     bool bRet = false;
     if( g_pBreakIt->GetBreakIter().is() )
     {
-        if (bForward && (m_nChgPos != -1) && (m_nChgPos < m_rText.getLength()))
+        if (bForward && m_nChgPos >= 0 && m_nChgPos < m_rText.getLength())
         {
             nCurScript =
                 g_pBreakIt->GetBreakIter()->getScriptType(m_rText, m_nChgPos);
@@ -94,19 +93,17 @@ bool SwScriptIterator::Next()
     return bRet;
 }
 
-// --------------------------------------------------------------------
-
-SwTxtAttrIterator::SwTxtAttrIterator( const SwTxtNode& rTNd, sal_uInt16 nWhchId,
-                                        xub_StrLen nStt,
+SwTextAttrIterator::SwTextAttrIterator( const SwTextNode& rTNd, sal_uInt16 nWhchId,
+                                        sal_Int32 nStt,
                                         bool bUseGetWhichOfScript )
-    : aSIter( rTNd.GetTxt(), nStt ), rTxtNd( rTNd ),
-    pParaItem( 0 ), nChgPos( nStt ), nAttrPos( 0 ), nWhichId( nWhchId ),
+    : aSIter( rTNd.GetText(), nStt ), rTextNd( rTNd ),
+    pParaItem( nullptr ), nAttrPos( 0 ), nChgPos( nStt ), nWhichId( nWhchId ),
     bIsUseGetWhichOfScript( bUseGetWhichOfScript )
 {
     SearchNextChg();
 }
 
-bool SwTxtAttrIterator::Next()
+bool SwTextAttrIterator::Next()
 {
     bool bRet = false;
     if (nChgPos < aSIter.GetText().getLength())
@@ -115,8 +112,8 @@ bool SwTxtAttrIterator::Next()
         if( !aStack.empty() )
         {
             do {
-                const SwTxtAttr* pHt = aStack.front();
-                sal_uInt16 nEndPos = *pHt->End();
+                const SwTextAttr* pHt = aStack.front();
+                const sal_Int32 nEndPos = *pHt->End();
                 if( nChgPos >= nEndPos )
                     aStack.pop_front();
                 else
@@ -126,12 +123,12 @@ bool SwTxtAttrIterator::Next()
 
         if( !aStack.empty() )
         {
-            sal_uInt16 nSavePos = nAttrPos;
+            const size_t nSavePos = nAttrPos;
             SearchNextChg();
             if( !aStack.empty() )
             {
-                const SwTxtAttr* pHt = aStack.front();
-                const sal_uInt16 nEndPos = *pHt->End();
+                const SwTextAttr* pHt = aStack.front();
+                const sal_Int32 nEndPos = *pHt->End();
                 if( nChgPos >= nEndPos )
                 {
                     nChgPos = nEndPos;
@@ -139,10 +136,10 @@ bool SwTxtAttrIterator::Next()
 
                     if( RES_TXTATR_CHARFMT == pHt->Which() )
                     {
-                        sal_uInt16 nWId = bIsUseGetWhichOfScript ?
-                                GetWhichOfScript( nWhichId,
-                                                  aSIter.GetCurrScript() ) : nWhichId;
-                        pCurItem = &pHt->GetCharFmt().GetCharFmt()->GetFmtAttr(nWId);
+                        const sal_uInt16 nWId = bIsUseGetWhichOfScript
+                            ? GetWhichOfScript( nWhichId, aSIter.GetCurrScript() )
+                            : nWhichId;
+                        pCurItem = &pHt->GetCharFormat().GetCharFormat()->GetFormatAttr(nWId);
                     }
                     else
                         pCurItem = &pHt->GetAttr();
@@ -157,9 +154,10 @@ bool SwTxtAttrIterator::Next()
     return bRet;
 }
 
-void SwTxtAttrIterator::AddToStack( const SwTxtAttr& rAttr )
+void SwTextAttrIterator::AddToStack( const SwTextAttr& rAttr )
 {
-    sal_uInt16 nIns = 0, nEndPos = *rAttr.End();
+    size_t nIns = 0;
+    const sal_Int32 nEndPos = *rAttr.End();
     for( ; nIns < aStack.size(); ++nIns )
         if( *aStack[ nIns ]->End() > nEndPos )
             break;
@@ -167,13 +165,13 @@ void SwTxtAttrIterator::AddToStack( const SwTxtAttr& rAttr )
     aStack.insert( aStack.begin() + nIns, &rAttr );
 }
 
-void SwTxtAttrIterator::SearchNextChg()
+void SwTextAttrIterator::SearchNextChg()
 {
     sal_uInt16 nWh = 0;
     if( nChgPos == aSIter.GetScriptChgPos() )
     {
         aSIter.Next();
-        pParaItem = 0;
+        pParaItem = nullptr;
         nAttrPos = 0;       // must be restart at the beginning, because
                             // some attributes can start before or inside
                             // the current scripttype!
@@ -184,14 +182,14 @@ void SwTxtAttrIterator::SearchNextChg()
         nWh = bIsUseGetWhichOfScript ?
                 GetWhichOfScript( nWhichId,
                                   aSIter.GetCurrScript() ) : nWhichId;
-        pParaItem = &rTxtNd.GetSwAttrSet().Get( nWh );
+        pParaItem = &rTextNd.GetSwAttrSet().Get( nWh );
     }
 
-    xub_StrLen nStt = nChgPos;
+    sal_Int32 nStt = nChgPos;
     nChgPos = aSIter.GetScriptChgPos();
     pCurItem = pParaItem;
 
-    const SwpHints* pHts = rTxtNd.GetpSwpHints();
+    const SwpHints* pHts = rTextNd.GetpSwpHints();
     if( pHts )
     {
         if( !nWh )
@@ -201,19 +199,19 @@ void SwTxtAttrIterator::SearchNextChg()
                                           aSIter.GetCurrScript() ) : nWhichId;
         }
 
-        const SfxPoolItem* pItem = 0;
+        const SfxPoolItem* pItem = nullptr;
         for( ; nAttrPos < pHts->Count(); ++nAttrPos )
         {
-            const SwTxtAttr* pHt = (*pHts)[ nAttrPos ];
+            const SwTextAttr* pHt = pHts->Get( nAttrPos );
             const sal_Int32* pEnd = pHt->End();
-            const sal_Int32 nHtStt = *pHt->GetStart();
+            const sal_Int32 nHtStt = pHt->GetStart();
             if( nHtStt < nStt && ( !pEnd || *pEnd <= nStt ))
                 continue;
 
             if( nHtStt >= nChgPos )
                 break;
 
-            pItem = CharFmt::GetItem( *pHt, nWh );
+            pItem = CharFormat::GetItem( *pHt, nWh );
             if ( pItem )
             {
                 if( nHtStt > nStt )
@@ -231,5 +229,4 @@ void SwTxtAttrIterator::SearchNextChg()
     }
 }
 
-
 /* vim:set shiftwidth=4 softtabstop=4 expandtab: */
