@@ -56,7 +56,7 @@
 #include <comcore.hrc>
 #include <undo.hrc>
 #include <bookmrk.hxx>
-#include <boost/scoped_ptr.hpp>
+#include <memory>
 
 OUString SwHistoryHint::GetDescription() const
 {
@@ -71,10 +71,10 @@ SwHistorySetFormat::SwHistorySetFormat( const SfxPoolItem* pFormatHt, sal_uLong
     switch ( m_pAttr->Which() )
     {
         case RES_PAGEDESC:
-            static_cast<SwFormatPageDesc&>(*m_pAttr).ChgDefinedIn( 0 );
+            static_cast<SwFormatPageDesc&>(*m_pAttr).ChgDefinedIn( nullptr );
             break;
         case RES_PARATR_DROP:
-            static_cast<SwFormatDrop&>(*m_pAttr).ChgDefinedIn( 0 );
+            static_cast<SwFormatDrop&>(*m_pAttr).ChgDefinedIn( nullptr );
             break;
         case RES_BOXATR_FORMULA:
         {
@@ -91,13 +91,13 @@ SwHistorySetFormat::SwHistorySetFormat( const SfxPoolItem* pFormatHt, sal_uLong
                     if (pTableNode)
                     {
                         SwTableFormulaUpdate aMsgHint( &pTableNode->GetTable() );
-                        aMsgHint.eFlags = TBL_BOXNAME;
+                        aMsgHint.m_eFlags = TBL_BOXNAME;
                         rNew.ChgDefinedIn( rOld.GetDefinedIn() );
                         rNew.ChangeState( &aMsgHint );
                     }
                 }
             }
-            rNew.ChgDefinedIn( 0 );
+            rNew.ChgDefinedIn( nullptr );
         }
         break;
     }
@@ -359,13 +359,13 @@ void SwHistorySetTOXMark::SetInDoc( SwDoc* pDoc, bool )
 
     // search for respective TOX type
     const sal_uInt16 nCnt = pDoc->GetTOXTypeCount( m_eTOXTypes );
-    SwTOXType* pToxType = 0;
+    SwTOXType* pToxType = nullptr;
     for ( sal_uInt16 n = 0; n < nCnt; ++n )
     {
         pToxType = const_cast<SwTOXType*>(pDoc->GetTOXType( m_eTOXTypes, n ));
         if ( pToxType->GetTypeName() == m_TOXName )
             break;
-        pToxType = 0;
+        pToxType = nullptr;
     }
 
     if ( !pToxType )  // TOX type not found, create new
@@ -428,9 +428,9 @@ SwHistorySetFootnote::SwHistorySetFootnote( SwTextFootnote* pTextFootnote, sal_u
     SwNode* pSaveNd = pDoc->GetNodes()[ m_nNodeIndex ];
 
     // keep pointer to StartNode of FootnoteSection and reset its attribute for now
-    // (as a result, its/all Frms will be deleted automatically)
+    // (as a result, its/all Frames will be deleted automatically)
     SwNodeIndex aSttIdx( *pTextFootnote->GetStartNode() );
-    pTextFootnote->SetStartNode( 0, false );
+    pTextFootnote->SetStartNode( nullptr, false );
 
     m_pUndo->SaveSection( aSttIdx );
     m_nNodeIndex = pSaveNd->GetIndex();
@@ -596,8 +596,8 @@ void SwHistoryBookmark::SetInDoc( SwDoc* pDoc, bool )
 
     SwNodes& rNds = pDoc->GetNodes();
     IDocumentMarkAccess* pMarkAccess = pDoc->getIDocumentMarkAccess();
-    boost::scoped_ptr<SwPaM> pPam;
-    ::sw::mark::IMark* pMark = NULL;
+    std::unique_ptr<SwPaM> pPam;
+    ::sw::mark::IMark* pMark = nullptr;
 
     if(m_bSavePos)
     {
@@ -623,7 +623,7 @@ void SwHistoryBookmark::SetInDoc( SwDoc* pDoc, bool )
             "<SwHistoryBookmark::SetInDoc(..)>"
             " - wrong node for a mark");
 
-        if(pPam.get() != NULL && pContentNd)
+        if(pPam.get() != nullptr && pContentNd)
         {
             pPam->SetMark();
             pPam->GetMark()->nNode = m_nOtherNode;
@@ -643,13 +643,13 @@ void SwHistoryBookmark::SetInDoc( SwDoc* pDoc, bool )
 
     if(pPam.get())
     {
-        if ( pMark != NULL )
+        if ( pMark != nullptr )
         {
             pMarkAccess->deleteMark( pMark );
         }
         ::sw::mark::IBookmark* const pBookmark =
             dynamic_cast< ::sw::mark::IBookmark* >( pMarkAccess->makeMark(*pPam, m_aName, m_eBkmkType) );
-        if ( pBookmark != NULL )
+        if ( pBookmark != nullptr )
         {
             pBookmark->SetKeyCode(m_aKeycode);
             pBookmark->SetShortName(m_aShortName);
@@ -697,12 +697,12 @@ SwHistorySetAttrSet::SwHistorySetAttrSet( const SfxItemSet& rSet,
             {
                 case RES_PAGEDESC:
                     static_cast<SwFormatPageDesc*>(
-                        const_cast<SfxPoolItem*>(pItem))->ChgDefinedIn( 0 );
+                        const_cast<SfxPoolItem*>(pItem))->ChgDefinedIn( nullptr );
                     break;
 
                 case RES_PARATR_DROP:
                     static_cast<SwFormatDrop*>(
-                        const_cast<SfxPoolItem*>(pItem))->ChgDefinedIn( 0 );
+                        const_cast<SfxPoolItem*>(pItem))->ChgDefinedIn( nullptr );
                     break;
 
                 case RES_BOXATR_FORMULA:
@@ -729,13 +729,13 @@ SwHistorySetAttrSet::SwHistorySetAttrSet( const SfxItemSet& rSet,
                                 {
                                     SwTableFormulaUpdate aMsgHint(
                                         &pTableNode->GetTable() );
-                                    aMsgHint.eFlags = TBL_BOXNAME;
+                                    aMsgHint.m_eFlags = TBL_BOXNAME;
                                     rNew.ChgDefinedIn( rOld.GetDefinedIn() );
                                     rNew.ChangeState( &aMsgHint );
                                 }
                             }
                         }
-                        rNew.ChgDefinedIn( 0 );
+                        rNew.ChgDefinedIn( nullptr );
                     }
                     break;
             }
@@ -889,9 +889,9 @@ void SwHistoryChangeFlyAnchor::SetInDoc( SwDoc* pDoc, bool )
         aTmp.SetAnchor( &aPos );
 
         // so the Layout does not get confused
-        if ( !pCNd || !pCNd->getLayoutFrm( pDoc->getIDocumentLayoutAccess().GetCurrentLayout(), 0, 0, false ) )
+        if ( !pCNd || !pCNd->getLayoutFrame( pDoc->getIDocumentLayoutAccess().GetCurrentLayout(), nullptr, nullptr, false ) )
         {
-            m_rFormat.DelFrms();
+            m_rFormat.DelFrames();
         }
 
         m_rFormat.SetFormatAttr( aTmp );
@@ -966,7 +966,7 @@ SwHistory::SwHistory( sal_uInt16 nInitSz )
 
 SwHistory::~SwHistory()
 {
-    Delete( 0 );
+    Delete();
     std::vector<SwHistoryHint*>::const_iterator it;
     for(it = m_SwpHstry.begin(); it != m_SwpHstry.end(); ++it)
         delete *it;
@@ -987,11 +987,11 @@ void SwHistory::Add(
     }
 
     // no default Attribute?
-    SwHistoryHint* pHt = 0;
+    SwHistoryHint* pHt = nullptr;
 
     //UUUU To be able to include the DrawingLayer FillItems something more
     // general has to be done to check if an Item is default than to check
-    // if it's pointzer equals that in Writer's global PoolDefaults (held in
+    // if its pointer equals that in Writer's global PoolDefaults (held in
     // aAttrTab and used to fill the pool defaults in Writer - looks as if
     // Writer is *older* than the SfxItemPool ?). I checked the possibility to
     // get the SfxItemPool here (works), but decided to use the SfxPoolItem's
@@ -1013,7 +1013,7 @@ void SwHistory::Add( SwTextAttr* pHint, sal_uLong nNodeIdx, bool bNewAttr )
 {
     OSL_ENSURE( !m_nEndDiff, "History was not deleted after REDO" );
 
-    SwHistoryHint * pHt = 0;
+    SwHistoryHint * pHt = nullptr;
     if( !bNewAttr )
     {
         switch ( pHint->Which() )
@@ -1097,13 +1097,13 @@ void SwHistory::Add( SwFlyFrameFormat& rFormat, sal_uInt16& rSetPos )
                 if ( pChainItem->GetNext() )
                 {
                     SwFormatChain aTmp( pChainItem->GetNext()->GetChain() );
-                    aTmp.SetPrev( 0 );
+                    aTmp.SetPrev( nullptr );
                     pChainItem->GetNext()->SetFormatAttr( aTmp );
                 }
                 if ( pChainItem->GetPrev() )
                 {
                     SwFormatChain aTmp( pChainItem->GetPrev()->GetChain() );
-                    aTmp.SetNext( 0 );
+                    aTmp.SetNext( nullptr );
                     pChainItem->GetPrev()->SetFormatAttr( aTmp );
                 }
             }
@@ -1244,10 +1244,10 @@ void SwHistory::CopyAttr(
     for( size_t n = 0; n < pHts->Count(); ++n )
     {
         // nAttrStt must even be set when !pEndIdx
-        pHt = pHts->GetTextHint(n);
+        pHt = pHts->Get(n);
         const sal_Int32 nAttrStt = pHt->GetStart();
         const sal_Int32 * pEndIdx = pHt->GetEnd();
-        if( 0 !=  pEndIdx && nAttrStt > nEnd )
+        if( nullptr !=  pEndIdx && nAttrStt > nEnd )
             break;
 
         // never copy Flys and Footnote !!
@@ -1286,7 +1286,7 @@ void SwHistory::CopyAttr(
 
 // Class to register the history at a Node, Format, HintsArray, ...
 SwRegHistory::SwRegHistory( SwHistory* pHst )
-    : SwClient( 0 )
+    : SwClient( nullptr )
     , m_pHistory( pHst )
     , m_nNodeIndex( ULONG_MAX )
 {
@@ -1303,7 +1303,7 @@ SwRegHistory::SwRegHistory( SwModify* pRegIn, const SwNode& rNd,
 }
 
 SwRegHistory::SwRegHistory( const SwNode& rNd, SwHistory* pHst )
-    : SwClient( 0 )
+    : SwClient( nullptr )
     , m_pHistory( pHst )
     , m_nNodeIndex( rNd.GetIndex() )
 {
@@ -1333,17 +1333,15 @@ void SwRegHistory::Modify( const SfxPoolItem* pOld, const SfxPoolItem* pNew )
         }
         else if (pOld && RES_ATTRSET_CHG == pNew->Which())
         {
-            SwHistoryHint* pNewHstr;
+            SwHistoryHint* pNewHstr(nullptr);
             const SfxItemSet& rSet = *static_cast< const SwAttrSetChg* >(pOld)->GetChgSet();
 
             if ( 1 < rSet.Count() )
             {
                 pNewHstr = new SwHistorySetAttrSet( rSet, m_nNodeIndex, m_WhichIdSet );
             }
-            else
+            else if (const SfxPoolItem* pItem = SfxItemIter( rSet ).FirstItem())
             {
-                const SfxPoolItem* pItem = SfxItemIter( rSet ).FirstItem();
-
                 if ( m_WhichIdSet.count( pItem->Which() ) )
                 {
                     pNewHstr = new SwHistorySetFormat( pItem, m_nNodeIndex );
@@ -1354,7 +1352,8 @@ void SwRegHistory::Modify( const SfxPoolItem* pOld, const SfxPoolItem* pNew )
                 }
             }
 
-            m_pHistory->m_SwpHstry.push_back( pNewHstr );
+            if (pNewHstr)
+                m_pHistory->m_SwpHstry.push_back( pNewHstr );
         }
     }
 }
@@ -1371,15 +1370,15 @@ bool SwRegHistory::InsertItems( const SfxItemSet& rSet,
         return false;
 
     SwTextNode * const pTextNode =
-        dynamic_cast<SwTextNode *>(const_cast<SwModify *>(GetRegisteredIn()));
+        dynamic_cast<SwTextNode *>(GetRegisteredIn());
 
     OSL_ENSURE(pTextNode, "SwRegHistory not registered at text node?");
     if (!pTextNode)
         return false;
 
-    if ( pTextNode->GetpSwpHints() && m_pHistory )
+    if (m_pHistory)
     {
-        pTextNode->GetpSwpHints()->Register( this );
+        pTextNode->GetOrCreateSwpHints().Register(this);
     }
 
     const bool bInserted = pTextNode->SetAttr( rSet, nStart, nEnd, nFlags );
@@ -1394,14 +1393,29 @@ bool SwRegHistory::InsertItems( const SfxItemSet& rSet,
         pTextNode->GetpSwpHints()->DeRegister();
     }
 
+#ifndef NDEBUG
     if ( m_pHistory && bInserted )
     {
-        SwHistoryHint* pNewHstr = new SwHistoryResetAttrSet( rSet,
-                                    pTextNode->GetIndex(), nStart, nEnd );
-        // the NodeIndex might be moved!
-
-        m_pHistory->m_SwpHstry.push_back( pNewHstr );
+        SfxItemIter aIter(rSet);
+        for (SfxPoolItem const* pItem = aIter.FirstItem(); pItem; pItem = aIter.NextItem())
+        {   // check that the history recorded a hint to reset every item
+            sal_uInt16 const nWhich(pItem->Which());
+            RES_TXTATR const nExpected(
+                (isCHRATR(nWhich) || RES_TXTATR_UNKNOWN_CONTAINER == nWhich)
+                    ? RES_TXTATR_AUTOFMT
+                    : static_cast<RES_TXTATR>(nWhich));
+            if (RES_TXTATR_AUTOFMT == nExpected && 0 == nStart && pTextNode->Len() == nEnd)
+                continue; // special case, may get set on text node itself
+            assert(std::find_if(
+                m_pHistory->m_SwpHstry.begin(), m_pHistory->m_SwpHstry.end(),
+                [nExpected](SwHistoryHint *const pHint) -> bool {
+                    SwHistoryResetText const*const pReset(
+                            dynamic_cast<SwHistoryResetText const*>(pHint));
+                    return (pReset) ? pReset->GetWhich() == nExpected : false;
+                }) != m_pHistory->m_SwpHstry.end());
+        }
     }
+#endif
 
     return bInserted;
 }
@@ -1428,27 +1442,28 @@ void SwRegHistory::_MakeSetWhichIds()
 
     if( GetRegisteredIn() )
     {
-        const SfxItemSet* pSet = 0;
-        if( GetRegisteredIn()->ISA( SwContentNode ) )
+        const SfxItemSet* pSet = nullptr;
+        if( dynamic_cast< const SwContentNode *>( GetRegisteredIn() ) != nullptr  )
         {
             pSet = static_cast<SwContentNode*>(
-                    const_cast<SwModify*>(GetRegisteredIn()))->GetpSwAttrSet();
+                    GetRegisteredIn())->GetpSwAttrSet();
         }
-        else if ( GetRegisteredIn()->ISA( SwFormat ) )
+        else if ( dynamic_cast< const SwFormat *>( GetRegisteredIn() ) != nullptr  )
         {
             pSet = &static_cast<SwFormat*>(
-                    const_cast<SwModify*>(GetRegisteredIn()))->GetAttrSet();
+                    GetRegisteredIn())->GetAttrSet();
         }
         if( pSet && pSet->Count() )
         {
             SfxItemIter aIter( *pSet );
-            sal_uInt16 nW = aIter.FirstItem()->Which();
-            while( true )
+            const SfxPoolItem* pItem = aIter.FirstItem();
+            while(pItem)
             {
+                sal_uInt16 nW = pItem->Which();
                 m_WhichIdSet.insert( nW );
                 if( aIter.IsAtEnd() )
                     break;
-                nW = aIter.NextItem()->Which();
+                pItem = aIter.NextItem();
             }
         }
     }
