@@ -17,7 +17,6 @@
  *   the License at http://www.apache.org/licenses/LICENSE-2.0 .
  */
 
-
 #include <com/sun/star/embed/XEmbedPersist.hpp>
 #include <com/sun/star/embed/Aspects.hpp>
 #include <com/sun/star/embed/ElementModes.hpp>
@@ -25,7 +24,7 @@
 #include <vcl/graphicfilter.hxx>
 #include <vcl/wmf.hxx>
 #include <svl/itemiter.hxx>
-#include "svl/urihelper.hxx"
+#include <svl/urihelper.hxx>
 
 #include <svtools/embedhlp.hxx>
 
@@ -51,7 +50,7 @@
 #include <fmtfsize.hxx>
 #include <fmtornt.hxx>
 
-#include <doctok/sprmids.hxx>
+#include <sprmids.hxx>
 
 #include <doc.hxx>
 #include "writerhelper.hxx"
@@ -66,10 +65,7 @@
 
 #include "docsh.hxx"
 #include <cstdio>
-
-#if OSL_DEBUG_LEVEL > 1
-#include <stdio.h>
-#endif
+#include <o3tl/enumrange.hxx>
 
 using namespace ::com::sun::star;
 using namespace nsFieldFlags;
@@ -85,16 +81,16 @@ using namespace nsFieldFlags;
 void WW8Export::OutputGrfNode( const SwGrfNode& /*rNode*/ )
 {
     OSL_TRACE("WW8Export::OutputGrfNode( const SwGrfNode& )" );
-    OSL_ENSURE( mpParentFrame, "frame not set!" );
-    if ( mpParentFrame )
+    OSL_ENSURE( m_pParentFrame, "frame not set!" );
+    if ( m_pParentFrame )
     {
-        OutGrf( *mpParentFrame );
-        pFib->fHasPic = 1;
+        OutGrf( *m_pParentFrame );
+        pFib->fHasPic = true;
     }
 }
 
 bool WW8Export::TestOleNeedsGraphic(const SwAttrSet& rSet,
-    SvStorageRef xOleStg, SvStorageRef xObjStg, OUString &rStorageName,
+    tools::SvRef<SotStorage> xOleStg, tools::SvRef<SotStorage> xObjStg, OUString &rStorageName,
     SwOLENode *pOLENd)
 {
     bool bGraphicNeeded = false;
@@ -105,7 +101,7 @@ bool WW8Export::TestOleNeedsGraphic(const SwAttrSet& rSet,
         switch (pItem->Which())
         {
             /*
-            For an inline object these properties are irrelevent because they
+            For an inline object these properties are irrelevant because they
             will be the same as the defaults that msword applies in their
             absence, so if that is all that there is for these inline objects
             then if there turns out to be enough information in the object
@@ -122,12 +118,12 @@ bool WW8Export::TestOleNeedsGraphic(const SwAttrSet& rSet,
                 bGraphicNeeded = true;
         }
     } while( !bGraphicNeeded && !aIter.IsAtEnd() &&
-        0 != ( pItem = aIter.NextItem() ) );
+        nullptr != ( pItem = aIter.NextItem() ) );
 
     /*
     Now we must see if the object contains a preview itself which is equal to
     the preview that we are currently using. If the graphics are equal then we
-    dont need to store another preview
+    don't need to store another preview
     */
     GDIMetaFile aWMF;
     long nX=0,nY=0;
@@ -145,23 +141,23 @@ bool WW8Export::TestOleNeedsGraphic(const SwAttrSet& rSet,
         if ( pOLENd )
             nAspect = pOLENd->GetAspect();
         SdrOle2Obj *pRet = SvxMSDffManager::CreateSdrOLEFromStorage(
-            rStorageName,xObjStg,pDoc->GetDocStorage(),aGraph,aRect,aVisArea,0,nErr,0,nAspect);
+            rStorageName,xObjStg,m_pDoc->GetDocStorage(),aGraph,aRect,aVisArea,nullptr,nErr,0,nAspect, m_pWriter->GetBaseURL());
 
         if (pRet)
         {
             uno::Reference< embed::XEmbeddedObject > xObj = pOLENd->GetOLEObj().GetOleRef();
             if ( xObj.is() )
             {
-                SvStream* pGraphicStream = NULL;
-                comphelper::EmbeddedObjectContainer aCnt( pDoc->GetDocStorage() );
+                SvStream* pGraphicStream = nullptr;
+                comphelper::EmbeddedObjectContainer aCnt( m_pDoc->GetDocStorage() );
                 try
                 {
                     uno::Reference< embed::XEmbedPersist > xPersist(
                             xObj,
                             uno::UNO_QUERY_THROW );
 
-                    // it makes no sence to search the object in the container by reference since the object was created
-                    // outside of the container and was not inserted there, only the name makes sence
+                    // it makes no sense to search the object in the container by reference since the object was created
+                    // outside of the container and was not inserted there, only the name makes sense
                     pGraphicStream =
                             ::utl::UcbStreamHelper::CreateStream( aCnt.GetGraphicStream( xPersist->getEntryName() ) );
                 }
@@ -173,21 +169,20 @@ bool WW8Export::TestOleNeedsGraphic(const SwAttrSet& rSet,
                 {
                     Graphic aGr1;
                     GraphicFilter& rGF = GraphicFilter::GetGraphicFilter();
-                    if( rGF.ImportGraphic( aGr1, aEmptyOUStr, *pGraphicStream, GRFILTER_FORMAT_DONTKNOW ) == GRFILTER_OK )
+                    if( rGF.ImportGraphic( aGr1, OUString(), *pGraphicStream ) == GRFILTER_OK )
                     {
                         Graphic aGr2;
                         delete pGraphicStream;
                         pGraphicStream =
                                 ::utl::UcbStreamHelper::CreateStream( aCnt.GetGraphicStream( pRet->GetObjRef() ) );
-                        if( rGF.ImportGraphic( aGr2, aEmptyOUStr, *pGraphicStream, GRFILTER_FORMAT_DONTKNOW ) == GRFILTER_OK )
+                        if( pGraphicStream && rGF.ImportGraphic( aGr2, OUString(), *pGraphicStream ) == GRFILTER_OK )
                         {
                             if ( aGr1 == aGr2 )
                                 bGraphicNeeded = false;
                         }
                     }
                 }
-                else
-                    delete pGraphicStream;
+                delete pGraphicStream;
             }
 
             delete pRet;
@@ -209,27 +204,13 @@ void WW8Export::OutputOLENode( const SwOLENode& rOLENode )
             0x0a, 0x08, 1,          // sprmCFOLE2
             0x56, 0x08, 1           // sprmCFObj
         };
-    static sal_uInt8 aSpecOLE_WW6[] = {
-            68, 4, 0, 0, 0, 0,      // sprmCPicLocation (len is 4)
-            75, 1,                  // sprmCFOLE2
-            118, 1                  // sprmCFObj
-        };
 
-    if ( bWrtWW8 )
-    {
-        pSpecOLE = aSpecOLE_WW8;
-        nSize = sizeof( aSpecOLE_WW8 );
-    }
-    else
-    {
-        pSpecOLE = aSpecOLE_WW6;
-        nSize = sizeof( aSpecOLE_WW6 );
-    }
+    pSpecOLE = aSpecOLE_WW8;
+    nSize = sizeof( aSpecOLE_WW8 );
     pDataAdr = pSpecOLE + 2; //WW6 sprm is 1 but has 1 byte len as well.
 
-    SvStorageRef xObjStg = GetWriter().GetStorage().OpenSotStorage(
-        OUString(SL::aObjectPool), STREAM_READWRITE |
-        STREAM_SHARE_DENYALL );
+    tools::SvRef<SotStorage> xObjStg = GetWriter().GetStorage().OpenSotStorage(
+        OUString(SL::aObjectPool) );
 
     if( xObjStg.Is()  )
     {
@@ -250,8 +231,7 @@ void WW8Export::OutputOLENode( const SwOLENode& rOLENode )
             Set_UInt32(pDataAdr, nPictureId);
             OUString sStorageName('_');
             sStorageName += OUString::number( nPictureId );
-            SvStorageRef xOleStg = xObjStg->OpenSotStorage( sStorageName,
-                                STREAM_READWRITE| STREAM_SHARE_DENYALL );
+            tools::SvRef<SotStorage> xOleStg = xObjStg->OpenSotStorage( sStorageName );
             if( xOleStg.Is() )
             {
                 /*
@@ -269,7 +249,7 @@ void WW8Export::OutputOLENode( const SwOLENode& rOLENode )
                         if ( !xOleStg->IsStream( aObjInfo ) )
                         {
                             const sal_uInt8 pObjInfoData[] = { 0x40, 0x00, 0x03, 0x00 };
-                            SvStorageStreamRef rObjInfoStream = xOleStg->OpenSotStream( aObjInfo );
+                            tools::SvRef<SotStorageStream> rObjInfoStream = xOleStg->OpenSotStream( aObjInfo );
                             if ( rObjInfoStream.Is() && !rObjInfoStream->GetError() )
                             {
                                 rObjInfoStream->Write( pObjInfoData, sizeof( pObjInfoData ) );
@@ -283,10 +263,10 @@ void WW8Export::OutputOLENode( const SwOLENode& rOLENode )
                 // in the escher export
                 OUString sServer = FieldString(ww::eEMBED) + xOleStg->GetUserName() + " ";
 
-                OutputField(0, ww::eEMBED, sServer, WRITEFIELD_START |
+                OutputField(nullptr, ww::eEMBED, sServer, WRITEFIELD_START |
                     WRITEFIELD_CMD_START | WRITEFIELD_CMD_END);
 
-                pChpPlc->AppendFkpEntry( Strm().Tell(),
+                m_pChpPlc->AppendFkpEntry( Strm().Tell(),
                         nSize, pSpecOLE );
 
                 bool bEndCR = true;
@@ -301,14 +281,14 @@ void WW8Export::OutputOLENode( const SwOLENode& rOLENode )
                 */
                 bool bGraphicNeeded = false;
 
-                if (mpParentFrame)
+                if (m_pParentFrame)
                 {
                     bGraphicNeeded = true;
 
-                    if (mpParentFrame->IsInline())
+                    if (m_pParentFrame->IsInline())
                     {
                         const SwAttrSet& rSet =
-                            mpParentFrame->GetFrmFmt().GetAttrSet();
+                            m_pParentFrame->GetFrameFormat().GetAttrSet();
                         bEndCR = false;
                         bGraphicNeeded = TestOleNeedsGraphic(rSet,
                             xOleStg, xObjStg, sStorageName, const_cast<SwOLENode*>(&rOLENode));
@@ -326,10 +306,10 @@ void WW8Export::OutputOLENode( const SwOLENode& rOLENode )
                     has no place to find the dimensions of the ole
                     object, and will not be able to draw it
                     */
-                    OutGrf(*mpParentFrame);
+                    OutGrf(*m_pParentFrame);
                 }
 
-                OutputField(0, ww::eEMBED, aEmptyOUStr,
+                OutputField(nullptr, ww::eEMBED, OUString(),
                     WRITEFIELD_END | WRITEFIELD_CLOSE);
 
                 if (bEndCR) //No newline in inline case
@@ -341,18 +321,16 @@ void WW8Export::OutputOLENode( const SwOLENode& rOLENode )
 
 void WW8Export::OutputLinkedOLE( const OUString& rOleId )
 {
-    uno::Reference< embed::XStorage > xDocStg = pDoc->GetDocStorage();
+    uno::Reference< embed::XStorage > xDocStg = m_pDoc->GetDocStorage();
     uno::Reference< embed::XStorage > xOleStg = xDocStg->openStorageElement( "OLELinks", embed::ElementModes::READ );
-    SotStorageRef xObjSrc = SotStorage::OpenOLEStorage( xOleStg, rOleId, STREAM_READ );
+    tools::SvRef<SotStorage> xObjSrc = SotStorage::OpenOLEStorage( xOleStg, rOleId, StreamMode::READ );
 
-    SotStorageRef xObjStg = GetWriter().GetStorage().OpenSotStorage(
-        OUString(SL::aObjectPool), STREAM_READWRITE |
-        STREAM_SHARE_DENYALL );
+    tools::SvRef<SotStorage> xObjStg = GetWriter().GetStorage().OpenSotStorage(
+        OUString(SL::aObjectPool) );
 
     if( xObjStg.Is() && xObjSrc.Is() )
     {
-        SotStorageRef xOleDst = xObjStg->OpenSotStorage( rOleId,
-                STREAM_READWRITE | STREAM_SHARE_DENYALL );
+        tools::SvRef<SotStorage> xOleDst = xObjStg->OpenSotStorage( rOleId );
         if ( xOleDst.Is() )
             xObjSrc->CopyTo( xOleDst );
 
@@ -362,46 +340,46 @@ void WW8Export::OutputLinkedOLE( const OUString& rOleId )
 
             // Ouput the cPicLocation attribute
             ww::bytes* pBuf = new ww::bytes();
-            GetWriter().InsUInt16( *pBuf, NS_sprm::LN_CPicLocation );
-            GetWriter().InsUInt32( *pBuf, rOleId.copy( 1 ).toInt32() );
+            SwWW8Writer::InsUInt16( *pBuf, NS_sprm::LN_CPicLocation );
+            SwWW8Writer::InsUInt32( *pBuf, rOleId.copy( 1 ).toInt32() );
 
-            GetWriter().InsUInt16( *pBuf, NS_sprm::LN_CFOle2 );
+            SwWW8Writer::InsUInt16( *pBuf, NS_sprm::LN_CFOle2 );
             pBuf->push_back( 1 );
 
-            GetWriter().InsUInt16( *pBuf, NS_sprm::LN_CFSpec );
+            SwWW8Writer::InsUInt16( *pBuf, NS_sprm::LN_CFSpec );
             pBuf->push_back( 1 );
 
-            GetWriter().InsUInt16( *pBuf, NS_sprm::LN_CFObj );
+            SwWW8Writer::InsUInt16( *pBuf, NS_sprm::LN_CFObj );
             pBuf->push_back( 1 );
 
-            pChpPlc->AppendFkpEntry( Strm().Tell(), pBuf->size(), pBuf->data() );
+            m_pChpPlc->AppendFkpEntry( Strm().Tell(), pBuf->size(), pBuf->data() );
             delete pBuf;
         }
     }
 }
 
-void WW8Export::OutGrf(const sw::Frame &rFrame)
+void WW8Export::OutGrf(const ww8::Frame &rFrame)
 {
     //Added for i120568,the hyperlink info within a graphic whose anchor type is "As character"
     //will be exported to ensure the fidelity
-    const SwFmtURL& rURL = rFrame.GetFrmFmt().GetAttrSet().GetURL();
+    const SwFormatURL& rURL = rFrame.GetFrameFormat().GetAttrSet().GetURL();
     bool bURLStarted = false;
-    if( !rURL.GetURL().isEmpty() && rFrame.GetWriterType() == sw::Frame::eGraphic)
+    if( !rURL.GetURL().isEmpty() && rFrame.GetWriterType() == ww8::Frame::eGraphic)
     {
         bURLStarted = true;
         m_pAttrOutput->StartURL( rURL.GetURL(), rURL.GetTargetFrameName() );
     }
 
     // Store the graphic settings in GrfNode so they may be written-out later
-    pGrf->Insert(rFrame);
+    m_pGrf->Insert(rFrame);
 
-    pChpPlc->AppendFkpEntry( Strm().Tell(), pO->size(), pO->data() );
+    m_pChpPlc->AppendFkpEntry( Strm().Tell(), pO->size(), pO->data() );
     pO->clear();
 
     // #i29408#
     // linked, as-character anchored graphics have to be exported as fields.
     const SwGrfNode* pGrfNd = rFrame.IsInline() && rFrame.GetContent()
-                              ? rFrame.GetContent()->GetGrfNode() : 0;
+                              ? rFrame.GetContent()->GetGrfNode() : nullptr;
     if ( pGrfNd && pGrfNd->IsLinkedFile() )
     {
         OUString sStr( FieldString(ww::eINCLUDEPICTURE) );
@@ -410,13 +388,13 @@ void WW8Export::OutGrf(const sw::Frame &rFrame)
             if ( pGrfNd )
             {
                 OUString aFileURL;
-                pGrfNd->GetFileFilterNms( &aFileURL, 0 );
+                pGrfNd->GetFileFilterNms( &aFileURL, nullptr );
                 sStr += aFileURL;
             }
         }
         sStr += "\" \\d";
 
-        OutputField( 0, ww::eINCLUDEPICTURE, sStr,
+        OutputField( nullptr, ww::eINCLUDEPICTURE, sStr,
                    WRITEFIELD_START | WRITEFIELD_CMD_START | WRITEFIELD_CMD_END );
     }
 
@@ -425,89 +403,77 @@ void WW8Export::OutGrf(const sw::Frame &rFrame)
     sal_uInt8 aArr[ 18 ];
     sal_uInt8* pArr = aArr;
 
-    const SwFrmFmt &rFlyFmt = rFrame.GetFrmFmt();
-    const RndStdIds eAn = rFlyFmt.GetAttrSet().GetAnchor(false).GetAnchorId();
+    const SwFrameFormat &rFlyFormat = rFrame.GetFrameFormat();
+    const RndStdIds eAn = rFlyFormat.GetAttrSet().GetAnchor(false).GetAnchorId();
     if (eAn == FLY_AS_CHAR)
     {
-        sal_Int16 eVert = rFlyFmt.GetVertOrient().GetVertOrient();
+        sal_Int16 eVert = rFlyFormat.GetVertOrient().GetVertOrient();
         if ((eVert == text::VertOrientation::CHAR_CENTER) || (eVert == text::VertOrientation::LINE_CENTER))
         {
             bool bVert = false;
             //The default for word in vertical text mode is to center,
             //otherwise a sub/super script hack is employed
-            if (pOutFmtNode && pOutFmtNode->ISA(SwCntntNode) )
+            if (m_pOutFormatNode && dynamic_cast< const SwContentNode *>( m_pOutFormatNode ) !=  nullptr )
             {
-                const SwTxtNode* pTxtNd = (const SwTxtNode*)pOutFmtNode;
-                SwPosition aPos(*pTxtNd);
-                bVert = pDoc->IsInVerticalText(aPos);
+                const SwTextNode* pTextNd = static_cast<const SwTextNode*>(m_pOutFormatNode);
+                SwPosition aPos(*pTextNd);
+                bVert = m_pDoc->IsInVerticalText(aPos);
             }
             if (!bVert)
             {
-                SwTwips nHeight = rFlyFmt.GetFrmSize().GetHeight();
+                SwTwips nHeight = rFlyFormat.GetFrameSize().GetHeight();
                 nHeight/=20; //nHeight was in twips, want it in half points, but
                              //then half of total height.
-                long nFontHeight = ((const SvxFontHeightItem&)
+                long nFontHeight = static_cast<const SvxFontHeightItem&>(
                     GetItem(RES_CHRATR_FONTSIZE)).GetHeight();
                 nHeight-=nFontHeight/20;
 
-                if (bWrtWW8)
-                    Set_UInt16( pArr, NS_sprm::LN_CHpsPos );
-                else
-                    Set_UInt8( pArr, 101 );
+                Set_UInt16( pArr, NS_sprm::LN_CHpsPos );
                 Set_UInt16( pArr, -((sal_Int16)nHeight));
             }
         }
     }
 
     // sprmCFSpec
-    if( bWrtWW8 )
-        Set_UInt16( pArr, 0x855 );
-    else
-        Set_UInt8( pArr, 117 );
+    Set_UInt16( pArr, 0x855 );
     Set_UInt8( pArr, 1 );
 
     // sprmCPicLocation
-    if( bWrtWW8 )
-        Set_UInt16( pArr, NS_sprm::LN_CPicLocation );
-    else
-    {
-        Set_UInt8( pArr, 68 );
-        Set_UInt8( pArr, 4 );
-    }
+    Set_UInt16( pArr, NS_sprm::LN_CPicLocation );
     Set_UInt32( pArr, GRF_MAGIC_321 );
 
     // vary Magic, so that different graphic attributes will not be merged
     static sal_uInt8 nAttrMagicIdx = 0;
     --pArr;
     Set_UInt8( pArr, nAttrMagicIdx++ );
-    pChpPlc->AppendFkpEntry( Strm().Tell(), static_cast< short >(pArr - aArr), aArr );
+    m_pChpPlc->AppendFkpEntry( Strm().Tell(), static_cast< short >(pArr - aArr), aArr );
 
     // #i75464#
     // Check, if graphic isn't exported as-character anchored.
     // Otherwise, an additional paragraph is exported for a graphic, which is
     // forced to be treated as inline, because it's anchored inside another frame.
     if ( !rFrame.IsInline() &&
-         ( ((eAn == FLY_AT_PARA) && ( bWrtWW8 || !IsInTable() )) ||
+         ( ((eAn == FLY_AT_PARA)) ||
            (eAn == FLY_AT_PAGE)) )
     {
         WriteChar( (char)0x0d ); // close the surrounding frame with CR
 
         static sal_uInt8 nSty[2] = { 0, 0 };
         pO->insert( pO->end(), nSty, nSty+2 );     // Style #0
-        bool bOldGrf = bOutGrf;
-        bOutGrf = true;
+        bool bOldGrf = m_bOutGrf;
+        m_bOutGrf = true;
 
-        OutputFormat( rFrame.GetFrmFmt(), false, false, true ); // Fly-Attrs
+        OutputFormat( rFrame.GetFrameFormat(), false, false, true ); // Fly-Attrs
 
-        bOutGrf = bOldGrf;
-        pPapPlc->AppendFkpEntry( Strm().Tell(), pO->size(), pO->data() );
+        m_bOutGrf = bOldGrf;
+        m_pPapPlc->AppendFkpEntry( Strm().Tell(), pO->size(), pO->data() );
         pO->clear();
     }
     // #i29408#
     // linked, as-character anchored graphics have to be exported as fields.
     else if ( pGrfNd && pGrfNd->IsLinkedFile() )
     {
-        OutputField( 0, ww::eINCLUDEPICTURE, OUString(), WRITEFIELD_CLOSE );
+        OutputField( nullptr, ww::eINCLUDEPICTURE, OUString(), WRITEFIELD_CLOSE );
     }
     //Added for i120568,the hyperlink info within a graphic whose anchor type is
     //"As character" will be exported to ensure the fidelity
@@ -524,7 +490,7 @@ GraphicDetails& GraphicDetails::operator=(const GraphicDetails &rOther)
     return *this;
 }
 
-void SwWW8WrGrf::Insert(const sw::Frame &rFly)
+void SwWW8WrGrf::Insert(const ww8::Frame &rFly)
 {
     const Size aSize( rFly.GetLayoutSize() );
     const sal_uInt16 nWidth = static_cast< sal_uInt16 >(aSize.Width());
@@ -532,7 +498,7 @@ void SwWW8WrGrf::Insert(const sw::Frame &rFly)
     maDetails.push_back(GraphicDetails(rFly, nWidth, nHeight));
 }
 
-void SwWW8WrGrf::WritePICFHeader(SvStream& rStrm, const sw::Frame &rFly,
+void SwWW8WrGrf::WritePICFHeader(SvStream& rStrm, const ww8::Frame &rFly,
     sal_uInt16 mm, sal_uInt16 nWidth, sal_uInt16 nHeight, const SwAttrSet* pAttrSet)
 {
     sal_Int16 nXSizeAdd = 0, nYSizeAdd = 0;
@@ -540,10 +506,10 @@ void SwWW8WrGrf::WritePICFHeader(SvStream& rStrm, const sw::Frame &rFly,
 
             // write Crop-Attribut content in Header ( if available )
     const SfxPoolItem* pItem;
-    if (pAttrSet && (SFX_ITEM_ON
+    if (pAttrSet && (SfxItemState::SET
         == pAttrSet->GetItemState(RES_GRFATR_CROPGRF, false, &pItem)))
     {
-        const SwCropGrf& rCr = *(SwCropGrf*)pItem;
+        const SwCropGrf& rCr = *static_cast<const SwCropGrf*>(pItem);
         nCropL = (sal_Int16)rCr.GetLeft();
         nCropR = (sal_Int16)rCr.GetRight();
         nCropT = (sal_Int16)rCr.GetTop();
@@ -553,54 +519,54 @@ void SwWW8WrGrf::WritePICFHeader(SvStream& rStrm, const sw::Frame &rFly,
     }
 
     Size aGrTwipSz(rFly.GetSize());
-    bool bWrtWW8 = rWrt.bWrtWW8;
-    sal_uInt16 nHdrLen = bWrtWW8 ? 0x44 : 0x3A;
+    sal_uInt16 nHdrLen = 0x44;
 
     sal_uInt8 aArr[ 0x44 ] = { 0 };
 
     sal_uInt8* pArr = aArr + 0x2E;  // Do borders first
 
-    const SwAttrSet& rAttrSet = rFly.GetFrmFmt().GetAttrSet();
-    if (SFX_ITEM_ON == rAttrSet.GetItemState(RES_BOX, false, &pItem))
+    const SwAttrSet& rAttrSet = rFly.GetFrameFormat().GetAttrSet();
+    if (SfxItemState::SET == rAttrSet.GetItemState(RES_BOX, false, &pItem))
     {
-        const SvxBoxItem* pBox = (const SvxBoxItem*)pItem;
+        const SvxBoxItem* pBox = static_cast<const SvxBoxItem*>(pItem);
         if( pBox )
         {
             bool bShadow = false;               // Shadow ?
-            const SvxShadowItem* pSI =
-                sw::util::HasItem<SvxShadowItem>(rAttrSet, RES_SHADOW);
-            if (pSI)
+            if (const SvxShadowItem* pSI = rAttrSet.GetItem<SvxShadowItem>(RES_SHADOW))
             {
                 bShadow = (pSI->GetLocation() != SVX_SHADOW_NONE) &&
                     (pSI->GetWidth() != 0);
             }
 
-            sal_uInt8 aLnArr[4] = { BOX_LINE_TOP, BOX_LINE_LEFT,
-                                BOX_LINE_BOTTOM, BOX_LINE_RIGHT };
+            static const SvxBoxItemLine aLnArr[4] = { SvxBoxItemLine::TOP, SvxBoxItemLine::LEFT,
+                                SvxBoxItemLine::BOTTOM, SvxBoxItemLine::RIGHT };
             for( sal_uInt8 i = 0; i < 4; ++i )
             {
-                const ::editeng::SvxBorderLine* pLn = pBox->GetLine( aLnArr[ i ] );
+                const ::editeng::SvxBorderLine* pLn = pBox->GetLine( aLnArr[i] );
                 WW8_BRC aBrc;
                 if (pLn)
                 {
-                    aBrc = rWrt.TranslateBorderLine( *pLn,
-                        pBox->GetDistance( aLnArr[ i ] ), bShadow );
+                    WW8_BRCVer9 aBrc90 = WW8Export::TranslateBorderLine( *pLn,
+                        pBox->GetDistance( aLnArr[i] ), bShadow );
+                    sal_uInt8 ico = msfilter::util::TransColToIco(msfilter::util::BGRToRGB(
+                        aBrc90.cv()));
+                    aBrc = WW8_BRC(aBrc90.dptLineWidth(), aBrc90.brcType(), ico,
+                        aBrc90.dptSpace(), aBrc90.fShadow(), aBrc90.fFrame());
                 }
 
                 // use importer logic to determine how large the exported
                 // border will really be in word and adjust accordingly
                 short nSpacing;
-                short nThick = aBrc.DetermineBorderProperties(!bWrtWW8,
-                    &nSpacing);
-                switch (aLnArr[ i ])
+                short nThick = aBrc.DetermineBorderProperties(&nSpacing);
+                switch (aLnArr[i])
                 {
-                    case BOX_LINE_TOP:
-                    case BOX_LINE_BOTTOM:
+                    case SvxBoxItemLine::TOP:
+                    case SvxBoxItemLine::BOTTOM:
                         nHeight -= bShadow ? nThick*2 : nThick;
                         nHeight = nHeight - nSpacing;
                         break;
-                    case BOX_LINE_LEFT:
-                    case BOX_LINE_RIGHT:
+                    case SvxBoxItemLine::LEFT:
+                    case SvxBoxItemLine::RIGHT:
                     default:
                         nWidth -= bShadow ? nThick*2 : nThick;
                         nWidth = nWidth - nSpacing;
@@ -609,11 +575,8 @@ void SwWW8WrGrf::WritePICFHeader(SvStream& rStrm, const sw::Frame &rFly,
                 memcpy( pArr, &aBrc.aBits1, 2);
                 pArr+=2;
 
-                if( bWrtWW8 )
-                {
-                    memcpy( pArr, &aBrc.aBits2, 2);
-                    pArr+=2;
-                }
+                memcpy( pArr, &aBrc.aBits2, 2);
+                pArr+=2;
             }
         }
     }
@@ -625,7 +588,7 @@ void SwWW8WrGrf::WritePICFHeader(SvStream& rStrm, const sw::Frame &rFly,
 
     /*
     Just in case our original size is too big to fit inside a ushort we can
-    substitute the final size and loose on retaining the scaling factor but
+    substitute the final size and lose on retaining the scaling factor but
     still keep the correct display size anyway.
     */
     const bool bIsSubstitutedSize = (aGrTwipSz.Width() > SHRT_MAX) || (aGrTwipSz.Height() > SHRT_MAX) ||
@@ -686,75 +649,33 @@ void SwWW8WrGrf::WritePICFHeader(SvStream& rStrm, const sw::Frame &rFly,
         Set_UInt16( pArr, nCropR );                     // set dxaCropRight
         Set_UInt16( pArr, nCropB );                     // set dyaCropBottom
     }
-    else
-    {
-        pArr += 8;
-    }
 
     rStrm.Write( aArr, nHdrLen );
 }
 
 void SwWW8WrGrf::WriteGrfFromGrfNode(SvStream& rStrm, const SwGrfNode &rGrfNd,
-    const sw::Frame &rFly, sal_uInt16 nWidth, sal_uInt16 nHeight)
+    const ww8::Frame &rFly, sal_uInt16 nWidth, sal_uInt16 nHeight)
 {
     if (rGrfNd.IsLinkedFile())     // Linked File
     {
         OUString aFileN;
-        rGrfNd.GetFileFilterNms( &aFileN, 0 );
+        rGrfNd.GetFileFilterNms( &aFileN, nullptr );
 
             sal_uInt16 mm = 94;                    // 94 = BMP, GIF
 
         WritePICFHeader(rStrm, rFly, mm, nWidth, nHeight,
             rGrfNd.GetpSwAttrSet());
-        rStrm << (sal_uInt8)aFileN.getLength();    // write Pascal-String
+        rStrm.WriteUChar( aFileN.getLength() );    // write Pascal-String
         SwWW8Writer::WriteString8(rStrm, aFileN, false,
             RTL_TEXTENCODING_MS_1252);
     }
     else                                // Embedded File or DDE or something like that
     {
-        if (rWrt.bWrtWW8)
-        {
-            WritePICFHeader(rStrm, rFly, 0x64, nWidth, nHeight,
-                rGrfNd.GetpSwAttrSet());
-            SwBasicEscherEx aInlineEscher(&rStrm, rWrt);
-            aInlineEscher.WriteGrfFlyFrame(rFly.GetFrmFmt(), 0x401);
-            aInlineEscher.WritePictures();
-        }
-        else
-        {
-            Graphic& rGrf = const_cast<Graphic&>(rGrfNd.GetGrf());
-            bool bSwapped = rGrf.IsSwapOut() ? true : false;
-            // always swapin via the Node
-            const_cast<SwGrfNode&>(rGrfNd).SwapIn();
-
-            GDIMetaFile aMeta;
-            switch (rGrf.GetType())
-            {
-                case GRAPHIC_BITMAP:        // Bitmap -> play in Metafile
-                    {
-                        VirtualDevice aVirt;
-                        aMeta.Record(&aVirt);
-                        aVirt.DrawBitmap( Point( 0,0 ), rGrf.GetBitmap() );
-                        aMeta.Stop();
-                        aMeta.WindStart();
-                        aMeta.SetPrefMapMode( rGrf.GetPrefMapMode());
-                        aMeta.SetPrefSize( rGrf.GetPrefSize());
-                    }
-                    break;
-                case GRAPHIC_GDIMETAFILE :      // GDI ( =SV ) Metafile
-                    aMeta = rGrf.GetGDIMetaFile();
-                    break;
-                default:
-                    return;
-            }
-
-            WritePICFHeader(rStrm, rFly, 8, nWidth, nHeight,
-                rGrfNd.GetpSwAttrSet());
-            WriteWindowMetafileBits(rStrm, aMeta);
-
-            if (bSwapped)
-                rGrf.SwapOut();
-        }
+        WritePICFHeader(rStrm, rFly, 0x64, nWidth, nHeight,
+            rGrfNd.GetpSwAttrSet());
+        SwBasicEscherEx aInlineEscher(&rStrm, rWrt);
+        aInlineEscher.WriteGrfFlyFrame(rFly.GetFrameFormat(), 0x401);
+        aInlineEscher.WritePictures();
     }
 }
 //For i120928,export graphic info of bullet
@@ -765,31 +686,29 @@ void SwWW8WrGrf::WritePICBulletFHeader(SvStream& rStrm, const Graphic &rGrf,
     sal_Int16 nCropL = 0, nCropR = 0, nCropT = 0, nCropB = 0;
 
     Size aGrTwipSz(rGrf.GetPrefSize());
-    bool bWrtWW8 = rWrt.bWrtWW8;
-    sal_uInt16 nHdrLen = bWrtWW8 ? 0x44 : 0x3A;
+    sal_uInt16 nHdrLen = 0x44;
 
     sal_uInt8 aArr[ 0x44 ] = { 0 };
 
     sal_uInt8* pArr = aArr + 0x2E;  //Do borders first
 
-    sal_uInt8 aLnArr[4] = { BOX_LINE_TOP, BOX_LINE_LEFT,
-    BOX_LINE_BOTTOM, BOX_LINE_RIGHT };
+    static const SvxBoxItemLine aLnArr[4] = { SvxBoxItemLine::TOP, SvxBoxItemLine::LEFT,
+        SvxBoxItemLine::BOTTOM, SvxBoxItemLine::RIGHT };
     for( sal_uInt8 i = 0; i < 4; ++i )
     {
         WW8_BRC aBrc;
 
         short nSpacing;
-        short nThick = aBrc.DetermineBorderProperties(!bWrtWW8,
-        &nSpacing);
-        switch (aLnArr[ i ])
+        short nThick = aBrc.DetermineBorderProperties(&nSpacing);
+        switch (aLnArr[i])
         {
-            case BOX_LINE_TOP:
-            case BOX_LINE_BOTTOM:
+            case SvxBoxItemLine::TOP:
+            case SvxBoxItemLine::BOTTOM:
             nHeight -= nThick;
             nHeight = nHeight - nSpacing;
             break;
-            case BOX_LINE_LEFT:
-            case BOX_LINE_RIGHT:
+            case SvxBoxItemLine::LEFT:
+            case SvxBoxItemLine::RIGHT:
             default:
             nWidth -= nThick;
             nWidth = nWidth - nSpacing;
@@ -798,11 +717,8 @@ void SwWW8WrGrf::WritePICBulletFHeader(SvStream& rStrm, const Graphic &rGrf,
         memcpy( pArr, &aBrc.aBits1, 2);
         pArr+=2;
 
-        if( bWrtWW8 )
-        {
-            memcpy( pArr, &aBrc.aBits2, 2);
-            pArr+=2;
-        }
+        memcpy(pArr, &aBrc.aBits2, 2);
+        pArr+=2;
     }
 
     pArr = aArr + 4;                                //skip lcb
@@ -852,38 +768,10 @@ void SwWW8WrGrf::WritePICBulletFHeader(SvStream& rStrm, const Graphic &rGrf,
 
 void SwWW8WrGrf::WriteGrfForBullet(SvStream& rStrm, const Graphic &rGrf, sal_uInt16 nWidth, sal_uInt16 nHeight)
 {
-    if (rWrt.bWrtWW8)
-    {
-        WritePICBulletFHeader(rStrm,rGrf, 0x64,nWidth,nHeight);
-        SwBasicEscherEx aInlineEscher(&rStrm, rWrt);
-        aInlineEscher.WriteGrfBullet(rGrf);
-        aInlineEscher.WritePictures();
-    }
-    else
-    {
-        GDIMetaFile aMeta;
-        switch (rGrf.GetType())
-        {
-            case GRAPHIC_BITMAP:        // Bitmap -> in Metafile abspielen
-            {
-                VirtualDevice aVirt;
-                aMeta.Record(&aVirt);
-                aVirt.DrawBitmap( Point( 0,0 ), rGrf.GetBitmap() );
-                aMeta.Stop();
-                aMeta.WindStart();
-                aMeta.SetPrefMapMode( rGrf.GetPrefMapMode());
-                aMeta.SetPrefSize( rGrf.GetPrefSize());
-            }
-            break;
-            case GRAPHIC_GDIMETAFILE :      // GDI ( =SV ) Metafile
-                aMeta = rGrf.GetGDIMetaFile();
-            break;
-            default:
-                return;
-        }
-        WritePICBulletFHeader(rStrm, rGrf, 8, nWidth, nHeight);
-        WriteWindowMetafileBits(rStrm, aMeta);
-    }
+    WritePICBulletFHeader(rStrm,rGrf, 0x64,nWidth,nHeight);
+    SwBasicEscherEx aInlineEscher(&rStrm, rWrt);
+    aInlineEscher.WriteGrfBullet(rGrf);
+    aInlineEscher.WritePictures();
 }
 
 void SwWW8WrGrf::WriteGraphicNode(SvStream& rStrm, const GraphicDetails &rItem)
@@ -892,20 +780,20 @@ void SwWW8WrGrf::WriteGraphicNode(SvStream& rStrm, const GraphicDetails &rItem)
     sal_uInt16 nHeight = rItem.mnHei;
     sal_uInt32 nPos = rStrm.Tell();         // store start of graphic
 
-    const sw::Frame &rFly = rItem.maFly;
+    const ww8::Frame &rFly = rItem.maFly;
     switch (rFly.GetWriterType())
     {
-        case sw::Frame::eGraphic:
+        case ww8::Frame::eGraphic:
         {
             const SwNode *pNode = rItem.maFly.GetContent();
-            const SwGrfNode *pNd = pNode ? pNode->GetGrfNode() : 0;
+            const SwGrfNode *pNd = pNode ? pNode->GetGrfNode() : nullptr;
             OSL_ENSURE(pNd, "Impossible");
             if (pNd)
                 WriteGrfFromGrfNode(rStrm, *pNd, rItem.maFly, nWidth, nHeight);
         }
         break;
         //For i120928,add branch to export graphic of bullet
-        case sw::Frame::eBulletGrf:
+        case ww8::Frame::eBulletGrf:
         {
             if (rItem.maFly.HasGraphic())
             {
@@ -915,45 +803,14 @@ void SwWW8WrGrf::WriteGraphicNode(SvStream& rStrm, const GraphicDetails &rItem)
         }
         break;
 
-        case sw::Frame::eOle:
+        case ww8::Frame::eOle:
         {
-#ifdef OLE_PREVIEW_AS_EMF
             const SwNode *pNode = rItem.maFly.GetContent();
-            const SwOLENode *pNd = pNode ? pNode->GetOLENode() : 0;
+            const SwOLENode *pNd = pNode ? pNode->GetOLENode() : nullptr;
             OSL_ENSURE(pNd, "Impossible");
-            if (!rWrt.bWrtWW8)
-            {
-                SwOLENode *pOleNd = const_cast<SwOLENode*>(pNd);
-                OSL_ENSURE( pOleNd, " Wer hat den OleNode versteckt ?" );
-                SwOLEObj&                   rSObj= pOleNd->GetOLEObj();
-                uno::Reference < embed::XEmbeddedObject > rObj(  rSObj.GetOleRef() );
-
-                comphelper::EmbeddedObjectContainer aCnt( pOleNd->GetDoc()->GetDocStorage() );
-
-                SvStream* pGraphicStream = ::utl::UcbStreamHelper::CreateStream( aCnt.GetGraphicStream( rObj ) );
-                OSL_ENSURE( pGraphicStream && !pGraphicStream->GetError(), "No graphic stream available!" );
-                if ( pGraphicStream && !pGraphicStream->GetError() )
-                {
-                    Graphic aGr;
-                    GraphicFilter& rGF = GraphicFilter::GetGraphicFilter();
-                    if( rGF.ImportGraphic( aGr, aEmptyOUStr, *pGraphicStream, GRFILTER_FORMAT_DONTKNOW ) == GRFILTER_OK )
-                    {
-                        //TODO/LATER: do we really want to use GDIMetafile?!
-                        GDIMetaFile aMtf;
-                        aMtf = aGr.GetGDIMetaFile();
-                        aMtf.WindStart();
-                        aMtf.Play(Application::GetDefaultDevice(), Point(0, 0),
-                            Size(2880, 2880));
-                        WritePICFHeader(rStrm, rFly, 8, nWidth, nHeight,
-                            pNd->GetpSwAttrSet());
-                        WriteWindowMetafileBits(rStrm, aMtf);
-                    }
-                }
-                else
-                    delete pGraphicStream;
-            }
-            else
+            if (pNd)
             {
+#ifdef OLE_PREVIEW_AS_EMF
                 //Convert this ole2 preview in ww8+ to an EMF for better unicode
                 //support (note that at this moment this breaks StarSymbol
                 //using graphics because I need to embed starsymbol in exported
@@ -961,40 +818,37 @@ void SwWW8WrGrf::WriteGraphicNode(SvStream& rStrm, const GraphicDetails &rItem)
                 WritePICFHeader(rStrm, rFly, 0x64, nWidth, nHeight,
                     pNd->GetpSwAttrSet());
                 SwBasicEscherEx aInlineEscher(&rStrm, rWrt);
-                aInlineEscher.WriteOLEFlyFrame(rFly.GetFrmFmt(), 0x401);
+                aInlineEscher.WriteOLEFlyFrame(rFly.GetFrameFormat(), 0x401);
                 aInlineEscher.WritePictures();
-            }
 #else
-            // cast away const
-            SwOLENode *pOleNd = const_cast<SwOLENode*>(pNd);
-            OSL_ENSURE( pOleNd, " Wer hat den OleNode versteckt ?" );
-            SwOLEObj&                   rSObj= pOleNd->GetOLEObj();
+                // cast away const
+                SwOLENode *pOleNd = const_cast<SwOLENode*>(pNd);
+                SwOLEObj& rSObj= pOleNd->GetOLEObj();
 
-            // TODO/LATER: do we need to load object?
-            Graphic* pGr = SdrOle2Obj::GetGraphicFromObject( pOleNd->GetDoc()->GetDocStorage(), rObj );
+                // TODO/LATER: do we need to load object?
+                Graphic* pGr = SdrOle2Obj::GetGraphicFromObject( pOleNd->GetDoc()->GetDocStorage(), rObj );
 
-            //TODO/LATER: do we really want to use GDIMetafile?!
-            GDIMetaFile aMtf;
-            if ( pGr )
-                aMtf = pGr->GetGDIMetaFile();
+                //TODO/LATER: do we really want to use GDIMetafile?!
+                GDIMetaFile aMtf;
+                if ( pGr )
+                    aMtf = pGr->GetGDIMetaFile();
 
-            Size aS(aMtf.GetPrefSize());
-            aMtf.WindStart();
-            aMtf.Play(Application::GetDefaultDevice(), Point(0, 0),
-                Size(2880, 2880));
+                Size aS(aMtf.GetPrefSize());
+                aMtf.WindStart();
+                aMtf.Play(Application::GetDefaultDevice(), Point(0, 0),
+                    Size(2880, 2880));
 
-            WritePICFHeader(rStrm, rFly, 8, nWidth, nHeight,
-                pNd->GetpSwAttrSet());
-            WriteWindowMetafileBits(rStrm, aMtf);
-            delete pGr;
+                WritePICFHeader(rStrm, rFly, 8, nWidth, nHeight,
+                    pNd->GetpSwAttrSet());
+                WriteWindowMetafileBits(rStrm, aMtf);
+                delete pGr;
 #endif
+            }
         }
         break;
-        case sw::Frame::eDrawing:
-        case sw::Frame::eTxtBox:
-        case sw::Frame::eFormControl:
-            OSL_ENSURE(rWrt.bWrtWW8,
-                "You can't try and export these in WW8 format, a filter bug");
+        case ww8::Frame::eDrawing:
+        case ww8::Frame::eTextBox:
+        case ww8::Frame::eFormControl:
             /*
             #i3958# We only export an empty dummy picture frame here, this is
             what word does the escher export should contain an anchored to
@@ -1002,16 +856,14 @@ void SwWW8WrGrf::WriteGraphicNode(SvStream& rStrm, const GraphicDetails &rItem)
             shebang surrounded with a SHAPE field. This isn't *my* hack :-),
             its what word does.
             */
-            if (rWrt.bWrtWW8)
             {
                 WritePICFHeader(rStrm, rFly, 0x64, nWidth, nHeight);
                 SwBasicEscherEx aInlineEscher(&rStrm, rWrt);
-                aInlineEscher.WriteEmptyFlyFrame(rFly.GetFrmFmt(), 0x401);
+                aInlineEscher.WriteEmptyFlyFrame(rFly.GetFrameFormat(), 0x401);
             }
             break;
         default:
-            OSL_ENSURE(!this,
-           "Some inline export not implemented, remind cmc before we ship :-)");
+            OSL_ENSURE(false, "Some inline export not implemented");
             break;
     }
 
