@@ -15,7 +15,7 @@
 #include <vcl/msgbox.hxx>
 #include <vcl/vclmedit.hxx>
 
-SwMessageAndEditDialog::SwMessageAndEditDialog(Window* pParent, const OString& rID,
+SwMessageAndEditDialog::SwMessageAndEditDialog(vcl::Window* pParent, const OUString& rID,
         const OUString& rUIXMLDescription)
     : ModalDialog(pParent, rID, rUIXMLDescription)
 {
@@ -30,4 +30,19 @@ SwMessageAndEditDialog::SwMessageAndEditDialog(Window* pParent, const OString& r
     get(m_pEdit, "edit");
 }
 
+SwMessageAndEditDialog::~SwMessageAndEditDialog()
+{
+    disposeOnce();
+}
+
+void SwMessageAndEditDialog::dispose()
+{
+    m_pOKPB.clear();
+    m_pImageIM.clear();
+    m_pPrimaryMessage.clear();
+    m_pSecondaryMessage.clear();
+    m_pEdit.clear();
+    ModalDialog::dispose();
+}
+
 /* vim:set shiftwidth=4 softtabstop=4 expandtab: */
