@@ -41,7 +41,7 @@
 
 #include <globals.hrc>
 #include <misc.hrc>
-#include <boost/scoped_ptr.hpp>
+#include <memory>
 
 using namespace ::com::sun::star;
 
@@ -52,21 +52,19 @@ const sal_uInt16 SwFootNotePage::aPageRg[] = {
 
 // handler to switch between the different possibilities how the footnote
 // region's height can be set.
-IMPL_LINK_NOARG(SwFootNotePage, HeightPage)
+IMPL_LINK_NOARG_TYPED(SwFootNotePage, HeightPage, Button*, void)
 {
     m_pMaxHeightEdit->Enable(false);
-    return 0;
 }
 
-IMPL_LINK_NOARG(SwFootNotePage, HeightMetric)
+IMPL_LINK_NOARG_TYPED(SwFootNotePage, HeightMetric, Button*, void)
 {
     m_pMaxHeightEdit->Enable();
     m_pMaxHeightEdit->GrabFocus();
-    return 0;
 }
 
 // handler limit values
-IMPL_LINK_NOARG(SwFootNotePage, HeightModify)
+IMPL_LINK_NOARG_TYPED(SwFootNotePage, HeightModify, Control&, void)
 {
     m_pMaxHeightEdit->SetMax(m_pMaxHeightEdit->Normalize(lMaxHeight -
             (m_pDistEdit->Denormalize(m_pDistEdit->GetValue(FUNIT_TWIP)) +
@@ -84,24 +82,20 @@ IMPL_LINK_NOARG(SwFootNotePage, HeightModify)
             (m_pMaxHeightEdit->Denormalize(m_pMaxHeightEdit->GetValue(FUNIT_TWIP)) +
             m_pDistEdit->Denormalize(m_pDistEdit->GetValue(FUNIT_TWIP)))),
             FUNIT_TWIP);
-    return 0;
 }
 
-IMPL_LINK_NOARG(SwFootNotePage, LineWidthChanged_Impl)
+IMPL_LINK_NOARG_TYPED(SwFootNotePage, LineWidthChanged_Impl, Edit&, void)
 {
     sal_Int64 nVal = static_cast<sal_Int64>(MetricField::ConvertDoubleValue(
                 m_pLineWidthEdit->GetValue( ),
                 m_pLineWidthEdit->GetDecimalDigits( ),
                 m_pLineWidthEdit->GetUnit(), MAP_TWIP ));
     m_pLineTypeBox->SetWidth( nVal );
-
-    return 0;
 }
 
-IMPL_LINK_NOARG(SwFootNotePage, LineColorSelected_Impl)
+IMPL_LINK_NOARG_TYPED(SwFootNotePage, LineColorSelected_Impl, ListBox&, void)
 {
     m_pLineTypeBox->SetColor( m_pLineColorBox->GetSelectEntryColor() );
-    return 0;
 }
 
 SwFootNotePage::SwFootNotePage(vcl::Window *pParent, const SfxItemSet &rSet)
@@ -159,7 +153,7 @@ VclPtr<SfxTabPage> SwFootNotePage::Create(vcl::Window *pParent, const SfxItemSet
 void SwFootNotePage::Reset(const SfxItemSet *rSet)
 {
     // if no example exists, otherwise Init here in Activate
-    boost::scoped_ptr<SwPageFootnoteInfo> pDefFootnoteInfo;
+    std::unique_ptr<SwPageFootnoteInfo> pDefFootnoteInfo;
     const SwPageFootnoteInfo* pFootnoteInfo;
     const SfxPoolItem* pItem = SfxTabPage::GetItem(*rSet, FN_PARAM_FTN_INFO);
     if( pItem )
@@ -178,16 +172,16 @@ void SwFootNotePage::Reset(const SfxItemSet *rSet)
     if(lHeight)
     {
         m_pMaxHeightEdit->SetValue(m_pMaxHeightEdit->Normalize(lHeight),FUNIT_TWIP);
-        m_pMaxHeightBtn->Check(true);
+        m_pMaxHeightBtn->Check();
     }
     else
     {
-        m_pMaxHeightPageBtn->Check(true);
+        m_pMaxHeightPageBtn->Check();
         m_pMaxHeightEdit->Enable(false);
     }
     m_pMaxHeightPageBtn->SetClickHdl(LINK(this,SwFootNotePage,HeightPage));
     m_pMaxHeightBtn->SetClickHdl(LINK(this,SwFootNotePage,HeightMetric));
-    Link<> aLk = LINK(this, SwFootNotePage, HeightModify);
+    Link<Control&,void> aLk = LINK(this, SwFootNotePage, HeightModify);
     m_pMaxHeightEdit->SetLoseFocusHdl( aLk );
     m_pDistEdit->SetLoseFocusHdl( aLk );
     m_pLineDistEdit->SetLoseFocusHdl( aLk );
@@ -225,7 +219,7 @@ void SwFootNotePage::Reset(const SfxItemSet *rSet)
     if ( pDocSh )
     {
         const SfxPoolItem* pColorItem = pDocSh->GetItem( SID_COLOR_TABLE );
-        if ( pColorItem != NULL )
+        if ( pColorItem != nullptr )
             pColorList = static_cast<const SvxColorListItem*>(pColorItem)->GetColorList();
     }
 
@@ -309,7 +303,7 @@ bool SwFootNotePage::FillItemSet(SfxItemSet *rSet)
     rFootnoteInfo.SetWidth(Fraction( static_cast< long >(m_pLineLengthEdit->GetValue()), 100));
 
     const SfxPoolItem* pOldItem;
-    if(0 == (pOldItem = GetOldItem( *rSet, FN_PARAM_FTN_INFO )) ||
+    if(nullptr == (pOldItem = GetOldItem( *rSet, FN_PARAM_FTN_INFO )) ||
                 aItem != *pOldItem )
         rSet->Put(aItem);
 
@@ -361,7 +355,7 @@ void SwFootNotePage::ActivatePage(const SfxItemSet& rSet)
     lMaxHeight /= 10;
 
     // set maximum values
-    HeightModify(0);
+    HeightModify(*m_pMaxHeightEdit);
 }
 
 SfxTabPage::sfxpg SwFootNotePage::DeactivatePage( SfxItemSet* _pSet)
