@@ -92,7 +92,7 @@ uno::Reference< text::XTextRange > SwVbaSelection::GetSelectedRange() throw ( un
     }
     else
     {
-        throw uno::RuntimeException("Not implemented", uno::Reference< uno::XInterface >() );
+        throw uno::RuntimeException("Not implemented" );
     }
     return xTextRange;
 }
@@ -120,7 +120,7 @@ SwVbaSelection::setText( const OUString& rText ) throw ( uno::RuntimeException,
 void SAL_CALL
 SwVbaSelection::TypeText( const OUString& rText ) throw ( uno::RuntimeException, std::exception )
 {
-    // FIXME: handle the property Options.ReplaceSelection, the default value is sal_True
+    // FIXME: handle the property Options.ReplaceSelection, the default value is true
     setText( rText );
 }
 
@@ -131,7 +131,7 @@ SwVbaSelection::HomeKey( const uno::Any& _unit, const uno::Any& _extend ) throw
     sal_Int32 nExtend = word::WdMovementType::wdMove;
     _unit >>= nUnit;
     _extend >>= nExtend;
-    bool bExtend = ( nExtend == word::WdMovementType::wdExtend ) ? sal_True : sal_False;
+    bool bExtend = nExtend == word::WdMovementType::wdExtend;
 
     switch( nUnit )
     {
@@ -154,7 +154,7 @@ SwVbaSelection::HomeKey( const uno::Any& _unit, const uno::Any& _extend ) throw
         }
         default:
         {
-            throw uno::RuntimeException("Not implemented", uno::Reference< uno::XInterface >() );
+            throw uno::RuntimeException("Not implemented" );
         }
     }
 }
@@ -166,7 +166,7 @@ SwVbaSelection::EndKey( const uno::Any& _unit, const uno::Any& _extend ) throw (
     sal_Int32 nExtend = word::WdMovementType::wdMove;
     _unit >>= nUnit;
     _extend >>= nExtend;
-    bool bExtend = ( nExtend == word::WdMovementType::wdExtend ) ? sal_True : sal_False;
+    bool bExtend = nExtend == word::WdMovementType::wdExtend;
 
     switch( nUnit )
     {
@@ -189,7 +189,7 @@ SwVbaSelection::EndKey( const uno::Any& _unit, const uno::Any& _extend ) throw (
         }
         default:
         {
-            throw uno::RuntimeException("Not implemented", uno::Reference< uno::XInterface >() );
+            throw uno::RuntimeException("Not implemented" );
         }
     }
 }
@@ -215,7 +215,7 @@ SwVbaSelection::Delete( const uno::Any& _unit, const uno::Any& _count ) throw (
             }
             default:
             {
-                throw uno::RuntimeException("Not implemented", uno::Reference< uno::XInterface >() );
+                throw uno::RuntimeException("Not implemented" );
             }
         }
     }
@@ -224,7 +224,7 @@ SwVbaSelection::Delete( const uno::Any& _unit, const uno::Any& _count ) throw (
 }
 
 void
-SwVbaSelection::Move( const uno::Any& _unit, const uno::Any& _count, const uno::Any& _extend, word::E_DIRECTION eDirection ) throw ( uno::RuntimeException )
+SwVbaSelection::Move( const uno::Any& _unit, const uno::Any& _count, const uno::Any& _extend, word::E_DIRECTION eDirection ) throw ( css::script::BasicErrorException, uno::RuntimeException )
 {
     sal_Int32 nUnit = word::WdUnits::wdCharacter;
     sal_Int32 nCount = 1;
@@ -240,7 +240,7 @@ SwVbaSelection::Move( const uno::Any& _unit, const uno::Any& _count, const uno::
     if( nCount == 0 )
         return;
 
-    bool bExpand = ( nExtend == word::WdMovementType::wdMove ) ? sal_False : sal_True;
+    bool bExpand = nExtend != word::WdMovementType::wdMove;
 
     switch( nUnit )
     {
@@ -248,7 +248,7 @@ SwVbaSelection::Move( const uno::Any& _unit, const uno::Any& _count, const uno::
         {
             if(  nExtend == word::WdMovementType::wdExtend )
             {
-                DebugHelper::exception(SbERR_BAD_ARGUMENT, OUString());
+                DebugHelper::basicexception(ERRCODE_BASIC_BAD_ARGUMENT, OUString());
                 return;
             }
             NextCell( nCount, eDirection );
@@ -258,7 +258,7 @@ SwVbaSelection::Move( const uno::Any& _unit, const uno::Any& _count, const uno::
         {
             if( eDirection == word::MOVE_LEFT || eDirection == word::MOVE_RIGHT )
             {
-                throw uno::RuntimeException("Not implemented", uno::Reference< uno::XInterface >() );
+                throw uno::RuntimeException("Not implemented" );
             }
             uno::Reference< view::XViewCursor > xViewCursor( mxTextViewCursor, uno::UNO_QUERY_THROW );
             if( eDirection == word::MOVE_UP )
@@ -271,7 +271,7 @@ SwVbaSelection::Move( const uno::Any& _unit, const uno::Any& _count, const uno::
         {
             if( eDirection == word::MOVE_UP || eDirection == word::MOVE_DOWN )
             {
-                throw uno::RuntimeException("Not implemented", uno::Reference< uno::XInterface >() );
+                throw uno::RuntimeException("Not implemented" );
             }
             if( word::gotoSelectedObjectAnchor( mxModel ) )
             {
@@ -311,14 +311,14 @@ SwVbaSelection::Move( const uno::Any& _unit, const uno::Any& _count, const uno::
             {
                 if( eDirection == word::MOVE_LEFT || eDirection == word::MOVE_RIGHT )
                 {
-                    throw uno::RuntimeException("Not implemented", uno::Reference< uno::XInterface >() );
+                    throw uno::RuntimeException("Not implemented" );
                 }
                 uno::Reference< text::XParagraphCursor > xParagraphCursor( xTextCursor, uno::UNO_QUERY_THROW );
                 for( sal_Int32 i=0; i<nCount; i++ )
                 {
-                    if( ( eDirection == word::MOVE_UP ) && ( xParagraphCursor->gotoPreviousParagraph( bExpand ) == sal_False ) )
+                    if( ( eDirection == word::MOVE_UP ) && !xParagraphCursor->gotoPreviousParagraph( bExpand ) )
                         break;
-                    else if( ( eDirection == word::MOVE_DOWN ) && ( xParagraphCursor->gotoNextParagraph( bExpand ) == sal_False ) )
+                    else if( ( eDirection == word::MOVE_DOWN ) && !xParagraphCursor->gotoNextParagraph( bExpand ) )
                         break;
                 }
             }
@@ -326,14 +326,14 @@ SwVbaSelection::Move( const uno::Any& _unit, const uno::Any& _count, const uno::
             {
                 if( eDirection == word::MOVE_UP || eDirection == word::MOVE_DOWN )
                 {
-                    throw uno::RuntimeException("Not implemented", uno::Reference< uno::XInterface >() );
+                    throw uno::RuntimeException("Not implemented" );
                 }
                 uno::Reference< text::XWordCursor > xWordCursor( xTextCursor, uno::UNO_QUERY_THROW );
                 for( sal_Int32 i=0; i<nCount; i++ )
                 {
-                    if( (eDirection == word::MOVE_LEFT ) && ( xWordCursor->gotoPreviousWord( bExpand ) == sal_False ) )
+                    if( (eDirection == word::MOVE_LEFT ) && !xWordCursor->gotoPreviousWord( bExpand ) )
                         break;
-                    else if( ( eDirection == word::MOVE_RIGHT ) && ( xWordCursor->gotoNextWord( bExpand ) == sal_False ) )
+                    else if( ( eDirection == word::MOVE_RIGHT ) && !xWordCursor->gotoNextWord( bExpand ) )
                         break;
                 }
             }
@@ -343,12 +343,13 @@ SwVbaSelection::Move( const uno::Any& _unit, const uno::Any& _count, const uno::
         }
         default:
         {
-            throw uno::RuntimeException("Not implemented", uno::Reference< uno::XInterface >() );
+            throw uno::RuntimeException("Not implemented" );
         }
     }
 }
 
-void SwVbaSelection::NextCell( sal_Int32 nCount, word::E_DIRECTION eDirection ) throw ( uno::RuntimeException )
+void SwVbaSelection::NextCell(sal_Int32 nCount, word::E_DIRECTION eDirection)
+    throw (css::script::BasicErrorException, uno::RuntimeException)
 {
     uno::Reference< beans::XPropertySet > xCursorProps( mxTextViewCursor, uno::UNO_QUERY_THROW );
     uno::Reference< text::XTextTable > xTextTable;
@@ -357,7 +358,7 @@ void SwVbaSelection::NextCell( sal_Int32 nCount, word::E_DIRECTION eDirection )
     xCursorProps->getPropertyValue("Cell") >>= xCell;
     if( !xTextTable.is() || !xCell.is() )
     {
-        DebugHelper::exception(SbERR_BAD_ARGUMENT, OUString());
+        DebugHelper::basicexception(ERRCODE_BASIC_BAD_ARGUMENT, OUString());
         return;
     }
     uno::Reference< beans::XPropertySet > xCellProps( xCell, uno::UNO_QUERY_THROW );
@@ -389,7 +390,7 @@ void SwVbaSelection::NextCell( sal_Int32 nCount, word::E_DIRECTION eDirection )
         }
         default:
         {
-            DebugHelper::exception(SbERR_BAD_ARGUMENT, OUString());
+            DebugHelper::basicexception(ERRCODE_BASIC_BAD_ARGUMENT, OUString());
             return;
         }
     }
@@ -399,7 +400,7 @@ void SwVbaSelection::NextCell( sal_Int32 nCount, word::E_DIRECTION eDirection )
 }
 
 void SAL_CALL
-SwVbaSelection::MoveRight( const uno::Any& _unit, const uno::Any& _count, const uno::Any& _extend ) throw ( uno::RuntimeException, std::exception )
+SwVbaSelection::MoveRight(const uno::Any& _unit, const uno::Any& _count, const uno::Any& _extend) throw (script::BasicErrorException, uno::RuntimeException, std::exception)
 {
     sal_Int32 nCount = 1;
 
@@ -419,7 +420,7 @@ SwVbaSelection::MoveRight( const uno::Any& _unit, const uno::Any& _count, const
 }
 
 void SAL_CALL
-SwVbaSelection::MoveLeft( const uno::Any& _unit, const uno::Any& _count, const uno::Any& _extend ) throw ( uno::RuntimeException, std::exception )
+SwVbaSelection::MoveLeft(const uno::Any& _unit, const uno::Any& _count, const uno::Any& _extend) throw (script::BasicErrorException, uno::RuntimeException, std::exception)
 {
     sal_Int32 nCount = 1;
     if( _count.hasValue() )
@@ -438,7 +439,7 @@ SwVbaSelection::MoveLeft( const uno::Any& _unit, const uno::Any& _count, const u
 }
 
 void SAL_CALL
-SwVbaSelection::MoveDown( const uno::Any& _unit, const uno::Any& _count, const uno::Any& _extend ) throw ( uno::RuntimeException, std::exception )
+SwVbaSelection::MoveDown(const uno::Any& _unit, const uno::Any& _count, const uno::Any& _extend) throw (script::BasicErrorException, uno::RuntimeException, std::exception)
 {
     sal_Int32 nCount = 1;
 
@@ -458,7 +459,7 @@ SwVbaSelection::MoveDown( const uno::Any& _unit, const uno::Any& _count, const u
 }
 
 void SAL_CALL
-SwVbaSelection::MoveUp( const uno::Any& _unit, const uno::Any& _count, const uno::Any& _extend ) throw ( uno::RuntimeException, std::exception )
+SwVbaSelection::MoveUp(const uno::Any& _unit, const uno::Any& _count, const uno::Any& _extend) throw (script::BasicErrorException, uno::RuntimeException, std::exception)
 {
     sal_Int32 nCount = 1;
 
@@ -557,7 +558,7 @@ uno::Reference< word::XRange > SAL_CALL SwVbaSelection::GoTo( const uno::Any& _w
 {
     sal_Int32 nWhat = 0;
     if( !( _what >>= nWhat ) )
-         DebugHelper::exception(SbERR_BAD_ARGUMENT, OUString());
+         DebugHelper::basicexception(ERRCODE_BASIC_BAD_ARGUMENT, OUString());
     switch( nWhat )
     {
         case word::WdGoToItem::wdGoToBookmark:
@@ -649,11 +650,11 @@ uno::Reference< word::XRange > SAL_CALL SwVbaSelection::GoTo( const uno::Any& _w
             if( nPage != 0 )
                 xPageCursor->jumpToPage( ( sal_Int16 )( nPage ) );
             else
-                throw uno::RuntimeException("Not implemented", uno::Reference< uno::XInterface >() );
+                throw uno::RuntimeException("Not implemented" );
             break;
         }
         default:
-            throw uno::RuntimeException("Not implemented", uno::Reference< uno::XInterface >() );
+            throw uno::RuntimeException("Not implemented" );
     }
     return getRange();
 }
@@ -694,9 +695,9 @@ uno::Any SAL_CALL SwVbaSelection::Information( sal_Int32 _type ) throw (uno::Run
             uno::Reference< text::XTextTable > xTextTable;
             xCursorProps->getPropertyValue("TextTable") >>= xTextTable;
             if( xTextTable.is() )
-                result = uno::makeAny( sal_True );
+                result = uno::makeAny( true );
             else
-                result = uno::makeAny( sal_False );
+                result = uno::makeAny( false );
             break;
         }
         case word::WdInformation::wdHeaderFooterType:
@@ -765,7 +766,7 @@ uno::Any SAL_CALL SwVbaSelection::Information( sal_Int32 _type ) throw (uno::Run
             break;
         }
         default:
-            throw uno::RuntimeException("Not implemented", uno::Reference< uno::XInterface >() );
+            throw uno::RuntimeException("Not implemented" );
     }
     return result;
 }
@@ -797,8 +798,8 @@ SwVbaSelection::Tables( const uno::Any& aIndex ) throw (uno::RuntimeException, s
     if( xTextTable.is() )
     {
             uno::Reference< css::text::XTextDocument > xTextDoc( mxModel, uno::UNO_QUERY_THROW );
-            uno::Reference< word::XTable > xVBATbl = new SwVbaTable( mxParent, mxContext, xTextDoc, xTextTable );
-            aRet <<= xVBATbl;
+            uno::Reference< word::XTable > xVBATable = new SwVbaTable( mxParent, mxContext, xTextDoc, xTextTable );
+            aRet <<= xVBATable;
             return aRet;
     }
 
@@ -811,13 +812,13 @@ SwVbaSelection::Tables( const uno::Any& aIndex ) throw (uno::RuntimeException, s
     SwXTextTableCursor* pTTCursor = dynamic_cast< SwXTextTableCursor* >( xTextTableCursor.get() );
     if ( pTTCursor )
     {
-        SwFrmFmt* pFmt = pTTCursor->GetFrmFmt();
-        if ( pFmt )
+        SwFrameFormat* pFormat = pTTCursor->GetFrameFormat();
+        if ( pFormat )
         {
-            uno::Reference< text::XTextTable > xTbl = SwXTextTables::GetObject(*pFmt);
+            uno::Reference< text::XTextTable > xTable = SwXTextTables::GetObject(*pFormat);
             uno::Reference< css::text::XTextDocument > xTextDoc( mxModel, uno::UNO_QUERY_THROW );
-            uno::Reference< word::XTable > xVBATbl = new SwVbaTable( mxParent, mxContext, xTextDoc, xTbl );
-            aRet <<= xVBATbl;
+            uno::Reference< word::XTable > xVBATable = new SwVbaTable( mxParent, mxContext, xTextDoc, xTable );
+            aRet <<= xVBATable;
         }
     }
     return aRet;
