@@ -9,7 +9,7 @@
 
 #include <uinums.hxx>
 
-#include <cppuhelper/implbase2.hxx>
+#include <cppuhelper/implbase.hxx>
 
 #include <com/sun/star/container/XIndexReplace.hpp>
 #include <com/sun/star/container/XNamed.hpp>
@@ -42,7 +42,7 @@ using namespace ::xmloff::token;
 namespace sw {
 
 class StoredChapterNumberingRules
-    : public ::cppu::WeakImplHelper2<container::XNamed,container::XIndexReplace>
+    : public ::cppu::WeakImplHelper<container::XNamed,container::XIndexReplace>
 {
 private:
     // TODO in case this ever becomes accessible via api need a invalidate
@@ -72,7 +72,7 @@ public:
 
     // XNamed
     virtual OUString SAL_CALL getName()
-        throw (uno::RuntimeException, std::exception) SAL_OVERRIDE
+        throw (uno::RuntimeException, std::exception) override
     {
         SolarMutexGuard g;
         SwNumRulesWithName const* pRules(m_rNumRules.GetRules(m_nIndex));
@@ -84,7 +84,7 @@ public:
     }
 
     virtual void SAL_CALL setName(OUString const& rName)
-        throw (uno::RuntimeException, std::exception) SAL_OVERRIDE
+        throw (uno::RuntimeException, std::exception) override
     {
         SolarMutexGuard g;
         SwNumRulesWithName *const pRules(GetOrCreateRules());
@@ -93,27 +93,27 @@ public:
 
     // XElementAccess
     virtual uno::Type SAL_CALL getElementType()
-        throw (uno::RuntimeException, std::exception) SAL_OVERRIDE
+        throw (uno::RuntimeException, std::exception) override
     {
         return ::cppu::UnoType<uno::Sequence<beans::PropertyValue>>::get();
     }
 
     virtual ::sal_Bool SAL_CALL hasElements()
-        throw (uno::RuntimeException, std::exception) SAL_OVERRIDE
+        throw (uno::RuntimeException, std::exception) override
     {
         return sal_True;
     }
 
     // XIndexAccess
     virtual sal_Int32 SAL_CALL getCount()
-        throw (uno::RuntimeException, std::exception) SAL_OVERRIDE
+        throw (uno::RuntimeException, std::exception) override
     {
         return MAXLEVEL;
     }
 
     virtual uno::Any SAL_CALL getByIndex(sal_Int32 nIndex)
         throw (lang::IndexOutOfBoundsException, lang::WrappedTargetException,
-               uno::RuntimeException, std::exception) SAL_OVERRIDE
+               uno::RuntimeException, std::exception) override
     {
         if (nIndex < 0 || MAXLEVEL <= nIndex)
             throw lang::IndexOutOfBoundsException();
@@ -124,18 +124,18 @@ public:
         {
             return uno::Any();
         }
-        SwNumFmt const* pNumFmt(0);
-        OUString const* pCharStyleName(0);
-        pRules->GetNumFmt(nIndex, pNumFmt, pCharStyleName);
-        if (!pNumFmt)
+        SwNumFormat const* pNumFormat(nullptr);
+        OUString const* pCharStyleName(nullptr);
+        pRules->GetNumFormat(nIndex, pNumFormat, pCharStyleName);
+        if (!pNumFormat)
         {   // the dialog only fills in those levels that are non-default
             return uno::Any(); // the export will ignore this level, yay
         }
         assert(pCharStyleName);
         OUString dummy; // pass in empty HeadingStyleName - can't import anyway
         uno::Sequence<beans::PropertyValue> const ret(
-            SwXNumberingRules::GetPropertiesForNumFmt(
-                *pNumFmt, *pCharStyleName, &dummy));
+            SwXNumberingRules::GetPropertiesForNumFormat(
+                *pNumFormat, *pCharStyleName, &dummy));
         return uno::makeAny(ret);
     }
 
@@ -144,7 +144,7 @@ public:
             sal_Int32 nIndex, uno::Any const& rElement)
         throw (lang::IllegalArgumentException, lang::IndexOutOfBoundsException,
                lang::WrappedTargetException, uno::RuntimeException,
-               std::exception) SAL_OVERRIDE
+               std::exception) override
     {
         if (nIndex < 0 || MAXLEVEL <= nIndex)
             throw lang::IndexOutOfBoundsException();
@@ -154,15 +154,15 @@ public:
                     static_cast< ::cppu::OWeakObject*>(this), 1);
 
         SolarMutexGuard g;
-        SwNumFmt numFmt;
+        SwNumFormat aNumberFormat;
         OUString charStyleName;
-        SwXNumberingRules::SetPropertiesToNumFmt(
-            numFmt,
+        SwXNumberingRules::SetPropertiesToNumFormat(
+            aNumberFormat,
             charStyleName,
-            0, 0, 0, 0, 0,
+            nullptr, nullptr, nullptr, nullptr, nullptr,
             props);
         SwNumRulesWithName *const pRules(GetOrCreateRules());
-        pRules->SetNumFmt(nIndex, numFmt, charStyleName);
+        pRules->SetNumFormat(nIndex, aNumberFormat, charStyleName);
     }
 };
 
@@ -189,9 +189,9 @@ public:
                                GetXMLToken(XML_N_SVG), XML_NAMESPACE_SVG);
     }
 
-    virtual void _ExportAutoStyles() SAL_OVERRIDE {}
-    virtual void _ExportMasterStyles() SAL_OVERRIDE {}
-    virtual void _ExportContent() SAL_OVERRIDE {}
+    virtual void _ExportAutoStyles() override {}
+    virtual void _ExportMasterStyles() override {}
+    virtual void _ExportContent() override {}
 
     void ExportRule(SvxXMLNumRuleExport & rExport,
             uno::Reference<container::XIndexReplace> const& xRule)
@@ -338,7 +338,7 @@ public:
     {
     }
 
-    virtual void EndElement() SAL_OVERRIDE
+    virtual void EndElement() override
     {
         assert(m_Contexts.size() < SwChapterNumRules::nMaxRules);
         for (auto iter = m_Contexts.begin(); iter != m_Contexts.end(); ++iter)
@@ -355,7 +355,7 @@ public:
 
     virtual SvXMLImportContext * CreateChildContext(
         sal_uInt16 const nPrefix, OUString const& rLocalName,
-        uno::Reference<xml::sax::XAttributeList> const& xAttrList) SAL_OVERRIDE
+        uno::Reference<xml::sax::XAttributeList> const& xAttrList) override
     {
         if (XML_NAMESPACE_TEXT == nPrefix && IsXMLToken(rLocalName, XML_OUTLINE_STYLE))
         {
@@ -390,14 +390,14 @@ public:
     StoredChapterNumberingImport(
             uno::Reference<uno::XComponentContext> const& xContext,
             SwChapterNumRules & rNumRules)
-        : SvXMLImport(xContext, "sw::StoredChapterNumberingImport", IMPORT_ALL)
+        : SvXMLImport(xContext, "sw::StoredChapterNumberingImport", SvXMLImportFlags::ALL)
         , m_rNumRules(rNumRules)
     {
     }
 
     virtual SvXMLImportContext * CreateContext(
         sal_uInt16 const nPrefix, OUString const& rLocalName,
-        uno::Reference<xml::sax::XAttributeList> const& xAttrList) SAL_OVERRIDE
+        uno::Reference<xml::sax::XAttributeList> const& xAttrList) override
     {
         if (XML_NAMESPACE_OFFICE == nPrefix && IsXMLToken(rLocalName, XML_STYLES))
         {
@@ -426,7 +426,7 @@ void ExportStoredChapterNumberingRules(SwChapterNumRules & rRules,
     uno::Reference<xml::sax::XDocumentHandler> const xHandler(
             xWriter, uno::UNO_QUERY);
 
-    StoredChapterNumberingExport exp(xContext, rFileName, xWriter);
+    uno::Reference<StoredChapterNumberingExport> exp(new StoredChapterNumberingExport(xContext, rFileName, xWriter));
 
     // if style name contains a space then name != display-name
     // ... and the import needs to map from name to display-name then!
@@ -438,9 +438,9 @@ void ExportStoredChapterNumberingRules(SwChapterNumRules & rRules,
         {
             for (size_t j = 0; j < MAXLEVEL; ++j)
             {
-                SwNumFmt const* pDummy(0);
-                OUString const* pCharStyleName(0);
-                pRule->GetNumFmt(j, pDummy, pCharStyleName);
+                SwNumFormat const* pDummy(nullptr);
+                OUString const* pCharStyleName(nullptr);
+                pRule->GetNumFormat(j, pDummy, pCharStyleName);
                 if (pCharStyleName && !pCharStyleName->isEmpty())
                 {
                     charStyles.insert(*pCharStyleName);
@@ -452,7 +452,7 @@ void ExportStoredChapterNumberingRules(SwChapterNumRules & rRules,
 
     try
     {
-        exp.ExportRules(charStyles, numRules);
+        exp->ExportRules(charStyles, numRules);
     }
     catch (uno::Exception const& e)
     {
