@@ -207,18 +207,17 @@ static const SwFieldPack aSwFields[] =
 static SwWrtShell* lcl_GetShell()
 {
     SwView* pView;
-    if ( 0 != (pView = ::GetActiveView()) )
+    if ( nullptr != (pView = ::GetActiveView()) )
         return pView->GetWrtShellPtr();
     OSL_FAIL("no current shell found!");
-    return 0;
+    return nullptr;
 }
 
 inline sal_uInt16 GetPackCount() {  return sizeof(aSwFields) / sizeof(SwFieldPack); }
 
 // FieldManager controls inserting and updating of fields
 SwFieldMgr::SwFieldMgr(SwWrtShell* pSh ) :
-    pModule(0),
-    pMacroItem(0),
+    pMacroItem(nullptr),
     pWrtShell(pSh),
     bEvalExp(true)
 {
@@ -238,13 +237,13 @@ bool  SwFieldMgr::CanInsertRefMark( const OUString& rStr )
     OSL_ENSURE(pSh, "no SwWrtShell found");
     if(pSh)
     {
-        sal_uInt16 nCnt = pSh->GetCrsrCnt();
+        sal_uInt16 nCnt = pSh->GetCursorCnt();
 
-        // the last Crsr doesn't have to be a spanned selection
-        if( 1 < nCnt && !pSh->SwCrsrShell::HasSelection() )
+        // the last Cursor doesn't have to be a spanned selection
+        if( 1 < nCnt && !pSh->SwCursorShell::HasSelection() )
             --nCnt;
 
-        bRet =  2 > nCnt && 0 == pSh->GetRefMark( rStr );
+        bRet =  2 > nCnt && nullptr == pSh->GetRefMark( rStr );
     }
     return bRet;
 }
@@ -258,25 +257,25 @@ void SwFieldMgr::RemoveFieldType(sal_uInt16 nResId, const OUString& rName )
         pSh->RemoveFieldType(nResId, rName);
 }
 
-sal_uInt16 SwFieldMgr::GetFieldTypeCount(sal_uInt16 nResId) const
+size_t SwFieldMgr::GetFieldTypeCount(sal_uInt16 nResId) const
 {
     SwWrtShell * pSh = pWrtShell ? pWrtShell : lcl_GetShell();
     OSL_ENSURE(pSh, "no SwWrtShell found");
     return pSh ? pSh->GetFieldTypeCount(nResId) : 0;
 }
 
-SwFieldType* SwFieldMgr::GetFieldType(sal_uInt16 nResId, sal_uInt16 nId) const
+SwFieldType* SwFieldMgr::GetFieldType(sal_uInt16 nResId, size_t nField) const
 {
     SwWrtShell * pSh = pWrtShell ? pWrtShell : lcl_GetShell();
     OSL_ENSURE(pSh, "no SwWrtShell found");
-    return pSh ? pSh->GetFieldType(nId, nResId) : 0;
+    return pSh ? pSh->GetFieldType(nField, nResId) : nullptr;
 }
 
 SwFieldType* SwFieldMgr::GetFieldType(sal_uInt16 nResId, const OUString& rName) const
 {
     SwWrtShell * pSh = pWrtShell ? pWrtShell : lcl_GetShell();
     OSL_ENSURE(pSh, "no SwWrtShell found");
-    return pSh ? pSh->GetFieldType(nResId, rName) : 0;
+    return pSh ? pSh->GetFieldType(nResId, rName) : nullptr;
 }
 
 // determine current field
@@ -286,7 +285,7 @@ SwField* SwFieldMgr::GetCurField()
     if ( pSh )
         pCurField = pSh->GetCurField( true );
     else
-        pCurField = NULL;
+        pCurField = nullptr;
 
     // initialise strings and format
     aCurPar1.clear();
@@ -295,7 +294,7 @@ SwField* SwFieldMgr::GetCurField()
     nCurFormat = 0;
 
     if(!pCurField)
-        return 0;
+        return nullptr;
 
     // preprocess current values; determine parameter 1 and parameter 2
     // as well as the format
@@ -456,8 +455,8 @@ bool SwFieldMgr::GetSubTypes(sal_uInt16 nTypeId, std::vector<OUString>& rToFill)
             case TYP_USERFLD:
             {
 
-                const sal_uInt16 nCount = pSh->GetFieldTypeCount();
-                for(sal_uInt16 i = 0; i < nCount; ++i)
+                const size_t nCount = pSh->GetFieldTypeCount();
+                for(size_t i = 0; i < nCount; ++i)
                 {
                     SwFieldType* pFieldType = pSh->GetFieldType( i );
                     const sal_uInt16 nWhich = pFieldType->Which();
@@ -731,7 +730,7 @@ bool SwFieldMgr::GoNextPrev( bool bNext, SwFieldType* pTyp )
     if (pTyp && pTyp->Which() == RES_DBFLD)
     {
         // for fieldcommand-edit (hop to all DB fields)
-        return pSh->MoveFieldType( 0, bNext, RES_DBFLD );
+        return pSh->MoveFieldType( nullptr, bNext, RES_DBFLD );
     }
 
     return pTyp && pSh && pSh->MoveFieldType( pTyp, bNext );
@@ -756,7 +755,7 @@ sal_uInt16 SwFieldMgr::GetCurTypeId() const
 bool SwFieldMgr::InsertField(
     const SwInsertField_Data& rData)
 {
-    SwField* pField   = 0;
+    SwField* pField   = nullptr;
     bool bExp = false;
     bool bTable = false;
     bool bPageVar = false;
@@ -954,10 +953,10 @@ bool SwFieldMgr::InsertField(
             //JP 28.08.95: DDE-Topics/-Items can have blanks in their names!
             //              That's not yet considered here.
             sal_Int32 nIndex = 0;
-            OUString sCmd = rData.m_sPar2.replaceFirst(OUString(' '), OUString(sfx2::cTokenSeparator), &nIndex);
+            OUString sCmd = rData.m_sPar2.replaceFirst(" ", OUString(sfx2::cTokenSeparator), &nIndex);
             if (nIndex>=0 && ++nIndex<sCmd.getLength())
             {
-                sCmd = sCmd.replaceFirst(OUString(' '), OUString(sfx2::cTokenSeparator), &nIndex);
+                sCmd = sCmd.replaceFirst(" ", OUString(sfx2::cTokenSeparator), &nIndex);
             }
 
             SwDDEFieldType aType( rData.m_sPar1, sCmd, static_cast<SfxLinkUpdateMode>(nFormatId) );
@@ -1069,7 +1068,7 @@ bool SwFieldMgr::InsertField(
 #if HAVE_FEATURE_DBCONNECTIVITY
             SwDBData aDBData;
 
-            // excract DBName from rData.m_sPar1. Format: DBName.TableName.CommandType.ExpStrg
+            // extract DBName from rData.m_sPar1. Format: DBName.TableName.CommandType.ExpStrg
             sal_Int32 nTablePos = rData.m_sPar1.indexOf(DB_DELIM);
             sal_Int32 nCmdTypePos = -1;
             sal_Int32 nExpPos = -1;
@@ -1193,9 +1192,6 @@ bool SwFieldMgr::InsertField(
                     new SwInputField( pTyp, rData.m_sPar1, rData.m_sPar2, nSubType|nsSwExtendedSubType::SUB_INVISIBLE, nFormatId);
                 pField = pInpField;
             }
-
-            // start dialog
-            pCurShell->StartInputFieldDlg(pField, false, rData.m_pParent);
             break;
         }
 
@@ -1255,7 +1251,7 @@ bool SwFieldMgr::InsertField(
 
     case TYP_FORMELFLD:
         {
-            if(pCurShell->GetFrmType(0,false) & FrmTypeFlags::TABLE)
+            if(pCurShell->GetFrameType(nullptr,false) & FrameTypeFlags::TABLE)
             {
                 pCurShell->StartAllAction();
 
@@ -1337,6 +1333,14 @@ bool SwFieldMgr::InsertField(
 
     pCurShell->Insert( *pField );
 
+    if (TYP_INPUTFLD == rData.m_nTypeId)
+    {
+        // start dialog, not before the field is inserted tdf#99529
+        pCurShell->Left(CRSR_SKIP_CHARS,
+                false, (INP_VAR == (nSubType & 0xff)) ? 1 : 2, false );
+        pCurShell->StartInputFieldDlg(pField, false, rData.m_pParent);
+    }
+
     if(bExp && bEvalExp)
         pCurShell->UpdateExpFields(true);
 
@@ -1349,7 +1353,7 @@ bool SwFieldMgr::InsertField(
     else if( bPageVar )
         static_cast<SwRefPageGetFieldType*>(pCurShell->GetFieldType( 0, RES_REFPAGEGETFLD ))->UpdateFields();
     else if( TYP_GETREFFLD == rData.m_nTypeId )
-        pField->GetTyp()->ModifyNotification( 0, 0 );
+        pField->GetTyp()->ModifyNotification( nullptr, nullptr );
 
     // delete temporary field
     delete pField;
@@ -1362,14 +1366,14 @@ bool SwFieldMgr::InsertField(
 void SwFieldMgr::UpdateCurField(sal_uLong nFormat,
                             const OUString& rPar1,
                             const OUString& rPar2,
-                            SwField * _pTmpField) // #111840#
+                            SwField * _pTmpField)
 {
     // change format
     OSL_ENSURE(pCurField, "no field at CursorPos");
 
     bool bDelete = false;
     SwField *pTmpField;       // mb: fixed memory leak
-    if (NULL != _pTmpField)
+    if (nullptr != _pTmpField)
     {
         pTmpField = _pTmpField;
     }
@@ -1401,10 +1405,10 @@ void SwFieldMgr::UpdateCurField(sal_uLong nFormat,
             // DDE-Topics/-Items can have blanks in their names!
             //  That's not yet considered here!
             sal_Int32 nIndex = 0;
-            sPar2 = sPar2.replaceFirst(OUString(' '), OUString(sfx2::cTokenSeparator), &nIndex );
+            sPar2 = sPar2.replaceFirst(" ", OUString(sfx2::cTokenSeparator), &nIndex );
             if (nIndex>=0 && ++nIndex<sPar2.getLength())
             {
-                sPar2 = sPar2.replaceFirst(OUString(' '), OUString(sfx2::cTokenSeparator), &nIndex);
+                sPar2 = sPar2.replaceFirst(" ", OUString(sfx2::cTokenSeparator), &nIndex);
             }
             break;
         }
@@ -1538,7 +1542,7 @@ void SwFieldMgr::UpdateCurField(sal_uLong nFormat,
 // explicitly evaluate ExpressionFields
 void SwFieldMgr::EvalExpFields(SwWrtShell* pSh)
 {
-    if (pSh == NULL)
+    if (pSh == nullptr)
         pSh = pWrtShell ? pWrtShell : ::lcl_GetShell();
 
     if(pSh)
@@ -1707,7 +1711,7 @@ Reference<XNumberingTypeInfo> SwFieldMgr::GetNumberingInfo() const
     {
         Reference<XComponentContext>         xContext( ::comphelper::getProcessComponentContext() );
         Reference<XDefaultNumberingProvider> xDefNum = text::DefaultNumberingProvider::create(xContext);
-        const_cast<SwFieldMgr*>(this)->xNumberingInfo = Reference<XNumberingTypeInfo>(xDefNum, UNO_QUERY);
+        const_cast<SwFieldMgr*>(this)->xNumberingInfo.set(xDefNum, UNO_QUERY);
     }
     return xNumberingInfo;
 }
