@@ -79,7 +79,7 @@
 #include <svx/dialogs.hrc>
 #include <osl/mutex.hxx>
 
-#include <boost/scoped_ptr.hpp>
+#include <memory>
 
 using namespace ::com::sun::star;
 SFX_IMPL_NAMED_VIEWFACTORY(SwPagePreview, "PrintPreview")
@@ -99,7 +99,6 @@ void SwPagePreview::InitInterface_Impl()
                                             RID_PVIEW_TOOLBOX);
 }
 
-TYPEINIT1(SwPagePreview,SfxViewShell)
 
 #define SWVIEWFLAGS ( SfxViewShellFlags::CAN_PRINT | SfxViewShellFlags::HAS_PRINTOPTIONS )
 
@@ -148,12 +147,12 @@ class SwPreviewZoomDlg : public SvxStandardDialog
     VclPtr<NumericField> m_pRowEdit;
     VclPtr<NumericField> m_pColEdit;
 
-    virtual void  Apply() SAL_OVERRIDE;
+    virtual void  Apply() override;
 
 public:
-    SwPreviewZoomDlg( SwPagePreviewWin& rParent );
+    explicit SwPreviewZoomDlg( SwPagePreviewWin& rParent );
     virtual ~SwPreviewZoomDlg();
-    virtual void dispose() SAL_OVERRIDE;
+    virtual void dispose() override;
 };
 
 SwPreviewZoomDlg::SwPreviewZoomDlg( SwPagePreviewWin& rParent )
@@ -188,11 +187,11 @@ void  SwPreviewZoomDlg::Apply()
 // all for SwPagePreviewWin
 SwPagePreviewWin::SwPagePreviewWin( vcl::Window *pParent, SwPagePreview& rPView )
     : Window(pParent, WinBits(WB_CLIPCHILDREN))
-    , mpViewShell(0)
+    , mpViewShell(nullptr)
     , mrView(rPView)
     , mbCalcScaleForPreviewLayout(true)
     , maPaintedPreviewDocRect(Rectangle(0,0,0,0))
-    , mpPgPreviewLayout(NULL)
+    , mpPgPreviewLayout(nullptr)
 {
     SetOutDevViewType( OUTDEV_VIEWTYPE_PRINTPREVIEW );
     SetHelpId(HID_PAGEPREVIEW);
@@ -334,6 +333,7 @@ bool SwPagePreviewWin::MovePage( int eMoveMode )
         nNewSttPage = nPageCount;
         SetSelectedPage( nPageCount );
         break;
+
     case MV_SELPAGE:
         // <nNewSttPage> and <SelectedPage()> are already set.
         // not start at first column, only if the
@@ -505,12 +505,12 @@ void SwPagePreviewWin::MouseButtonDown( const MouseEvent& rMEvt )
         {
             // close page preview, set new cursor position and switch to
             // normal view.
-            OUString sNewCrsrPos = OUString::number( aDocPos.X() ) + ";" +
+            OUString sNewCursorPos = OUString::number( aDocPos.X() ) + ";" +
                                    OUString::number( aDocPos.Y() ) + ";";
-            mrView.SetNewCrsrPos( sNewCrsrPos );
+            mrView.SetNewCursorPos( sNewCursorPos );
 
-            SfxViewFrame *pTmpFrm = mrView.GetViewFrame();
-            pTmpFrm->GetBindings().Execute( SID_VIEWSHELL0, NULL, 0,
+            SfxViewFrame *pTmpFrame = mrView.GetViewFrame();
+            pTmpFrame->GetBindings().Execute( SID_VIEWSHELL0, nullptr, 0,
                                                     SfxCallMode::ASYNCHRON );
         }
         else if ( bIsDocPos || bPosInEmptyPage )
@@ -626,7 +626,7 @@ void SwPagePreview::_ExecPgUpAndPgDown( const bool  _bPgUp,
             const int eMvMode = _bPgUp ?
                                 SwPagePreviewWin::MV_PAGE_UP :
                                 SwPagePreviewWin::MV_PAGE_DOWN;
-            if ( ChgPage( eMvMode, true ) )
+            if ( ChgPage( eMvMode ) )
                 pViewWin->Invalidate();
         }
         else
@@ -758,7 +758,7 @@ void  SwPagePreview::Execute( SfxRequest &rReq )
         {
             const SfxItemSet *pArgs = rReq.GetArgs();
             const SfxPoolItem* pItem;
-            boost::scoped_ptr<AbstractSvxZoomDialog> pDlg;
+            std::unique_ptr<AbstractSvxZoomDialog> pDlg;
             if(!pArgs)
             {
                 SfxItemSet aCoreSet(GetPool(), SID_ATTR_ZOOM, SID_ATTR_ZOOM);
@@ -856,7 +856,7 @@ void  SwPagePreview::Execute( SfxRequest &rReq )
                 {
                     pViewWin->SetSelectedPage( nNewSelectedPage );
                     pViewWin->SetSttPage( nNewStartPage );
-                    bRefresh = ChgPage( SwPagePreviewWin::MV_SELPAGE, true );
+                    bRefresh = ChgPage( SwPagePreviewWin::MV_SELPAGE );
                 }
                 GetViewShell()->ShowPreviewSelection( nNewSelectedPage );
                 // invalidate page status.
@@ -880,6 +880,24 @@ void  SwPagePreview::Execute( SfxRequest &rReq )
             _ExecPgUpAndPgDown( rReq.GetSlot() == FN_PAGEUP, &rReq );
             break;
         }
+        case SID_JUMP_TO_SPECIFIC_PAGE:
+        {
+            sal_uInt16 nPageNum = 1;
+            const SfxItemSet *pArgs = rReq.GetArgs();
+            if( pArgs && pArgs->Count())
+            {
+                nPageNum = static_cast<const SfxUInt16Item &>(pArgs->Get(SID_JUMP_TO_SPECIFIC_PAGE)).GetValue();
+
+                if( nPageNum > 0 && nPageNum <= mnPageCount )
+                {
+                    pViewWin->SetSttPage( nPageNum);
+                    pViewWin->SetSelectedPage( nPageNum );
+                    ChgPage( SwPagePreviewWin::MV_SPECIFIC_PAGE, false );
+                    ScrollViewSzChg();
+                }
+            }
+        }
+        break;
         case FN_START_OF_LINE:
         case FN_START_OF_DOCUMENT:
             pViewWin->SetSelectedPage( 1 );
@@ -890,12 +908,12 @@ void  SwPagePreview::Execute( SfxRequest &rReq )
             eMvMode = SwPagePreviewWin::MV_DOC_END; bRetVal = true; goto MOVEPAGE;
 MOVEPAGE:
             {
-                bool nRet = ChgPage( eMvMode, true );
+                bool bRet = ChgPage( eMvMode );
                 // return value fuer Basic
                 if(bRetVal)
-                    rReq.SetReturnValue(SfxBoolItem(rReq.GetSlot(), !nRet));
+                    rReq.SetReturnValue(SfxBoolItem(rReq.GetSlot(), !bRet));
 
-                bRefresh = nRet;
+                bRefresh = bRet;
                 rReq.Done();
             }
             break;
@@ -939,8 +957,8 @@ MOVEPAGE:
             if(GetViewShell()->IsDummyPage( nSelPage ) && GetViewShell()->IsDummyPage( --nSelPage ))
                 nSelPage +=2;
             SetNewPage( nSelPage );
-            SfxViewFrame *pTmpFrm = GetViewFrame();
-            pTmpFrm->GetBindings().Execute( SID_VIEWSHELL0, NULL, 0,
+            SfxViewFrame *pTmpFrame = GetViewFrame();
+            pTmpFrame->GetBindings().Execute( SID_VIEWSHELL0, nullptr, 0,
                                                     SfxCallMode::ASYNCHRON );
         }
         break;
@@ -1144,6 +1162,7 @@ void SwPagePreview::Init(const SwViewOption * pPrefs)
     aOpt.SetTable( true );
     aOpt.SetSnap( false );
     aOpt.SetGridVisible( false );
+    aOpt.SetHideWhitespaceMode( false );
 
     GetViewShell()->ApplyViewOptions( aOpt );
     GetViewShell()->ApplyAccessiblityOptions(SW_MOD()->GetAccessibilityOptions());
@@ -1164,15 +1183,15 @@ SwPagePreview::SwPagePreview(SfxViewFrame *pViewFrame, SfxViewShell* pOldSh):
     pViewWin( VclPtr<SwPagePreviewWin>::Create(&(GetViewFrame())->GetWindow(), *this ) ),
     nNewPage(USHRT_MAX),
     sPageStr(SW_RES(STR_PAGE)),
-    pHScrollbar(0),
-    pVScrollbar(0),
+    pHScrollbar(nullptr),
+    pVScrollbar(nullptr),
     pScrollFill(VclPtr<ScrollBarBox>::Create( &pViewFrame->GetWindow(),
         pViewFrame->GetFrame().GetParentFrame() ? 0 : WB_SIZEABLE )),
     mnPageCount( 0 ),
     mbResetFormDesignMode( false ),
     mbFormDesignModeToReset( false )
 {
-    SetName(OUString("PageView" ));
+    SetName("PageView");
     SetWindow( pViewWin );
     SetHelpId(SW_PAGEPREVIEW);
     _CreateScrollbar( true );
@@ -1191,15 +1210,15 @@ SwPagePreview::SwPagePreview(SfxViewFrame *pViewFrame, SfxViewShell* pOldSh):
 
     SwViewShell *pVS, *pNew;
 
-    if( pOldSh && pOldSh->IsA( TYPE( SwPagePreview ) ) )
+    if( pOldSh && dynamic_cast<const SwPagePreview *>(pOldSh) != nullptr )
         pVS = static_cast<SwPagePreview*>(pOldSh)->GetViewShell();
     else
     {
-        if( pOldSh && pOldSh->IsA( TYPE( SwView ) ) )
+        if( pOldSh && dynamic_cast<const SwView *>(pOldSh) != nullptr )
         {
             pVS = static_cast<SwView*>(pOldSh)->GetWrtShellPtr();
             // save the current ViewData of the previous SwView
-            pOldSh->WriteUserData( sSwViewData, false );
+            pOldSh->WriteUserData( sSwViewData );
         }
         else
             pVS = GetDocShell()->GetWrtShell();
@@ -1207,7 +1226,7 @@ SwPagePreview::SwPagePreview(SfxViewFrame *pViewFrame, SfxViewShell* pOldSh):
         {
             // Set the current page as the first.
             sal_uInt16 nPhysPg, nVirtPg;
-            static_cast<SwCrsrShell*>(pVS)->GetPageNum( nPhysPg, nVirtPg, true, false );
+            static_cast<SwCursorShell*>(pVS)->GetPageNum( nPhysPg, nVirtPg, true, false );
             if( 1 != pViewWin->GetCol() && 1 == nPhysPg )
                 --nPhysPg;
             pViewWin->SetSttPage( nPhysPg );
@@ -1223,11 +1242,11 @@ SwPagePreview::SwPagePreview(SfxViewFrame *pViewFrame, SfxViewShell* pOldSh):
     }
 
     if( pVS )
-        pNew = new SwViewShell( *pVS, pViewWin, 0, VSHELLFLAG_ISPREVIEW );
+        pNew = new SwViewShell( *pVS, pViewWin, nullptr, VSHELLFLAG_ISPREVIEW );
     else
         pNew = new SwViewShell(
                 *static_cast<SwDocShell*>(pViewFrame->GetObjectShell())->GetDoc(),
-                pViewWin, 0, 0, VSHELLFLAG_ISPREVIEW );
+                pViewWin, nullptr, nullptr, VSHELLFLAG_ISPREVIEW );
 
     pViewWin->SetViewShell( pNew );
     pNew->SetSfxViewShell( this );
@@ -1236,9 +1255,9 @@ SwPagePreview::SwPagePreview(SfxViewFrame *pViewFrame, SfxViewShell* pOldSh):
 
 SwPagePreview::~SwPagePreview()
 {
-    SetWindow( 0 );
+    SetWindow( nullptr );
     SwViewShell* pVShell =  pViewWin->GetViewShell();
-    pVShell->SetWin(0);
+    pVShell->SetWin(nullptr);
     delete pVShell;
 
     pViewWin.disposeAndClear();
@@ -1250,7 +1269,7 @@ SwPagePreview::~SwPagePreview()
 
 SwDocShell* SwPagePreview::GetDocShell()
 {
-    return PTR_CAST(SwDocShell, GetViewFrame()->GetObjectShell());
+    return dynamic_cast<SwDocShell*>( GetViewFrame()->GetObjectShell() );
 }
 
 int SwPagePreview::_CreateScrollbar( bool bHori )
@@ -1263,7 +1282,7 @@ int SwPagePreview::_CreateScrollbar( bool bHori )
     ppScrollbar = VclPtr<SwScrollbar>::Create( pMDI, bHori );
 
     ScrollDocSzChg();
-    ppScrollbar->EnableDrag( true );
+    ppScrollbar->EnableDrag();
     ppScrollbar->SetEndScrollHdl( LINK( this, SwPagePreview, EndScrollHdl ));
 
     ppScrollbar->SetScrollHdl( LINK( this, SwPagePreview, ScrollHdl ));
@@ -1402,10 +1421,11 @@ void SwPagePreview::SetVisArea( const Rectangle &rRect, bool bUpdateScrollbar )
     pViewWin->Invalidate();
 }
 
-IMPL_LINK( SwPagePreview, ScrollHdl, SwScrollbar *, pScrollbar )
+IMPL_LINK_TYPED( SwPagePreview, ScrollHdl, ScrollBar *, p, void )
 {
+    SwScrollbar* pScrollbar = static_cast<SwScrollbar*>(p);
     if(!GetViewShell())
-        return 0;
+        return;
     if( !pScrollbar->IsHoriScroll() &&
         pScrollbar->GetType() == SCROLL_DRAG &&
         Help::IsQuickHelpEnabled() &&
@@ -1432,13 +1452,13 @@ IMPL_LINK( SwPagePreview, ScrollHdl, SwScrollbar *, pScrollbar )
     }
     else
         EndScrollHdl( pScrollbar );
-    return 0;
 }
 
-IMPL_LINK( SwPagePreview, EndScrollHdl, SwScrollbar *, pScrollbar )
+IMPL_LINK_TYPED( SwPagePreview, EndScrollHdl, ScrollBar *, p, void )
 {
+    SwScrollbar* pScrollbar = static_cast<SwScrollbar*>(p);
     if(!GetViewShell())
-        return 0;
+        return;
 
     // boolean to avoid unnecessary invalidation of the window.
     bool bInvalidateWin = true;
@@ -1523,7 +1543,6 @@ IMPL_LINK( SwPagePreview, EndScrollHdl, SwScrollbar *, pScrollbar )
     {
         pViewWin->Invalidate();
     }
-    return 0;
 }
 
 Point SwPagePreview::AlignToPixel(const Point &rPt) const
@@ -1545,7 +1564,7 @@ void SwPagePreview::DocSzChgd( const Size &rSz )
 
     if( aVisArea.GetWidth() )
     {
-        ChgPage( SwPagePreviewWin::MV_CALC, true );
+        ChgPage( SwPagePreviewWin::MV_CALC );
         ScrollDocSzChg();
 
         pViewWin->Invalidate();
@@ -1649,25 +1668,25 @@ void SwPagePreview::ScrollDocSzChg()
 // All about printing
 SfxPrinter*  SwPagePreview::GetPrinter( bool bCreate )
 {
-    return pViewWin->GetViewShell()->getIDocumentDeviceAccess()->getPrinter( bCreate );
+    return pViewWin->GetViewShell()->getIDocumentDeviceAccess().getPrinter( bCreate );
 }
 
 sal_uInt16  SwPagePreview::SetPrinter( SfxPrinter *pNew, SfxPrinterChangeFlags nDiffFlags, bool )
 {
     SwViewShell &rSh = *GetViewShell();
-    SfxPrinter* pOld = rSh.getIDocumentDeviceAccess()->getPrinter( false );
+    SfxPrinter* pOld = rSh.getIDocumentDeviceAccess().getPrinter( false );
     if ( pOld && pOld->IsPrinting() )
         return SFX_PRINTERROR_BUSY;
 
     SwEditShell &rESh = static_cast<SwEditShell&>(rSh);  //Buh...
     if( ( SfxPrinterChangeFlags::PRINTER | SfxPrinterChangeFlags::JOBSETUP ) & nDiffFlags )
     {
-        rSh.getIDocumentDeviceAccess()->setPrinter( pNew, true, true );
+        rSh.getIDocumentDeviceAccess().setPrinter( pNew, true, true );
         if( nDiffFlags & SfxPrinterChangeFlags::PRINTER )
             rESh.SetModified();
     }
     if ( ( nDiffFlags & SfxPrinterChangeFlags::OPTIONS ) == SfxPrinterChangeFlags::OPTIONS )
-        ::SetPrinter( rSh.getIDocumentDeviceAccess(), pNew, false );
+        ::SetPrinter( &rSh.getIDocumentDeviceAccess(), pNew, false );
 
     const bool bChgOri  = bool(nDiffFlags & SfxPrinterChangeFlags::CHG_ORIENTATION);
     const bool bChgSize = bool(nDiffFlags & SfxPrinterChangeFlags::CHG_SIZE);
@@ -1783,7 +1802,7 @@ void SwPagePreviewWin::AdjustPreviewToNewZoom( const sal_uInt16 _nZoomFactor,
  * when less than the desired number of rows fits into
  * the view
  */
-void SwPagePreviewWin::Scroll(long nXMove, long nYMove, sal_uInt16 /*nFlags*/)
+void SwPagePreviewWin::Scroll(long nXMove, long nYMove, ScrollFlags /*nFlags*/)
 {
     maPaintedPreviewDocRect.Move(nXMove, nYMove);
     mpPgPreviewLayout->Prepare( 0, maPaintedPreviewDocRect.TopLeft(),
@@ -1824,20 +1843,20 @@ bool SwPagePreview::HandleWheelCommands( const CommandEvent& rCEvt )
     return bOk;
 }
 
-uno::Reference< ::com::sun::star::accessibility::XAccessible >
+uno::Reference< css::accessibility::XAccessible >
     SwPagePreviewWin::CreateAccessible()
 {
     SolarMutexGuard aGuard; // this should have happened already!!!
 
-    OSL_ENSURE( GetViewShell() != NULL, "We need a view shell" );
-    ::com::sun::star::uno::Reference< ::com::sun::star::accessibility::XAccessible > xAcc = GetAccessible( false );
+    OSL_ENSURE( GetViewShell() != nullptr, "We need a view shell" );
+    css::uno::Reference< css::accessibility::XAccessible > xAcc = GetAccessible( false );
     if (xAcc.is())
     {
         return xAcc;
     }
     if (mpViewShell)
     {
-        ::com::sun::star::uno::Reference< ::com::sun::star::accessibility::XAccessible > xAccPreview = mpViewShell->CreateAccessiblePreview();
+        css::uno::Reference< css::accessibility::XAccessible > xAccPreview = mpViewShell->CreateAccessiblePreview();
         SetAccessible(xAccPreview);
     }
     return GetAccessible( false );
