@@ -36,31 +36,29 @@ public class MainThreadDialogExecutor implements XCallback
     private boolean    m_bCalled = false;
     private boolean    m_bClose = false;
 
-    static public boolean Show( XComponentContext xContext, WikiDialog aWikiDialog )
+    public static boolean Show( XComponentContext xContext, WikiDialog aWikiDialog )
     {
         MainThreadDialogExecutor aExecutor = new MainThreadDialogExecutor( aWikiDialog );
         return GetCallback( xContext, aExecutor );
     }
 
-    static public boolean Execute( XComponentContext xContext, XDialog xDialog )
-    {
-        MainThreadDialogExecutor aExecutor = new MainThreadDialogExecutor( xDialog );
-        return GetCallback( xContext, aExecutor );
-    }
 
-    static public boolean Execute( XComponentContext xContext, XMessageBox xMessageBox )
+
+    public static boolean Execute( XComponentContext xContext, XMessageBox xMessageBox )
     {
         MainThreadDialogExecutor aExecutor = new MainThreadDialogExecutor( xMessageBox );
         return GetCallback( xContext, aExecutor );
     }
 
-    static public boolean Close( XComponentContext xContext, XDialog xDialog )
+    public static boolean Close( XComponentContext xContext, XDialog xDialog )
     {
-        MainThreadDialogExecutor aExecutor = new MainThreadDialogExecutor( xDialog, true );
+        MainThreadDialogExecutor aExecutor = new MainThreadDialogExecutor( xDialog );
+        aExecutor.m_bClose = true;
+        aExecutor.m_bCalled = true; // no yielding, asynchronous closing
         return GetCallback( xContext, aExecutor );
     }
 
-    static private boolean GetCallback( XComponentContext xContext, MainThreadDialogExecutor aExecutor )
+    private static boolean GetCallback( XComponentContext xContext, MainThreadDialogExecutor aExecutor )
     {
         try
         {
@@ -116,13 +114,6 @@ public class MainThreadDialogExecutor implements XCallback
         m_xDialog = xDialog;
     }
 
-    private MainThreadDialogExecutor( XDialog xDialog, boolean bClose )
-    {
-        m_xDialog = xDialog;
-        m_bClose = true;
-        m_bCalled = true; // no yielding, asynchronous closing
-    }
-
     private MainThreadDialogExecutor( XMessageBox xMessageBox )
     {
         m_xMessageBox = xMessageBox;
@@ -163,5 +154,5 @@ public class MainThreadDialogExecutor implements XCallback
 
         m_bCalled = true;
     }
-};
+}
 
