@@ -25,7 +25,7 @@
 #include <tools/rcid.h>
 
 Resource::Resource( const ResId& rResId )
-    : m_pResMgr(NULL)
+    : m_pResMgr(nullptr)
 {
     GetRes( rResId.SetRT( RSC_RESOURCE ) );
 }
@@ -39,50 +39,6 @@ void Resource::GetRes( const ResId& rResId )
     IncrementRes( sizeof( RSHEADER_TYPE ) );
 }
 
-namespace tools {
-
-Time::Time( const ResId& rResId )
-{
-    nTime = 0;
-    rResId.SetRT( RSC_TIME );
-    ResMgr* pResMgr = NULL;
-
-    ResMgr::GetResourceSkipHeader( rResId, &pResMgr );
-
-    sal_uIntPtr nObjMask = (sal_uInt16)pResMgr->ReadLong();
-
-    if ( 0x01 & nObjMask )
-        SetHour( (sal_uInt16)pResMgr->ReadShort() );
-    if ( 0x02 & nObjMask )
-        SetMin( (sal_uInt16)pResMgr->ReadShort() );
-    if ( 0x04 & nObjMask )
-        SetSec( (sal_uInt16)pResMgr->ReadShort() );
-    if ( 0x08 & nObjMask )
-        // TODO: when we change the place that writes this binary resource format to match:
-        // SetNanoSec( pResMgr->ReadLong() );
-        // In the meantime:
-        SetNanoSec( pResMgr->ReadShort() * ::tools::Time::nanoPerCenti );
-}
-
-} /* namespace tools */
-
-Date::Date( const ResId& rResId ) : nDate(0)
-{
-    rResId.SetRT( RSC_DATE );
-    ResMgr* pResMgr = NULL;
-
-    ResMgr::GetResourceSkipHeader( rResId, &pResMgr );
-
-    sal_uIntPtr nObjMask = (sal_uInt16)pResMgr->ReadLong();
-
-    if ( 0x01 & nObjMask )
-        SetYear( (sal_uInt16)pResMgr->ReadShort() );
-    if ( 0x02 & nObjMask )
-        SetMonth( (sal_uInt16)pResMgr->ReadShort() );
-    if ( 0x04 & nObjMask )
-        SetDay( (sal_uInt16)pResMgr->ReadShort() );
-}
-
 OUString ResId::toString() const
 {
     SetRT( RSC_STRING );
@@ -107,10 +63,10 @@ OUString ResId::toString() const
     }
 
     // String loading
-    RSHEADER_TYPE * pResHdr = (RSHEADER_TYPE*)pResMgr->GetClass();
+    RSHEADER_TYPE * pResHdr = static_cast<RSHEADER_TYPE*>(pResMgr->GetClass());
 
-    sal_Int32 nStringLen = rtl_str_getLength( (char*)(pResHdr+1) );
-    OUString sRet((const char*)(pResHdr+1), nStringLen, RTL_TEXTENCODING_UTF8);
+    sal_Int32 nStringLen = rtl_str_getLength( reinterpret_cast<char*>(pResHdr+1) );
+    OUString sRet(reinterpret_cast<char*>(pResHdr+1), nStringLen, RTL_TEXTENCODING_UTF8);
 
     sal_uInt32 nSize = sizeof( RSHEADER_TYPE )
         + sal::static_int_cast< sal_uInt32 >(nStringLen) + 1;
