@@ -17,7 +17,6 @@
  *   the License at http://www.apache.org/licenses/LICENSE-2.0 .
  */
 
-#include <stdio.h>
 #include "filglob.hxx"
 #include "filerror.hxx"
 #include "shell.hxx"
@@ -62,7 +61,7 @@ namespace {
     {
         OUString aResourceName;
         OUString aResourceType;
-        sal_Bool      bRemovable;
+        bool bRemovable = false;
         bool bResourceName = false;
         bool bResourceType = false;
         bool bRemoveProperty = false;
@@ -153,7 +152,7 @@ namespace {
 namespace fileaccess {
 
 
-    sal_Bool isChild( const OUString& srcUnqPath,
+    bool isChild( const OUString& srcUnqPath,
                       const OUString& dstUnqPath )
     {
         static sal_Unicode slash = '/';
@@ -166,7 +165,7 @@ namespace fileaccess {
             ||
             ( ( dstL > srcL )
               &&
-              ( srcUnqPath.compareTo( dstUnqPath, srcL ) == 0 )
+              dstUnqPath.startsWith(srcUnqPath)
               &&
               ( dstUnqPath[ srcL ] == slash ) )
         );
@@ -211,7 +210,7 @@ namespace fileaccess {
 
     osl::FileBase::RC osl_File_copy( const OUString& strPath,
                                      const OUString& strDestPath,
-                                     sal_Bool test )
+                                     bool test )
     {
         if( test )
         {
@@ -226,7 +225,7 @@ namespace fileaccess {
 
     osl::FileBase::RC osl_File_move( const OUString& strPath,
                                      const OUString& strDestPath,
-                                     sal_Bool test )
+                                     bool test )
     {
         if( test )
         {
@@ -252,7 +251,7 @@ namespace fileaccess {
 
         if( errorCode ==  TASKHANDLER_UNSUPPORTED_COMMAND )
         {
-            aAny <<= UnsupportedCommandException( OUString(  OSL_LOG_PREFIX  ), uno::Reference< uno::XInterface >() );
+            aAny <<= UnsupportedCommandException( OSL_LOG_PREFIX );
             cancelCommandExecution( aAny,xEnv );
         }
         else if( errorCode == TASKHANDLING_WRONG_SETPROPERTYVALUES_ARGUMENT ||
@@ -368,7 +367,7 @@ namespace fileaccess {
                 ioErrorCode,
                 generateErrorArguments(aUncPath),
                 xEnv,
-                OUString( "an error occurred during file opening"),
+                "an error occurred during file opening",
                 xComProc);
         }
         else if( errorCode == TASKHANDLING_OPEN_FOR_DIRECTORYLISTING  ||
@@ -421,7 +420,7 @@ namespace fileaccess {
                 ioErrorCode,
                 generateErrorArguments(aUncPath),
                 xEnv,
-                OUString( "an error occurred during opening a directory"),
+                "an error occurred during opening a directory",
                 xComProc);
         }
         else if( errorCode == TASKHANDLING_NOTCONNECTED_FOR_WRITE          ||
@@ -436,7 +435,7 @@ namespace fileaccess {
                 ioErrorCode,
                 generateErrorArguments(aUncPath),
                 xEnv,
-                OUString( "an error occurred writing or reading from a file"),
+                "an error occurred writing or reading from a file",
                 xComProc );
         }
         else if( errorCode == TASKHANDLING_FILEIOERROR_FOR_NO_SPACE )
@@ -446,7 +445,7 @@ namespace fileaccess {
                 ioErrorCode,
                 generateErrorArguments(aUncPath),
                 xEnv,
-                OUString( "device full"),
+                "device full",
                 xComProc);
         }
         else if( errorCode == TASKHANDLING_FILEIOERROR_FOR_WRITE ||
@@ -498,7 +497,7 @@ namespace fileaccess {
                 ioErrorCode,
                 generateErrorArguments(aUncPath),
                 xEnv,
-                OUString( "an error occurred during opening a file"),
+                "an error occurred during opening a file",
                 xComProc);
         }
         else if( errorCode == TASKHANDLING_NONAMESET_INSERT_COMMAND ||
@@ -536,7 +535,7 @@ namespace fileaccess {
                 ioErrorCode,
                 generateErrorArguments(aUncPath),
                 xEnv,
-                OUString( "there were problems with the filesize"),
+                "there were problems with the filesize",
                 xComProc);
         }
         else if(errorCode == TASKHANDLING_INPUTSTREAM_FOR_WRITE)
@@ -636,7 +635,7 @@ namespace fileaccess {
                 generateErrorArguments(getParentName(aUncPath)),
                 //TODO! ok to supply physical URL to getParentName()?
                 xEnv,
-                OUString( "a folder could not be created"),
+                "a folder could not be created",
                 xComProc  );
         }
         else if( errorCode == TASKHANDLING_VALIDFILESTATUSWHILE_FOR_REMOVE  ||
@@ -687,7 +686,7 @@ namespace fileaccess {
                 ioErrorCode,
                 generateErrorArguments(aUncPath),
                 xEnv,
-                OUString( "a file status object could not be filled"),
+                "a file status object could not be filled",
                 xComProc  );
         }
         else if( errorCode == TASKHANDLING_DELETEFILE_FOR_REMOVE  ||
@@ -734,7 +733,7 @@ namespace fileaccess {
                 ioErrorCode,
                 generateErrorArguments(aUncPath),
                 xEnv,
-                OUString( "a file or directory could not be deleted"),
+                "a file or directory could not be deleted",
                 xComProc );
         }
         else if( errorCode == TASKHANDLING_TRANSFER_BY_COPY_SOURCE         ||
@@ -784,14 +783,14 @@ namespace fileaccess {
                 ioErrorCode,
                 generateErrorArguments(aUncPath),
                 xEnv,
-                OUString( "accessing the root during transfer"),
+                "accessing the root during transfer",
                 xComProc );
         }
         else if( errorCode == TASKHANDLING_TRANSFER_INVALIDSCHEME )
         {
             aAny <<=
                 InteractiveBadTransferURLException(
-                    OUString( "bad tranfer url"),
+                    OUString( "bad transfer url"),
                     xComProc);
             cancelCommandExecution( aAny,xEnv );
         }
