@@ -22,6 +22,7 @@
 #include "com/sun/star/beans/XPropertySet.hpp"
 #include "com/sun/star/embed/ElementModes.hpp"
 #include "com/sun/star/embed/StorageFactory.hpp"
+#include <osl/diagnose.h>
 #include "comphelper/processfactory.hxx"
 
 #include "tdoc_uri.hxx"
@@ -34,13 +35,13 @@ using namespace com::sun::star;
 using namespace tdoc_ucp;
 
 
-//=========================================================================
-//=========================================================================
-//
+
+
+
 // StorageElementFactory Implementation.
-//
-//=========================================================================
-//=========================================================================
+
+
+
 
 StorageElementFactory::StorageElementFactory(
     const uno::Reference< uno::XComponentContext > & rxContext,
@@ -50,14 +51,14 @@ StorageElementFactory::StorageElementFactory(
 {
 }
 
-//=========================================================================
+
 StorageElementFactory::~StorageElementFactory()
 {
     OSL_ENSURE( m_aMap.empty(),
         "StorageElementFactory::~StorageElementFactory - Dangling storages!" );
 }
 
-//=========================================================================
+
 uno::Reference< embed::XStorage >
 StorageElementFactory::createTemporaryStorage()
     throw ( uno::Exception,
@@ -72,9 +73,7 @@ StorageElementFactory::createTemporaryStorage()
 
     OSL_ENSURE( xStorageFac.is(), "Can't create storage factory!" );
     if ( xStorageFac.is() )
-        xStorage = uno::Reference< embed::XStorage >(
-                            xStorageFac->createInstance(),
-                            uno::UNO_QUERY );
+        xStorage.set( xStorageFac->createInstance(), uno::UNO_QUERY );
 
     if ( !xStorage.is() )
         throw uno::RuntimeException();
@@ -82,7 +81,7 @@ StorageElementFactory::createTemporaryStorage()
     return xStorage;
 }
 
-//=========================================================================
+
 uno::Reference< embed::XStorage >
 StorageElementFactory::createStorage( const OUString & rUri,
                                       StorageAccessMode eMode )
@@ -180,7 +179,7 @@ StorageElementFactory::createStorage( const OUString & rUri,
         bool bWritable = ( ( eMode == READ_WRITE_NOCREATE )
                             || ( eMode == READ_WRITE_CREATE ) );
 
-        std::auto_ptr< Storage > xElement(
+        uno::Reference< Storage > xElement(
             new Storage( m_xContext, this, aUriKey, xParentStorage, xStorage ) );
 
         aIt = m_aMap.insert(
@@ -189,7 +188,6 @@ StorageElementFactory::createStorage( const OUString & rUri,
                 xElement.get() ) ).first;
 
         aIt->second->m_aContainerIt = aIt;
-        xElement.release();
         return aIt->second;
     }
     else if ( osl_atomic_increment( &aIt->second->m_refCount ) > 1 )
@@ -236,7 +234,7 @@ StorageElementFactory::createStorage( const OUString & rUri,
     }
 }
 
-//=========================================================================
+
 uno::Reference< io::XInputStream >
 StorageElementFactory::createInputStream( const OUString & rUri,
                                           const OUString & rPassword )
@@ -265,7 +263,7 @@ StorageElementFactory::createInputStream( const OUString & rUri,
     return xStream->getInputStream();
 }
 
-//=========================================================================
+
 uno::Reference< io::XOutputStream >
 StorageElementFactory::createOutputStream( const OUString & rUri,
                                            const OUString & rPassword,
@@ -310,7 +308,7 @@ StorageElementFactory::createOutputStream( const OUString & rUri,
         new OutputStream( m_xContext, rUri, xParentStorage, xStream->getOutputStream() ) );
 }
 
-//=========================================================================
+
 uno::Reference< io::XStream >
 StorageElementFactory::createStream( const OUString & rUri,
                                      const OUString & rPassword,
@@ -350,8 +348,8 @@ StorageElementFactory::createStream( const OUString & rUri,
         new Stream( m_xContext, rUri, xParentStorage, xStream ) );
 }
 
-//=========================================================================
-void StorageElementFactory::releaseElement( Storage * pElement ) SAL_THROW(())
+
+void StorageElementFactory::releaseElement( Storage * pElement )
 {
     OSL_ASSERT( pElement );
     osl::MutexGuard aGuard( m_aMutex );
@@ -359,11 +357,11 @@ void StorageElementFactory::releaseElement( Storage * pElement ) SAL_THROW(())
         m_aMap.erase( pElement->m_aContainerIt );
 }
 
-//=========================================================================
-//
+
+
 // Non-UNO interface
-//
-//=========================================================================
+
+
 
 uno::Reference< embed::XStorage > StorageElementFactory::queryParentStorage(
         const OUString & rUri, StorageAccessMode eMode )
@@ -388,7 +386,7 @@ uno::Reference< embed::XStorage > StorageElementFactory::queryParentStorage(
     return xParentStorage;
 }
 
-//=========================================================================
+
 uno::Reference< embed::XStorage > StorageElementFactory::queryStorage(
         const uno::Reference< embed::XStorage > & xParentStorage,
         const OUString & rUri,
@@ -433,8 +431,7 @@ uno::Reference< embed::XStorage > StorageElementFactory::queryStorage(
                     "No XPropertySet interface!" );
         try
         {
-            uno::Any aPropValue = xPropSet->getPropertyValue(
-                OUString( "OpenMode" ) );
+            uno::Any aPropValue = xPropSet->getPropertyValue("OpenMode");
 
             sal_Int32 nOpenMode = 0;
             if ( aPropValue >>= nOpenMode )
@@ -446,9 +443,7 @@ uno::Reference< embed::XStorage > StorageElementFactory::queryStorage(
                         {
                             // document opened, but not readable.
                             throw embed::InvalidStorageException(
-                                OUString(
-                                    "Storage is open, but not readable!" ),
-                                uno::Reference< uno::XInterface >() );
+                                    "Storage is open, but not readable!" );
                         }
                         // storage okay
                         break;
@@ -459,9 +454,7 @@ uno::Reference< embed::XStorage > StorageElementFactory::queryStorage(
                         {
                             // document opened, but not writable.
                             throw embed::InvalidStorageException(
-                                OUString(
-                                    "Storage is open, but not writable!" ),
-                                uno::Reference< uno::XInterface >() );
+                                    "Storage is open, but not writable!" );
                         }
                         // storage okay
                         break;
@@ -473,9 +466,7 @@ uno::Reference< embed::XStorage > StorageElementFactory::queryStorage(
                     "Bug! Value of property OpenMode has wrong type!" );
 
                 throw uno::RuntimeException(
-                    OUString(
-                        "Bug! Value of property OpenMode has wrong type!" ),
-                    uno::Reference< uno::XInterface >() );
+                        "Bug! Value of property OpenMode has wrong type!" );
             }
         }
         catch ( beans::UnknownPropertyException const & e )
@@ -537,7 +528,7 @@ uno::Reference< embed::XStorage > StorageElementFactory::queryStorage(
     return xStorage;
 }
 
-//=========================================================================
+
 uno::Reference< io::XStream >
 StorageElementFactory::queryStream(
                 const uno::Reference< embed::XStorage > & xParentStorage,
