@@ -18,30 +18,29 @@
  */
 
 #include <rtl/strbuf.hxx>
+#include <sal/log.hxx>
 #include <unotools/calendarwrapper.hxx>
 #include <com/sun/star/i18n/CalendarFieldIndex.hpp>
-#include <com/sun/star/i18n/LocaleCalendar.hpp>
+#include <com/sun/star/i18n/LocaleCalendar2.hpp>
 
 using namespace ::com::sun::star;
 using namespace ::com::sun::star::i18n;
 using namespace ::com::sun::star::uno;
 
-const double MILLISECONDS_PER_DAY = 1000.0 * 60.0 * 60.0 * 24.0;
-
 CalendarWrapper::CalendarWrapper(
             const Reference< uno::XComponentContext > & rxContext
             )
         :
         aEpochStart( Date( 1, 1, 1970 ) )
 {
-    xC = LocaleCalendar::create(rxContext);
+    xC = LocaleCalendar2::create(rxContext);
 }
 
 CalendarWrapper::~CalendarWrapper()
 {
 }
 
-void CalendarWrapper::loadDefaultCalendar( const ::com::sun::star::lang::Locale& rLocale )
+void CalendarWrapper::loadDefaultCalendar( const css::lang::Locale& rLocale )
 {
     try
     {
@@ -54,7 +53,7 @@ void CalendarWrapper::loadDefaultCalendar( const ::com::sun::star::lang::Locale&
     }
 }
 
-void CalendarWrapper::loadCalendar( const OUString& rUniqueID, const ::com::sun::star::lang::Locale& rLocale )
+void CalendarWrapper::loadCalendar( const OUString& rUniqueID, const css::lang::Locale& rLocale )
 {
     try
     {
@@ -68,7 +67,7 @@ void CalendarWrapper::loadCalendar( const OUString& rUniqueID, const ::com::sun:
     }
 }
 
-::com::sun::star::uno::Sequence< OUString > CalendarWrapper::getAllCalendars( const ::com::sun::star::lang::Locale& rLocale ) const
+css::uno::Sequence< OUString > CalendarWrapper::getAllCalendars( const css::lang::Locale& rLocale ) const
 {
     try
     {
@@ -80,7 +79,7 @@ void CalendarWrapper::loadCalendar( const OUString& rUniqueID, const ::com::sun:
         SAL_WARN( "unotools.i18n", "getAllCalendars: Exception caught " << e.Message );
     }
 
-    return ::com::sun::star::uno::Sequence< OUString > (0);
+    return css::uno::Sequence< OUString > (0);
 }
 
 OUString CalendarWrapper::getUniqueID() const
@@ -124,83 +123,13 @@ double CalendarWrapper::getDateTime() const
     return 0.0;
 }
 
-sal_Int32 CalendarWrapper::getCombinedOffsetInMillis(
-        sal_Int16 nParentFieldIndex, sal_Int16 nChildFieldIndex ) const
-{
-    sal_Int32 nOffset = 0;
-    try
-    {
-        if ( xC.is() )
-        {
-            nOffset = static_cast<sal_Int32>( xC->getValue( nParentFieldIndex )) * 60000;
-            sal_Int16 nSecondMillis = xC->getValue( nChildFieldIndex );
-            if (nOffset < 0)
-                nOffset -= static_cast<sal_uInt16>( nSecondMillis);
-            else
-                nOffset += static_cast<sal_uInt16>( nSecondMillis);
-        }
-    }
-    catch (const Exception& e)
-    {
-        SAL_WARN( "unotools.i18n", "getCombinedOffsetInMillis: Exception caught " << e.Message );
-    }
-    return nOffset;
-}
-
-sal_Int32 CalendarWrapper::getZoneOffsetInMillis() const
-{
-    return getCombinedOffsetInMillis( CalendarFieldIndex::ZONE_OFFSET,
-            CalendarFieldIndex::ZONE_OFFSET_SECOND_MILLIS);
-}
-
-sal_Int32 CalendarWrapper::getDSTOffsetInMillis() const
-{
-    return getCombinedOffsetInMillis( CalendarFieldIndex::DST_OFFSET,
-            CalendarFieldIndex::DST_OFFSET_SECOND_MILLIS);
-}
-
 void CalendarWrapper::setLocalDateTime( double fTimeInDays )
 {
     try
     {
         if ( xC.is() )
         {
-            // First set a nearby value to obtain the timezone and DST offset.
-            // This is necessary to let ICU choose the corresponding
-            // OlsonTimeZone transitions. Since ICU incorporates also
-            // historical data even the timezone may differ for different
-            // dates! (Which was the cause for #i76623# when the timezone of a
-            // previously set date was used.) Timezone may also include
-            // seconds, so use milliseconds field as well.
-            xC->setDateTime( fTimeInDays );
-            sal_Int32 nZone1 = getZoneOffsetInMillis();
-            sal_Int32 nDST1  = getDSTOffsetInMillis();
-            double fLoc = fTimeInDays - (double)(nZone1 + nDST1) / MILLISECONDS_PER_DAY;
-            xC->setDateTime( fLoc );
-            sal_Int32 nZone2 = getZoneOffsetInMillis();
-            sal_Int32 nDST2  = getDSTOffsetInMillis();
-            // If DSTs differ after calculation, we crossed boundaries. Do it
-            // again, this time using the DST corrected initial value for the
-            // real local time.
-            // See also localtime/gmtime conversion pitfalls at
-            // http://www.erack.de/download/timetest.c
-            if ( nDST1 != nDST2 )
-            {
-                fLoc = fTimeInDays - (double)(nZone2 + nDST2) / MILLISECONDS_PER_DAY;
-                xC->setDateTime( fLoc );
-                // #i17222# If the DST onset rule says to switch from 00:00 to
-                // 01:00 and we tried to set onsetDay 00:00 with DST, the
-                // result was onsetDay-1 23:00 and no DST, which is not what we
-                // want. So once again without DST, resulting in onsetDay
-                // 01:00 and DST. Yes, this seems to be weird, but logically
-                // correct.
-                sal_Int32 nDST3 = getDSTOffsetInMillis();
-                if ( nDST2 != nDST3 && !nDST3 )
-                {
-                    fLoc = fTimeInDays - (double)(nZone2 + nDST3) / MILLISECONDS_PER_DAY;
-                    xC->setDateTime( fLoc );
-                }
-            }
+            xC->setLocalDateTime( fTimeInDays );
         }
     }
     catch (const Exception& e)
@@ -215,11 +144,7 @@ double CalendarWrapper::getLocalDateTime() const
     {
         if ( xC.is() )
         {
-            double fTimeInDays = xC->getDateTime();
-            sal_Int32 nZone = getZoneOffsetInMillis();
-            sal_Int32 nDST = getDSTOffsetInMillis();
-            fTimeInDays += (double)(nZone + nDST) / MILLISECONDS_PER_DAY;
-            return fTimeInDays;
+            return xC->getLocalDateTime();
         }
     }
     catch (const Exception& e)
@@ -325,7 +250,7 @@ sal_Int16 CalendarWrapper::getNumberOfDaysInWeek() const
     return 0;
 }
 
-::com::sun::star::uno::Sequence< ::com::sun::star::i18n::CalendarItem2 > CalendarWrapper::getMonths() const
+css::uno::Sequence< css::i18n::CalendarItem2 > CalendarWrapper::getMonths() const
 {
     try
     {
@@ -336,10 +261,10 @@ sal_Int16 CalendarWrapper::getNumberOfDaysInWeek() const
     {
         SAL_WARN( "unotools.i18n", "getMonths: Exception caught " << e.Message );
     }
-    return ::com::sun::star::uno::Sequence< ::com::sun::star::i18n::CalendarItem2 > (0);
+    return css::uno::Sequence< css::i18n::CalendarItem2 > (0);
 }
 
-::com::sun::star::uno::Sequence< ::com::sun::star::i18n::CalendarItem2 > CalendarWrapper::getDays() const
+css::uno::Sequence< css::i18n::CalendarItem2 > CalendarWrapper::getDays() const
 {
     try
     {
@@ -350,7 +275,7 @@ sal_Int16 CalendarWrapper::getNumberOfDaysInWeek() const
     {
         SAL_WARN( "unotools.i18n", "getDays: Exception caught " << e.Message );
     }
-    return ::com::sun::star::uno::Sequence< ::com::sun::star::i18n::CalendarItem2 > (0);
+    return css::uno::Sequence< css::i18n::CalendarItem2 > (0);
 }
 
 OUString CalendarWrapper::getDisplayName( sal_Int16 nCalendarDisplayIndex, sal_Int16 nIdx, sal_Int16 nNameType ) const
@@ -385,7 +310,7 @@ OUString CalendarWrapper::getDisplayString( sal_Int32 nCalendarDisplayCode, sal_
 
 // --- XCalendar3 ------------------------------------------------------------
 
-::com::sun::star::i18n::Calendar2 CalendarWrapper::getLoadedCalendar() const
+css::i18n::Calendar2 CalendarWrapper::getLoadedCalendar() const
 {
     try
     {
@@ -396,10 +321,10 @@ OUString CalendarWrapper::getDisplayString( sal_Int32 nCalendarDisplayCode, sal_
     {
         SAL_WARN( "unotools.i18n", "getLoadedCalendar2: Exception caught " << e.Message );
     }
-    return ::com::sun::star::i18n::Calendar2();
+    return css::i18n::Calendar2();
 }
 
-::com::sun::star::uno::Sequence< ::com::sun::star::i18n::CalendarItem2 > CalendarWrapper::getGenitiveMonths() const
+css::uno::Sequence< css::i18n::CalendarItem2 > CalendarWrapper::getGenitiveMonths() const
 {
     try
     {
@@ -410,10 +335,10 @@ OUString CalendarWrapper::getDisplayString( sal_Int32 nCalendarDisplayCode, sal_
     {
         SAL_WARN( "unotools.i18n", "getGenitiveMonths: Exception caught " << e.Message );
     }
-    return ::com::sun::star::uno::Sequence< ::com::sun::star::i18n::CalendarItem2 > (0);
+    return css::uno::Sequence< css::i18n::CalendarItem2 > (0);
 }
 
-::com::sun::star::uno::Sequence< ::com::sun::star::i18n::CalendarItem2 > CalendarWrapper::getPartitiveMonths() const
+css::uno::Sequence< css::i18n::CalendarItem2 > CalendarWrapper::getPartitiveMonths() const
 {
     try
     {
@@ -424,7 +349,7 @@ OUString CalendarWrapper::getDisplayString( sal_Int32 nCalendarDisplayCode, sal_
     {
         SAL_WARN( "unotools.i18n", "getPartitiveMonths: Exception caught " << e.Message );
     }
-    return ::com::sun::star::uno::Sequence< ::com::sun::star::i18n::CalendarItem2 > (0);
+    return css::uno::Sequence< css::i18n::CalendarItem2 > (0);
 }
 
 /* vim:set shiftwidth=4 softtabstop=4 expandtab: */
