@@ -48,8 +48,7 @@
 #include <com/sun/star/io/XActiveDataSink.hpp>
 #include <com/sun/star/io/XActiveDataControl.hpp>
 #include <com/sun/star/io/XSeekable.hpp>
-#include <cppuhelper/implbase1.hxx>
-#include <cppuhelper/implbase2.hxx>
+#include <cppuhelper/implbase.hxx>
 #include <tools/inetmsg.hxx>
 #include <com/sun/star/io/XTruncate.hpp>
 #include <com/sun/star/lang/IllegalArgumentException.hpp>
@@ -70,78 +69,60 @@ namespace utl
 /**
     Helper class for getting a XInputStream when opening a content
  */
-class UcbDataSink_Impl : public ::cppu::WeakImplHelper2< XActiveDataControl, XActiveDataSink >
+class UcbDataSink_Impl : public ::cppu::WeakImplHelper< XActiveDataControl, XActiveDataSink >
 {
     UcbLockBytesRef         m_xLockBytes;
 
 public:
-                            UcbDataSink_Impl( UcbLockBytes* pLockBytes )
-                                : m_xLockBytes( pLockBytes )
-                            {}
+    explicit UcbDataSink_Impl( UcbLockBytes* pLockBytes )
+        : m_xLockBytes( pLockBytes )
+    {}
 
     // XActiveDataControl.
-    virtual void SAL_CALL   addListener ( const Reference<XStreamListener> &/*rxListener*/) throw(RuntimeException, std::exception) SAL_OVERRIDE {}
-    virtual void SAL_CALL   removeListener ( const Reference<XStreamListener> &/*rxListener*/) throw(RuntimeException, std::exception) SAL_OVERRIDE {}
-    virtual void SAL_CALL   start() throw(RuntimeException, std::exception) SAL_OVERRIDE {}
-    virtual void SAL_CALL   terminate() throw(RuntimeException, std::exception) SAL_OVERRIDE
+    virtual void SAL_CALL   addListener ( const Reference<XStreamListener> &/*rxListener*/) throw(RuntimeException, std::exception) override {}
+    virtual void SAL_CALL   removeListener ( const Reference<XStreamListener> &/*rxListener*/) throw(RuntimeException, std::exception) override {}
+    virtual void SAL_CALL   start() throw(RuntimeException, std::exception) override {}
+    virtual void SAL_CALL   terminate() throw(RuntimeException, std::exception) override
                             { m_xLockBytes->terminate_Impl(); }
 
     // XActiveDataSink.
-    virtual void SAL_CALL   setInputStream ( const Reference<XInputStream> &rxInputStream) throw(RuntimeException, std::exception) SAL_OVERRIDE
+    virtual void SAL_CALL   setInputStream ( const Reference<XInputStream> &rxInputStream) throw(RuntimeException, std::exception) override
                             { m_xLockBytes->setInputStream_Impl (rxInputStream); }
-    virtual Reference<XInputStream> SAL_CALL getInputStream() throw(RuntimeException, std::exception) SAL_OVERRIDE
+    virtual Reference<XInputStream> SAL_CALL getInputStream() throw(RuntimeException, std::exception) override
                             { return m_xLockBytes->getInputStream_Impl(); }
 };
 
 /**
     Helper class for getting a XStream when opening a content
  */
-class UcbStreamer_Impl : public ::cppu::WeakImplHelper2< XActiveDataStreamer, XActiveDataControl >
+class UcbStreamer_Impl : public ::cppu::WeakImplHelper< XActiveDataStreamer, XActiveDataControl >
 {
     Reference < XStream >   m_xStream;
     UcbLockBytesRef         m_xLockBytes;
 
 public:
-                            UcbStreamer_Impl( UcbLockBytes* pLockBytes )
-                                : m_xLockBytes( pLockBytes )
-                            {}
+    explicit UcbStreamer_Impl( UcbLockBytes* pLockBytes )
+        : m_xLockBytes( pLockBytes )
+    {}
 
     // XActiveDataControl.
-    virtual void SAL_CALL   addListener ( const Reference<XStreamListener> &/*rxListener*/) throw(RuntimeException, std::exception) SAL_OVERRIDE {}
-    virtual void SAL_CALL   removeListener ( const Reference<XStreamListener> &/*rxListener*/) throw(RuntimeException, std::exception) SAL_OVERRIDE {}
-    virtual void SAL_CALL   start() throw(RuntimeException, std::exception) SAL_OVERRIDE {}
-    virtual void SAL_CALL   terminate() throw(RuntimeException, std::exception) SAL_OVERRIDE
+    virtual void SAL_CALL   addListener ( const Reference<XStreamListener> &/*rxListener*/) throw(RuntimeException, std::exception) override {}
+    virtual void SAL_CALL   removeListener ( const Reference<XStreamListener> &/*rxListener*/) throw(RuntimeException, std::exception) override {}
+    virtual void SAL_CALL   start() throw(RuntimeException, std::exception) override {}
+    virtual void SAL_CALL   terminate() throw(RuntimeException, std::exception) override
                             { m_xLockBytes->terminate_Impl(); }
 
     // XActiveDataStreamer
-    virtual void SAL_CALL   setStream( const Reference< XStream >& aStream ) throw(RuntimeException, std::exception) SAL_OVERRIDE
+    virtual void SAL_CALL   setStream( const Reference< XStream >& aStream ) throw(RuntimeException, std::exception) override
                             { m_xStream = aStream; m_xLockBytes->setStream_Impl( aStream ); }
-    virtual Reference< XStream > SAL_CALL getStream() throw(RuntimeException, std::exception) SAL_OVERRIDE
+    virtual Reference< XStream > SAL_CALL getStream() throw(RuntimeException, std::exception) override
                             { return m_xStream; }
 };
 
-/**
-    Helper class for progress handling while executing UCB commands
- */
-class ProgressHandler_Impl: public ::cppu::WeakImplHelper1< XProgressHandler >
-{
-    Link<>                  m_aProgress;
-
-public:
-                            ProgressHandler_Impl( const Link<>& rLink )
-                                : m_aProgress( rLink )
-                            {}
-    // XProgressHandler
-    virtual void SAL_CALL   push(const Any & /*rStatus*/) throw (RuntimeException, std::exception) SAL_OVERRIDE {}
-    virtual void SAL_CALL   pop() throw (RuntimeException, std::exception) SAL_OVERRIDE {}
-    virtual void SAL_CALL   update(const Any & /*rStatus*/) throw (RuntimeException, std::exception) SAL_OVERRIDE
-                            { if ( m_aProgress.IsSet() ) m_aProgress.Call( 0 ); }
-};
-
 /**
     Helper class for managing interactions and progress when executing UCB commands
  */
-class UcbTaskEnvironment : public ::cppu::WeakImplHelper1< XCommandEnvironment >
+class UcbTaskEnvironment : public ::cppu::WeakImplHelper< XCommandEnvironment >
 {
     Reference< XInteractionHandler >                m_xInteractionHandler;
     Reference< XProgressHandler >                   m_xProgressHandler;
@@ -153,27 +134,27 @@ public:
                                 , m_xProgressHandler( rxProgressHandler )
                             {}
 
-    virtual Reference<XInteractionHandler> SAL_CALL getInteractionHandler() throw (RuntimeException, std::exception) SAL_OVERRIDE
+    virtual Reference<XInteractionHandler> SAL_CALL getInteractionHandler() throw (RuntimeException, std::exception) override
     { return m_xInteractionHandler; }
 
-    virtual Reference<XProgressHandler> SAL_CALL    getProgressHandler() throw (RuntimeException, std::exception) SAL_OVERRIDE
+    virtual Reference<XProgressHandler> SAL_CALL    getProgressHandler() throw (RuntimeException, std::exception) override
     { return m_xProgressHandler; }
 };
 
 /**
     Helper class for property change notifies when executing UCB commands
 */
-class UcbPropertiesChangeListener_Impl : public ::cppu::WeakImplHelper1< XPropertiesChangeListener >
+class UcbPropertiesChangeListener_Impl : public ::cppu::WeakImplHelper< XPropertiesChangeListener >
 {
 public:
     UcbLockBytesRef         m_xLockBytes;
 
-                            UcbPropertiesChangeListener_Impl( UcbLockBytesRef rRef )
-                                : m_xLockBytes( rRef )
-                            {}
+    explicit UcbPropertiesChangeListener_Impl( UcbLockBytesRef rRef )
+        : m_xLockBytes( rRef )
+    {}
 
-    virtual void SAL_CALL   disposing ( const EventObject &/*rEvent*/) throw(RuntimeException, std::exception) SAL_OVERRIDE {}
-    virtual void SAL_CALL   propertiesChange ( const Sequence<PropertyChangeEvent> &rEvent) throw(RuntimeException, std::exception) SAL_OVERRIDE;
+    virtual void SAL_CALL   disposing ( const EventObject &/*rEvent*/) throw(RuntimeException, std::exception) override {}
+    virtual void SAL_CALL   propertiesChange ( const Sequence<PropertyChangeEvent> &rEvent) throw(RuntimeException, std::exception) override;
 };
 
 void SAL_CALL UcbPropertiesChangeListener_Impl::propertiesChange ( const Sequence<PropertyChangeEvent> &rEvent) throw(RuntimeException, std::exception)
@@ -234,14 +215,13 @@ class Moderator
 {
     // usage restriction:
     // It might be possible, that the call to the interactionhandler and/or
-    // progresshandler is done asynchrounsly, while the 'execute' simply
-    // returns. This would imply that these class must be refcounted !!!
+    // progresshandler is done asynchronously, while the 'execute' simply
+    // returns. This would imply that these class must be refcounted!!!
 
 public:
     Moderator(
         Reference < XContent >& xContent,
         Reference < XInteractionHandler >& xInteract,
-        Reference < XProgressHandler >& xProgress,
         const Command& rArg
     )
         throw(
@@ -283,7 +263,7 @@ public:
         }
 
     protected:
-        bool applies() const SAL_OVERRIDE {
+        bool applies() const override {
             return m_aModerator.m_aResultType != NORESULT;
         }
 
@@ -317,7 +297,7 @@ public:
         }
 
     protected:
-        bool applies() const SAL_OVERRIDE {
+        bool applies() const override {
             return m_aModerator.m_aReplyType != NOREPLY;
         }
 
@@ -328,16 +308,13 @@ public:
     void setReply(ReplyType);
 
     void handle( const Reference<XInteractionRequest >& Request );
-    void push( const Any& Status );
-    void update( const Any& Status );
-    void pop(  );
 
     void setStream(const Reference< XStream >& aStream);
     void setInputStream(const Reference<XInputStream> &rxInputStream);
 
 protected:
-    virtual void SAL_CALL run() SAL_OVERRIDE;
-    virtual void SAL_CALL onTerminated() SAL_OVERRIDE;
+    virtual void SAL_CALL run() override;
+    virtual void SAL_CALL onTerminated() override;
 
 private:
     osl::Mutex        m_aMutex;
@@ -359,11 +336,11 @@ private:
 };
 
 class ModeratorsActiveDataStreamer
-    : public ::cppu::WeakImplHelper1<XActiveDataStreamer>
+    : public ::cppu::WeakImplHelper<XActiveDataStreamer>
 {
 public:
 
-    ModeratorsActiveDataStreamer(Moderator &theModerator);
+    explicit ModeratorsActiveDataStreamer(Moderator &theModerator);
 
     virtual ~ModeratorsActiveDataStreamer();
 
@@ -374,14 +351,14 @@ public:
     )
         throw(
             RuntimeException, std::exception
-        ) SAL_OVERRIDE;
+        ) override;
 
     virtual Reference<XStream> SAL_CALL
     getStream (
         void
     ) throw(
         RuntimeException, std::exception
-    ) SAL_OVERRIDE
+    ) override
     {
         osl::MutexGuard aGuard(m_aMutex);
         return m_xStream;
@@ -395,11 +372,11 @@ private:
 };
 
 class ModeratorsActiveDataSink
-    : public ::cppu::WeakImplHelper1<XActiveDataSink>
+    : public ::cppu::WeakImplHelper<XActiveDataSink>
 {
 public:
 
-    ModeratorsActiveDataSink(Moderator &theModerator);
+    explicit ModeratorsActiveDataSink(Moderator &theModerator);
 
     virtual ~ModeratorsActiveDataSink();
 
@@ -410,14 +387,14 @@ public:
     )
         throw(
             RuntimeException, std::exception
-        ) SAL_OVERRIDE;
+        ) override;
 
     virtual Reference<XInputStream> SAL_CALL
     getInputStream (
         void
     ) throw(
         RuntimeException, std::exception
-    ) SAL_OVERRIDE
+    ) override
     {
         osl::MutexGuard aGuard(m_aMutex);
         return m_xStream;
@@ -478,73 +455,23 @@ ModeratorsActiveDataStreamer::setStream (
 }
 
 class ModeratorsInteractionHandler
-    : public ::cppu::WeakImplHelper1<XInteractionHandler>
+    : public ::cppu::WeakImplHelper<XInteractionHandler>
 {
 public:
 
-    ModeratorsInteractionHandler(Moderator &theModerator);
+    explicit ModeratorsInteractionHandler(Moderator &theModerator);
 
     virtual ~ModeratorsInteractionHandler();
 
     virtual void SAL_CALL
     handle( const Reference<XInteractionRequest >& Request )
-        throw (RuntimeException, std::exception) SAL_OVERRIDE;
+        throw (RuntimeException, std::exception) override;
 
 private:
 
     Moderator& m_aModerator;
 };
 
-class ModeratorsProgressHandler
-    : public ::cppu::WeakImplHelper1<XProgressHandler>
-{
-public:
-    ModeratorsProgressHandler(Moderator &theModerator);
-
-    virtual ~ModeratorsProgressHandler();
-
-    virtual void SAL_CALL push( const Any& Status )
-        throw (
-            RuntimeException, std::exception) SAL_OVERRIDE;
-
-    virtual void SAL_CALL update( const Any& Status )
-        throw (RuntimeException, std::exception) SAL_OVERRIDE;
-
-    virtual void SAL_CALL pop(  )
-        throw (RuntimeException, std::exception) SAL_OVERRIDE;
-
-private:
-    Moderator& m_aModerator;
-};
-
-ModeratorsProgressHandler::ModeratorsProgressHandler(Moderator &theModerator)
-    : m_aModerator(theModerator)
-{
-}
-
-ModeratorsProgressHandler::~ModeratorsProgressHandler()
-{
-}
-
-void SAL_CALL ModeratorsProgressHandler::push( const Any& Status )
-    throw (
-        RuntimeException, std::exception)
-{
-    m_aModerator.push(Status);
-}
-
-void SAL_CALL ModeratorsProgressHandler::update( const Any& Status )
-    throw (RuntimeException, std::exception)
-{
-    m_aModerator.update(Status);
-}
-
-void SAL_CALL ModeratorsProgressHandler::pop(  )
-    throw (RuntimeException, std::exception)
-{
-    m_aModerator.pop();
-}
-
 ModeratorsInteractionHandler::ModeratorsInteractionHandler(
     Moderator &aModerator)
     : m_aModerator(aModerator)
@@ -570,12 +497,11 @@ ModeratorsInteractionHandler::handle(
 Moderator::Moderator(
     Reference < XContent >& xContent,
     Reference < XInteractionHandler >& xInteract,
-    Reference < XProgressHandler >& xProgress,
     const Command& rArg
 )
     throw(
-        ::com::sun::star::ucb::ContentCreationException,
-        ::com::sun::star::uno::RuntimeException
+        css::ucb::ContentCreationException,
+        css::uno::RuntimeException
     )
     : m_aMutex(),
 
@@ -591,14 +517,14 @@ Moderator::Moderator(
       m_aContent(
           xContent,
           new UcbTaskEnvironment(
-              xInteract.is() ? new ModeratorsInteractionHandler(*this) : 0,
-              xProgress.is() ? new ModeratorsProgressHandler(*this) : 0),
+              xInteract.is() ? new ModeratorsInteractionHandler(*this) : nullptr,
+              nullptr),
           comphelper::getProcessComponentContext())
 {
     // now exchange the whole data sink stuff
     // with a thread safe version
 
-    Reference<XInterface> *pxSink = NULL;
+    Reference<XInterface> *pxSink = nullptr;
 
     PostCommandArgument2 aPostArg;
     OpenCommandArgument2 aOpenArg;
@@ -618,13 +544,11 @@ Moderator::Moderator(
 
     Reference < XActiveDataSink > xActiveSink(*pxSink,UNO_QUERY);
     if(xActiveSink.is())
-        *pxSink = Reference<XInterface>(
-            (cppu::OWeakObject*)new ModeratorsActiveDataSink(*this));
+        pxSink->set( static_cast<cppu::OWeakObject*>(new ModeratorsActiveDataSink(*this)));
 
     Reference<XActiveDataStreamer> xStreamer( *pxSink, UNO_QUERY );
     if ( xStreamer.is() )
-        *pxSink = Reference<XInterface>(
-            (cppu::OWeakObject*)new ModeratorsActiveDataStreamer(*this));
+        pxSink->set( static_cast<cppu::OWeakObject*>(new ModeratorsActiveDataStreamer(*this)));
 
     if(dec == 0)
         m_aArg.Argument <<= aPostArg;
@@ -698,56 +622,6 @@ void Moderator::handle( const Reference<XInteractionRequest >& Request )
     } while(aReplyType != REQUESTHANDLED);
 }
 
-void Moderator::push( const Any& Status )
-{
-    {
-        salhelper::ConditionModifier aMod(m_aRes);
-        m_aResultType = PROGRESSPUSH;
-        m_aResult = Status;
-    }
-    ReplyType aReplyType;
-    {
-        salhelper::ConditionWaiter aWait(m_aRep);
-        aReplyType = m_aReplyType;
-        m_aReplyType = NOREPLY;
-    }
-    if(aReplyType == EXIT)
-        setReply(EXIT);
-}
-
-void Moderator::update( const Any& Status )
-{
-    {
-        salhelper::ConditionModifier aMod(m_aRes);
-        m_aResultType = PROGRESSUPDATE;
-        m_aResult = Status;
-    }
-    ReplyType aReplyType;
-    {
-        salhelper::ConditionWaiter aWait(m_aRep);
-        aReplyType = m_aReplyType;
-        m_aReplyType = NOREPLY;
-    }
-    if(aReplyType == EXIT)
-        setReply(EXIT);
-}
-
-void Moderator::pop(  )
-{
-    {
-        salhelper::ConditionModifier aMod(m_aRes);
-        m_aResultType = PROGRESSPOP;
-    }
-    ReplyType aReplyType;
-    {
-        salhelper::ConditionWaiter aWait(m_aRep);
-        aReplyType = m_aReplyType;
-        m_aReplyType = NOREPLY;
-    }
-    if(aReplyType == EXIT)
-        setReply(EXIT);
-}
-
 void Moderator::setStream(const Reference< XStream >& aStream)
 {
     {
@@ -842,16 +716,14 @@ static bool _UCBOpenContentSync(
     Reference < XContent > xContent,
     const Command& rArg,
     Reference < XInterface > xSink,
-    Reference < XInteractionHandler > xInteract,
-    Reference < XProgressHandler > xProgress );
+    Reference < XInteractionHandler > xInteract );
 
 static bool UCBOpenContentSync(
     UcbLockBytesRef xLockBytes,
     Reference < XContent > xContent,
     const Command& rArg,
     Reference < XInterface > xSink,
-    Reference < XInteractionHandler > xInteract,
-    Reference < XProgressHandler > xProgress )
+    Reference < XInteractionHandler > xInteract )
 {
     // http protocol must be handled in a special way:
     //        during the opening process the input stream may change
@@ -859,7 +731,7 @@ static bool UCBOpenContentSync(
     //        headers is valid
 
     Reference<XContentIdentifier> xContId(
-        xContent.is() ? xContent->getIdentifier() : 0 );
+        xContent.is() ? xContent->getIdentifier() : nullptr );
 
     OUString aScheme;
     if(xContId.is())
@@ -869,9 +741,10 @@ static bool UCBOpenContentSync(
     if( ! aScheme.equalsIgnoreAsciiCase("http")                &&
         ! aScheme.equalsIgnoreAsciiCase("https")               &&
         ! aScheme.equalsIgnoreAsciiCase("vnd.sun.star.webdav") &&
+        ! aScheme.equalsIgnoreAsciiCase("vnd.sun.star.webdavs") &&
         ! aScheme.equalsIgnoreAsciiCase("ftp"))
         return _UCBOpenContentSync(
-            xLockBytes,xContent,rArg,xSink,xInteract,xProgress);
+            xLockBytes,xContent,rArg,xSink,xInteract);
 
     if ( !aScheme.equalsIgnoreAsciiCase( "http" ) &&
          !aScheme.equalsIgnoreAsciiCase( "https" ) )
@@ -892,10 +765,10 @@ static bool UCBOpenContentSync(
     bool bAborted(false);
     bool bResultAchieved(false);
 
-    Moderator* pMod = 0;
+    Moderator* pMod = nullptr;
     try
     {
-        pMod = new Moderator(xContent,xInteract,xProgress,rArg);
+        pMod = new Moderator(xContent,xInteract,rArg);
         pMod->create();
     }
     catch (const ContentCreationException&)
@@ -914,22 +787,16 @@ static bool UCBOpenContentSync(
         switch(res.type) {
         case Moderator::PROGRESSPUSH:
             {
-                if(xProgress.is())
-                    xProgress->push(res.result);
                 pMod->setReply(Moderator::REQUESTHANDLED);
                 break;
             }
         case Moderator::PROGRESSUPDATE:
             {
-                if(xProgress.is())
-                    xProgress->update(res.result);
                 pMod->setReply(Moderator::REQUESTHANDLED);
                 break;
             }
         case Moderator::PROGRESSPOP:
             {
-                if(xProgress.is())
-                    xProgress->pop();
                 pMod->setReply(Moderator::REQUESTHANDLED);
                 break;
             }
@@ -991,7 +858,7 @@ static bool UCBOpenContentSync(
                         = ir->getSelection();
                     if(ref.is()) {
                         Reference<XInterface> xInt(ref.get());
-                        xRet = Reference<XInteractionRetry>(xInt,UNO_QUERY);
+                        xRet.set(xInt,UNO_QUERY);
                     }
                 }
 
@@ -1094,11 +961,10 @@ static bool _UCBOpenContentSync(
     Reference < XContent > xContent,
     const Command& rArg,
     Reference < XInterface > xSink,
-    Reference < XInteractionHandler > xInteract,
-    Reference < XProgressHandler > xProgress )
+    Reference < XInteractionHandler > xInteract )
 {
     ::ucbhelper::Content aContent(
-        xContent, new UcbTaskEnvironment( xInteract, xProgress ),
+        xContent, new UcbTaskEnvironment( xInteract, nullptr ),
         comphelper::getProcessComponentContext() );
     Reference < XContentIdentifier > xIdent = xContent->getIdentifier();
     OUString aScheme = xIdent->getContentProviderScheme();
@@ -1177,8 +1043,7 @@ static bool _UCBOpenContentSync(
 
 UcbLockBytes::UcbLockBytes( UcbLockBytesHandler* pHandler )
     : m_aExpireDate( DateTime::EMPTY )
-    , m_xInputStream (NULL)
-    , m_pCommandThread( NULL )
+    , m_xInputStream (nullptr)
     , m_xHandler( pHandler )
     , m_nError( ERRCODE_NONE )
     , m_bTerminated  (false)
@@ -1236,7 +1101,7 @@ bool UcbLockBytes::setStream_Impl( const Reference<XStream>& aStream )
     {
         m_xOutputStream = aStream->getOutputStream();
         setInputStream_Impl( aStream->getInputStream(), false );
-        m_xSeekable = Reference < XSeekable > ( aStream, UNO_QUERY );
+        m_xSeekable.set( aStream, UNO_QUERY );
     }
     else
     {
@@ -1262,15 +1127,15 @@ bool UcbLockBytes::setInputStream_Impl( const Reference<XInputStream> &rxInputSt
 
         if( bSetXSeekable )
         {
-            m_xSeekable = Reference < XSeekable > ( rxInputStream, UNO_QUERY );
+            m_xSeekable.set( rxInputStream, UNO_QUERY );
             if( !m_xSeekable.is() && rxInputStream.is() )
             {
                 Reference < XComponentContext > xContext = ::comphelper::getProcessComponentContext();
-                Reference< XOutputStream > rxTempOut = Reference < XOutputStream > ( TempFile::create(xContext), UNO_QUERY_THROW );
+                Reference< XOutputStream > rxTempOut( css::io::TempFile::create(xContext), UNO_QUERY_THROW );
 
                 ::comphelper::OStorageHelper::CopyInputToOutput( rxInputStream, rxTempOut );
-                m_xInputStream = Reference< XInputStream >( rxTempOut, UNO_QUERY );
-                m_xSeekable = Reference < XSeekable > ( rxTempOut, UNO_QUERY );
+                m_xInputStream.set( rxTempOut, UNO_QUERY );
+                m_xSeekable.set( rxTempOut, UNO_QUERY );
             }
         }
 
@@ -1344,7 +1209,7 @@ ErrCode UcbLockBytes::ReadAt(sal_uInt64 const nPos,
     {
         return ERRCODE_IO_CANTSEEK;
     }
-    catch (const com::sun::star::lang::IllegalArgumentException&)
+    catch (const css::lang::IllegalArgumentException&)
     {
         return ERRCODE_IO_CANTSEEK;
     }
@@ -1451,7 +1316,7 @@ ErrCode UcbLockBytes::SetSize (sal_uInt64 const nNewSize)
             nSize = 0;
         }
         else {
-            DBG_WARNING("Not truncatable!");
+            SAL_INFO("unotools.ucbhelper", "Not truncatable!");
         }
     }
 
@@ -1505,15 +1370,10 @@ ErrCode UcbLockBytes::Stat( SvLockBytesStat *pStat, SvLockBytesStatFlag) const
     return ERRCODE_NONE;
 }
 
-IMPL_STATIC_LINK_NOARG(UcbLockBytes, DataAvailHdl)
-{
-    return 0;
-}
-
 UcbLockBytesRef UcbLockBytes::CreateInputLockBytes( const Reference< XInputStream >& xInputStream )
 {
     if( !xInputStream.is() )
-        return NULL;
+        return nullptr;
 
     UcbLockBytesRef xLockBytes = new UcbLockBytes(nullptr);
     xLockBytes->setDontClose_Impl();
@@ -1525,7 +1385,7 @@ UcbLockBytesRef UcbLockBytes::CreateInputLockBytes( const Reference< XInputStrea
 UcbLockBytesRef UcbLockBytes::CreateLockBytes( const Reference< XStream >& xStream )
 {
     if( !xStream.is() )
-        return NULL;
+        return nullptr;
 
     UcbLockBytesRef xLockBytes = new UcbLockBytes(nullptr);
     xLockBytes->setDontClose_Impl();
@@ -1538,15 +1398,15 @@ UcbLockBytesRef UcbLockBytes::CreateLockBytes( const Reference < XContent >& xCo
         StreamMode eOpenMode, const Reference < XInteractionHandler >& xInteractionHandler, UcbLockBytesHandler* pHandler )
 {
     if( !xContent.is() )
-        return NULL;
+        return nullptr;
 
     UcbLockBytesRef xLockBytes = new UcbLockBytes( pHandler );
     xLockBytes->SetSynchronMode( !pHandler );
     Reference< XActiveDataControl > xSink;
     if ( eOpenMode & StreamMode::WRITE )
-        xSink = (XActiveDataControl*) new UcbStreamer_Impl( xLockBytes );
+        xSink = static_cast<XActiveDataControl*>(new UcbStreamer_Impl( xLockBytes ));
     else
-        xSink = (XActiveDataControl*) new UcbDataSink_Impl( xLockBytes );
+        xSink = static_cast<XActiveDataControl*>(new UcbDataSink_Impl( xLockBytes ));
 
     if ( rProps.getLength() )
     {
@@ -1566,14 +1426,11 @@ UcbLockBytesRef UcbLockBytes::CreateLockBytes( const Reference < XContent >& xCo
     aCommand.Name = "open";
     aCommand.Argument <<= aArgument;
 
-    Reference< XProgressHandler > xProgressHdl = new ProgressHandler_Impl( LINK( &xLockBytes, UcbLockBytes, DataAvailHdl ) );
-
     bool bError = UCBOpenContentSync( xLockBytes,
                                       xContent,
                                       aCommand,
                                       xSink,
-                                      xInteractionHandler,
-                                      xProgressHdl );
+                                      xInteractionHandler );
 
     if ( xLockBytes->GetError() == ERRCODE_NONE && ( bError || !xLockBytes->getInputStream().is() ) )
     {
