@@ -29,14 +29,15 @@ VbaPageSetupBase::VbaPageSetupBase(const uno::Reference< XHelperInterface >& xPa
 {
 }
 
-double SAL_CALL VbaPageSetupBase::getTopMargin() throw (css::uno::RuntimeException)
+double SAL_CALL VbaPageSetupBase::getTopMargin() throw (css::uno::RuntimeException, std::exception)
 {
-    sal_Bool headerOn = sal_False;
     sal_Int32 topMargin = 0;
-    sal_Int32 headerHeight = 0;
 
     try
     {
+        bool headerOn = false;
+        sal_Int32 headerHeight = 0;
+
         uno::Any aValue = mxPageProps->getPropertyValue( "HeaderIsOn" );
         aValue >>= headerOn;
 
@@ -57,14 +58,15 @@ double SAL_CALL VbaPageSetupBase::getTopMargin() throw (css::uno::RuntimeExcepti
     return Millimeter::getInPoints( topMargin );
 }
 
-void SAL_CALL VbaPageSetupBase::setTopMargin( double margin ) throw (css::uno::RuntimeException)
+void SAL_CALL VbaPageSetupBase::setTopMargin( double margin ) throw (css::uno::RuntimeException, std::exception)
 {
     sal_Int32 topMargin = Millimeter::getInHundredthsOfOneMillimeter( margin );
-    sal_Bool headerOn = sal_False;
-    sal_Int32 headerHeight = 0;
 
     try
     {
+        bool headerOn = false;
+        sal_Int32 headerHeight = 0;
+
         uno::Any aValue = mxPageProps->getPropertyValue( "HeaderIsOn" );
         aValue >>= headerOn;
 
@@ -83,14 +85,15 @@ void SAL_CALL VbaPageSetupBase::setTopMargin( double margin ) throw (css::uno::R
     }
 }
 
-double SAL_CALL VbaPageSetupBase::getBottomMargin() throw (css::uno::RuntimeException)
+double SAL_CALL VbaPageSetupBase::getBottomMargin() throw (css::uno::RuntimeException, std::exception)
 {
-    sal_Bool footerOn = sal_False;
     sal_Int32 bottomMargin = 0;
-    sal_Int32 footerHeight = 0;
 
     try
     {
+        bool footerOn = false;
+        sal_Int32 footerHeight = 0;
+
         uno::Any aValue = mxPageProps->getPropertyValue( "FooterIsOn" );
         aValue >>= footerOn;
 
@@ -111,14 +114,15 @@ double SAL_CALL VbaPageSetupBase::getBottomMargin() throw (css::uno::RuntimeExce
     return Millimeter::getInPoints( bottomMargin );
 }
 
-void SAL_CALL VbaPageSetupBase::setBottomMargin( double margin ) throw (css::uno::RuntimeException)
+void SAL_CALL VbaPageSetupBase::setBottomMargin( double margin ) throw (css::uno::RuntimeException, std::exception)
 {
     sal_Int32 bottomMargin = Millimeter::getInHundredthsOfOneMillimeter( margin );
-    sal_Bool footerOn = sal_False;
-    sal_Int32 footerHeight = 0;
 
     try
     {
+        bool footerOn = false;
+        sal_Int32 footerHeight = 0;
+
         uno::Any aValue = mxPageProps->getPropertyValue( "FooterIsOn" );
         aValue >>= footerOn;
 
@@ -137,7 +141,7 @@ void SAL_CALL VbaPageSetupBase::setBottomMargin( double margin ) throw (css::uno
     }
 }
 
-double SAL_CALL VbaPageSetupBase::getRightMargin() throw (css::uno::RuntimeException)
+double SAL_CALL VbaPageSetupBase::getRightMargin() throw (css::uno::RuntimeException, std::exception)
 {
     sal_Int32 rightMargin = 0;
     try
@@ -152,7 +156,7 @@ double SAL_CALL VbaPageSetupBase::getRightMargin() throw (css::uno::RuntimeExcep
     return Millimeter::getInPoints( rightMargin );
 }
 
-void SAL_CALL VbaPageSetupBase::setRightMargin( double margin ) throw (css::uno::RuntimeException)
+void SAL_CALL VbaPageSetupBase::setRightMargin( double margin ) throw (css::uno::RuntimeException, std::exception)
 {
     sal_Int32 rightMargin = Millimeter::getInHundredthsOfOneMillimeter( margin );
     try
@@ -167,7 +171,7 @@ void SAL_CALL VbaPageSetupBase::setRightMargin( double margin ) throw (css::uno:
 
 }
 
-double SAL_CALL VbaPageSetupBase::getLeftMargin() throw (css::uno::RuntimeException)
+double SAL_CALL VbaPageSetupBase::getLeftMargin() throw (css::uno::RuntimeException, std::exception)
 {
     sal_Int32 leftMargin = 0;
     try
@@ -182,7 +186,7 @@ double SAL_CALL VbaPageSetupBase::getLeftMargin() throw (css::uno::RuntimeExcept
     return Millimeter::getInPoints( leftMargin );
 }
 
-void SAL_CALL VbaPageSetupBase::setLeftMargin( double margin ) throw (css::uno::RuntimeException)
+void SAL_CALL VbaPageSetupBase::setLeftMargin( double margin ) throw (css::uno::RuntimeException, std::exception)
 {
     sal_Int32 leftMargin = Millimeter::getInHundredthsOfOneMillimeter( margin );
     try
@@ -254,12 +258,12 @@ void SAL_CALL VbaPageSetupBase::setFooterMargin( double margin ) throw (css::uno
     }
 }
 
-sal_Int32 SAL_CALL VbaPageSetupBase::getOrientation() throw (css::uno::RuntimeException)
+sal_Int32 SAL_CALL VbaPageSetupBase::getOrientation() throw (css::uno::RuntimeException, std::exception)
 {
     sal_Int32 orientation = mnOrientPortrait;
     try
     {
-        sal_Bool isLandscape = sal_False;
+        bool isLandscape = false;
         uno::Any aValue = mxPageProps->getPropertyValue( "IsLandscape" );
         aValue >>= isLandscape;
 
@@ -274,25 +278,25 @@ sal_Int32 SAL_CALL VbaPageSetupBase::getOrientation() throw (css::uno::RuntimeEx
     return orientation;
 }
 
-void SAL_CALL VbaPageSetupBase::setOrientation( sal_Int32 orientation ) throw (css::uno::RuntimeException)
+void SAL_CALL VbaPageSetupBase::setOrientation( sal_Int32 orientation ) throw (css::uno::RuntimeException, std::exception)
 {
     if( ( orientation != mnOrientPortrait ) &&
         ( orientation != mnOrientLandscape ) )
     {
-        DebugHelper::exception(SbERR_BAD_PARAMETER, OUString() );
+        DebugHelper::runtimeexception(ERRCODE_BASIC_BAD_PARAMETER, OUString() );
     }
 
     try
     {
-        sal_Bool isLandscape = sal_False;
+        bool isLandscape = false;
         uno::Any aValue = mxPageProps->getPropertyValue( "IsLandscape" );
         aValue >>= isLandscape;
 
-        sal_Bool switchOrientation = sal_False;
+        bool switchOrientation = false;
         if(( isLandscape && orientation != mnOrientLandscape ) ||
             ( !isLandscape && orientation != mnOrientPortrait ))
         {
-            switchOrientation = sal_True;
+            switchOrientation = true;
         }
 
         if( switchOrientation )
