@@ -55,8 +55,6 @@
 
 #include "rtl/instance.hxx"
 
-typedef const FT_Vector* FT_Vector_CPtr;
-
 #include <vector>
 
 // TODO: move file mapping stuff to OSL
@@ -66,34 +64,12 @@ typedef const FT_Vector* FT_Vector_CPtr;
 #include <sys/mman.h>
 #include "fontmanager.hxx"
 
-// the gamma table makes artificial bold look better for CJK glyphs
-static unsigned char aGammaTable[257];
-
-static void InitGammaTable()
-{
-    static const int M_MAX = 255;
-    static const int M_X   = 128;
-    static const int M_Y   = 208;
-
-    int x, a;
-    for( x = 0; x < 256; x++)
-    {
-        if ( x <= M_X )
-            a = ( x * M_Y + M_X / 2) / M_X;
-        else
-            a = M_Y + ( ( x - M_X ) * ( M_MAX - M_Y ) +
-                ( M_MAX - M_X ) / 2 ) / ( M_MAX - M_X );
-
-        aGammaTable[x] = (unsigned char)a;
-    }
-}
-
-static FT_Library aLibFT = 0;
+static FT_Library aLibFT = nullptr;
 
 // enable linking with old FT versions
 static int nFTVERSION = 0;
 
-typedef ::boost::unordered_map<const char*, boost::shared_ptr<FtFontFile>, rtl::CStringHash, rtl::CStringEqual> FontFileList;
+typedef std::unordered_map<const char*, std::shared_ptr<FtFontFile>, rtl::CStringHash, rtl::CStringEqual> FontFileList;
 
 namespace { struct vclFontFileList : public rtl::Static< FontFileList, vclFontFileList > {}; }
 
@@ -112,7 +88,7 @@ static int nDefaultPrioAntiAlias   = 1;
 
 FtFontFile::FtFontFile( const OString& rNativeFileName )
 :   maNativeFileName( rNativeFileName ),
-    mpFileMap( NULL ),
+    mpFileMap( nullptr ),
     mnFileSize( 0 ),
     mnRefCount( 0 ),
     mnLangBoost( 0 )
@@ -123,7 +99,7 @@ FtFontFile::FtFontFile( const OString& rNativeFileName )
         mnLangBoost += 0x1000;     // no langinfo => good
     else
     {
-        static const char* pLangBoost = NULL;
+        static const char* pLangBoost = nullptr;
         static bool bOnce = true;
         if( bOnce )
         {
@@ -169,30 +145,30 @@ bool FtFontFile::Map()
             return false;
         }
         mnFileSize = aStat.st_size;
-        mpFileMap = (const unsigned char*)
-            mmap( NULL, mnFileSize, PROT_READ, MAP_SHARED, nFile, 0 );
+        mpFileMap = static_cast<unsigned char*>(
+            mmap( nullptr, mnFileSize, PROT_READ, MAP_SHARED, nFile, 0 ));
         if( mpFileMap == MAP_FAILED )
-            mpFileMap = NULL;
+            mpFileMap = nullptr;
         close( nFile );
     }
 
-    return (mpFileMap != NULL);
+    return (mpFileMap != nullptr);
 }
 
 void FtFontFile::Unmap()
 {
-    if( (--mnRefCount > 0) || (mpFileMap == NULL) )
+    if( (--mnRefCount > 0) || (mpFileMap == nullptr) )
         return;
 
-    munmap( (char*)mpFileMap, mnFileSize );
-    mpFileMap = NULL;
+    munmap( mpFileMap, mnFileSize );
+    mpFileMap = nullptr;
 }
 
 #if ENABLE_GRAPHITE
 // wrap FtFontInfo's table function
 const void * graphiteFontTable(const void* appFaceHandle, unsigned int name, size_t *len)
 {
-    const FtFontInfo * pFontInfo = reinterpret_cast<const FtFontInfo*>(appFaceHandle);
+    const FtFontInfo * pFontInfo = static_cast<const FtFontInfo*>(appFaceHandle);
     typedef union {
         char m_c[5];
         unsigned int m_id;
@@ -216,22 +192,21 @@ const void * graphiteFontTable(const void* appFaceHandle, unsigned int name, siz
 #endif
 
 FtFontInfo::FtFontInfo( const ImplDevFontAttributes& rDevFontAttributes,
-    const OString& rNativeFileName, int nFaceNum, sal_IntPtr nFontId, int nSynthetic)
+    const OString& rNativeFileName, int nFaceNum, sal_IntPtr nFontId)
 :
-    maFaceFT( NULL ),
+    maFaceFT( nullptr ),
     mpFontFile( FtFontFile::FindFontFile( rNativeFileName ) ),
     mnFaceNum( nFaceNum ),
     mnRefCount( 0 ),
-    mnSynthetic( nSynthetic ),
 #if ENABLE_GRAPHITE
     mbCheckedGraphite(false),
-    mpGraphiteFace(NULL),
+    mpGraphiteFace(nullptr),
 #endif
     mnFontId( nFontId ),
     maDevFontAttributes( rDevFontAttributes ),
-    mpFontCharMap( NULL ),
-    mpChar2Glyph( NULL ),
-    mpGlyph2Char( NULL )
+    mpFontCharMap( nullptr ),
+    mpChar2Glyph( nullptr ),
+    mpGlyph2Char( nullptr )
 {
     // prefer font with low ID
     maDevFontAttributes.mnQuality += 10000 - nFontId;
@@ -242,7 +217,7 @@ FtFontInfo::FtFontInfo( const ImplDevFontAttributes& rDevFontAttributes,
 FtFontInfo::~FtFontInfo()
 {
     if( mpFontCharMap )
-        mpFontCharMap->DeReference();
+        mpFontCharMap = nullptr;
     delete mpChar2Glyph;
     delete mpGlyph2Char;
 #if ENABLE_GRAPHITE
@@ -262,10 +237,10 @@ FT_FaceRec_* FtFontInfo::GetFaceFT()
     if (!maFaceFT && mpFontFile->Map())
     {
         FT_Error rc = FT_New_Memory_Face( aLibFT,
-            (FT_Byte*)mpFontFile->GetBuffer(),
+            mpFontFile->GetBuffer(),
             mpFontFile->GetFileSize(), mnFaceNum, &maFaceFT );
         if( (rc != FT_Err_Ok) || (maFaceFT->num_glyphs <= 0) )
-            maFaceFT = NULL;
+            maFaceFT = nullptr;
     }
 
    ++mnRefCount;
@@ -278,7 +253,7 @@ GraphiteFaceWrapper * FtFontInfo::GetGraphiteFace()
     if (mbCheckedGraphite)
         return mpGraphiteFace;
     // test for graphite here so that it is cached most efficiently
-    if (GetTable("Silf", 0))
+    if (GetTable("Silf"))
     {
         static const char* pGraphiteCacheStr = getenv( "SAL_GRAPHITE_CACHE_SIZE" );
         int graphiteSegCacheSize = pGraphiteCacheStr ? (atoi(pGraphiteCacheStr)) : 0;
@@ -300,7 +275,7 @@ void FtFontInfo::ReleaseFaceFT()
     if (--mnRefCount <= 0)
     {
         FT_Done_Face( maFaceFT );
-        maFaceFT = NULL;
+        maFaceFT = nullptr;
         mpFontFile->Unmap();
     }
 }
@@ -318,7 +293,7 @@ const unsigned char* FtFontInfo::GetTable( const char* pTag, sal_uLong* pLength
     const unsigned char* pBuffer = mpFontFile->GetBuffer();
     int nFileSize = mpFontFile->GetFileSize();
     if( !pBuffer || nFileSize<1024 )
-        return NULL;
+        return nullptr;
 
     // we currently handle TTF, TTC and OTF headers
     unsigned nFormat = GetUInt( pBuffer );
@@ -327,18 +302,18 @@ const unsigned char* FtFontInfo::GetTable( const char* pTag, sal_uLong* pLength
     if( nFormat == T_ttcf )         // TTC_MAGIC
         p += GetUInt( p + 4 * mnFaceNum );
     else if( nFormat != 0x00010000 && nFormat != T_true && nFormat != T_otto) // TTF_MAGIC and Apple TTF Magic and PS-OpenType font
-        return NULL;
+        return nullptr;
 
     // walk table directory until match
     int nTables = GetUShort( p - 8 );
     if( nTables >= 64 )  // something fishy?
-        return NULL;
+        return nullptr;
     for( int i = 0; i < nTables; ++i, p+=16 )
     {
         if( p[0]==pTag[0] && p[1]==pTag[1] && p[2]==pTag[2] && p[3]==pTag[3] )
         {
             sal_uLong nLength = GetUInt( p + 12 );
-            if( pLength != NULL )
+            if( pLength != nullptr )
                 *pLength = nLength;
             const unsigned char* pTable = pBuffer + GetUInt( p + 8 );
             if( (pTable + nLength) <= (mpFontFile->GetBuffer() + nFileSize) )
@@ -346,7 +321,7 @@ const unsigned char* FtFontInfo::GetTable( const char* pTag, sal_uLong* pLength
         }
     }
 
-    return NULL;
+    return nullptr;
 }
 
 void FtFontInfo::AnnounceFont( PhysicalFontCollection* pFontCollection )
@@ -376,7 +351,6 @@ FreetypeManager::FreetypeManager()
     if( pEnv )
         nDefaultPrioAutoHint  = pEnv[0] - '0';
 
-    InitGammaTable();
     vclFontFileList::get();
 }
 
@@ -402,7 +376,7 @@ void FreetypeManager::AddFontFile( const OString& rNormalizedName,
         return;
 
     FtFontInfo* pFontInfo = new FtFontInfo( rDevFontAttr,
-        rNormalizedName, nFaceNum, nFontId, 0);
+        rNormalizedName, nFaceNum, nFontId);
     maFontList[ nFontId ] = pFontInfo;
     if( mnMaxFontId < nFontId )
         mnMaxFontId = nFontId;
@@ -429,7 +403,7 @@ void FreetypeManager::ClearFontList( )
 
 ServerFont* FreetypeManager::CreateFont( const FontSelectPattern& rFSD )
 {
-    FtFontInfo* pFontInfo = NULL;
+    FtFontInfo* pFontInfo = nullptr;
 
     // find a FontInfo matching to the font id
     sal_IntPtr nFontId = reinterpret_cast<sal_IntPtr>( rFSD.mpFontData );
@@ -438,7 +412,7 @@ ServerFont* FreetypeManager::CreateFont( const FontSelectPattern& rFSD )
         pFontInfo = it->second;
 
     if( !pFontInfo )
-        return NULL;
+        return nullptr;
 
     ServerFont* pNew = new ServerFont( rFSD, pFontInfo );
 
@@ -466,27 +440,28 @@ ServerFont::ServerFont( const FontSelectPattern& rFSD, FtFontInfo* pFI )
     maFontSelData(rFSD),
     mnRefCount(1),
     mnBytesUsed( sizeof(ServerFont) ),
-    mpPrevGCFont( NULL ),
-    mpNextGCFont( NULL ),
+    mpPrevGCFont( nullptr ),
+    mpNextGCFont( nullptr ),
     mnCos( 0x10000),
     mnSin( 0 ),
-    mbCollectedZW( false ),
     mnPrioEmbedded(nDefaultPrioEmbedded),
     mnPrioAntiAlias(nDefaultPrioAntiAlias),
     mnPrioAutoHint(nDefaultPrioAutoHint),
     mpFontInfo( pFI ),
     mnLoadFlags( 0 ),
-    maFaceFT( NULL ),
-    maSizeFT( NULL ),
+    maFaceFT( nullptr ),
+    maSizeFT( nullptr ),
     mbFaceOk( false ),
     mbArtItalic( false ),
     mbArtBold( false ),
     mbUseGamma( false ),
-    mpLayoutEngine( NULL )
+    mpLayoutEngine( nullptr )
 {
     // TODO: move update of mpFontEntry into FontEntry class when
-    // it becomes reponsible for the ServerFont instantiation
-    ((ImplServerFontEntry*)rFSD.mpFontEntry)->SetServerFont( this );
+    // it becomes responsible for the ServerFont instantiation
+    static_cast<ImplServerFontEntry*>(rFSD.mpFontEntry)->SetServerFont( this );
+
+    maFaceFT = pFI->GetFaceFT();
 
     if( rFSD.mnOrientation != 0 )
     {
@@ -504,7 +479,6 @@ ServerFont::ServerFont( const FontSelectPattern& rFSD, FtFontInfo* pFI )
     if( (mnWidth < 0) || (mfStretch > +64.0) || (mfStretch < -64.0) )
         return;
 
-    maFaceFT = pFI->GetFaceFT();
     if( !maFaceFT )
         return;
 
@@ -547,7 +521,7 @@ ServerFont::ServerFont( const FontSelectPattern& rFSD, FtFontInfo* pFI )
         //static const int TT_CODEPAGE_RANGE_950  = (1L << 20); // Chinese: Traditional
         //static const int TT_CODEPAGE_RANGE_1361 = (1L << 21); // Korean Johab
         static const int TT_CODEPAGE_RANGES1_CJKT = 0x3F0000; // all of the above
-        const TT_OS2* pOs2 = (const TT_OS2*)FT_Get_Sfnt_Table( maFaceFT, ft_sfnt_os2 );
+        const TT_OS2* pOs2 = static_cast<const TT_OS2*>(FT_Get_Sfnt_Table( maFaceFT, ft_sfnt_os2 ));
         if ((pOs2) && (pOs2->ulCodePageRange1 & TT_CODEPAGE_RANGES1_CJKT )
         && rFSD.mnHeight < 20)
         mbUseGamma = true;
@@ -557,14 +531,14 @@ ServerFont::ServerFont( const FontSelectPattern& rFSD, FtFontInfo* pFI )
         mnLoadFlags |= FT_LOAD_NO_BITMAP;
 }
 
-void ServerFont::SetFontOptions( boost::shared_ptr<ImplFontOptions> pFontOptions)
+void ServerFont::SetFontOptions(std::shared_ptr<FontConfigFontOptions> xFontOptions)
 {
-    mpFontOptions = pFontOptions;
+    mxFontOptions = xFontOptions;
 
-    if (!mpFontOptions)
+    if (!mxFontOptions)
         return;
 
-    FontAutoHint eHint = mpFontOptions->GetUseAutoHint();
+    FontAutoHint eHint = mxFontOptions->GetUseAutoHint();
     if( eHint == AUTOHINT_DONTKNOW )
         eHint = mbUseGamma ? AUTOHINT_TRUE : AUTOHINT_FALSE;
 
@@ -573,13 +547,13 @@ void ServerFont::SetFontOptions( boost::shared_ptr<ImplFontOptions> pFontOptions
 
     if( (mnSin != 0) && (mnCos != 0) ) // hinting for 0/90/180/270 degrees only
         mnLoadFlags |= FT_LOAD_NO_HINTING;
-    mnLoadFlags |= FT_LOAD_IGNORE_GLOBAL_ADVANCE_WIDTH; //#88334#
+    mnLoadFlags |= FT_LOAD_IGNORE_GLOBAL_ADVANCE_WIDTH;
 
-    if( mpFontOptions->DontUseAntiAlias() )
+    if (mxFontOptions->DontUseAntiAlias())
       mnPrioAntiAlias = 0;
-    if( mpFontOptions->DontUseEmbeddedBitmaps() )
+    if (mxFontOptions->DontUseEmbeddedBitmaps())
       mnPrioEmbedded = 0;
-    if( mpFontOptions->DontUseHinting() )
+    if (mxFontOptions->DontUseHinting())
       mnPrioAutoHint = 0;
 
     if( mnPrioAutoHint <= 0 )
@@ -589,7 +563,7 @@ void ServerFont::SetFontOptions( boost::shared_ptr<ImplFontOptions> pFontOptions
     if( !(mnLoadFlags & FT_LOAD_NO_HINTING) )
     {
        mnLoadFlags |= FT_LOAD_TARGET_NORMAL;
-       switch( mpFontOptions->GetHintStyle() )
+       switch (mxFontOptions->GetHintStyle())
        {
            case HINT_NONE:
                 mnLoadFlags |= FT_LOAD_NO_HINTING;
@@ -610,25 +584,20 @@ void ServerFont::SetFontOptions( boost::shared_ptr<ImplFontOptions> pFontOptions
         mnLoadFlags |= FT_LOAD_NO_BITMAP;
 }
 
-boost::shared_ptr<ImplFontOptions> ServerFont::GetFontOptions() const
+std::shared_ptr<FontConfigFontOptions> ServerFont::GetFontOptions() const
 {
-    return mpFontOptions;
+    return mxFontOptions;
 }
 
-const OString* ServerFont::GetFontFileName() const
+const OString& ServerFont::GetFontFileName() const
 {
     return mpFontInfo->GetFontFileName();
 }
 
-bool ServerFont::TestFont() const
-{
-    return mbFaceOk;
-}
 
 ServerFont::~ServerFont()
 {
-    if( mpLayoutEngine )
-        delete mpLayoutEngine;
+    delete mpLayoutEngine;
 
     if( maSizeFT )
         FT_Done_Size( maSizeFT );
@@ -638,16 +607,13 @@ ServerFont::~ServerFont()
     ReleaseFromGarbageCollect();
 }
 
-int ServerFont::GetEmUnits() const
-{
-    return maFaceFT->units_per_EM;
-}
 
 void ServerFont::FetchFontMetric( ImplFontMetricData& rTo, long& rFactor ) const
 {
     static_cast<ImplFontAttributes&>(rTo) = mpFontInfo->GetFontAttributes();
 
-    rTo.mbScalableFont  = true;
+    rTo.mbScalableFont  = true; // FIXME: Shouldn't this check FT_IS_SCALABLE( maFaceFT )?
+    rTo.mbTrueTypeFont  = FT_IS_SFNT( maFaceFT ) != 0;
     rTo.mbDevice        = true;
     rTo.mbKernableFont  = FT_HAS_KERNING( maFaceFT ) != 0;
     rTo.mnOrientation = GetFontSelData().mnOrientation;
@@ -660,7 +626,7 @@ void ServerFont::FetchFontMetric( ImplFontMetricData& rTo, long& rFactor ) const
 
     rFactor = 0x100;
 
-    const TT_OS2* pOS2 = (const TT_OS2*)FT_Get_Sfnt_Table( maFaceFT, ft_sfnt_os2 );
+    const TT_OS2* pOS2 = static_cast<const TT_OS2*>(FT_Get_Sfnt_Table( maFaceFT, ft_sfnt_os2 ));
     const double fScale = (double)GetFontSelData().mnHeight / maFaceFT->units_per_EM;
 
     rTo.mnAscent = 0;
@@ -684,7 +650,7 @@ void ServerFont::FetchFontMetric( ImplFontMetricData& rTo, long& rFactor ) const
     }
     else
     {
-        const TT_HoriHeader* pHHea = (const TT_HoriHeader*)FT_Get_Sfnt_Table(maFaceFT, ft_sfnt_hhea);
+        const TT_HoriHeader* pHHea = static_cast<const TT_HoriHeader*>(FT_Get_Sfnt_Table(maFaceFT, ft_sfnt_hhea));
         if (pHHea)
         {
             rTo.mnAscent = pHHea->Ascender * fScale + 0.5;
@@ -826,13 +792,13 @@ int ServerFont::ApplyGlyphTransform( int nGlyphFlags,
 
     if( pGlyphFT->format != FT_GLYPH_FORMAT_BITMAP )
     {
-        FT_Glyph_Transform( pGlyphFT, NULL, &aVector );
+        FT_Glyph_Transform( pGlyphFT, nullptr, &aVector );
 
         // orthogonal transforms are better handled by bitmap operations
         if( bStretched || (bForBitmapProcessing && (nAngle % 900) != 0) )
         {
             // apply non-orthogonal or stretch transformations
-            FT_Glyph_Transform( pGlyphFT, &aMatrix, NULL );
+            FT_Glyph_Transform( pGlyphFT, &aMatrix, nullptr );
             nAngle = 0;
         }
     }
@@ -902,13 +868,7 @@ sal_GlyphId ServerFont::FixupGlyphIndex( sal_GlyphId aGlyphId, sal_UCS4 aChar )
         GlyphSubstitution::const_iterator it = maGlyphSubstitution.find( aGlyphId );
         if( it == maGlyphSubstitution.end() )
         {
-            sal_GlyphId nTemp = GetVerticalChar( aChar );
-            if( nTemp ) // is substitution possible
-                nTemp = GetRawGlyphIndex( nTemp );
-            if( nTemp ) // substitute manually if sensible
-                aGlyphId = nTemp | (GF_GSUB | GF_ROTL);
-            else
-                nGlyphFlags |= GetVerticalFlags( aChar );
+            nGlyphFlags |= GetVerticalFlags( aChar );
         }
         else
         {
@@ -976,7 +936,7 @@ void ServerFont::InitGlyphData( sal_GlyphId aGlyphId, GlyphData& rGD ) const
     rGD.SetCharWidth( nCharWidth );
 
     FT_Glyph pGlyphFT;
-    rc = FT_Get_Glyph( maFaceFT->glyph, &pGlyphFT );
+    FT_Get_Glyph( maFaceFT->glyph, &pGlyphFT );
 
     ApplyGlyphTransform( nGlyphFlags, pGlyphFT, false );
     rGD.SetDelta( (pGlyphFT->advance.x + 0x8000) >> 16, -((pGlyphFT->advance.y + 0x8000) >> 16) );
@@ -994,7 +954,7 @@ void ServerFont::InitGlyphData( sal_GlyphId aGlyphId, GlyphData& rGD ) const
     FT_Done_Glyph( pGlyphFT );
 }
 
-bool ServerFont::GetAntialiasAdvice( void ) const
+bool ServerFont::GetAntialiasAdvice() const
 {
     if( GetFontSelData().mbNonAntialiased || (mnPrioAntiAlias<=0) )
         return false;
@@ -1003,284 +963,15 @@ bool ServerFont::GetAntialiasAdvice( void ) const
     return bAdviseAA;
 }
 
-bool ServerFont::GetGlyphBitmap1( sal_GlyphId aGlyphId, RawBitmap& rRawBitmap ) const
-{
-    FT_Activate_Size( maSizeFT );
-
-    int nGlyphFlags;
-    SplitGlyphFlags( *this, aGlyphId, nGlyphFlags );
-
-    FT_Int nLoadFlags = mnLoadFlags;
-    // #i70930# force mono-hinting for monochrome text
-    nLoadFlags &= ~0xF0000;
-    nLoadFlags |= FT_LOAD_TARGET_MONO;
-
-    if( mbArtItalic )
-        nLoadFlags |= FT_LOAD_NO_BITMAP;
-
-    // for 0/90/180/270 degree fonts enable hinting even if not advisable
-    // non-hinted and non-antialiased bitmaps just look too ugly
-    if( (mnCos==0 || mnSin==0) && (mnPrioAutoHint > 0) )
-        nLoadFlags &= ~FT_LOAD_NO_HINTING;
-
-    if( mnPrioEmbedded <= mnPrioAutoHint )
-        nLoadFlags |= FT_LOAD_NO_BITMAP;
-
-    FT_Error rc = FT_Load_Glyph( maFaceFT, aGlyphId, nLoadFlags );
-
-    if( rc != FT_Err_Ok )
-        return false;
-
-    if (mbArtBold)
-        FT_GlyphSlot_Embolden(maFaceFT->glyph);
-
-    FT_Glyph pGlyphFT;
-    rc = FT_Get_Glyph( maFaceFT->glyph, &pGlyphFT );
-    if( rc != FT_Err_Ok )
-        return false;
-
-    int nAngle = ApplyGlyphTransform( nGlyphFlags, pGlyphFT, true );
-
-    if( mbArtItalic )
-    {
-        FT_Matrix aMatrix;
-        aMatrix.xx = aMatrix.yy = 0x10000L;
-        aMatrix.xy = 0x6000L, aMatrix.yx = 0;
-        FT_Glyph_Transform( pGlyphFT, &aMatrix, NULL );
-    }
-
-    // Check for zero area bounding boxes as this crashes some versions of FT.
-    // This also provides a handy short cut as much of the code following
-    //  becomes an expensive nop when a glyph covers no pixels.
-    FT_BBox cbox;
-    FT_Glyph_Get_CBox(pGlyphFT, ft_glyph_bbox_unscaled, &cbox);
-
-    if( (cbox.xMax - cbox.xMin) == 0 || (cbox.yMax - cbox.yMin == 0) )
-    {
-        nAngle = 0;
-        memset(&rRawBitmap, 0, sizeof rRawBitmap);
-        FT_Done_Glyph( pGlyphFT );
-        return true;
-    }
-
-    if( pGlyphFT->format != FT_GLYPH_FORMAT_BITMAP )
-    {
-        if( pGlyphFT->format == FT_GLYPH_FORMAT_OUTLINE )
-            ((FT_OutlineGlyphRec*)pGlyphFT)->outline.flags |= FT_OUTLINE_HIGH_PRECISION;
-        FT_Render_Mode nRenderMode = FT_RENDER_MODE_MONO;
-
-        rc = FT_Glyph_To_Bitmap( &pGlyphFT, nRenderMode, NULL, true );
-        if( rc != FT_Err_Ok )
-        {
-            FT_Done_Glyph( pGlyphFT );
-            return false;
-        }
-    }
-
-    const FT_BitmapGlyph pBmpGlyphFT = reinterpret_cast<const FT_BitmapGlyph>(pGlyphFT);
-    // NOTE: autohinting in FT<=2.0.2 miscalculates the offsets below by +-1
-    rRawBitmap.mnXOffset        = +pBmpGlyphFT->left;
-    rRawBitmap.mnYOffset        = -pBmpGlyphFT->top;
-
-    const FT_Bitmap& rBitmapFT  = pBmpGlyphFT->bitmap;
-    rRawBitmap.mnHeight         = rBitmapFT.rows;
-    rRawBitmap.mnBitCount       = 1;
-    rRawBitmap.mnWidth          = rBitmapFT.width;
-    rRawBitmap.mnScanlineSize   = rBitmapFT.pitch;
-
-    const sal_uLong nNeededSize = rRawBitmap.mnScanlineSize * rRawBitmap.mnHeight;
-
-    if( rRawBitmap.mnAllocated < nNeededSize )
-    {
-        rRawBitmap.mnAllocated = 2*nNeededSize;
-        rRawBitmap.mpBits.reset(new unsigned char[ rRawBitmap.mnAllocated ]);
-    }
-
-    if (!mbArtBold)
-    {
-        memcpy( rRawBitmap.mpBits.get(), rBitmapFT.buffer, nNeededSize );
-    }
-    else
-    {
-        memset( rRawBitmap.mpBits.get(), 0, nNeededSize );
-        const unsigned char* pSrcLine = rBitmapFT.buffer;
-        unsigned char* pDstLine = rRawBitmap.mpBits.get();
-        for( int h = rRawBitmap.mnHeight; --h >= 0; )
-        {
-            memcpy( pDstLine, pSrcLine, rBitmapFT.pitch );
-            pDstLine += rRawBitmap.mnScanlineSize;
-            pSrcLine += rBitmapFT.pitch;
-        }
-
-        unsigned char* p = rRawBitmap.mpBits.get();
-        for( sal_uLong y=0; y < rRawBitmap.mnHeight; y++ )
-        {
-            unsigned char nLastByte = 0;
-            for( sal_uLong x=0; x < rRawBitmap.mnScanlineSize; x++ )
-            {
-            unsigned char nTmp = p[x] << 7;
-            p[x] |= (p[x] >> 1) | nLastByte;
-            nLastByte = nTmp;
-            }
-            p += rRawBitmap.mnScanlineSize;
-        }
-    }
-
-    FT_Done_Glyph( pGlyphFT );
-
-    // special case for 0/90/180/270 degree orientation
-    switch( nAngle )
-    {
-        case  -900:
-        case  +900:
-        case +1800:
-        case +2700:
-            rRawBitmap.Rotate( nAngle );
-            break;
-    }
-
-    return true;
-}
-
-bool ServerFont::GetGlyphBitmap8( sal_GlyphId aGlyphId, RawBitmap& rRawBitmap ) const
-{
-    FT_Activate_Size( maSizeFT );
-
-    int nGlyphFlags;
-    SplitGlyphFlags( *this, aGlyphId, nGlyphFlags );
-
-    FT_Int nLoadFlags = mnLoadFlags;
-
-    if( mbArtItalic )
-        nLoadFlags |= FT_LOAD_NO_BITMAP;
-
-    if( (nGlyphFlags & GF_UNHINTED) || (mnPrioAutoHint < mnPrioAntiAlias) )
-        nLoadFlags |= FT_LOAD_NO_HINTING;
-
-    if( mnPrioEmbedded <= mnPrioAntiAlias )
-        nLoadFlags |= FT_LOAD_NO_BITMAP;
-
-    FT_Error rc = FT_Load_Glyph( maFaceFT, aGlyphId, nLoadFlags );
-
-    if( rc != FT_Err_Ok )
-        return false;
-
-    if (mbArtBold)
-        FT_GlyphSlot_Embolden(maFaceFT->glyph);
-
-    FT_Glyph pGlyphFT;
-    rc = FT_Get_Glyph( maFaceFT->glyph, &pGlyphFT );
-    if( rc != FT_Err_Ok )
-        return false;
-
-    int nAngle = ApplyGlyphTransform( nGlyphFlags, pGlyphFT, true );
-
-    if( mbArtItalic )
-    {
-        FT_Matrix aMatrix;
-        aMatrix.xx = aMatrix.yy = 0x10000L;
-        aMatrix.xy = 0x6000L, aMatrix.yx = 0;
-        FT_Glyph_Transform( pGlyphFT, &aMatrix, NULL );
-    }
-
-    if( pGlyphFT->format == FT_GLYPH_FORMAT_OUTLINE )
-        ((FT_OutlineGlyph)pGlyphFT)->outline.flags |= FT_OUTLINE_HIGH_PRECISION;
-
-    bool bEmbedded = (pGlyphFT->format == FT_GLYPH_FORMAT_BITMAP);
-    if( !bEmbedded )
-    {
-        rc = FT_Glyph_To_Bitmap( &pGlyphFT, FT_RENDER_MODE_NORMAL, NULL, true );
-        if( rc != FT_Err_Ok )
-        {
-            FT_Done_Glyph( pGlyphFT );
-            return false;
-        }
-    }
-
-    const FT_BitmapGlyph pBmpGlyphFT = reinterpret_cast<const FT_BitmapGlyph>(pGlyphFT);
-    rRawBitmap.mnXOffset        = +pBmpGlyphFT->left;
-    rRawBitmap.mnYOffset        = -pBmpGlyphFT->top;
-
-    const FT_Bitmap& rBitmapFT  = pBmpGlyphFT->bitmap;
-    rRawBitmap.mnHeight         = rBitmapFT.rows;
-    rRawBitmap.mnWidth          = rBitmapFT.width;
-    rRawBitmap.mnBitCount       = 8;
-    rRawBitmap.mnScanlineSize   = bEmbedded ? rBitmapFT.width : rBitmapFT.pitch;
-    rRawBitmap.mnScanlineSize = (rRawBitmap.mnScanlineSize + 3) & -4;
-
-    const sal_uLong nNeededSize = rRawBitmap.mnScanlineSize * rRawBitmap.mnHeight;
-    if( rRawBitmap.mnAllocated < nNeededSize )
-    {
-        rRawBitmap.mnAllocated = 2*nNeededSize;
-        rRawBitmap.mpBits.reset(new unsigned char[ rRawBitmap.mnAllocated ]);
-    }
-
-    const unsigned char* pSrc = rBitmapFT.buffer;
-    unsigned char* pDest = rRawBitmap.mpBits.get();
-    if( !bEmbedded )
-    {
-        for( int y = rRawBitmap.mnHeight, x; --y >= 0 ; )
-        {
-            for( x = 0; x < rBitmapFT.width; ++x )
-                *(pDest++) = *(pSrc++);
-            for(; x < int(rRawBitmap.mnScanlineSize); ++x )
-                *(pDest++) = 0;
-        }
-    }
-    else
-    {
-        for( int y = rRawBitmap.mnHeight, x; --y >= 0 ; )
-        {
-            unsigned char nSrc = 0;
-            for( x = 0; x < rBitmapFT.width; ++x, nSrc+=nSrc )
-            {
-                if( (x & 7) == 0 )
-                    nSrc = *(pSrc++);
-                *(pDest++) = (0x7F - nSrc) >> 8;
-            }
-            for(; x < int(rRawBitmap.mnScanlineSize); ++x )
-                *(pDest++) = 0;
-        }
-    }
-
-    if( !bEmbedded && mbUseGamma )
-    {
-        unsigned char* p = rRawBitmap.mpBits.get();
-        for( sal_uLong y=0; y < rRawBitmap.mnHeight; y++ )
-        {
-            for( sal_uLong x=0; x < rRawBitmap.mnWidth; x++ )
-            {
-                p[x] = aGammaTable[ p[x] ];
-            }
-            p += rRawBitmap.mnScanlineSize;
-        }
-    }
-
-    FT_Done_Glyph( pGlyphFT );
-
-    // special case for 0/90/180/270 degree orientation
-    switch( nAngle )
-    {
-        case  -900:
-        case  +900:
-        case +1800:
-        case +2700:
-            rRawBitmap.Rotate( nAngle );
-            break;
-    }
-
-    return true;
-}
-
 // determine unicode ranges in font
 
-const ImplFontCharMap* ServerFont::GetImplFontCharMap( void ) const
+const FontCharMapPtr ServerFont::GetFontCharMap() const
 {
-    const ImplFontCharMap* pIFCMap = mpFontInfo->GetImplFontCharMap();
-    return pIFCMap;
+    const FontCharMapPtr pFCMap = mpFontInfo->GetFontCharMap();
+    return pFCMap;
 }
 
-const ImplFontCharMap* FtFontInfo::GetImplFontCharMap( void )
+const FontCharMapPtr FtFontInfo::GetFontCharMap()
 {
     // check if the charmap is already cached
     if( mpFontCharMap )
@@ -1290,9 +981,15 @@ const ImplFontCharMap* FtFontInfo::GetImplFontCharMap( void )
     CmapResult aCmapResult;
     bool bOK = GetFontCodeRanges( aCmapResult );
     if( bOK )
-        mpFontCharMap = new ImplFontCharMap( aCmapResult );
+    {
+        FontCharMapPtr pFontCharMap( new FontCharMap ( aCmapResult ) );
+        mpFontCharMap = pFontCharMap;
+    }
     else
-        mpFontCharMap = ImplFontCharMap::GetDefaultMap();
+    {
+        FontCharMapPtr pFontCharMap( new FontCharMap() );
+        mpFontCharMap = pFontCharMap;
+    }
     // mpFontCharMap on either branch now has a refcount of 1
     return mpFontCharMap;
 }
@@ -1323,7 +1020,7 @@ bool FtFontInfo::GetFontCodeRanges( CmapResult& rResult ) const
         if( !nGlyphIndex )
             break;
         aCodes.push_back( cCode );  // first code inside range
-        sal_uInt32 cNext = cCode;
+        sal_uInt32 cNext;
         do cNext = FT_Get_Next_Char( maFaceFT, cCode, &nGlyphIndex ); while( cNext == ++cCode );
         aCodes.push_back( cCode );  // first code outside range
         cCode = cNext;
@@ -1375,7 +1072,7 @@ bool ServerFont::GetFontCapabilities(vcl::FontCapabilities &rFontCapabilities) c
 class PolyArgs
 {
 public:
-                PolyArgs( PolyPolygon& rPolyPoly, sal_uInt16 nMaxPoints );
+                PolyArgs( tools::PolyPolygon& rPolyPoly, sal_uInt16 nMaxPoints );
                 ~PolyArgs();
 
     void        AddPoint( long nX, long nY, PolyFlags);
@@ -1385,7 +1082,7 @@ public:
     long        GetPosY() const { return maPosition.y;}
 
 private:
-    PolyPolygon& mrPolyPoly;
+    tools::PolyPolygon& mrPolyPoly;
 
     Point*      mpPointAry;
     sal_uInt8*       mpFlagAry;
@@ -1397,7 +1094,7 @@ private:
     bool        bHasOffline;
 };
 
-PolyArgs::PolyArgs( PolyPolygon& rPolyPoly, sal_uInt16 nMaxPoints )
+PolyArgs::PolyArgs( tools::PolyPolygon& rPolyPoly, sal_uInt16 nMaxPoints )
 :   mrPolyPoly(rPolyPoly),
     mnMaxPoints(nMaxPoints),
     mnPoints(0),
@@ -1441,7 +1138,7 @@ void PolyArgs::ClosePolygon()
     DBG_ASSERT( (mpFlagAry[0]==POLY_NORMAL), "FTGlyphOutline: PolyFinishFE failed!" );
     DBG_ASSERT( (mpFlagAry[mnPoints]==POLY_NORMAL), "FTGlyphOutline: PolyFinishFS failed!" );
 
-    Polygon aPoly( mnPoints, mpPointAry, (bHasOffline ? mpFlagAry : NULL) );
+    tools::Polygon aPoly( mnPoints, mpPointAry, (bHasOffline ? mpFlagAry : nullptr) );
 
     // #i35928#
     // This may be a invalid polygons, e.g. the last point is a control point.
@@ -1477,9 +1174,9 @@ extern "C" {
 // TODO: wait till all compilers accept that calling conventions
 // for functions are the same independent of implementation constness,
 // then uncomment the const-tokens in the function interfaces below
-static int FT_move_to( FT_Vector_CPtr p0, void* vpPolyArgs )
+static int FT_move_to( const FT_Vector* p0, void* vpPolyArgs )
 {
-    PolyArgs& rA = *reinterpret_cast<PolyArgs*>(vpPolyArgs);
+    PolyArgs& rA = *static_cast<PolyArgs*>(vpPolyArgs);
 
     // move_to implies a new polygon => finish old polygon first
     rA.ClosePolygon();
@@ -1488,16 +1185,16 @@ static int FT_move_to( FT_Vector_CPtr p0, void* vpPolyArgs )
     return 0;
 }
 
-static int FT_line_to( FT_Vector_CPtr p1, void* vpPolyArgs )
+static int FT_line_to( const FT_Vector* p1, void* vpPolyArgs )
 {
-    PolyArgs& rA = *reinterpret_cast<PolyArgs*>(vpPolyArgs);
+    PolyArgs& rA = *static_cast<PolyArgs*>(vpPolyArgs);
     rA.AddPoint( p1->x, p1->y, POLY_NORMAL );
     return 0;
 }
 
-static int FT_conic_to( FT_Vector_CPtr p1, FT_Vector_CPtr p2, void* vpPolyArgs )
+static int FT_conic_to( const FT_Vector* p1, const FT_Vector* p2, void* vpPolyArgs )
 {
-    PolyArgs& rA = *reinterpret_cast<PolyArgs*>(vpPolyArgs);
+    PolyArgs& rA = *static_cast<PolyArgs*>(vpPolyArgs);
 
     // VCL's Polygon only knows cubic beziers
     const long nX1 = (2 * rA.GetPosX() + 4 * p1->x + 3) / 6;
@@ -1512,9 +1209,9 @@ static int FT_conic_to( FT_Vector_CPtr p1, FT_Vector_CPtr p2, void* vpPolyArgs )
     return 0;
 }
 
-static int FT_cubic_to( FT_Vector_CPtr p1, FT_Vector_CPtr p2, FT_Vector_CPtr p3, void* vpPolyArgs )
+static int FT_cubic_to( const FT_Vector* p1, const FT_Vector* p2, const FT_Vector* p3, void* vpPolyArgs )
 {
-    PolyArgs& rA = *reinterpret_cast<PolyArgs*>(vpPolyArgs);
+    PolyArgs& rA = *static_cast<PolyArgs*>(vpPolyArgs);
     rA.AddPoint( p1->x, p1->y, POLY_CONTROL );
     rA.AddPoint( p2->x, p2->y, POLY_CONTROL );
     rA.AddPoint( p3->x, p3->y, POLY_NORMAL );
@@ -1564,7 +1261,7 @@ bool ServerFont::GetGlyphOutline( sal_GlyphId aGlyphId,
         FT_Matrix aMatrix;
         aMatrix.xx = aMatrix.yy = 0x10000L;
         aMatrix.xy = 0x6000L, aMatrix.yx = 0;
-        FT_Glyph_Transform( pGlyphFT, &aMatrix, NULL );
+        FT_Glyph_Transform( pGlyphFT, &aMatrix, nullptr );
     }
 
     FT_Outline& rOutline = reinterpret_cast<FT_OutlineGlyphRec*>(pGlyphFT)->outline;
@@ -1575,7 +1272,7 @@ bool ServerFont::GetGlyphOutline( sal_GlyphId aGlyphId,
     }
 
     long nMaxPoints = 1 + rOutline.n_points * 3;
-    PolyPolygon aToolPolyPolygon;
+    tools::PolyPolygon aToolPolyPolygon;
     PolyArgs aPolyArg( aToolPolyPolygon, nMaxPoints );
 
     /*int nAngle =*/ ApplyGlyphTransform( nGlyphFlags, pGlyphFT, false );
@@ -1587,7 +1284,7 @@ bool ServerFont::GetGlyphOutline( sal_GlyphId aGlyphId,
     aFuncs.cubic_to = &FT_cubic_to;
     aFuncs.shift    = 0;
     aFuncs.delta    = 0;
-    rc = FT_Outline_Decompose( &rOutline, &aFuncs, (void*)&aPolyArg );
+    FT_Outline_Decompose( &rOutline, &aFuncs, static_cast<void*>(&aPolyArg) );
     aPolyArg.ClosePolygon();    // close last polygon
     FT_Done_Glyph( pGlyphFT );
 
@@ -1607,8 +1304,6 @@ bool ServerFont::ApplyGSUB( const FontSelectPattern& rFSD )
     ReqFeatureTagList aReqFeatureTagList;
     if( rFSD.mbVertical )
         aReqFeatureTagList.push_back( MKTAG("vert") );
-    sal_uLong nRequestedScript = 0;     //MKTAG("hani");//### TODO: where to get script?
-    sal_uLong nRequestedLangsys = 0;    //MKTAG("ZHT"); //### TODO: where to get langsys?
     // TODO: request more features depending on script and language system
 
     if( aReqFeatureTagList.empty()) // nothing to do
@@ -1625,7 +1320,6 @@ bool ServerFont::ApplyGSUB( const FontSelectPattern& rFSD )
     const sal_uInt16 nOfsScriptList     = GetUShort( pGsubHeader+4 );
     const sal_uInt16 nOfsFeatureTable   = GetUShort( pGsubHeader+6 );
     const sal_uInt16 nOfsLookupList     = GetUShort( pGsubHeader+8 );
-    pGsubHeader += 10;
 
     typedef std::vector<sal_uInt16> UshortList;
     UshortList aFeatureIndexList;
@@ -1636,11 +1330,8 @@ bool ServerFont::ApplyGSUB( const FontSelectPattern& rFSD )
     pScriptHeader += 2;
     for( sal_uInt16 nScriptIndex = 0; nScriptIndex < nCntScript; ++nScriptIndex )
     {
-        const sal_uLong nScriptTag      = GetUInt( pScriptHeader+0 ); // e.g. hani/arab/kana/hang
         const sal_uInt16 nOfsScriptTable= GetUShort( pScriptHeader+4 );
         pScriptHeader += 6;
-        if( (nScriptTag != nRequestedScript) && (nRequestedScript != 0) )
-            continue;
 
         const FT_Byte* pScriptTable     = pGsubBase + nOfsScriptList + nOfsScriptTable;
         const sal_uInt16 nDefaultLangsysOfs = GetUShort( pScriptTable+0 );
@@ -1648,18 +1339,12 @@ bool ServerFont::ApplyGSUB( const FontSelectPattern& rFSD )
         pScriptTable += 4;
         sal_uInt16 nLangsysOffset = 0;
 
-        for( sal_uInt16 nLangsysIndex = 0; nLangsysIndex < nCntLangSystem; ++nLangsysIndex )
+        if (nCntLangSystem != 0)
         {
-            const sal_uLong nTag    = GetUInt( pScriptTable+0 );    // e.g. KOR/ZHS/ZHT/JAN
-            const sal_uInt16 nOffset= GetUShort( pScriptTable+4 );
-            pScriptTable += 6;
-            if( (nTag != nRequestedLangsys) && (nRequestedLangsys != 0) )
-                continue;
-            nLangsysOffset = nOffset;
-            break;
+            nLangsysOffset = GetUShort( pScriptTable+4 );
         }
 
-        if( (nDefaultLangsysOfs != 0) && (nDefaultLangsysOfs != nLangsysOffset) )
+        if (nDefaultLangsysOfs != 0 && nDefaultLangsysOfs != nLangsysOffset)
         {
             const FT_Byte* pLangSys = pGsubBase + nOfsScriptList + nOfsScriptTable + nDefaultLangsysOfs;
             const sal_uInt16 nReqFeatureIdx = GetUShort( pLangSys+2 );
@@ -1812,7 +1497,6 @@ bool ServerFont::ApplyGSUB( const FontSelectPattern& rFSD )
                 case 1:     // Single Substitution Format 1
                     {
                         const sal_uInt16 nDeltaGlyphId = GetUShort( pSubLookup );
-                        pSubLookup += 2;
                         for(; it != aSubstVector.end(); ++it )
                             (*it).second = (*it).first + nDeltaGlyphId;
                     }
