@@ -39,12 +39,12 @@
 
 void ListBox::EnableQuickSelection( const bool& b )
 {
-    mpImplLB->GetMainWindow().EnableQuickSelection(b);
+    mpImplLB->GetMainWindow()->EnableQuickSelection(b);
 }
 
 ListBox::ListBox(WindowType nType)
     : Control(nType)
-    , mpImplLB(NULL)
+    , mpImplLB(nullptr)
 {
     ImplInitListBoxData();
 }
@@ -70,24 +70,26 @@ ListBox::ListBox( vcl::Window* pParent, const ResId& rResId ) :
 
 ListBox::~ListBox()
 {
-    ImplCallEventListeners( VCLEVENT_OBJECT_DYING );
+    disposeOnce();
+}
 
-    // When destroying the FloatWin TH does a GrabFocus to the Parent:
-    // that means this "ListBox => PreNotify() ..."
-    ImplListBox *pImplLB = mpImplLB;
-    mpImplLB = NULL;
-    delete pImplLB;
+void ListBox::dispose()
+{
+    CallEventListeners( VCLEVENT_OBJECT_DYING );
 
-    delete mpFloatWin;
-    delete mpImplWin;
-    delete mpBtn;
+    mpImplLB.disposeAndClear();
+    mpFloatWin.disposeAndClear();
+    mpImplWin.disposeAndClear();
+    mpBtn.disposeAndClear();
+
+    Control::dispose();
 }
 
 void ListBox::ImplInitListBoxData()
 {
-    mpFloatWin      = NULL;
-    mpImplWin       = NULL;
-    mpBtn           = NULL;
+    mpFloatWin      = nullptr;
+    mpImplWin       = nullptr;
+    mpBtn           = nullptr;
     mnDDHeight      = 0;
     mnSaveValue     = LISTBOX_ENTRY_NOTFOUND;
     mnLineCount     = 0;
@@ -102,10 +104,9 @@ void ListBox::ImplInit( vcl::Window* pParent, WinBits nStyle )
     if ( !(nStyle & WB_NOBORDER) && ( nStyle & WB_DROPDOWN ) )
         nStyle |= WB_BORDER;
 
-    Control::ImplInit( pParent, nStyle, NULL );
-    SetBackground();
+    Control::ImplInit( pParent, nStyle, nullptr );
 
-    ::com::sun::star::uno::Reference< ::com::sun::star::datatransfer::dnd::XDropTargetListener> xDrop = new DNDEventDispatcher(this);
+    css::uno::Reference< css::datatransfer::dnd::XDropTargetListener> xDrop = new DNDEventDispatcher(this);
 
     if( nStyle & WB_DROPDOWN )
     {
@@ -121,7 +122,7 @@ void ListBox::ImplInit( vcl::Window* pParent, WinBits nStyle )
                 Rectangle aBoundingRgn( aCtrlRegion );
                 Rectangle aContentRgn( aCtrlRegion );
                 if( GetNativeControlRegion( CTRL_LISTBOX, PART_ENTIRE_CONTROL, aCtrlRegion,
-                                            CTRL_STATE_ENABLED, aControlValue, OUString(),
+                                            ControlState::ENABLED, aControlValue, OUString(),
                                             aBoundingRgn, aContentRgn ) )
                 {
                     sal_Int32 nHeight = aBoundingRgn.GetHeight();
@@ -130,21 +131,24 @@ void ListBox::ImplInit( vcl::Window* pParent, WinBits nStyle )
                 }
         }
 
-        mpFloatWin = new ImplListBoxFloatingWindow( this );
+        mpFloatWin = VclPtr<ImplListBoxFloatingWindow>::Create( this );
         mpFloatWin->SetAutoWidth( true );
         mpFloatWin->SetPopupModeEndHdl( LINK( this, ListBox, ImplPopupModeEndHdl ) );
         mpFloatWin->GetDropTarget()->addDropTargetListener(xDrop);
 
-        mpImplWin = new ImplWin( this, (nStyle & (WB_LEFT|WB_RIGHT|WB_CENTER))|WB_NOBORDER );
-        mpImplWin->buttonDownSignal.connect( boost::bind( &ListBox::ImplClickButtonHandler, this, _1 ));
-        mpImplWin->userDrawSignal.connect( boost::bind( &ListBox::ImplUserDrawHandler, this, _1 ) );
+        mpImplWin = VclPtr<ImplWin>::Create( this, (nStyle & (WB_LEFT|WB_RIGHT|WB_CENTER))|WB_NOBORDER );
+        mpImplWin->buttonDownSignal.connect( [this]( Control* pControl )
+                                             { this->ImplClickButtonHandler( pControl ); } );
+        mpImplWin->userDrawSignal.connect( [this]( UserDrawEvent* pUserDrawEvent )
+                                           { this->ImplUserDrawHandler( pUserDrawEvent ); } );
         mpImplWin->Show();
         mpImplWin->GetDropTarget()->addDropTargetListener(xDrop);
         mpImplWin->SetEdgeBlending(GetEdgeBlending());
 
-        mpBtn = new ImplBtn( this, WB_NOLIGHTBORDER | WB_RECTSTYLE );
+        mpBtn = VclPtr<ImplBtn>::Create( this, WB_NOLIGHTBORDER | WB_RECTSTYLE );
         ImplInitDropDownButton( mpBtn );
-        mpBtn->buttonDownSignal.connect( boost::bind( &ListBox::ImplClickButtonHandler, this, _1 ));
+        mpBtn->buttonDownSignal.connect( [this]( Control* pControl )
+                                         { this->ImplClickButtonHandler( pControl ); } );
         mpBtn->Show();
         mpBtn->GetDropTarget()->addDropTargetListener(xDrop);
     }
@@ -152,12 +156,13 @@ void ListBox::ImplInit( vcl::Window* pParent, WinBits nStyle )
     vcl::Window* pLBParent = this;
     if ( mpFloatWin )
         pLBParent = mpFloatWin;
-    mpImplLB = new ImplListBox( pLBParent, nStyle&(~WB_BORDER) );
+    mpImplLB = VclPtr<ImplListBox>::Create( pLBParent, nStyle&(~WB_BORDER) );
     mpImplLB->SetSelectHdl( LINK( this, ListBox, ImplSelectHdl ) );
     mpImplLB->SetScrollHdl( LINK( this, ListBox, ImplScrollHdl ) );
     mpImplLB->SetCancelHdl( LINK( this, ListBox, ImplCancelHdl ) );
     mpImplLB->SetDoubleClickHdl( LINK( this, ListBox, ImplDoubleClickHdl ) );
-    mpImplLB->userDrawSignal.connect( boost::bind( &ListBox::ImplUserDrawHandler, this, _1 ) );
+    mpImplLB->userDrawSignal.connect( [this]( UserDrawEvent* pUserDrawEvent )
+                                      { this->ImplUserDrawHandler( pUserDrawEvent ); } );
     mpImplLB->SetFocusHdl( LINK( this, ListBox, ImplFocusHdl ) );
     mpImplLB->SetListItemSelectHdl( LINK( this, ListBox, ImplListItemSelectHdl ) );
     mpImplLB->SetPosPixel( Point() );
@@ -173,7 +178,7 @@ void ListBox::ImplInit( vcl::Window* pParent, WinBits nStyle )
         mpImplLB->SetSelectionChangedHdl( LINK( this, ListBox, ImplSelectionChangedHdl ) );
     }
     else
-        mpImplLB->GetMainWindow().AllowGrabFocus( true );
+        mpImplLB->GetMainWindow()->AllowGrabFocus( true );
 
     SetCompoundControl( true );
 }
@@ -198,7 +203,7 @@ void ListBox::ImplLoadRes( const ResId& rResId )
 
     for( sal_Int32 i = 0; i < nNumber; i++ )
     {
-        sal_Int32 nPos = InsertEntry( ReadStringRes(), LISTBOX_APPEND );
+        sal_Int32 nPos = InsertEntry( ReadStringRes() );
 
         sal_IntPtr nId = ReadLongRes();
         if( nId )
@@ -209,7 +214,7 @@ void ListBox::ImplLoadRes( const ResId& rResId )
         SelectEntryPos( nSelPos );
 }
 
-IMPL_LINK_NOARG(ListBox, ImplSelectHdl)
+IMPL_LINK_NOARG_TYPED(ListBox, ImplSelectHdl, LinkParamNone*, void)
 {
     bool bPopup = IsInDropDown();
     if( IsDropDownBox() )
@@ -232,41 +237,33 @@ IMPL_LINK_NOARG(ListBox, ImplSelectHdl)
 
     if ( ( !IsTravelSelect() || mpImplLB->IsSelectionChanged() ) || ( bPopup && !IsMultiSelectionEnabled() ) )
         Select();
-
-    return 1;
 }
 
-IMPL_LINK( ListBox, ImplFocusHdl, void *, nPos )
+IMPL_LINK_TYPED( ListBox, ImplFocusHdl, sal_Int32, nPos, void )
 {
-    ImplCallEventListeners( VCLEVENT_LISTBOX_FOCUS , nPos);
-    return 1;
+    CallEventListeners( VCLEVENT_LISTBOX_FOCUS, reinterpret_cast<void*>(nPos) );
 }
 
-IMPL_LINK( ListBox, ImplListItemSelectHdl, void*, EMPTYARG )
+IMPL_LINK_NOARG_TYPED( ListBox, ImplListItemSelectHdl, LinkParamNone*, void )
 {
-    ImplCallEventListeners( VCLEVENT_DROPDOWN_SELECT );
-    return 1;
+    CallEventListeners( VCLEVENT_DROPDOWN_SELECT );
 }
 
-IMPL_LINK_NOARG(ListBox, ImplScrollHdl)
+IMPL_LINK_NOARG_TYPED(ListBox, ImplScrollHdl, ImplListBox*, void)
 {
-    ImplCallEventListeners( VCLEVENT_LISTBOX_SCROLLED );
-    return 1;
+    CallEventListeners( VCLEVENT_LISTBOX_SCROLLED );
 }
 
-IMPL_LINK_NOARG(ListBox, ImplCancelHdl)
+IMPL_LINK_NOARG_TYPED(ListBox, ImplCancelHdl, LinkParamNone*, void)
 {
     if( IsInDropDown() )
         mpFloatWin->EndPopupMode();
-
-    return 1;
 }
 
-IMPL_LINK( ListBox, ImplSelectionChangedHdl, void*, n )
+IMPL_LINK_TYPED( ListBox, ImplSelectionChangedHdl, sal_Int32, nChanged, void )
 {
     if ( !mpImplLB->IsTrackingSelect() )
     {
-        sal_Int32 nChanged = (sal_Int32)reinterpret_cast<sal_uLong>(n);
         const ImplEntryList* pEntryList = mpImplLB->GetEntryList();
         if ( pEntryList->IsEntryPosSelected( nChanged ) )
         {
@@ -290,34 +287,32 @@ IMPL_LINK( ListBox, ImplSelectionChangedHdl, void*, n )
         }
         mpImplWin->Invalidate();
     }
-    return 1;
 }
 
-IMPL_LINK_NOARG(ListBox, ImplDoubleClickHdl)
+IMPL_LINK_NOARG_TYPED(ListBox, ImplDoubleClickHdl, ImplListBoxWindow*, void)
 {
     DoubleClick();
-    return 1;
 }
 
 void ListBox::ImplClickButtonHandler( Control* )
 {
     if( !mpFloatWin->IsInPopupMode() )
     {
-        ImplCallEventListeners( VCLEVENT_DROPDOWN_PRE_OPEN );
+        CallEventListeners( VCLEVENT_DROPDOWN_PRE_OPEN );
         mpImplWin->GrabFocus();
         mpBtn->SetPressed( true );
         mpFloatWin->StartFloat( true );
-        ImplCallEventListeners( VCLEVENT_DROPDOWN_OPEN );
+        CallEventListeners( VCLEVENT_DROPDOWN_OPEN );
 
         ImplClearLayoutData();
         if( mpImplLB )
-            mpImplLB->GetMainWindow().ImplClearLayoutData();
+            mpImplLB->GetMainWindow()->ImplClearLayoutData();
         if( mpImplWin )
             mpImplWin->ImplClearLayoutData();
     }
 }
 
-IMPL_LINK_NOARG(ListBox, ImplPopupModeEndHdl)
+IMPL_LINK_NOARG_TYPED(ListBox, ImplPopupModeEndHdl, FloatingWindow*, void)
 {
     if( mpFloatWin->IsPopupModeCanceled() )
     {
@@ -332,7 +327,7 @@ IMPL_LINK_NOARG(ListBox, ImplPopupModeEndHdl)
             ImplAddDel( &aCheckDelete );
             Select();
             if ( aCheckDelete.IsDead() )
-                return 0;
+                return;
             ImplRemoveDel( &aCheckDelete );
 
             mpImplLB->SetTravelSelect( bTravelSelect );
@@ -341,13 +336,12 @@ IMPL_LINK_NOARG(ListBox, ImplPopupModeEndHdl)
 
     ImplClearLayoutData();
     if( mpImplLB )
-        mpImplLB->GetMainWindow().ImplClearLayoutData();
+        mpImplLB->GetMainWindow()->ImplClearLayoutData();
     if( mpImplWin )
         mpImplWin->ImplClearLayoutData();
 
     mpBtn->SetPressed( false );
-    ImplCallEventListeners( VCLEVENT_DROPDOWN_CLOSE );
-    return 0;
+    CallEventListeners( VCLEVENT_DROPDOWN_CLOSE );
 }
 
 void ListBox::ToggleDropDown()
@@ -358,22 +352,27 @@ void ListBox::ToggleDropDown()
             mpFloatWin->EndPopupMode();
         else
         {
-            ImplCallEventListeners( VCLEVENT_DROPDOWN_PRE_OPEN );
+            CallEventListeners( VCLEVENT_DROPDOWN_PRE_OPEN );
             mpImplWin->GrabFocus();
             mpBtn->SetPressed( true );
             mpFloatWin->StartFloat( true );
-            ImplCallEventListeners( VCLEVENT_DROPDOWN_OPEN );
+            CallEventListeners( VCLEVENT_DROPDOWN_OPEN );
         }
     }
 }
 
-void ListBox::Draw( OutputDevice* pDev, const Point& rPos, const Size& rSize, sal_uLong nFlags )
+void ListBox::ApplySettings(vcl::RenderContext& rRenderContext)
 {
-    mpImplLB->GetMainWindow().ImplInitSettings( true, true, true );
+    rRenderContext.SetBackground();
+}
+
+void ListBox::Draw( OutputDevice* pDev, const Point& rPos, const Size& rSize, DrawFlags nFlags )
+{
+    mpImplLB->GetMainWindow()->ApplySettings(*pDev);
 
     Point aPos = pDev->LogicToPixel( rPos );
     Size aSize = pDev->LogicToPixel( rSize );
-    vcl::Font aFont = mpImplLB->GetMainWindow().GetDrawPixelFont( pDev );
+    vcl::Font aFont = mpImplLB->GetMainWindow()->GetDrawPixelFont( pDev );
     OutDevType eOutDevType = pDev->GetOutDevType();
 
     pDev->Push();
@@ -384,8 +383,8 @@ void ListBox::Draw( OutputDevice* pDev, const Point& rPos, const Size& rSize, sa
     // Border/Background
     pDev->SetLineColor();
     pDev->SetFillColor();
-    bool bBorder = !(nFlags & WINDOW_DRAW_NOBORDER ) && (GetStyle() & WB_BORDER);
-    bool bBackground = !(nFlags & WINDOW_DRAW_NOBACKGROUND) && IsControlBackground();
+    bool bBorder = !(nFlags & DrawFlags::NoBorder ) && (GetStyle() & WB_BORDER);
+    bool bBackground = !(nFlags & DrawFlags::NoBackground) && IsControlBackground();
     if ( bBorder || bBackground )
     {
         Rectangle aRect( aPos, aSize );
@@ -401,13 +400,13 @@ void ListBox::Draw( OutputDevice* pDev, const Point& rPos, const Size& rSize, sa
     }
 
     // Content
-    if ( ( nFlags & WINDOW_DRAW_MONO ) || ( eOutDevType == OUTDEV_PRINTER ) )
+    if ( ( nFlags & DrawFlags::Mono ) || ( eOutDevType == OUTDEV_PRINTER ) )
     {
         pDev->SetTextColor( Color( COL_BLACK ) );
     }
     else
     {
-        if ( !(nFlags & WINDOW_DRAW_NODISABLE ) && !IsEnabled() )
+        if ( !(nFlags & DrawFlags::NoDisable ) && !IsEnabled() )
         {
             const StyleSettings& rStyleSettings = GetSettings().GetStyleSettings();
             pDev->SetTextColor( rStyleSettings.GetDisableColor() );
@@ -419,15 +418,15 @@ void ListBox::Draw( OutputDevice* pDev, const Point& rPos, const Size& rSize, sa
     }
 
     long nOnePixel = GetDrawPixel( pDev, 1 );
-    sal_uInt16 nTextStyle = TEXT_DRAW_VCENTER;
+    DrawTextFlags nTextStyle = DrawTextFlags::VCenter;
     Rectangle aTextRect( aPos, aSize );
 
     if ( GetStyle() & WB_CENTER )
-        nTextStyle |= TEXT_DRAW_CENTER;
+        nTextStyle |= DrawTextFlags::Center;
     else if ( GetStyle() & WB_RIGHT )
-        nTextStyle |= TEXT_DRAW_RIGHT;
+        nTextStyle |= DrawTextFlags::Right;
     else
-        nTextStyle |= TEXT_DRAW_LEFT;
+        nTextStyle |= DrawTextFlags::Left;
 
     aTextRect.Left() += 3*nOnePixel;
     aTextRect.Right() -= 3*nOnePixel;
@@ -519,9 +518,15 @@ vcl::Window* ListBox::GetPreferredKeyInputWindow()
 void ListBox::LoseFocus()
 {
     if( IsDropDownBox() )
-        mpImplWin->HideFocus();
+    {
+        if (mpImplWin)
+            mpImplWin->HideFocus();
+    }
     else
-        mpImplLB->HideFocus();
+    {
+        if (mpImplLB)
+            mpImplLB->HideFocus();
+    }
 
     Control::LoseFocus();
 }
@@ -530,10 +535,10 @@ void ListBox::DataChanged( const DataChangedEvent& rDCEvt )
 {
     Control::DataChanged( rDCEvt );
 
-    if ( (rDCEvt.GetType() == DATACHANGED_FONTS) ||
-         (rDCEvt.GetType() == DATACHANGED_FONTSUBSTITUTION) ||
-         ((rDCEvt.GetType() == DATACHANGED_SETTINGS) &&
-          (rDCEvt.GetFlags() & SETTINGS_STYLE)) )
+    if ( (rDCEvt.GetType() == DataChangedEventType::FONTS) ||
+         (rDCEvt.GetType() == DataChangedEventType::FONTSUBSTITUTION) ||
+         ((rDCEvt.GetType() == DataChangedEventType::SETTINGS) &&
+          (rDCEvt.GetFlags() & AllSettingsFlags::STYLE)) )
     {
         SetBackground();    // Due to a hack in Window::UpdateSettings the background must be reset
                             // otherwise it will overpaint NWF drawn listboxes
@@ -543,7 +548,7 @@ void ListBox::DataChanged( const DataChangedEvent& rDCEvt )
         if ( mpImplWin )
         {
             mpImplWin->SetSettings( GetSettings() ); // If not yet set...
-            ImplInitFieldSettings( mpImplWin, true, true, true );
+            mpImplWin->ApplySettings(*mpImplWin);
 
             mpBtn->SetSettings( GetSettings() );
             ImplInitDropDownButton( mpBtn );
@@ -597,18 +602,18 @@ sal_uInt16 ListBox::GetDropDownLineCount() const
     return mnLineCount;
 }
 
-void ListBox::setPosSizePixel( long nX, long nY, long nWidth, long nHeight, sal_uInt16 nFlags )
+void ListBox::setPosSizePixel( long nX, long nY, long nWidth, long nHeight, PosSizeFlags nFlags )
 {
-    if( IsDropDownBox() && ( nFlags & WINDOW_POSSIZE_SIZE ) )
+    if( IsDropDownBox() && ( nFlags & PosSizeFlags::Size ) )
     {
         Size aPrefSz = mpFloatWin->GetPrefSize();
-        if ( ( nFlags & WINDOW_POSSIZE_HEIGHT ) && ( nHeight >= 2*mnDDHeight ) )
+        if ( ( nFlags & PosSizeFlags::Height ) && ( nHeight >= 2*mnDDHeight ) )
             aPrefSz.Height() = nHeight-mnDDHeight;
-        if ( nFlags & WINDOW_POSSIZE_WIDTH )
+        if ( nFlags & PosSizeFlags::Width )
             aPrefSz.Width() = nWidth;
         mpFloatWin->SetPrefSize( aPrefSz );
 
-        if ( IsAutoSizeEnabled() && ! (nFlags & WINDOW_POSSIZE_DROPDOWN) )
+        if ( IsAutoSizeEnabled() && ! (nFlags & PosSizeFlags::Dropdown) )
             nHeight = mnDDHeight;
     }
 
@@ -625,7 +630,7 @@ void ListBox::Resize()
         long nBottom = aOutSz.Height();
 
         // Note: in case of no border, pBorder will actually be this
-        vcl::Window *pBorder = GetWindow( WINDOW_BORDER );
+        vcl::Window *pBorder = GetWindow( GetWindowType::Border );
         ImplControlValue aControlValue;
         Point aPoint;
         Rectangle aContent, aBound;
@@ -634,7 +639,7 @@ void ListBox::Resize()
         Rectangle aArea( aPoint, pBorder->GetOutputSizePixel() );
 
         if ( GetNativeControlRegion( CTRL_LISTBOX, PART_BUTTON_DOWN,
-                    aArea, 0, aControlValue, OUString(), aBound, aContent) )
+                    aArea, ControlState::NONE, aControlValue, OUString(), aBound, aContent) )
         {
             long nTop = 0;
             // Convert back from border space to local coordinates
@@ -647,7 +652,7 @@ void ListBox::Resize()
 
             // Adjust the size of the edit field
             if ( GetNativeControlRegion( CTRL_LISTBOX, PART_SUB_EDIT,
-                        aArea, 0, aControlValue, OUString(), aBound, aContent) )
+                        aArea, ControlState::NONE, aControlValue, OUString(), aBound, aContent) )
             {
                 // Convert back from border space to local coordinates
                 aContent.Move( -aPoint.X(), -aPoint.Y() );
@@ -691,7 +696,7 @@ void ListBox::Resize()
 void ListBox::FillLayoutData() const
 {
     mpControlData->mpLayoutData = new vcl::ControlLayoutData();
-    const Control& rMainWin = mpImplLB->GetMainWindow();
+    const ImplListBoxWindow* rMainWin = mpImplLB->GetMainWindow();
     if( mpFloatWin )
     {
         // Dropdown mode
@@ -699,14 +704,14 @@ void ListBox::FillLayoutData() const
         mpImplWin->SetLayoutDataParent( this );
         if( mpFloatWin->IsReallyVisible() )
         {
-            AppendLayoutData( rMainWin );
-            rMainWin.SetLayoutDataParent( this );
+            AppendLayoutData( *rMainWin );
+            rMainWin->SetLayoutDataParent( this );
         }
     }
     else
     {
-        AppendLayoutData( rMainWin );
-        rMainWin.SetLayoutDataParent( this );
+        AppendLayoutData( *rMainWin );
+        rMainWin->SetLayoutDataParent( this );
     }
 }
 
@@ -721,16 +726,16 @@ long ListBox::GetIndexForPoint( const Point& rPoint, sal_Int32& rPos ) const
     {
         // Point must be either in main list window
         // or in impl window (dropdown case)
-        ImplListBoxWindow& rMain = mpImplLB->GetMainWindow();
+        ImplListBoxWindow* rMain = mpImplLB->GetMainWindow();
 
         // Convert coordinates to ImplListBoxWindow pixel coordinate space
         Point aConvPoint = LogicToPixel( rPoint );
         aConvPoint = OutputToAbsoluteScreenPixel( aConvPoint );
-        aConvPoint = rMain.AbsoluteScreenToOutputPixel( aConvPoint );
-        aConvPoint = rMain.PixelToLogic( aConvPoint );
+        aConvPoint = rMain->AbsoluteScreenToOutputPixel( aConvPoint );
+        aConvPoint = rMain->PixelToLogic( aConvPoint );
 
         // Try to find entry
-        sal_Int32 nEntry = rMain.GetEntryPosForPoint( aConvPoint );
+        sal_Int32 nEntry = rMain->GetEntryPosForPoint( aConvPoint );
         if( nEntry == LISTBOX_ENTRY_NOTFOUND )
         {
             // Not found, maybe dropdown case
@@ -769,14 +774,14 @@ long ListBox::GetIndexForPoint( const Point& rPoint, sal_Int32& rPos ) const
 
 void ListBox::StateChanged( StateChangedType nType )
 {
-    if( nType == StateChangedType::READONLY )
+    if( nType == StateChangedType::ReadOnly )
     {
         if( mpImplWin )
             mpImplWin->Enable( !IsReadOnly() );
         if( mpBtn )
             mpBtn->Enable( !IsReadOnly() );
     }
-    else if( nType == StateChangedType::ENABLE )
+    else if( nType == StateChangedType::Enable )
     {
         mpImplLB->Enable( IsEnabled() );
         if( mpImplWin )
@@ -785,7 +790,7 @@ void ListBox::StateChanged( StateChangedType nType )
             if ( IsNativeControlSupported(CTRL_LISTBOX, PART_ENTIRE_CONTROL)
                     && ! IsNativeControlSupported(CTRL_LISTBOX, PART_BUTTON_DOWN) )
             {
-                GetWindow( WINDOW_BORDER )->Invalidate( INVALIDATE_NOERASE );
+                GetWindow( GetWindowType::Border )->Invalidate( InvalidateFlags::NoErase );
             }
             else
                 mpImplWin->Invalidate();
@@ -793,44 +798,44 @@ void ListBox::StateChanged( StateChangedType nType )
         if( mpBtn )
             mpBtn->Enable( IsEnabled() );
     }
-    else if( nType == StateChangedType::UPDATEMODE )
+    else if( nType == StateChangedType::UpdateMode )
     {
         mpImplLB->SetUpdateMode( IsUpdateMode() );
     }
-    else if ( nType == StateChangedType::ZOOM )
+    else if ( nType == StateChangedType::Zoom )
     {
         mpImplLB->SetZoom( GetZoom() );
         if ( mpImplWin )
         {
             mpImplWin->SetZoom( GetZoom() );
-            mpImplWin->SetFont( mpImplLB->GetMainWindow().GetFont() );
+            mpImplWin->SetFont( mpImplLB->GetMainWindow()->GetFont() );
             mpImplWin->Invalidate();
         }
         Resize();
     }
-    else if ( nType == StateChangedType::CONTROLFONT )
+    else if ( nType == StateChangedType::ControlFont )
     {
         mpImplLB->SetControlFont( GetControlFont() );
         if ( mpImplWin )
         {
             mpImplWin->SetControlFont( GetControlFont() );
-            mpImplWin->SetFont( mpImplLB->GetMainWindow().GetFont() );
+            mpImplWin->SetFont( mpImplLB->GetMainWindow()->GetFont() );
             mpImplWin->Invalidate();
         }
         Resize();
     }
-    else if ( nType == StateChangedType::CONTROLFOREGROUND )
+    else if ( nType == StateChangedType::ControlForeground )
     {
         mpImplLB->SetControlForeground( GetControlForeground() );
         if ( mpImplWin )
         {
             mpImplWin->SetControlForeground( GetControlForeground() );
             mpImplWin->SetTextColor( GetControlForeground() );
-            mpImplWin->SetFont( mpImplLB->GetMainWindow().GetFont() );
+            mpImplWin->SetFont( mpImplLB->GetMainWindow()->GetFont() );
             mpImplWin->Invalidate();
         }
     }
-    else if ( nType == StateChangedType::CONTROLBACKGROUND )
+    else if ( nType == StateChangedType::ControlBackground )
     {
         mpImplLB->SetControlBackground( GetControlBackground() );
         if ( mpImplWin )
@@ -843,21 +848,21 @@ void ListBox::StateChanged( StateChangedType nType )
             }
             else
             {
-                mpImplWin->SetBackground( mpImplLB->GetMainWindow().GetControlBackground() );
-                mpImplWin->SetControlBackground( mpImplLB->GetMainWindow().GetControlBackground() );
+                mpImplWin->SetBackground( mpImplLB->GetMainWindow()->GetControlBackground() );
+                mpImplWin->SetControlBackground( mpImplLB->GetMainWindow()->GetControlBackground() );
             }
-            mpImplWin->SetFont( mpImplLB->GetMainWindow().GetFont() );
+            mpImplWin->SetFont( mpImplLB->GetMainWindow()->GetFont() );
             mpImplWin->Invalidate();
         }
     }
-    else if ( nType == StateChangedType::STYLE )
+    else if ( nType == StateChangedType::Style )
     {
         SetStyle( ImplInitStyle( GetStyle() ) );
-        mpImplLB->GetMainWindow().EnableSort( ( GetStyle() & WB_SORT ) ? true : false );
-        bool bSimpleMode = ( GetStyle() & WB_SIMPLEMODE ) ? true : false;
+        mpImplLB->GetMainWindow()->EnableSort( ( GetStyle() & WB_SORT ) != 0 );
+        bool bSimpleMode = ( GetStyle() & WB_SIMPLEMODE ) != 0;
         mpImplLB->SetMultiSelectionSimpleMode( bSimpleMode );
     }
-    else if( nType == StateChangedType::MIRRORING )
+    else if( nType == StateChangedType::Mirroring )
     {
         if( mpBtn )
         {
@@ -875,10 +880,10 @@ void ListBox::StateChanged( StateChangedType nType )
 
 bool ListBox::PreNotify( NotifyEvent& rNEvt )
 {
-    bool nDone = false;
+    bool bDone = false;
     if ( mpImplLB )
     {
-        if( ( rNEvt.GetType() == EVENT_KEYINPUT ) && ( rNEvt.GetWindow() == mpImplWin ) )
+        if( ( rNEvt.GetType() == MouseNotifyEvent::KEYINPUT ) && ( rNEvt.GetWindow() == mpImplWin ) )
         {
             KeyEvent aKeyEvt = *rNEvt.GetKeyEvent();
             switch( aKeyEvt.GetKeyCode().GetCode() )
@@ -888,15 +893,15 @@ bool ListBox::PreNotify( NotifyEvent& rNEvt )
                     if( mpFloatWin && !mpFloatWin->IsInPopupMode() &&
                         aKeyEvt.GetKeyCode().IsMod2() )
                     {
-                        ImplCallEventListeners( VCLEVENT_DROPDOWN_PRE_OPEN );
+                        CallEventListeners( VCLEVENT_DROPDOWN_PRE_OPEN );
                         mpBtn->SetPressed( true );
                         mpFloatWin->StartFloat( false );
-                        ImplCallEventListeners( VCLEVENT_DROPDOWN_OPEN );
-                        nDone = true;
+                        CallEventListeners( VCLEVENT_DROPDOWN_OPEN );
+                        bDone = true;
                     }
                     else
                     {
-                        nDone = mpImplLB->ProcessKeyInput( aKeyEvt );
+                        bDone = mpImplLB->ProcessKeyInput( aKeyEvt );
                     }
                 }
                 break;
@@ -906,11 +911,11 @@ bool ListBox::PreNotify( NotifyEvent& rNEvt )
                         aKeyEvt.GetKeyCode().IsMod2() )
                     {
                         mpFloatWin->EndPopupMode();
-                        nDone = true;
+                        bDone = true;
                     }
                     else
                     {
-                        nDone = mpImplLB->ProcessKeyInput( aKeyEvt );
+                        bDone = mpImplLB->ProcessKeyInput( aKeyEvt );
                     }
                 }
                 break;
@@ -919,57 +924,59 @@ bool ListBox::PreNotify( NotifyEvent& rNEvt )
                     if( IsInDropDown() )
                     {
                         mpImplLB->ProcessKeyInput( aKeyEvt );
-                        nDone = true;
+                        bDone = true;
                     }
                 }
                 break;
 
                 default:
                 {
-                    nDone = mpImplLB->ProcessKeyInput( aKeyEvt );
+                    bDone = mpImplLB->ProcessKeyInput( aKeyEvt );
                 }
             }
         }
-        else if ( rNEvt.GetType() == EVENT_LOSEFOCUS )
+        else if ( rNEvt.GetType() == MouseNotifyEvent::LOSEFOCUS )
         {
             if ( IsInDropDown() && !HasChildPathFocus( true ) )
                 mpFloatWin->EndPopupMode();
         }
-        else if ( (rNEvt.GetType() == EVENT_COMMAND) &&
-                  (rNEvt.GetCommandEvent()->GetCommand() == COMMAND_WHEEL) &&
+        else if ( (rNEvt.GetType() == MouseNotifyEvent::COMMAND) &&
+                  (rNEvt.GetCommandEvent()->GetCommand() == CommandEventId::Wheel) &&
                   (rNEvt.GetWindow() == mpImplWin) )
         {
-            sal_uInt16 nWheelBehavior( GetSettings().GetMouseSettings().GetWheelBehavior() );
-            if  (   ( nWheelBehavior == MOUSE_WHEEL_ALWAYS )
-                ||  (   ( nWheelBehavior == MOUSE_WHEEL_FOCUS_ONLY )
+            MouseWheelBehaviour nWheelBehavior( GetSettings().GetMouseSettings().GetWheelBehavior() );
+            if  (   ( nWheelBehavior == MouseWheelBehaviour::ALWAYS )
+                ||  (   ( nWheelBehavior == MouseWheelBehaviour::FocusOnly )
                     &&  HasChildPathFocus()
                     )
                 )
             {
-                nDone = mpImplLB->HandleWheelAsCursorTravel( *rNEvt.GetCommandEvent() );
+                bDone = mpImplLB->HandleWheelAsCursorTravel( *rNEvt.GetCommandEvent() );
             }
             else
             {
-                nDone = false;  // Don't consume this event, let the default handling take it (i.e. scroll the context)
+                bDone = false;  // Don't consume this event, let the default handling take it (i.e. scroll the context)
             }
         }
     }
 
-    return nDone || Control::PreNotify( rNEvt );
+    return bDone || Control::PreNotify( rNEvt );
 }
 
 void ListBox::Select()
 {
-    ImplCallEventListenersAndHandler( VCLEVENT_LISTBOX_SELECT, maSelectHdl, this );
+    ImplCallEventListenersAndHandler( VCLEVENT_LISTBOX_SELECT, [this] () { maSelectHdl.Call(*this); } );
 }
 
 void ListBox::DoubleClick()
 {
-    ImplCallEventListenersAndHandler( VCLEVENT_LISTBOX_DOUBLECLICK, maDoubleClickHdl, this );
+    ImplCallEventListenersAndHandler( VCLEVENT_LISTBOX_DOUBLECLICK, [this] () { maDoubleClickHdl.Call(*this); } );
 }
 
 void ListBox::Clear()
 {
+    if (!mpImplLB)
+        return;
     mpImplLB->Clear();
     if( IsDropDownBox() )
     {
@@ -993,7 +1000,7 @@ void ListBox::SetNoSelection()
         mpImplWin->SetImage( aImage );
         mpImplWin->Invalidate();
     }
-    ImplCallEventListeners(VCLEVENT_LISTBOX_STATEUPDATE);
+    CallEventListeners(VCLEVENT_LISTBOX_STATEUPDATE);
 }
 
 sal_Int32 ListBox::InsertEntry( const OUString& rStr, sal_Int32 nPos )
@@ -1025,13 +1032,15 @@ void ListBox::RemoveEntry( sal_Int32 nPos )
 
 Image ListBox::GetEntryImage( sal_Int32 nPos ) const
 {
-    if ( mpImplLB->GetEntryList()->HasEntryImage( nPos ) )
+    if ( mpImplLB && mpImplLB->GetEntryList()->HasEntryImage( nPos ) )
         return mpImplLB->GetEntryList()->GetEntryImage( nPos );
     return Image();
 }
 
 sal_Int32 ListBox::GetEntryPos( const OUString& rStr ) const
 {
+    if (!mpImplLB)
+        return LISTBOX_ENTRY_NOTFOUND;
     sal_Int32 nPos = mpImplLB->GetEntryList()->FindEntry( rStr );
     if ( nPos != LISTBOX_ENTRY_NOTFOUND )
         nPos = nPos - mpImplLB->GetEntryList()->GetMRUCount();
@@ -1040,6 +1049,8 @@ sal_Int32 ListBox::GetEntryPos( const OUString& rStr ) const
 
 sal_Int32 ListBox::GetEntryPos( const void* pData ) const
 {
+    if (!mpImplLB)
+        return LISTBOX_ENTRY_NOTFOUND;
     sal_Int32 nPos = mpImplLB->GetEntryList()->FindEntry( pData );
     if ( nPos != LISTBOX_ENTRY_NOTFOUND )
         nPos = nPos - mpImplLB->GetEntryList()->GetMRUCount();
@@ -1048,11 +1059,15 @@ sal_Int32 ListBox::GetEntryPos( const void* pData ) const
 
 OUString ListBox::GetEntry( sal_Int32 nPos ) const
 {
+    if (!mpImplLB)
+        return OUString();
     return mpImplLB->GetEntryList()->GetEntryText( nPos + mpImplLB->GetEntryList()->GetMRUCount() );
 }
 
 sal_Int32 ListBox::GetEntryCount() const
 {
+    if (!mpImplLB)
+        return 0;
     return mpImplLB->GetEntryList()->GetEntryCount() - mpImplLB->GetEntryList()->GetMRUCount();
 }
 
@@ -1063,11 +1078,16 @@ OUString ListBox::GetSelectEntry(sal_Int32 nIndex) const
 
 sal_Int32 ListBox::GetSelectEntryCount() const
 {
+    if (!mpImplLB)
+        return 0;
     return mpImplLB->GetEntryList()->GetSelectEntryCount();
 }
 
 sal_Int32 ListBox::GetSelectEntryPos( sal_Int32 nIndex ) const
 {
+    if (!mpImplLB || !mpImplLB->GetEntryList())
+        return LISTBOX_ENTRY_NOTFOUND;
+
     sal_Int32 nPos = mpImplLB->GetEntryList()->GetSelectEntryPos( nIndex );
     if ( nPos != LISTBOX_ENTRY_NOTFOUND )
     {
@@ -1095,19 +1115,22 @@ void ListBox::SelectEntry( const OUString& rStr, bool bSelect )
 
 void ListBox::SelectEntryPos( sal_Int32 nPos, bool bSelect )
 {
+    if (!mpImplLB)
+        return;
+
     if ( 0 <= nPos && nPos < mpImplLB->GetEntryList()->GetEntryCount() )
     {
         sal_Int32 oldSelectCount = GetSelectEntryCount(), newSelectCount = 0, nCurrentPos = mpImplLB->GetCurrentPos();
         mpImplLB->SelectEntry( nPos + mpImplLB->GetEntryList()->GetMRUCount(), bSelect );
         newSelectCount = GetSelectEntryCount();
         if (oldSelectCount == 0 && newSelectCount > 0)
-            ImplCallEventListeners(VCLEVENT_LISTBOX_STATEUPDATE);
+            CallEventListeners(VCLEVENT_LISTBOX_STATEUPDATE);
         //Only when bSelect == true, send both Selection & Focus events
         if (nCurrentPos != nPos && bSelect)
         {
-            ImplCallEventListeners( VCLEVENT_LISTBOX_SELECT, reinterpret_cast<void*>(nPos));
+            CallEventListeners( VCLEVENT_LISTBOX_SELECT, reinterpret_cast<void*>(nPos));
             if (HasFocus())
-                ImplCallEventListeners( VCLEVENT_LISTBOX_FOCUS, reinterpret_cast<void*>(nPos));
+                CallEventListeners( VCLEVENT_LISTBOX_FOCUS, reinterpret_cast<void*>(nPos));
         }
     }
 }
@@ -1122,12 +1145,12 @@ void* ListBox::GetEntryData( sal_Int32 nPos ) const
     return mpImplLB->GetEntryList()->GetEntryData( nPos + mpImplLB->GetEntryList()->GetMRUCount() );
 }
 
-void ListBox::SetEntryFlags( sal_Int32 nPos, long nFlags )
+void ListBox::SetEntryFlags( sal_Int32 nPos, ListBoxEntryFlags nFlags )
 {
     mpImplLB->SetEntryFlags( nPos + mpImplLB->GetEntryList()->GetMRUCount(), nFlags );
 }
 
-long ListBox::GetEntryFlags( sal_Int32 nPos ) const
+ListBoxEntryFlags ListBox::GetEntryFlags( sal_Int32 nPos ) const
 {
     return mpImplLB->GetEntryList()->GetEntryFlags( nPos + mpImplLB->GetEntryList()->GetMRUCount() );
 }
@@ -1157,8 +1180,8 @@ bool ListBox::IsInDropDown() const
 
 Rectangle ListBox::GetBoundingRectangle( sal_Int32 nItem ) const
 {
-    Rectangle aRect = mpImplLB->GetMainWindow().GetBoundingRectangle( nItem );
-    Rectangle aOffset = mpImplLB->GetMainWindow().GetWindowExtentsRelative( (vcl::Window*)this );
+    Rectangle aRect = mpImplLB->GetMainWindow()->GetBoundingRectangle( nItem );
+    Rectangle aOffset = mpImplLB->GetMainWindow()->GetWindowExtentsRelative( static_cast<vcl::Window*>(const_cast<ListBox *>(this)) );
     aRect.Move( aOffset.TopLeft().X(), aOffset.TopLeft().Y() );
     return aRect;
 }
@@ -1175,12 +1198,12 @@ void ListBox::EnableMultiSelection( bool bMulti, bool bStackSelection )
     // WB_SIMPLEMODE:
     // The MultiListBox behaves just like a normal ListBox
     // MultiSelection is possible via corresponding additional keys
-    bool bSimpleMode = ( GetStyle() & WB_SIMPLEMODE ) ? true : false;
+    bool bSimpleMode = ( GetStyle() & WB_SIMPLEMODE ) != 0;
     mpImplLB->SetMultiSelectionSimpleMode( bSimpleMode );
 
     // In a MultiSelection, we can't see us travelling without focus
     if ( mpFloatWin )
-        mpImplLB->GetMainWindow().AllowGrabFocus( bMulti );
+        mpImplLB->GetMainWindow()->AllowGrabFocus( bMulti );
 }
 
 bool ListBox::IsMultiSelectionEnabled() const
@@ -1217,7 +1240,7 @@ Size ListBox::CalcMinimumSize() const
         Rectangle aContent, aBound;
         Size aTestSize( 100, 20 );
         Rectangle aArea( aPoint, aTestSize );
-        if( GetNativeControlRegion( CTRL_LISTBOX, PART_SUB_EDIT, aArea, 0,
+        if( GetNativeControlRegion( CTRL_LISTBOX, PART_SUB_EDIT, aArea, ControlState::NONE,
                     aControlValue, OUString(), aBound, aContent) )
         {
             // use the themes drop down size
@@ -1234,7 +1257,7 @@ Size ListBox::CalcMinimumSize() const
         ImplControlValue aControlValue;
         Rectangle aRect( Point( 0, 0 ), aSz );
         Rectangle aContent, aBound;
-        if( GetNativeControlRegion( CTRL_LISTBOX, PART_ENTIRE_CONTROL, aRect, 0,
+        if( GetNativeControlRegion( CTRL_LISTBOX, PART_ENTIRE_CONTROL, aRect, ControlState::NONE,
                     aControlValue, OUString(), aBound, aContent) )
         {
             if( aBound.GetHeight() > aSz.Height() )
@@ -1283,7 +1306,7 @@ Size ListBox::CalcAdjustedSize( const Size& rPrefSize ) const
 {
     Size aSz = rPrefSize;
     sal_Int32 nLeft, nTop, nRight, nBottom;
-    ((vcl::Window*)this)->GetBorder( nLeft, nTop, nRight, nBottom );
+    static_cast<vcl::Window*>(const_cast<ListBox *>(this))->GetBorder( nLeft, nTop, nRight, nBottom );
     aSz.Height() -= nTop+nBottom;
     if ( !IsDropDownBox() )
     {
@@ -1348,7 +1371,7 @@ void ListBox::GetMaxVisColumnsAndLines( sal_uInt16& rnCols, sal_uInt16& rnLines
     float nCharWidth = approximate_char_width();
     if ( !IsDropDownBox() )
     {
-        Size aOutSz = mpImplLB->GetMainWindow().GetOutputSizePixel();
+        Size aOutSz = mpImplLB->GetMainWindow()->GetOutputSizePixel();
         rnCols = (sal_uInt16) (aOutSz.Width()/nCharWidth);
         rnLines = (sal_uInt16) (aOutSz.Height()/mpImplLB->GetEntryHeight());
     }
@@ -1369,24 +1392,24 @@ void ListBox::UserDraw( const UserDrawEvent& )
 {
 }
 
-void ListBox::DrawEntry( const UserDrawEvent& rEvt, bool bDrawImage, bool bDrawText, bool bDrawTextAtImagePos )
+void ListBox::DrawEntry(const UserDrawEvent& rEvt, bool bDrawImage, bool bDrawText, bool bDrawTextAtImagePos)
 {
-    if ( rEvt.GetDevice() == &mpImplLB->GetMainWindow() )
-        mpImplLB->GetMainWindow().DrawEntry( rEvt.GetItemId(), bDrawImage, bDrawText, bDrawTextAtImagePos );
-    else if ( rEvt.GetDevice() == mpImplWin )
-        mpImplWin->DrawEntry( bDrawImage, bDrawText, bDrawTextAtImagePos );
+    if (rEvt.GetWindow() == mpImplLB->GetMainWindow())
+        mpImplLB->GetMainWindow()->DrawEntry(*rEvt.GetRenderContext(), rEvt.GetItemId(), bDrawImage, bDrawText, bDrawTextAtImagePos );
+    else if (rEvt.GetWindow() == mpImplWin)
+        mpImplWin->DrawEntry(*rEvt.GetRenderContext(), bDrawImage, bDrawText, bDrawTextAtImagePos);
 }
 
 void ListBox::SetUserItemSize( const Size& rSz )
 {
-    mpImplLB->GetMainWindow().SetUserItemSize( rSz );
+    mpImplLB->GetMainWindow()->SetUserItemSize( rSz );
     if ( mpImplWin )
         mpImplWin->SetUserItemSize( rSz );
 }
 
 void ListBox::EnableUserDraw( bool bUserDraw )
 {
-    mpImplLB->GetMainWindow().EnableUserDraw( bUserDraw );
+    mpImplLB->GetMainWindow()->EnableUserDraw( bUserDraw );
     if ( mpImplWin )
         mpImplWin->EnableUserDraw( bUserDraw );
 }
@@ -1396,7 +1419,7 @@ void ListBox::SetReadOnly( bool bReadOnly )
     if ( mpImplLB->IsReadOnly() != bReadOnly )
     {
         mpImplLB->SetReadOnly( bReadOnly );
-        StateChanged( StateChangedType::READONLY );
+        CompatStateChanged( StateChangedType::ReadOnly );
     }
 }
 
@@ -1465,6 +1488,7 @@ void ListBox::SetEdgeBlending(bool bNew)
 
         if(IsDropDownBox())
         {
+            assert(mpImplWin);
             mpImplWin->Invalidate();
         }
         else
