@@ -20,19 +20,21 @@
 #include <tools/debug.hxx>
 #include <vcl/status.hxx>
 #include <vcl/prgsbar.hxx>
+#include <vcl/settings.hxx>
 
 #define PROGRESSBAR_OFFSET          3
 #define PROGRESSBAR_WIN_OFFSET      2
 
 void ProgressBar::ImplInit()
 {
-    mnPercent   = 0;
-    mbCalcNew   = sal_True;
+    mnPercent = 0;
+    mnPreviousPercent = 0;
+    mbCalcNew = true;
 
-    ImplInitSettings( sal_True, sal_True, sal_True );
+    ImplInitSettings( true, true, true );
 }
 
-static WinBits clearProgressBarBorder( Window* pParent, WinBits nOrgStyle )
+static WinBits clearProgressBarBorder( vcl::Window* pParent, WinBits nOrgStyle )
 {
     WinBits nOutStyle = nOrgStyle;
     if( pParent && (nOrgStyle & WB_BORDER) != 0 )
@@ -43,25 +45,20 @@ static WinBits clearProgressBarBorder( Window* pParent, WinBits nOrgStyle )
     return nOutStyle;
 }
 
-ProgressBar::ProgressBar( Window* pParent, WinBits nWinStyle ) :
+Size ProgressBar::GetOptimalSize() const
+{
+    return Size(150, 20);
+}
+
+ProgressBar::ProgressBar( vcl::Window* pParent, WinBits nWinStyle ) :
     Window( pParent, clearProgressBarBorder( pParent, nWinStyle ) )
 {
-    SetOutputSizePixel( Size( 150, 20 ) );
+    SetOutputSizePixel( GetOptimalSize() );
     ImplInit();
 }
 
-ProgressBar::ProgressBar( Window* pParent, const ResId& rResId ) :
-    Window( pParent, rResId )
-{
-    ImplInit();
-}
-
-ProgressBar::~ProgressBar()
-{
-}
-
-void ProgressBar::ImplInitSettings( sal_Bool bFont,
-                                    sal_Bool bForeground, sal_Bool bBackground )
+void ProgressBar::ImplInitSettings( bool bFont,
+                                    bool bForeground, bool bBackground )
 {
     const StyleSettings& rStyleSettings = GetSettings().GetStyleSettings();
 
@@ -82,11 +79,11 @@ void ProgressBar::ImplInitSettings( sal_Bool bFont,
             IsNativeControlSupported( CTRL_PROGRESS, PART_ENTIRE_CONTROL ) )
         {
             if( (GetStyle() & WB_BORDER) )
-                SetBorderStyle( WINDOW_BORDER_REMOVEBORDER );
-            EnableChildTransparentMode( sal_True );
-            SetPaintTransparent( sal_True );
+                SetBorderStyle( WindowBorderStyle::REMOVEBORDER );
+            EnableChildTransparentMode();
+            SetPaintTransparent( true );
             SetBackground();
-            SetParentClipMode( PARENTCLIPMODE_NOCLIP );
+            SetParentClipMode( ParentClipMode::NoClip );
         }
         else
         {
@@ -120,89 +117,93 @@ void ProgressBar::ImplInitSettings( sal_Bool bFont,
     }
 }
 
-
-void ProgressBar::ImplDrawProgress( sal_uInt16 nOldPerc, sal_uInt16 nNewPerc )
+void ProgressBar::ImplDrawProgress(vcl::RenderContext& rRenderContext, sal_uInt16 nOldPerc, sal_uInt16 nNewPerc)
 {
-    if ( mbCalcNew )
+    if (mbCalcNew)
     {
-        mbCalcNew = sal_False;
+        mbCalcNew = false;
 
-        Size aSize = GetOutputSizePixel();
-        mnPrgsHeight = aSize.Height()-(PROGRESSBAR_WIN_OFFSET*2);
-        mnPrgsWidth = (mnPrgsHeight*2)/3;
+        Size aSize(GetOutputSizePixel());
+        mnPrgsHeight = aSize.Height() - (PROGRESSBAR_WIN_OFFSET * 2);
+        mnPrgsWidth = (mnPrgsHeight * 2) / 3;
         maPos.Y() = PROGRESSBAR_WIN_OFFSET;
-        long nMaxWidth = (aSize.Width()-(PROGRESSBAR_WIN_OFFSET*2)+PROGRESSBAR_OFFSET);
+        long nMaxWidth = (aSize.Width() - (PROGRESSBAR_WIN_OFFSET * 2) + PROGRESSBAR_OFFSET);
         sal_uInt16 nMaxCount = (sal_uInt16)(nMaxWidth / (mnPrgsWidth+PROGRESSBAR_OFFSET));
-        if ( nMaxCount <= 1 )
+        if (nMaxCount <= 1)
+        {
             nMaxCount = 1;
+        }
         else
         {
-            while ( ((10000/(10000/nMaxCount))*(mnPrgsWidth+PROGRESSBAR_OFFSET)) > nMaxWidth )
+            while (((10000 / (10000 / nMaxCount)) * (mnPrgsWidth + PROGRESSBAR_OFFSET)) > nMaxWidth)
+            {
                 nMaxCount--;
+            }
         }
-        mnPercentCount = 10000/nMaxCount;
-        nMaxWidth = ((10000/(10000/nMaxCount))*(mnPrgsWidth+PROGRESSBAR_OFFSET))-PROGRESSBAR_OFFSET;
-        maPos.X() = (aSize.Width()-nMaxWidth)/2;
+        mnPercentCount = 10000 / nMaxCount;
+        nMaxWidth = ((10000 / (10000 / nMaxCount)) * (mnPrgsWidth + PROGRESSBAR_OFFSET)) - PROGRESSBAR_OFFSET;
+        maPos.X() = (aSize.Width() - nMaxWidth) / 2;
     }
 
-    ::DrawProgress( this, maPos, PROGRESSBAR_OFFSET, mnPrgsWidth, mnPrgsHeight,
-                    nOldPerc*100, nNewPerc*100, mnPercentCount,
-                    Rectangle( Point(), GetSizePixel() ) );
+    ::DrawProgress(this, rRenderContext, maPos, PROGRESSBAR_OFFSET, mnPrgsWidth, mnPrgsHeight,
+                   nOldPerc * 100, nNewPerc * 100, mnPercentCount,
+                   Rectangle(Point(), GetSizePixel()));
 }
 
-void ProgressBar::Paint( const Rectangle& )
+void ProgressBar::Paint(vcl::RenderContext& rRenderContext, const Rectangle& /*rRect*/)
 {
-    ImplDrawProgress( 0, mnPercent );
+    ImplDrawProgress(rRenderContext, mnPreviousPercent, mnPercent);
 }
 
-
 void ProgressBar::Resize()
 {
-    mbCalcNew = sal_True;
+    mbCalcNew = true;
     if ( IsReallyVisible() )
         Invalidate();
 }
 
 void ProgressBar::SetValue( sal_uInt16 nNewPercent )
 {
-    DBG_ASSERTWARNING( nNewPercent <= 100, "StatusBar::SetProgressValue(): nPercent > 100" );
+    SAL_WARN_IF( nNewPercent > 100, "vcl", "StatusBar::SetProgressValue(): nPercent > 100" );
 
     if ( nNewPercent < mnPercent )
     {
-        mbCalcNew = sal_True;
+        mbCalcNew = true;
         mnPercent = nNewPercent;
+        mnPreviousPercent = 0;
         if ( IsReallyVisible() )
         {
             Invalidate();
             Update();
         }
     }
-    else
+    else if ( mnPercent != nNewPercent )
     {
-        ImplDrawProgress( mnPercent, nNewPercent );
+        mnPreviousPercent = mnPercent;
         mnPercent = nNewPercent;
+        Invalidate();
     }
 }
 
 void ProgressBar::StateChanged( StateChangedType nType )
 {
 /* FIXME: !!! We do not support text output at the moment
-    if ( (nType == STATE_CHANGE_ZOOM) ||
-         (nType == STATE_CHANGE_CONTROLFONT) )
+    if ( (nType == StateChangedType::Zoom) ||
+         (nType == StateChangedType::ControlFont) )
     {
-        ImplInitSettings( sal_True, sal_False, sal_False );
+        ImplInitSettings( true, false, false );
         Invalidate();
     }
     else
 */
-    if ( nType == STATE_CHANGE_CONTROLFOREGROUND )
+    if ( nType == StateChangedType::ControlForeground )
     {
-        ImplInitSettings( sal_False, sal_True, sal_False );
+        ImplInitSettings( false, true, false );
         Invalidate();
     }
-    else if ( nType == STATE_CHANGE_CONTROLBACKGROUND )
+    else if ( nType == StateChangedType::ControlBackground )
     {
-        ImplInitSettings( sal_False, sal_False, sal_True );
+        ImplInitSettings( false, false, true );
         Invalidate();
     }
 
@@ -211,10 +212,10 @@ void ProgressBar::StateChanged( StateChangedType nType )
 
 void ProgressBar::DataChanged( const DataChangedEvent& rDCEvt )
 {
-    if ( (rDCEvt.GetType() == DATACHANGED_SETTINGS) &&
-         (rDCEvt.GetFlags() & SETTINGS_STYLE) )
+    if ( (rDCEvt.GetType() == DataChangedEventType::SETTINGS) &&
+         (rDCEvt.GetFlags() & AllSettingsFlags::STYLE) )
     {
-        ImplInitSettings( sal_True, sal_True, sal_True );
+        ImplInitSettings( true, true, true );
         Invalidate();
     }
 
