@@ -29,13 +29,6 @@
 #include <svdata.hxx>
 #include <tools/resid.hxx>
 
-TYPEINIT1( TextUndo, SfxUndoAction );
-TYPEINIT1( TextUndoDelPara, TextUndo );
-TYPEINIT1( TextUndoConnectParas, TextUndo );
-TYPEINIT1( TextUndoSplitPara, TextUndo );
-TYPEINIT1( TextUndoInsertChars, TextUndo );
-TYPEINIT1( TextUndoRemoveChars, TextUndo );
-
 
 namespace
 {
@@ -65,7 +58,6 @@ void Shorten (OUString& rString)
 
 } // namespace
 
-
 TextUndoManager::TextUndoManager( TextEngine* p )
 {
     mpTextEngine = p;
@@ -82,9 +74,9 @@ bool TextUndoManager::Undo()
 
     UndoRedoStart();
 
-    mpTextEngine->SetIsInUndo( sal_True );
+    mpTextEngine->SetIsInUndo( true );
     bool bDone = SfxUndoManager::Undo();
-    mpTextEngine->SetIsInUndo( sal_False );
+    mpTextEngine->SetIsInUndo( false );
 
     UndoRedoEnd();
 
@@ -96,12 +88,11 @@ bool TextUndoManager::Redo()
     if ( GetRedoActionCount() == 0 )
         return false;
 
-
     UndoRedoStart();
 
-    mpTextEngine->SetIsInUndo( sal_True );
+    mpTextEngine->SetIsInUndo( true );
     bool bDone = SfxUndoManager::Redo();
-    mpTextEngine->SetIsInUndo( sal_False );
+    mpTextEngine->SetIsInUndo( false );
 
     UndoRedoEnd();
 
@@ -122,8 +113,6 @@ void TextUndoManager::UndoRedoEnd()
         GetView()->ImpSetSelection( aNewSel );
     }
 
-    mpTextEngine->UpdateSelections();
-
     mpTextEngine->FormatAndUpdate( GetView() );
 }
 
@@ -147,7 +136,7 @@ void TextUndo::SetSelection( const TextSelection& rSel )
         GetView()->ImpSetSelection( rSel );
 }
 
-TextUndoDelPara::TextUndoDelPara( TextEngine* pTextEngine, TextNode* pNode, sal_uLong nPara )
+TextUndoDelPara::TextUndoDelPara( TextEngine* pTextEngine, TextNode* pNode, sal_uInt32 nPara )
                     : TextUndo( pTextEngine )
 {
     mpNode = pNode;
@@ -176,20 +165,20 @@ void TextUndoDelPara::Undo()
 void TextUndoDelPara::Redo()
 {
     // pNode is not valid anymore in case an Undo joined paragraphs
-    mpNode = GetDoc()->GetNodes().GetObject( mnPara );
+    mpNode = GetDoc()->GetNodes()[ mnPara ];
 
     delete GetTEParaPortions()->GetObject( mnPara );
     GetTEParaPortions()->Remove( mnPara );
 
     // do not delete Node because of Undo!
-    GetDoc()->GetNodes().Remove( mnPara );
+    GetDoc()->GetNodes().erase( ::std::find( GetDoc()->GetNodes().begin(), GetDoc()->GetNodes().end(), mpNode ) );
     GetTextEngine()->ImpParagraphRemoved( mnPara );
 
     mbDelObject = true; // belongs again to the Undo
 
-    sal_uLong nParas = GetDoc()->GetNodes().Count();
-    sal_uLong n = mnPara < nParas ? mnPara : (nParas-1);
-    TextNode* pN = GetDoc()->GetNodes().GetObject( n );
+    const sal_uInt32 nParas = static_cast<sal_uInt32>(GetDoc()->GetNodes().size());
+    const sal_uInt32 n = mnPara < nParas ? mnPara : nParas-1;
+    TextNode* pN = GetDoc()->GetNodes()[ n ];
     TextPaM aPaM( n, pN->GetText().getLength() );
     SetSelection( aPaM );
 }
@@ -199,7 +188,7 @@ OUString TextUndoDelPara::GetComment () const
     return ResId(STR_TEXTUNDO_DELPARA, *ImplGetResMgr());
 }
 
-TextUndoConnectParas::TextUndoConnectParas( TextEngine* pTextEngine, sal_uLong nPara, sal_uInt16 nPos )
+TextUndoConnectParas::TextUndoConnectParas( TextEngine* pTextEngine, sal_uInt32 nPara, sal_Int32 nPos )
                     :   TextUndo( pTextEngine )
 {
     mnPara = nPara;
@@ -227,7 +216,7 @@ OUString TextUndoConnectParas::GetComment () const
     return ResId(STR_TEXTUNDO_CONNECTPARAS, *ImplGetResMgr()).toString();
 }
 
-TextUndoSplitPara::TextUndoSplitPara( TextEngine* pTextEngine, sal_uLong nPara, sal_uInt16 nPos )
+TextUndoSplitPara::TextUndoSplitPara( TextEngine* pTextEngine, sal_uInt32 nPara, sal_Int32 nPos )
                     : TextUndo( pTextEngine )
 {
     mnPara = nPara;
@@ -264,7 +253,7 @@ TextUndoInsertChars::TextUndoInsertChars( TextEngine* pTextEngine, const TextPaM
 void TextUndoInsertChars::Undo()
 {
     TextSelection aSel( maTextPaM, maTextPaM );
-    aSel.GetEnd().GetIndex() = aSel.GetEnd().GetIndex() + maText.getLength();
+    aSel.GetEnd().GetIndex() += maText.getLength();
     TextPaM aPaM = GetTextEngine()->ImpDeleteText( aSel );
     SetSelection( aPaM );
 }
@@ -274,16 +263,16 @@ void TextUndoInsertChars::Redo()
     TextSelection aSel( maTextPaM, maTextPaM );
     GetTextEngine()->ImpInsertText( aSel, maText );
     TextPaM aNewPaM( maTextPaM );
-    aNewPaM.GetIndex() = aNewPaM.GetIndex() + maText.getLength();
+    aNewPaM.GetIndex() += maText.getLength();
     SetSelection( TextSelection( aSel.GetStart(), aNewPaM ) );
 }
 
 bool TextUndoInsertChars::Merge( SfxUndoAction* pNextAction )
 {
-    if ( !pNextAction->ISA( TextUndoInsertChars ) )
+    if ( nullptr == dynamic_cast< const TextUndoInsertChars*>( pNextAction ) )
         return false;
 
-    TextUndoInsertChars* pNext = (TextUndoInsertChars*)pNextAction;
+    TextUndoInsertChars* pNext = static_cast<TextUndoInsertChars*>(pNextAction);
 
     if ( maTextPaM.GetPara() != pNext->maTextPaM.GetPara() )
         return false;
@@ -314,14 +303,14 @@ void TextUndoRemoveChars::Undo()
 {
     TextSelection aSel( maTextPaM, maTextPaM );
     GetTextEngine()->ImpInsertText( aSel, maText );
-    aSel.GetEnd().GetIndex() = aSel.GetEnd().GetIndex() + maText.getLength();
+    aSel.GetEnd().GetIndex() += maText.getLength();
     SetSelection( aSel );
 }
 
 void TextUndoRemoveChars::Redo()
 {
     TextSelection aSel( maTextPaM, maTextPaM );
-    aSel.GetEnd().GetIndex() = aSel.GetEnd().GetIndex() + maText.getLength();
+    aSel.GetEnd().GetIndex() += maText.getLength();
     TextPaM aPaM = GetTextEngine()->ImpDeleteText( aSel );
     SetSelection( aPaM );
 }
