@@ -146,9 +146,9 @@ static const char* pDictOps[] = {
     "dFamilyBlues",     "dFamilyOtherBlues",    "nStdHW",           "nStdVW",
     "xESC",             "nUniqueID",            "aXUID",            "nCharset",
     "nEncoding",        "nCharStrings",         "PPrivate",         "nSubrs",
-    "nDefaultWidthX",   "nNominalWidthX",       NULL,               NULL,
-    NULL,               NULL,                   NULL,               NULL,
-    "shortint",         "longint",              "BCD",              NULL
+    "nDefaultWidthX",   "nNominalWidthX",       nullptr,               nullptr,
+    nullptr,               nullptr,                   nullptr,               nullptr,
+    "shortint",         "longint",              "BCD",              nullptr
 };
 
 // TOP DICT escapes (also covers PRIV DICT escapes)
@@ -156,36 +156,36 @@ static const char* pDictEscs[] = {
     "sCopyright",           "bIsFixedPitch",    "nItalicAngle",     "nUnderlinePosition",
     "nUnderlineThickness",  "nPaintType",       "tCharstringType",  "aFontMatrix",
     "nStrokeWidth",         "nBlueScale",       "nBlueShift",       "nBlueFuzz",
-    "dStemSnapH",           "dStemSnapV",       "bForceBold",       NULL,
-    NULL,                   "nLanguageGroup",   "nExpansionFactor", "nInitialRandomSeed",
+    "dStemSnapH",           "dStemSnapV",       "bForceBold",       nullptr,
+    nullptr,                   "nLanguageGroup",   "nExpansionFactor", "nInitialRandomSeed",
     "nSyntheticBase",       "sPostScript",      "sBaseFontName",    "dBaseFontBlend",
-    NULL,                   NULL,               NULL,               NULL,
-    NULL,                   NULL,               "rROS",             "nCIDFontVersion",
+    nullptr,                   nullptr,               nullptr,               nullptr,
+    nullptr,                   nullptr,               "rROS",             "nCIDFontVersion",
     "nCIDFontRevision",     "nCIDFontType",     "nCIDCount",        "nUIDBase",
     "nFDArray",             "nFDSelect",        "sFontName"
 };
 
 static const char* pType1Ops[] = {
-    NULL,               "2hstem",           NULL,               "2vstem",
+    nullptr,               "2hstem",           nullptr,               "2vstem",
     "1vmoveto",         "Arlineto",         "1hlineto",         "1vlineto",
     "Crrcurveto",       "0closepath",       "Lcallsubr",        "0return",
-    "xT1ESC",           "2hsbw",            "0endchar",         NULL,
-    NULL,               NULL,               NULL,               NULL,
-    NULL,               "2rmoveto",         "1hmoveto",         NULL,
-    NULL,               NULL,               NULL,               NULL,
-    NULL,               NULL,               "4vhcurveto",       "4hvcurveto"
+    "xT1ESC",           "2hsbw",            "0endchar",         nullptr,
+    nullptr,               nullptr,               nullptr,               nullptr,
+    nullptr,               "2rmoveto",         "1hmoveto",         nullptr,
+    nullptr,               nullptr,               nullptr,               nullptr,
+    nullptr,               nullptr,               "4vhcurveto",       "4hvcurveto"
 };
 
 static const char* pT1EscOps[] = {
-    "0dotsection",      "6vstem3",          "6hstem3",          NULL,
-    NULL,               NULL,               "5seac",            "4sbw",
-    NULL,               "1abs",             "2add",             "2sub",
-    "2div",             NULL,               NULL,               NULL,
-    "Gcallothersubr",   "1pop",             NULL,               NULL,
-    NULL,               NULL,               NULL,               NULL,
-    NULL,               NULL,               NULL,               NULL,
-    NULL,               NULL,               NULL,               NULL,
-    NULL,               "2setcurrentpoint"
+    "0dotsection",      "6vstem3",          "6hstem3",          nullptr,
+    nullptr,               nullptr,               "5seac",            "4sbw",
+    nullptr,               "1abs",             "2add",             "2sub",
+    "2div",             nullptr,               nullptr,               nullptr,
+    "Gcallothersubr",   "1pop",             nullptr,               nullptr,
+    nullptr,               nullptr,               nullptr,               nullptr,
+    nullptr,               nullptr,               nullptr,               nullptr,
+    nullptr,               nullptr,               nullptr,               nullptr,
+    nullptr,               "2setcurrentpoint"
 };
 
 struct TYPE1OP
@@ -208,26 +208,26 @@ struct TYPE1OP
 };
 
 static const char* pType2Ops[] = {
-    NULL,           "hhstem",       NULL,           "vvstem",
+    nullptr,           "hhstem",       nullptr,           "vvstem",
     "mvmoveto",     "Arlineto",     "Ehlineto",     "Evlineto",
-    "Crrcurveto",   NULL,           "Lcallsubr",    "Xreturn",
-    "xT2ESC",       NULL,           "eendchar",     NULL,
-    NULL,           NULL,           "Hhstemhm",     "Khintmask",
+    "Crrcurveto",   nullptr,           "Lcallsubr",    "Xreturn",
+    "xT2ESC",       nullptr,           "eendchar",     nullptr,
+    nullptr,           nullptr,           "Hhstemhm",     "Khintmask",
     "Kcntrmask",    "Mrmoveto",     "mhmoveto",     "Vvstemhm",
     ".rcurveline",  ".rlinecurve",  ".vvcurveto",   ".hhcurveto",
     ".shortint",    "Gcallgsubr",   ".vhcurveto",   ".hvcurveto"
 };
 
 static const char* pT2EscOps[] = {
-    NULL,       NULL,       NULL,       "2and",
-    "2or",      "1not",     NULL,       NULL,
-    NULL,       "1abs",     "2add",     "2sub",
-    "2div",     NULL,       "1neg",     "2eq",
-    NULL,       NULL,       "1drop",    NULL,
+    nullptr,       nullptr,       nullptr,       "2and",
+    "2or",      "1not",     nullptr,       nullptr,
+    nullptr,       "1abs",     "2add",     "2sub",
+    "2div",     nullptr,       "1neg",     "2eq",
+    nullptr,       nullptr,       "1drop",    nullptr,
     "1put",     "1get",     "4ifelse",  "0random",
-    "2mul",     NULL,       "1sqrt",    "1dup",
-    "2exch",    "Iindex",   "Rroll",    NULL,
-    NULL,       NULL,       "7hflex",   "Fflex",
+    "2mul",     nullptr,       "1sqrt",    "1dup",
+    "2exch",    "Iindex",   "Rroll",    nullptr,
+    nullptr,       nullptr,       "7hflex",   "Fflex",
     "9hflex1",  "fflex1"
 };
 
@@ -399,7 +399,7 @@ public: // TODO: is public really needed?
     void    updateWidth( bool bUseFirstVal);
 
 private:
-    // typeop exceution context
+    // typeop execution context
     int mnStackIdx;
     ValType mnValStack[ NMAXSTACK+4];
     ValType mnTransVals[ NMAXTRANS];
@@ -414,15 +414,15 @@ private:
 CffSubsetterContext::CffSubsetterContext( const U8* pBasePtr, int nBaseLen)
     : mpBasePtr( pBasePtr)
     , mpBaseEnd( pBasePtr+nBaseLen)
-    , mpReadPtr(NULL)
-    , mpReadEnd(NULL)
-    , mpWritePtr(NULL)
+    , mpReadPtr(nullptr)
+    , mpReadEnd(nullptr)
+    , mpWritePtr(nullptr)
     , mbSawError(false)
     , mbNeedClose(false)
     , mbIgnoreHints(false)
     , mnCntrMask(0)
-    , mpCharStringOps(NULL)
-    , mpCharStringEscs(NULL)
+    , mpCharStringOps(nullptr)
+    , mpCharStringEscs(nullptr)
     , mnStackIdx(0)
     , mnHintSize(0)
     , mnHorzHintSize(0)
@@ -506,11 +506,10 @@ void CffSubsetterContext::setCharStringType( int nVal)
 
 void CffSubsetterContext::readDictOp()
 {
-    ValType nVal = 0;
     const U8 c = *mpReadPtr;
     if( c <= 21 ) {
         int nOpId = *(mpReadPtr++);
-        const char* pCmdName = 0;
+        const char* pCmdName = nullptr;
         if( nOpId != 12)
             pCmdName = pDictOps[nOpId];
         else {
@@ -534,8 +533,8 @@ void CffSubsetterContext::readDictOp()
             default: break; // TODO: handle more boolean dictops?
             }
             break;
-        case 'n':   // dict-op number
-            nVal = popVal();
+        case 'n': { // dict-op number
+            ValType nVal = popVal();
             nInt = static_cast<int>(nVal);
             switch( nOpId) {
             case  10: mpCffLocal->maStemStdHW = nVal; break;    // "StdHW"
@@ -555,7 +554,7 @@ void CffSubsetterContext::readDictOp()
             case 937: mnFDSelectBase = nInt; break;             // "nFDSelect"
             default: break; // TODO: handle more numeric dictops?
             }
-            break;
+            } break;
         case 'a': { // array
             switch( nOpId) {
             case   5: maFontBBox.clear(); break;     // "FontBBox"
@@ -563,7 +562,7 @@ void CffSubsetterContext::readDictOp()
             default: break; // TODO: reset other arrays?
             }
             for( int i = 0; i < size(); ++i ) {
-                nVal = getVal(i);
+                ValType nVal = getVal(i);
                 switch( nOpId) {
                 case   5: maFontBBox.push_back( nVal); break;     // "FontBBox"
                 case 907: maFontMatrix.push_back( nVal); break; // "FontMatrix"
@@ -573,7 +572,7 @@ void CffSubsetterContext::readDictOp()
             clear();
             } break;
         case 'd': { // delta array
-            nVal = 0;
+            ValType nVal = 0;
             for( int i = 0; i < size(); ++i ) {
                 nVal += getVal(i);
                 switch( nOpId) {
@@ -606,7 +605,7 @@ void CffSubsetterContext::readDictOp()
             int nSid2 = popInt();
             (void)nSid1; // TODO: use
             (void)nSid2; // TODO: use
-            nVal = popVal();
+            popVal();
             mbCIDFont = true;
             } break;
         case 't':   // CharstringType
@@ -614,11 +613,7 @@ void CffSubsetterContext::readDictOp()
             setCharStringType( nInt );
             break;
         }
-
-        return;
-    }
-
-    if( (c >= 32) || (c == 28) ) {
+    } else if( (c >= 32) || (c == 28) ) {
 //      --mpReadPtr;
         read2push();
     } else if( c == 29 ) {      // longint
@@ -630,13 +625,13 @@ void CffSubsetterContext::readDictOp()
         if( (sizeof(nS32) != 4) && (nS32 & (1U<<31)))
             nS32 |= (~0U) << 31;    // assuming 2s complement
         mpReadPtr += 4;
-        nVal = static_cast<ValType>(nS32);
+        ValType nVal = static_cast<ValType>(nS32);
         push( nVal );
     } else if( c == 30) {       // real number
         ++mpReadPtr; // skip 30
         const RealType fReal = readRealVal();
         // push value onto stack
-        nVal = fReal;
+        ValType nVal = fReal;
         push( nVal);
     }
 }
@@ -1753,7 +1748,7 @@ Type1Emitter::~Type1Emitter()
         return;
     if( mbCloseOutfile )
         fclose( mpFileOut);
-    mpFileOut = NULL;
+    mpFileOut = nullptr;
 }
 
 void Type1Emitter::setSubsetName( const char* pSubsetName)
@@ -2019,7 +2014,7 @@ bool CffSubsetterContext::emitAsType1( Type1Emitter& rEmitter,
 
     if( mpCffLocal->mfBlueScale) {
         pOut += sprintf( pOut, "/BlueScale ");
-        pOut += dbl2str( pOut, mpCffLocal->mfBlueScale, 6);
+        pOut += dbl2str( pOut, mpCffLocal->mfBlueScale);
         pOut += sprintf( pOut, " def\n");
     }
     if( mpCffLocal->mfBlueShift) {  // default BlueShift==7
