@@ -38,7 +38,7 @@ static inline sal_uInt8 lcl_getDuotoneColorComponent( sal_uInt8 base, sal_uInt16
     return (sal_uInt8) (color1+color2);
 }
 
-bool Bitmap::Filter( BmpFilter eFilter, const BmpFilterParam* pFilterParam, const Link* pProgress )
+bool Bitmap::Filter( BmpFilter eFilter, const BmpFilterParam* pFilterParam )
 {
     bool bRet = false;
 
@@ -66,36 +66,36 @@ bool Bitmap::Filter( BmpFilter eFilter, const BmpFilterParam* pFilterParam, cons
         case( BMP_FILTER_SHARPEN ):
         {
             const long pSharpenMatrix[] = { -1, -1,  -1, -1, 16, -1, -1, -1,  -1 };
-            bRet = ImplConvolute3( &pSharpenMatrix[ 0 ], 8, pFilterParam, pProgress );
+            bRet = ImplConvolute3( &pSharpenMatrix[ 0 ], 8 );
         }
         break;
 
         case( BMP_FILTER_REMOVENOISE ):
-            bRet = ImplMedianFilter( pFilterParam, pProgress );
+            bRet = ImplMedianFilter();
         break;
 
         case( BMP_FILTER_SOBEL_GREY ):
-            bRet = ImplSobelGrey( pFilterParam, pProgress );
+            bRet = ImplSobelGrey();
         break;
 
         case( BMP_FILTER_SOLARIZE ):
-            bRet = ImplSolarize( pFilterParam, pProgress );
+            bRet = ImplSolarize( pFilterParam );
         break;
 
         case( BMP_FILTER_SEPIA ):
-            bRet = ImplSepia( pFilterParam, pProgress );
+            bRet = ImplSepia( pFilterParam );
         break;
 
         case( BMP_FILTER_MOSAIC ):
-            bRet = ImplMosaic( pFilterParam, pProgress );
+            bRet = ImplMosaic( pFilterParam );
         break;
 
         case( BMP_FILTER_EMBOSS_GREY ):
-            bRet = ImplEmbossGrey( pFilterParam, pProgress );
+            bRet = ImplEmbossGrey( pFilterParam );
         break;
 
         case( BMP_FILTER_POPART ):
-            bRet = ImplPopArt( pFilterParam, pProgress );
+            bRet = ImplPopArt();
         break;
 
         case( BMP_FILTER_DUOTONE ):
@@ -110,8 +110,7 @@ bool Bitmap::Filter( BmpFilter eFilter, const BmpFilterParam* pFilterParam, cons
     return bRet;
 }
 
-bool Bitmap::ImplConvolute3( const long* pMatrix, long nDivisor,
-                             const BmpFilterParam* /*pFilterParam*/, const Link* /*pProgress*/ )
+bool Bitmap::ImplConvolute3( const long* pMatrix, long nDivisor )
 {
     BitmapReadAccess*   pReadAcc = AcquireReadAccess();
     bool                bRet = false;
@@ -127,9 +126,9 @@ bool Bitmap::ImplConvolute3( const long* pMatrix, long nDivisor,
             const long      nHeight = pWriteAcc->Height(), nHeight2 = nHeight + 2;
             long*           pColm = new long[ nWidth2 ];
             long*           pRows = new long[ nHeight2 ];
-            BitmapColor*    pColRow1 = (BitmapColor*) new sal_uInt8[ sizeof( BitmapColor ) * nWidth2 ];
-            BitmapColor*    pColRow2 = (BitmapColor*) new sal_uInt8[ sizeof( BitmapColor ) * nWidth2 ];
-            BitmapColor*    pColRow3 = (BitmapColor*) new sal_uInt8[ sizeof( BitmapColor ) * nWidth2 ];
+            BitmapColor*    pColRow1 = reinterpret_cast<BitmapColor*>(new sal_uInt8[ sizeof( BitmapColor ) * nWidth2 ]);
+            BitmapColor*    pColRow2 = reinterpret_cast<BitmapColor*>(new sal_uInt8[ sizeof( BitmapColor ) * nWidth2 ]);
+            BitmapColor*    pColRow3 = reinterpret_cast<BitmapColor*>(new sal_uInt8[ sizeof( BitmapColor ) * nWidth2 ]);
             BitmapColor*    pRowTmp1 = pColRow1;
             BitmapColor*    pRowTmp2 = pColRow2;
             BitmapColor*    pRowTmp3 = pColRow3;
@@ -228,13 +227,13 @@ bool Bitmap::ImplConvolute3( const long* pMatrix, long nDivisor,
             }
 
             delete[] pKoeff;
-            delete[] (sal_uInt8*) pColRow1;
-            delete[] (sal_uInt8*) pColRow2;
-            delete[] (sal_uInt8*) pColRow3;
+            delete[] reinterpret_cast<sal_uInt8*>(pColRow1);
+            delete[] reinterpret_cast<sal_uInt8*>(pColRow2);
+            delete[] reinterpret_cast<sal_uInt8*>(pColRow3);
             delete[] pColm;
             delete[] pRows;
 
-            aNewBmp.ReleaseAccess( pWriteAcc );
+            Bitmap::ReleaseAccess( pWriteAcc );
 
             bRet = true;
         }
@@ -256,7 +255,7 @@ bool Bitmap::ImplConvolute3( const long* pMatrix, long nDivisor,
     return bRet;
 }
 
-bool Bitmap::ImplMedianFilter( const BmpFilterParam* /*pFilterParam*/, const Link* /*pProgress*/ )
+bool Bitmap::ImplMedianFilter()
 {
     BitmapReadAccess*   pReadAcc = AcquireReadAccess();
     bool                bRet = false;
@@ -272,9 +271,9 @@ bool Bitmap::ImplMedianFilter( const BmpFilterParam* /*pFilterParam*/, const Lin
             const long      nHeight = pWriteAcc->Height(), nHeight2 = nHeight + 2;
             long*           pColm = new long[ nWidth2 ];
             long*           pRows = new long[ nHeight2 ];
-            BitmapColor*    pColRow1 = (BitmapColor*) new sal_uInt8[ sizeof( BitmapColor ) * nWidth2 ];
-            BitmapColor*    pColRow2 = (BitmapColor*) new sal_uInt8[ sizeof( BitmapColor ) * nWidth2 ];
-            BitmapColor*    pColRow3 = (BitmapColor*) new sal_uInt8[ sizeof( BitmapColor ) * nWidth2 ];
+            BitmapColor*    pColRow1 = reinterpret_cast<BitmapColor*>(new sal_uInt8[ sizeof( BitmapColor ) * nWidth2 ]);
+            BitmapColor*    pColRow2 = reinterpret_cast<BitmapColor*>(new sal_uInt8[ sizeof( BitmapColor ) * nWidth2 ]);
+            BitmapColor*    pColRow3 = reinterpret_cast<BitmapColor*>(new sal_uInt8[ sizeof( BitmapColor ) * nWidth2 ]);
             BitmapColor*    pRowTmp1 = pColRow1;
             BitmapColor*    pRowTmp2 = pColRow2;
             BitmapColor*    pRowTmp3 = pColRow3;
@@ -357,13 +356,13 @@ bool Bitmap::ImplMedianFilter( const BmpFilterParam* /*pFilterParam*/, const Lin
                 }
             }
 
-            delete[] (sal_uInt8*) pColRow1;
-            delete[] (sal_uInt8*) pColRow2;
-            delete[] (sal_uInt8*) pColRow3;
+            delete[] reinterpret_cast<sal_uInt8*>(pColRow1);
+            delete[] reinterpret_cast<sal_uInt8*>(pColRow2);
+            delete[] reinterpret_cast<sal_uInt8*>(pColRow3);
             delete[] pColm;
             delete[] pRows;
 
-            aNewBmp.ReleaseAccess( pWriteAcc );
+            Bitmap::ReleaseAccess( pWriteAcc );
 
             bRet = true;
         }
@@ -385,7 +384,7 @@ bool Bitmap::ImplMedianFilter( const BmpFilterParam* /*pFilterParam*/, const Lin
     return bRet;
 }
 
-bool Bitmap::ImplSobelGrey( const BmpFilterParam* /*pFilterParam*/, const Link* /*pProgress*/ )
+bool Bitmap::ImplSobelGrey()
 {
     bool bRet = ImplMakeGreyscales( 256 );
 
@@ -489,7 +488,7 @@ bool Bitmap::ImplSobelGrey( const BmpFilterParam* /*pFilterParam*/, const Link*
 
                 delete[] pHMap;
                 delete[] pVMap;
-                aNewBmp.ReleaseAccess( pWriteAcc );
+                Bitmap::ReleaseAccess( pWriteAcc );
                 bRet = true;
             }
 
@@ -511,7 +510,7 @@ bool Bitmap::ImplSobelGrey( const BmpFilterParam* /*pFilterParam*/, const Link*
     return bRet;
 }
 
-bool Bitmap::ImplEmbossGrey( const BmpFilterParam* pFilterParam, const Link* /*pProgress*/ )
+bool Bitmap::ImplEmbossGrey( const BmpFilterParam* pFilterParam )
 {
     bool bRet = ImplMakeGreyscales( 256 );
 
@@ -601,7 +600,7 @@ bool Bitmap::ImplEmbossGrey( const BmpFilterParam* pFilterParam, const Link* /*p
 
                 delete[] pHMap;
                 delete[] pVMap;
-                aNewBmp.ReleaseAccess( pWriteAcc );
+                Bitmap::ReleaseAccess( pWriteAcc );
                 bRet = true;
             }
 
@@ -623,7 +622,7 @@ bool Bitmap::ImplEmbossGrey( const BmpFilterParam* pFilterParam, const Link* /*p
     return bRet;
 }
 
-bool Bitmap::ImplSolarize( const BmpFilterParam* pFilterParam, const Link* /*pProgress*/ )
+bool Bitmap::ImplSolarize( const BmpFilterParam* pFilterParam )
 {
     bool                bRet = false;
     BitmapWriteAccess*  pWriteAcc = AcquireWriteAccess();
@@ -671,7 +670,7 @@ bool Bitmap::ImplSolarize( const BmpFilterParam* pFilterParam, const Link* /*pPr
     return bRet;
 }
 
-bool Bitmap::ImplSepia( const BmpFilterParam* pFilterParam, const Link* /*pProgress*/ )
+bool Bitmap::ImplSepia( const BmpFilterParam* pFilterParam )
 {
     BitmapReadAccess*   pReadAcc = AcquireReadAccess();
     bool                bRet = false;
@@ -735,7 +734,7 @@ bool Bitmap::ImplSepia( const BmpFilterParam* pFilterParam, const Link* /*pProgr
                 }
             }
 
-            aNewBmp.ReleaseAccess( pWriteAcc );
+            Bitmap::ReleaseAccess( pWriteAcc );
             bRet = true;
         }
 
@@ -756,7 +755,7 @@ bool Bitmap::ImplSepia( const BmpFilterParam* pFilterParam, const Link* /*pProgr
     return bRet;
 }
 
-bool Bitmap::ImplMosaic( const BmpFilterParam* pFilterParam, const Link* /*pProgress*/ )
+bool Bitmap::ImplMosaic( const BmpFilterParam* pFilterParam )
 {
     sal_uLong               nTileWidth = ( pFilterParam && pFilterParam->meFilter == BMP_FILTER_MOSAIC ) ?
                                      pFilterParam->maMosaicTileSize.mnTileWidth : 4;
@@ -778,7 +777,7 @@ bool Bitmap::ImplMosaic( const BmpFilterParam* pFilterParam, const Link* /*pProg
 
         if( GetBitCount() > 8 )
         {
-            pNewBmp = NULL;
+            pNewBmp = nullptr;
             pReadAcc = pWriteAcc = AcquireWriteAccess();
         }
         else
@@ -899,7 +898,7 @@ bool Bitmap::ImplMosaic( const BmpFilterParam* pFilterParam, const Link* /*pProg
 
         if( pNewBmp )
         {
-            pNewBmp->ReleaseAccess( pWriteAcc );
+            Bitmap::ReleaseAccess( pWriteAcc );
 
             if( bRet )
             {
@@ -931,9 +930,9 @@ extern "C" int SAL_CALL ImplPopArtCmpFnc( const void* p1, const void* p2 )
 {
     int nRet;
 
-    if( ( (PopArtEntry*) p1 )->mnCount < ( (PopArtEntry*) p2 )->mnCount )
+    if( static_cast<PopArtEntry const *>(p1)->mnCount < static_cast<PopArtEntry const *>(p2)->mnCount )
         nRet = 1;
-    else if( ( (PopArtEntry*) p1 )->mnCount == ( (PopArtEntry*) p2 )->mnCount )
+    else if( static_cast<PopArtEntry const *>(p1)->mnCount == static_cast<PopArtEntry const *>(p2)->mnCount )
         nRet = 0;
     else
         nRet = -1;
@@ -941,9 +940,10 @@ extern "C" int SAL_CALL ImplPopArtCmpFnc( const void* p1, const void* p2 )
     return nRet;
 }
 
-bool Bitmap::ImplPopArt( const BmpFilterParam* /*pFilterParam*/, const Link* /*pProgress*/ )
+bool Bitmap::ImplPopArt()
 {
-    bool bRet = ( GetBitCount() > 8 ) ? Convert( BMP_CONVERSION_8BIT_COLORS ) : true;
+    /* note: GetBitCount() after that is no more than 8 */
+    bool bRet = ( GetBitCount() <= 8 ) || Convert( BMP_CONVERSION_8BIT_COLORS );
 
     if( bRet )
     {
@@ -955,8 +955,8 @@ bool Bitmap::ImplPopArt( const BmpFilterParam* /*pFilterParam*/, const Link* /*p
         {
             const long      nWidth = pWriteAcc->Width();
             const long      nHeight = pWriteAcc->Height();
-            const sal_uLong nEntryCount = 1UL << pWriteAcc->GetBitCount();
-            sal_uLong       n;
+            const int       nEntryCount = 1 << pWriteAcc->GetBitCount();
+            int n;
             PopArtEntry*    pPopArtTable = new PopArtEntry[ nEntryCount ];
 
             for( n = 0; n < nEntryCount; n++ )
@@ -1160,9 +1160,9 @@ bool Bitmap::ImplSeparableUnsharpenFilter(const double radius) {
     BitmapColor aColor, aColorBlur;
 
     // For all pixels in original image subtract pixels values from blurred image
-    for( int x = 0; x < nWidth; x++ )
+    for( long x = 0; x < nWidth; x++ )
     {
-        for( int y = 0; y < nHeight; y++ )
+        for( long y = 0; y < nHeight; y++ )
         {
             aColorBlur = pReadAccBlur->GetColor( y , x );
             aColor = pReadAcc->GetColor( y , x );
@@ -1194,9 +1194,9 @@ bool Bitmap::ImplDuotoneFilter( const sal_uLong nColorOne, const sal_uLong nColo
     const BitmapColor aColorOne( static_cast< sal_uInt8 >( nColorOne >> 16 ), static_cast< sal_uInt8 >( nColorOne >> 8 ), static_cast< sal_uInt8 >( nColorOne ) );
     const BitmapColor aColorTwo( static_cast< sal_uInt8 >( nColorTwo >> 16 ), static_cast< sal_uInt8 >( nColorTwo >> 8 ), static_cast< sal_uInt8 >( nColorTwo ) );
 
-    for( int x = 0; x < nWidth; x++ )
+    for( long x = 0; x < nWidth; x++ )
     {
-        for( int y = 0; y < nHeight; y++ )
+        for( long y = 0; y < nHeight; y++ )
         {
             BitmapColor aColor = pReadAcc->GetColor( y, x );
             sal_uInt8 luminance = aColor.GetLuminance();
