@@ -17,7 +17,7 @@
  *   the License at http://www.apache.org/licenses/LICENSE-2.0 .
  */
 
-#include <cppuhelper/compbase1.hxx>
+#include <cppuhelper/compbase.hxx>
 
 #include <com/sun/star/geometry/RealSize2D.hpp>
 #include <com/sun/star/geometry/RealPoint2D.hpp>
@@ -290,7 +290,7 @@ namespace vcl
 
                 ::Bitmap aBitmap( aPixelSize,
                                   sal::static_int_cast<sal_uInt16>(nDepth),
-                                  aLayout.Palette.is() ? &aPalette : NULL );
+                                  aLayout.Palette.is() ? &aPalette : nullptr );
                 ::Bitmap aAlpha;
                 if( nAlphaDepth )
                     aAlpha = ::Bitmap( aPixelSize,
@@ -300,10 +300,10 @@ namespace vcl
 
                 { // limit scoped access
                     Bitmap::ScopedWriteAccess pWriteAccess( aBitmap );
-                    Bitmap::ScopedWriteAccess pAlphaWriteAccess( nAlphaDepth ? aAlpha.AcquireWriteAccess() : NULL,
+                    Bitmap::ScopedWriteAccess pAlphaWriteAccess( nAlphaDepth ? aAlpha.AcquireWriteAccess() : nullptr,
                                                                aAlpha );
 
-                    ENSURE_OR_THROW(pWriteAccess.get() != NULL,
+                    ENSURE_OR_THROW(pWriteAccess.get() != nullptr,
                                     "Cannot get write access to bitmap");
 
                     const sal_Int32 nWidth(aPixelSize.Width());
@@ -417,30 +417,30 @@ namespace vcl
 
         namespace
         {
-            class StandardColorSpace : public cppu::WeakImplHelper1< com::sun::star::rendering::XColorSpace >
+            class StandardColorSpace : public cppu::WeakImplHelper< css::rendering::XColorSpace >
             {
             private:
                 uno::Sequence< sal_Int8 > m_aComponentTags;
 
-                virtual ::sal_Int8 SAL_CALL getType(  ) throw (uno::RuntimeException, std::exception) SAL_OVERRIDE
+                virtual ::sal_Int8 SAL_CALL getType(  ) throw (uno::RuntimeException, std::exception) override
                 {
                     return rendering::ColorSpaceType::RGB;
                 }
-                virtual uno::Sequence< ::sal_Int8 > SAL_CALL getComponentTags(  ) throw (uno::RuntimeException, std::exception) SAL_OVERRIDE
+                virtual uno::Sequence< ::sal_Int8 > SAL_CALL getComponentTags(  ) throw (uno::RuntimeException, std::exception) override
                 {
                     return m_aComponentTags;
                 }
-                virtual ::sal_Int8 SAL_CALL getRenderingIntent(  ) throw (uno::RuntimeException, std::exception) SAL_OVERRIDE
+                virtual ::sal_Int8 SAL_CALL getRenderingIntent(  ) throw (uno::RuntimeException, std::exception) override
                 {
                     return rendering::RenderingIntent::PERCEPTUAL;
                 }
-                virtual uno::Sequence< beans::PropertyValue > SAL_CALL getProperties(  ) throw (uno::RuntimeException, std::exception) SAL_OVERRIDE
+                virtual uno::Sequence< beans::PropertyValue > SAL_CALL getProperties(  ) throw (uno::RuntimeException, std::exception) override
                 {
                     return uno::Sequence< beans::PropertyValue >();
                 }
                 virtual uno::Sequence< double > SAL_CALL convertColorSpace( const uno::Sequence< double >& deviceColor,
                                                                             const uno::Reference< rendering::XColorSpace >& targetColorSpace ) throw (lang::IllegalArgumentException,
-                                                                                                                                                      uno::RuntimeException, std::exception) SAL_OVERRIDE
+                                                                                                                                                      uno::RuntimeException, std::exception) override
                 {
                     // TODO(P3): if we know anything about target
                     // colorspace, this can be greatly sped up
@@ -448,7 +448,7 @@ namespace vcl
                         convertToARGB(deviceColor));
                     return targetColorSpace->convertFromARGB(aIntermediate);
                 }
-                virtual uno::Sequence< rendering::RGBColor > SAL_CALL convertToRGB( const uno::Sequence< double >& deviceColor ) throw (lang::IllegalArgumentException, uno::RuntimeException, std::exception) SAL_OVERRIDE
+                virtual uno::Sequence< rendering::RGBColor > SAL_CALL convertToRGB( const uno::Sequence< double >& deviceColor ) throw (lang::IllegalArgumentException, uno::RuntimeException, std::exception) override
                 {
                     const double*  pIn( deviceColor.getConstArray() );
                     const sal_Size nLen( deviceColor.getLength() );
@@ -465,7 +465,7 @@ namespace vcl
                     }
                     return aRes;
                 }
-                virtual uno::Sequence< rendering::ARGBColor > SAL_CALL convertToARGB( const uno::Sequence< double >& deviceColor ) throw (lang::IllegalArgumentException, uno::RuntimeException, std::exception) SAL_OVERRIDE
+                virtual uno::Sequence< rendering::ARGBColor > SAL_CALL convertToARGB( const uno::Sequence< double >& deviceColor ) throw (lang::IllegalArgumentException, uno::RuntimeException, std::exception) override
                 {
                     const double*  pIn( deviceColor.getConstArray() );
                     const sal_Size nLen( deviceColor.getLength() );
@@ -482,7 +482,7 @@ namespace vcl
                     }
                     return aRes;
                 }
-                virtual uno::Sequence< rendering::ARGBColor > SAL_CALL convertToPARGB( const uno::Sequence< double >& deviceColor ) throw (lang::IllegalArgumentException, uno::RuntimeException, std::exception) SAL_OVERRIDE
+                virtual uno::Sequence< rendering::ARGBColor > SAL_CALL convertToPARGB( const uno::Sequence< double >& deviceColor ) throw (lang::IllegalArgumentException, uno::RuntimeException, std::exception) override
                 {
                     const double*  pIn( deviceColor.getConstArray() );
                     const sal_Size nLen( deviceColor.getLength() );
@@ -499,7 +499,7 @@ namespace vcl
                     }
                     return aRes;
                 }
-                virtual uno::Sequence< double > SAL_CALL convertFromRGB( const uno::Sequence< rendering::RGBColor >& rgbColor ) throw (lang::IllegalArgumentException, uno::RuntimeException, std::exception) SAL_OVERRIDE
+                virtual uno::Sequence< double > SAL_CALL convertFromRGB( const uno::Sequence< rendering::RGBColor >& rgbColor ) throw (lang::IllegalArgumentException, uno::RuntimeException, std::exception) override
                 {
                     const rendering::RGBColor* pIn( rgbColor.getConstArray() );
                     const sal_Size             nLen( rgbColor.getLength() );
@@ -516,7 +516,7 @@ namespace vcl
                     }
                     return aRes;
                 }
-                virtual uno::Sequence< double > SAL_CALL convertFromARGB( const uno::Sequence< rendering::ARGBColor >& rgbColor ) throw (lang::IllegalArgumentException, uno::RuntimeException, std::exception) SAL_OVERRIDE
+                virtual uno::Sequence< double > SAL_CALL convertFromARGB( const uno::Sequence< rendering::ARGBColor >& rgbColor ) throw (lang::IllegalArgumentException, uno::RuntimeException, std::exception) override
                 {
                     const rendering::ARGBColor* pIn( rgbColor.getConstArray() );
                     const sal_Size              nLen( rgbColor.getLength() );
@@ -533,7 +533,7 @@ namespace vcl
                     }
                     return aRes;
                 }
-                virtual uno::Sequence< double > SAL_CALL convertFromPARGB( const uno::Sequence< rendering::ARGBColor >& rgbColor ) throw (lang::IllegalArgumentException, uno::RuntimeException, std::exception) SAL_OVERRIDE
+                virtual uno::Sequence< double > SAL_CALL convertFromPARGB( const uno::Sequence< rendering::ARGBColor >& rgbColor ) throw (lang::IllegalArgumentException, uno::RuntimeException, std::exception) override
                 {
                     const rendering::ARGBColor* pIn( rgbColor.getConstArray() );
                     const sal_Size              nLen( rgbColor.getLength() );
