@@ -24,10 +24,13 @@
 #include "unx/i18n_xkb.hxx"
 
 SalI18N_KeyboardExtension::SalI18N_KeyboardExtension( Display* pDisplay )
-    : mbUseExtension( sal_True ),
-      mnDefaultGroup( 0 )
+    : mbUseExtension(true)
+    , mnDefaultGroup(0)
+    , mnGroup(0)
+    , mnEventBase(0)
+    , mnErrorBase(0)
+    , mpDisplay(pDisplay)
 {
-    mpDisplay = pDisplay;
 
     // allow user to set the default keyboard group idx or to disable the usage
     // of x keyboard extension at all:
@@ -35,11 +38,11 @@ SalI18N_KeyboardExtension::SalI18N_KeyboardExtension( Display* pDisplay )
     //      setenv SAL_XKEYBOARDGROUP 2     sets the keyboard group index to 2
     // keyboard group index must be in [1,4], may be specified in hex or decimal
     static char *pUseKeyboardExtension = getenv( "SAL_XKEYBOARDGROUP" );
-    if ( pUseKeyboardExtension != NULL )
+    if ( pUseKeyboardExtension != nullptr )
     {
         mbUseExtension = pUseKeyboardExtension[0] != '\0' ;
         if ( mbUseExtension )
-            mnDefaultGroup = strtol( pUseKeyboardExtension, NULL, 0 );
+            mnDefaultGroup = strtol( pUseKeyboardExtension, nullptr, 0 );
         if ( mnDefaultGroup > XkbMaxKbdGroup )
             mnDefaultGroup = 0;
     }
@@ -53,9 +56,9 @@ SalI18N_KeyboardExtension::SalI18N_KeyboardExtension( Display* pDisplay )
         int nExtMajorVersion = XkbMajorVersion;
         int nExtMinorVersion = XkbMinorVersion;
 
-        mbUseExtension = (sal_Bool)XkbQueryExtension( mpDisplay,
-            &nMajorExtOpcode, (int*)&mnEventBase, (int*)&mnErrorBase,
-            &nExtMajorVersion, &nExtMinorVersion );
+        mbUseExtension = XkbQueryExtension( mpDisplay,
+            &nMajorExtOpcode, &mnEventBase, &mnErrorBase,
+            &nExtMajorVersion, &nExtMinorVersion ) != 0;
     }
 
     // query notification for changes of the keyboard group
@@ -87,12 +90,12 @@ SalI18N_KeyboardExtension::Dispatch( XEvent* pEvent )
 
     // only handle state notify events for now, and only interested
     // in group details
-    sal_uInt32 nXKBType = ((XkbAnyEvent*)pEvent)->xkb_type;
+    sal_uInt32 nXKBType = reinterpret_cast<XkbAnyEvent*>(pEvent)->xkb_type;
     switch ( nXKBType )
     {
         case XkbStateNotify:
 
-            mnGroup = ((XkbStateNotifyEvent*)pEvent)->group;
+            mnGroup = reinterpret_cast<XkbStateNotifyEvent*>(pEvent)->group;
             break;
 
         default:
