@@ -17,7 +17,6 @@
  *   the License at http://www.apache.org/licenses/LICENSE-2.0 .
  */
 
-
 #include <cups/cups.h>
 #include <cups/http.h>
 #include <cups/ipp.h>
@@ -35,12 +34,15 @@
 
 #include <officecfg/Office/Common.hxx>
 
+#include <vcl/button.hxx>
+#include <vcl/dialog.hxx>
+#include <vcl/fixed.hxx>
+
 #include <algorithm>
 
 using namespace psp;
 using namespace osl;
 
-
 struct GetPPDAttribs
 {
     osl::Condition      m_aCondition;
@@ -93,14 +95,13 @@ struct GetPPDAttribs
         if (m_aCondition.wait( pDelay ) != Condition::result_ok
             )
         {
-            #if OSL_DEBUG_LEVEL > 1
-            fprintf( stderr, "cupsGetPPD %s timed out\n", m_aParameter.getStr() );
-            #endif
+            SAL_WARN("vcl.unx.print",
+                    "cupsGetPPD " << m_aParameter << " timed out");
         }
         m_pSyncMutex->acquire();
 
         OString aRetval = m_aResult;
-        m_aResult = OString();
+        m_aResult.clear();
         unref();
 
         return aRetval;
@@ -110,7 +111,8 @@ struct GetPPDAttribs
 extern "C" {
     static void getPPDWorker(void* pData)
     {
-        GetPPDAttribs* pAttribs = (GetPPDAttribs*)pData;
+        osl_setThreadName("CUPSManager getPPDWorker");
+        GetPPDAttribs* pAttribs = static_cast<GetPPDAttribs*>(pData);
         pAttribs->executeCall();
     }
 }
@@ -145,7 +147,7 @@ OString CUPSManager::threadedCupsGetPPD( const char* pPrinter )
 
 static const char* setPasswordCallback( const char* pIn )
 {
-    const char* pRet = NULL;
+    const char* pRet = nullptr;
 
     PrinterInfoManager& rMgr = PrinterInfoManager::get();
     if( rMgr.getType() == PrinterInfoManager::CUPS ) // sanity check
@@ -159,7 +161,7 @@ static const char* setPasswordCallback( const char* pIn )
 
 CUPSManager* CUPSManager::tryLoadCUPS()
 {
-    CUPSManager* pManager = NULL;
+    CUPSManager* pManager = nullptr;
     static const char* pEnv = getenv("SAL_DISABLE_CUPS");
 
     if (!pEnv || !*pEnv)
@@ -171,6 +173,7 @@ extern "C"
 {
 static void run_dest_thread_stub( void* pThis )
 {
+    osl_setThreadName("CUPSManager cupsGetDests");
     CUPSManager::runDestThread( pThis );
 }
 }
@@ -178,9 +181,10 @@ static void run_dest_thread_stub( void* pThis )
 CUPSManager::CUPSManager() :
         PrinterInfoManager( CUPS ),
         m_nDests( 0 ),
-        m_pDests( NULL ),
+        m_pDests( nullptr ),
         m_bNewDests( false ),
-        m_bPPDThreadRunning( false )
+        m_bPPDThreadRunning( false ),
+        batchMode( false )
 {
     m_aDestThread = osl_createThread( run_dest_thread_stub, this );
 }
@@ -196,43 +200,36 @@ CUPSManager::~CUPSManager()
     }
 
     if (m_nDests && m_pDests)
-        cupsFreeDests( m_nDests, (cups_dest_t*)m_pDests );
+        cupsFreeDests( m_nDests, static_cast<cups_dest_t*>(m_pDests) );
 }
 
 void CUPSManager::runDestThread( void* pThis )
 {
-    ((CUPSManager*)pThis)->runDests();
+    static_cast<CUPSManager*>(pThis)->runDests();
 }
 
 void CUPSManager::runDests()
 {
-#if OSL_DEBUG_LEVEL > 1
-    fprintf( stderr, "starting cupsGetDests\n" );
-#endif
-    cups_dest_t* pDests = NULL;
+    SAL_INFO("vcl.unx.print", "starting cupsGetDests");
+    cups_dest_t* pDests = nullptr;
 
     // n#722902 - do a fast-failing check for cups working *at all* first
     http_t* p_http;
     if( (p_http=httpConnectEncrypt(
              cupsServer(),
              ippPort(),
-             cupsEncryption())) != NULL )
+             cupsEncryption())) != nullptr )
     {
-        // neat, cups is up, clean up the canary
-        httpClose(p_http);
-
-        int nDests = cupsGetDests( &pDests );
-#if OSL_DEBUG_LEVEL > 1
-        fprintf( stderr, "came out of cupsGetDests\n" );
-#endif
+        int nDests = cupsGetDests2(p_http,  &pDests);
+        SAL_INFO("vcl.unx.print", "came out of cupsGetDests");
 
         osl::MutexGuard aGuard( m_aCUPSMutex );
         m_nDests = nDests;
         m_pDests = pDests;
         m_bNewDests = true;
-#if OSL_DEBUG_LEVEL > 1
-        fprintf( stderr, "finished cupsGetDests\n" );
-#endif
+        SAL_INFO("vcl.unx.print", "finished cupsGetDests");
+
+        httpClose(p_http);
     }
 }
 
@@ -253,7 +250,7 @@ void CUPSManager::initialize()
     {
         osl_joinWithThread( m_aDestThread );
         osl_destroyThread( m_aDestThread );
-        m_aDestThread = NULL;
+        m_aDestThread = nullptr;
     }
     m_bNewDests = false;
 
@@ -263,16 +260,13 @@ void CUPSManager::initialize()
     if( ! (m_nDests && m_pDests ) )
         return;
 
-    if( isCUPSDisabled() )
-        return;
-
     // check for CUPS server(?) > 1.2
     // since there is no API to query, check for options that were
     // introduced in dests with 1.2
     // this is needed to check for %%IncludeFeature support
     // (#i65684#, #i65491#)
     bool bUsePDF = false;
-    cups_dest_t* pDest = ((cups_dest_t*)m_pDests);
+    cups_dest_t* pDest = static_cast<cups_dest_t*>(m_pDests);
     const char* pOpt = cupsGetOption( "printer-info",
                                                       pDest->num_options,
                                                       pDest->options );
@@ -293,14 +287,14 @@ void CUPSManager::initialize()
     int nPrinter = m_nDests;
 
     // reset global default PPD options; these are queried on demand from CUPS
-    m_aGlobalDefaults.m_pParser = NULL;
+    m_aGlobalDefaults.m_pParser = nullptr;
     m_aGlobalDefaults.m_aContext = PPDContext();
 
     // add CUPS printers, should there be a printer
     // with the same name as a CUPS printer, overwrite it
     while( nPrinter-- )
     {
-        pDest = ((cups_dest_t*)m_pDests)+nPrinter;
+        pDest = static_cast<cups_dest_t*>(m_pDests)+nPrinter;
         OUString aPrinterName = OStringToOUString( pDest->name, aEncoding );
         if( pDest->instance && *pDest->instance )
         {
@@ -328,9 +322,8 @@ void CUPSManager::initialize()
                 aPrinter.m_aInfo.m_aLocation=OStringToOUString(pDest->options[k].value, aEncoding);
         }
 
-
         OUStringBuffer aBuf( 256 );
-        aBuf.appendAscii( "CUPS:" );
+        aBuf.append( "CUPS:" );
         aBuf.append( aPrinterName );
         // note: the parser that goes with the PrinterInfo
         // is created implicitly by the JobData::operator=()
@@ -339,9 +332,9 @@ void CUPSManager::initialize()
         // would mean we'd have to download PPDs for each and
         // every printer - which would be really bad runtime
         // behaviour
-        aPrinter.m_aInfo.m_pParser = NULL;
-        aPrinter.m_aInfo.m_aContext.setParser( NULL );
-        boost::unordered_map< OUString, PPDContext, OUStringHash >::const_iterator c_it = m_aDefaultContexts.find( aPrinterName );
+        aPrinter.m_aInfo.m_pParser = nullptr;
+        aPrinter.m_aInfo.m_aContext.setParser( nullptr );
+        std::unordered_map< OUString, PPDContext, OUStringHash >::const_iterator c_it = m_aDefaultContexts.find( aPrinterName );
         if( c_it != m_aDefaultContexts.end() )
         {
             aPrinter.m_aInfo.m_pParser = c_it->second.getParser();
@@ -358,7 +351,7 @@ void CUPSManager::initialize()
     // remove everything that is not a CUPS printer and not
     // a special purpose printer (PDF, Fax)
     std::list< OUString > aRemovePrinters;
-    for( boost::unordered_map< OUString, Printer, OUStringHash >::iterator it = m_aPrinters.begin();
+    for( std::unordered_map< OUString, Printer, OUStringHash >::iterator it = m_aPrinters.begin();
          it != m_aPrinters.end(); ++it )
     {
         if( m_aCUPSDestMap.find( it->first ) != m_aCUPSDestMap.end() )
@@ -397,25 +390,17 @@ static void updatePrinterContextInfo( ppd_group_t* pPPDGroup, PPDContext& rConte
                         if( pValue != pKey->getDefaultValue() )
                         {
                             rContext.setValue( pKey, pValue, true );
-#if OSL_DEBUG_LEVEL > 1
-                            fprintf( stderr, "key %s is set to %s\n", pOption->keyword, pChoice->choice );
-#endif
+                            SAL_INFO("vcl.unx.print", "key " << pOption->keyword << " is set to " << pChoice->choice);
 
                         }
-#if OSL_DEBUG_LEVEL > 1
                         else
-                            fprintf( stderr, "key %s is defaulted to %s\n", pOption->keyword, pChoice->choice );
-#endif
+                            SAL_INFO("vcl.unx.print", "key " << pOption->keyword << " is defaulted to " << pChoice->choice);
                     }
-#if OSL_DEBUG_LEVEL > 1
                     else
-                        fprintf( stderr, "caution: value %s not found in key %s\n", pChoice->choice, pOption->keyword );
-#endif
+                        SAL_INFO("vcl.unx.print", "caution: value " << pChoice->choice << " not found in key " << pOption->keyword);
                 }
-#if OSL_DEBUG_LEVEL > 1
                 else
-                    fprintf( stderr, "caution: key %s not found in parser\n", pOption->keyword );
-#endif
+                    SAL_INFO("vcl.unx.print", "caution: key " << pOption->keyword << " not found in parser");
             }
         }
     }
@@ -429,7 +414,7 @@ static void updatePrinterContextInfo( ppd_group_t* pPPDGroup, PPDContext& rConte
 
 const PPDParser* CUPSManager::createCUPSParser( const OUString& rPrinter )
 {
-    const PPDParser* pNewParser = NULL;
+    const PPDParser* pNewParser = nullptr;
     OUString aPrinter;
 
     if( rPrinter.startsWith("CUPS:") )
@@ -439,17 +424,16 @@ const PPDParser* CUPSManager::createCUPSParser( const OUString& rPrinter )
 
     if( m_aCUPSMutex.tryToAcquire() )
     {
-        if( m_nDests && m_pDests && ! isCUPSDisabled() )
+        if (m_nDests && m_pDests)
         {
-            boost::unordered_map< OUString, int, OUStringHash >::iterator dest_it =
+            std::unordered_map< OUString, int, OUStringHash >::iterator dest_it =
             m_aCUPSDestMap.find( aPrinter );
             if( dest_it != m_aCUPSDestMap.end() )
             {
-                cups_dest_t* pDest = ((cups_dest_t*)m_pDests) + dest_it->second;
+                cups_dest_t* pDest = static_cast<cups_dest_t*>(m_pDests) + dest_it->second;
                 OString aPPDFile = threadedCupsGetPPD( pDest->name );
-                #if OSL_DEBUG_LEVEL > 1
-                fprintf( stderr, "PPD for %s is %s\n", OUStringToOString( aPrinter, osl_getThreadTextEncoding() ).getStr(), aPPDFile.getStr() );
-                #endif
+                SAL_INFO("vcl.unx.print",
+                        "PPD for " << aPrinter << " is " << aPPDFile);
                 if( !aPPDFile.isEmpty() )
                 {
                     rtl_TextEncoding aEncoding = osl_getThreadTextEncoding();
@@ -464,14 +448,11 @@ const PPDParser* CUPSManager::createCUPSParser( const OUString& rPrinter )
                         pNewParser = pCUPSParser;
 
                         /*int nConflicts =*/ cupsMarkOptions( pPPD, pDest->num_options, pDest->options );
-                        #if OSL_DEBUG_LEVEL > 1
-                        fprintf( stderr, "processing the following options for printer %s (instance %s):\n",
-                        pDest->name, pDest->instance );
+                        SAL_INFO("vcl.unx.print", "processing the following options for printer " << pDest->name << " (instance " << pDest->instance << "):");
                         for( int k = 0; k < pDest->num_options; k++ )
-                            fprintf( stderr, "   \"%s\" = \"%s\"\n",
-                        pDest->options[k].name,
-                        pDest->options[k].value );
-                        #endif
+                            SAL_INFO("vcl.unx.print",
+                                "   \"" << pDest->options[k].name <<
+                                "\" = \"" << pDest->options[k].value << "\"");
                         PrinterInfo& rInfo = m_aPrinters[ aPrinter ].m_aInfo;
 
                         // remember the default context for later use
@@ -489,35 +470,27 @@ const PPDParser* CUPSManager::createCUPSParser( const OUString& rPrinter )
                         // clean up the mess
                         ppdClose( pPPD );
                     }
-                    #if OSL_DEBUG_LEVEL > 1
                     else
-                        fprintf( stderr, "ppdOpenFile failed, falling back to generic driver\n" );
-                    #endif
+                        SAL_INFO("vcl.unx.print", "ppdOpenFile failed, falling back to generic driver");
 
                     // remove temporary PPD file
                     unlink( aPPDFile.getStr() );
                 }
-                #if OSL_DEBUG_LEVEL > 1
                 else
-                    fprintf( stderr, "cupsGetPPD failed, falling back to generic driver\n" );
-                #endif
+                    SAL_INFO("vcl.unx.print", "cupsGetPPD failed, falling back to generic driver");
             }
-            #if OSL_DEBUG_LEVEL > 1
             else
-                fprintf( stderr, "no dest found for printer %s\n", OUStringToOString( aPrinter, osl_getThreadTextEncoding() ).getStr() );
-            #endif
+                SAL_INFO("vcl.unx.print", "no dest found for printer " << aPrinter);
         }
         m_aCUPSMutex.release();
     }
-    #if OSL_DEBUG_LEVEL >1
     else
-        fprintf( stderr, "could not acquire CUPS mutex !!!\n" );
-    #endif
+        SAL_WARN("vcl.unx.print", "could not acquire CUPS mutex !!!" );
 
     if( ! pNewParser )
     {
         // get the default PPD
-        pNewParser = PPDParser::getParser( OUString( "SGENPRT" ) );
+        pNewParser = PPDParser::getParser( "SGENPRT" );
 
         PrinterInfo& rInfo = m_aPrinters[ aPrinter ].m_aInfo;
 
@@ -530,29 +503,28 @@ const PPDParser* CUPSManager::createCUPSParser( const OUString& rPrinter )
 
 void CUPSManager::setupJobContextData( JobData& rData )
 {
-    boost::unordered_map< OUString, int, OUStringHash >::iterator dest_it =
+    std::unordered_map< OUString, int, OUStringHash >::iterator dest_it =
         m_aCUPSDestMap.find( rData.m_aPrinterName );
 
     if( dest_it == m_aCUPSDestMap.end() )
         return PrinterInfoManager::setupJobContextData( rData );
 
-    boost::unordered_map< OUString, Printer, OUStringHash >::iterator p_it =
+    std::unordered_map< OUString, Printer, OUStringHash >::iterator p_it =
         m_aPrinters.find( rData.m_aPrinterName );
     if( p_it == m_aPrinters.end() ) // huh ?
     {
-#if OSL_DEBUG_LEVEL > 1
-        fprintf( stderr, "CUPS printer list in disorder, no dest for printer %s !\n", OUStringToOString( rData.m_aPrinterName, osl_getThreadTextEncoding() ).getStr() );
-#endif
+        SAL_WARN("vcl.unx.print", "CUPS printer list in disorder, "
+                "no dest for printer " << rData.m_aPrinterName);
         return;
     }
 
-    if( p_it->second.m_aInfo.m_pParser == NULL )
+    if( p_it->second.m_aInfo.m_pParser == nullptr )
     {
         // in turn calls createCUPSParser
         // which updates the printer info
         p_it->second.m_aInfo.m_pParser = PPDParser::getParser( p_it->second.m_aInfo.m_aDriverName );
     }
-    if( p_it->second.m_aInfo.m_aContext.getParser() == NULL )
+    if( p_it->second.m_aInfo.m_aContext.getParser() == nullptr )
     {
         OUString aPrinter;
         if( p_it->second.m_aInfo.m_aDriverName.startsWith("CUPS:") )
@@ -569,7 +541,7 @@ void CUPSManager::setupJobContextData( JobData& rData )
 
 FILE* CUPSManager::startSpool( const OUString& rPrintername, bool bQuickCommand )
 {
-    OSL_TRACE( "endSpool: %s, %s",
+    OSL_TRACE( "startSpool: %s, %s",
                OUStringToOString( rPrintername, RTL_TEXTENCODING_UTF8 ).getStr(),
               bQuickCommand ? "true" : "false" );
 
@@ -580,7 +552,7 @@ FILE* CUPSManager::startSpool( const OUString& rPrintername, bool bQuickCommand
     }
 
     OUString aTmpURL, aTmpFile;
-    osl_createTempFile( NULL, NULL, &aTmpURL.pData );
+    osl_createTempFile( nullptr, nullptr, &aTmpURL.pData );
     osl_getSystemPathFromFileURL( aTmpURL.pData, &aTmpFile.pData );
     OString aSysFile = OUStringToOString( aTmpFile, osl_getThreadTextEncoding() );
     FILE* fp = fopen( aSysFile.getStr(), "w" );
@@ -596,10 +568,10 @@ struct less_ppd_key : public ::std::binary_function<double, double, bool>
     { return left->getOrderDependency() < right->getOrderDependency(); }
 };
 
-void CUPSManager::getOptionsFromDocumentSetup( const JobData& rJob, bool bBanner, int& rNumOptions, void** rOptions ) const
+void CUPSManager::getOptionsFromDocumentSetup( const JobData& rJob, bool bBanner, int& rNumOptions, void** rOptions )
 {
     rNumOptions = 0;
-    *rOptions = NULL;
+    *rOptions = nullptr;
 
     // emit features ordered to OrderDependency
     // ignore features that are set to default
@@ -618,11 +590,17 @@ void CUPSManager::getOptionsFromDocumentSetup( const JobData& rJob, bool bBanner
         {
             const PPDKey* pKey = aKeys[i];
             const PPDValue* pValue = rJob.m_aContext.getValue( pKey );
-            if(pValue && pValue->m_eType == eInvocation && !pValue->m_aOption.isEmpty() )
+            OUString sPayLoad;
+            if (pValue && pValue->m_eType == eInvocation)
+            {
+                sPayLoad = pValue->m_bCustomOption ? pValue->m_aCustomOption : pValue->m_aOption;
+            }
+
+            if (!sPayLoad.isEmpty())
             {
                 OString aKey = OUStringToOString( pKey->getKey(), RTL_TEXTENCODING_ASCII_US );
-                OString aValue = OUStringToOString( pValue->m_aOption, RTL_TEXTENCODING_ASCII_US );
-                rNumOptions = cupsAddOption( aKey.getStr(), aValue.getStr(), rNumOptions, (cups_option_t**)rOptions );
+                OString aValue = OUStringToOString( sPayLoad, RTL_TEXTENCODING_ASCII_US );
+                rNumOptions = cupsAddOption( aKey.getStr(), aValue.getStr(), rNumOptions, reinterpret_cast<cups_option_t**>(rOptions) );
             }
         }
     }
@@ -630,17 +608,17 @@ void CUPSManager::getOptionsFromDocumentSetup( const JobData& rJob, bool bBanner
     if( rJob.m_nPDFDevice > 0 && rJob.m_nCopies > 1 )
     {
         OString aVal( OString::number( rJob.m_nCopies ) );
-        rNumOptions = cupsAddOption( "copies", aVal.getStr(), rNumOptions, (cups_option_t**)rOptions );
+        rNumOptions = cupsAddOption( "copies", aVal.getStr(), rNumOptions, reinterpret_cast<cups_option_t**>(rOptions) );
         aVal = OString::boolean(rJob.m_bCollate);
-        rNumOptions = cupsAddOption( "collate", aVal.getStr(), rNumOptions, (cups_option_t**)rOptions );
+        rNumOptions = cupsAddOption( "collate", aVal.getStr(), rNumOptions, reinterpret_cast<cups_option_t**>(rOptions) );
     }
     if( ! bBanner )
     {
-        rNumOptions = cupsAddOption( "job-sheets", "none", rNumOptions, (cups_option_t**)rOptions );
+        rNumOptions = cupsAddOption( "job-sheets", "none", rNumOptions, reinterpret_cast<cups_option_t**>(rOptions) );
     }
 }
 
-bool CUPSManager::endSpool( const OUString& rPrintername, const OUString& rJobTitle, FILE* pFile, const JobData& rDocumentJobData, bool bBanner )
+bool CUPSManager::endSpool( const OUString& rPrintername, const OUString& rJobTitle, FILE* pFile, const JobData& rDocumentJobData, bool bBanner, const OUString& rFaxNumber )
 {
     OSL_TRACE( "endSpool: %s, %s, copy count = %d",
                OUStringToOString( rPrintername, RTL_TEXTENCODING_UTF8 ).getStr(),
@@ -648,61 +626,139 @@ bool CUPSManager::endSpool( const OUString& rPrintername, const OUString& rJobTi
                rDocumentJobData.m_nCopies
                );
 
-    int nJobID = 0;
-
     osl::MutexGuard aGuard( m_aCUPSMutex );
 
-    boost::unordered_map< OUString, int, OUStringHash >::iterator dest_it =
+    std::unordered_map< OUString, int, OUStringHash >::iterator dest_it =
         m_aCUPSDestMap.find( rPrintername );
     if( dest_it == m_aCUPSDestMap.end() )
     {
         OSL_TRACE( "defer to PrinterInfoManager::endSpool" );
-        return PrinterInfoManager::endSpool( rPrintername, rJobTitle, pFile, rDocumentJobData, bBanner );
+        return PrinterInfoManager::endSpool( rPrintername, rJobTitle, pFile, rDocumentJobData, bBanner, rFaxNumber );
     }
 
-    boost::unordered_map< FILE*, OString, FPtrHash >::const_iterator it = m_aSpoolFiles.find( pFile );
-    if( it != m_aSpoolFiles.end() )
+    std::unordered_map< FILE*, OString, FPtrHash >::const_iterator it = m_aSpoolFiles.find( pFile );
+    if( it == m_aSpoolFiles.end() )
+        return false;
+    fclose( pFile );
+    PendingJob job( rPrintername, rJobTitle, rDocumentJobData, bBanner, rFaxNumber, it->second );
+    m_aSpoolFiles.erase( pFile );
+    pendingJobs.push_back( job );
+    if( !batchMode ) // process immediately, otherwise will be handled by flushBatchPrint()
+        return processPendingJobs();
+    return true;
+}
+
+bool CUPSManager::startBatchPrint()
+{
+    batchMode = true;
+    return true;
+}
+
+bool CUPSManager::supportsBatchPrint() const
+{
+    return true;
+}
+
+bool CUPSManager::flushBatchPrint()
+{
+    osl::MutexGuard aGuard( m_aCUPSMutex );
+    batchMode = false;                 // reset the batch print mode
+    return processPendingJobs();
+}
+
+bool CUPSManager::processPendingJobs()
+{
+    // Print all jobs that have the same data using one CUPS call (i.e. merge all jobs that differ only in files to print).
+    PendingJob currentJobData;
+    bool first = true;
+    std::vector< OString > files;
+    bool ok = true;
+    while( !pendingJobs.empty())
     {
-        fclose( pFile );
+        if( first )
+        {
+            currentJobData = pendingJobs.front();
+            first = false;
+        }
+        else if( currentJobData.printerName != pendingJobs.front().printerName
+                || currentJobData.jobTitle != pendingJobs.front().jobTitle
+                || currentJobData.jobData != pendingJobs.front().jobData
+                || currentJobData.banner != pendingJobs.front().banner )
+        {
+            if( !printJobs( currentJobData, files ))
+                ok = false;
+            files.clear();
+            currentJobData = pendingJobs.front();
+        }
+        files.push_back( pendingJobs.front().file );
+        pendingJobs.pop_front();
+    }
+    if( !first )
+    {
+        if( !printJobs( currentJobData, files )) // print the last batch
+            ok = false;
+    }
+    return ok;
+}
+
+bool CUPSManager::printJobs( const PendingJob& job, const std::vector< OString >& files )
+{
+    std::unordered_map< OUString, int, OUStringHash >::iterator dest_it =
+        m_aCUPSDestMap.find( job.printerName );
+
         rtl_TextEncoding aEnc = osl_getThreadTextEncoding();
 
         // setup cups options
         int nNumOptions = 0;
-        cups_option_t* pOptions = NULL;
-        getOptionsFromDocumentSetup( rDocumentJobData, bBanner, nNumOptions, (void**)&pOptions );
+        cups_option_t* pOptions = nullptr;
+        getOptionsFromDocumentSetup( job.jobData, job.banner, nNumOptions, reinterpret_cast<void**>(&pOptions) );
 
-        cups_dest_t* pDest = ((cups_dest_t*)m_pDests) + dest_it->second;
-        nJobID = cupsPrintFile( pDest->name,
-        it->second.getStr(),
-        OUStringToOString( rJobTitle, aEnc ).getStr(),
-        nNumOptions, pOptions );
-#if OSL_DEBUG_LEVEL > 1
-        fprintf( stderr, "cupsPrintFile( %s, %s, %s, %d, %p ) returns %d\n",
-                    pDest->name,
-                    it->second.getStr(),
-                    OUStringToOString( rJobTitle, aEnc ).getStr(),
-                    nNumOptions,
-                    pOptions,
-                    nJobID
-                    );
+        OString sJobName(OUStringToOString(job.jobTitle, aEnc));
+
+        //fax4CUPS, "the job name will be dialled for you"
+        //so override the jobname with the desired number
+        if (!job.faxNumber.isEmpty())
+        {
+            sJobName = OUStringToOString(job.faxNumber, aEnc);
+        }
+
+        cups_dest_t* pDest = static_cast<cups_dest_t*>(m_pDests) + dest_it->second;
+
+        std::vector< const char* > fnames;
+        for( std::vector< OString >::const_iterator it = files.begin();
+             it != files.end();
+             ++it )
+            fnames.push_back( it->getStr());
+
+        int nJobID = cupsPrintFiles(pDest->name,
+            fnames.size(),
+            fnames.data(),
+            sJobName.getStr(),
+            nNumOptions, pOptions);
+        SAL_INFO("vcl.unx.print", "cupsPrintFile( " << pDest->name << ", "
+                << ( fnames.size() == 1 ? files.front() : OString::number( fnames.size()) ).getStr() << ", " << sJobName << ", " << nNumOptions
+                << ", " << pOptions << " ) returns " << nJobID);
         for( int n = 0; n < nNumOptions; n++ )
-            fprintf( stderr, "    option %s=%s\n", pOptions[n].name, pOptions[n].value );
+            SAL_INFO("vcl.unx.print",
+                "    option " << pOptions[n].name << "=" << pOptions[n].value);
+#if OSL_DEBUG_LEVEL > 1
         OString aCmd( "cp " );
-        aCmd = aCmd + it->second;
+        aCmd = aCmd + files.front();
         aCmd = aCmd + OString( " $HOME/cupsprint.ps" );
         system( aCmd.getStr() );
 #endif
 
-        unlink( it->second.getStr() );
-        m_aSpoolFiles.erase( pFile );
+        for( std::vector< OString >::const_iterator it = files.begin();
+             it != files.end();
+             ++it )
+            unlink( it->getStr());
+
         if( pOptions )
             cupsFreeOptions( nNumOptions, pOptions );
-    }
 
     return nJobID != 0;
 }
 
-
 void CUPSManager::changePrinterInfo( const OUString& rPrinter, const PrinterInfo& rNewInfo )
 {
     PrinterInfoManager::changePrinterInfo( rPrinter, rNewInfo );
@@ -716,15 +772,11 @@ bool CUPSManager::checkPrintersChanged( bool bWait )
         if(  m_aDestThread )
         {
             // initial asynchronous detection still running
-            #if OSL_DEBUG_LEVEL > 1
-            fprintf( stderr, "syncing cups discovery thread\n" );
-            #endif
+            SAL_INFO("vcl.unx.print", "syncing cups discovery thread");
             osl_joinWithThread( m_aDestThread );
             osl_destroyThread( m_aDestThread );
-            m_aDestThread = NULL;
-            #if OSL_DEBUG_LEVEL > 1
-            fprintf( stderr, "done: syncing cups discovery thread\n" );
-            #endif
+            m_aDestThread = nullptr;
+            SAL_INFO("vcl.unx.print", "done: syncing cups discovery thread");
         }
         else
         {
@@ -738,9 +790,9 @@ bool CUPSManager::checkPrintersChanged( bool bWait )
             // there is no way to query CUPS whether the printer list has changed
             // so get the dest list anew
             if( m_nDests && m_pDests )
-                cupsFreeDests( m_nDests, (cups_dest_t*)m_pDests );
+                cupsFreeDests( m_nDests, static_cast<cups_dest_t*>(m_pDests) );
             m_nDests = 0;
-            m_pDests = NULL;
+            m_pDests = nullptr;
             runDests();
         }
     }
@@ -785,15 +837,15 @@ bool CUPSManager::removePrinter( const OUString& rName, bool bCheck )
 bool CUPSManager::setDefaultPrinter( const OUString& rName )
 {
     bool bSuccess = false;
-    boost::unordered_map< OUString, int, OUStringHash >::iterator nit =
+    std::unordered_map< OUString, int, OUStringHash >::iterator nit =
         m_aCUPSDestMap.find( rName );
     if( nit != m_aCUPSDestMap.end() && m_aCUPSMutex.tryToAcquire() )
     {
-        cups_dest_t* pDests = (cups_dest_t*)m_pDests;
+        cups_dest_t* pDests = static_cast<cups_dest_t*>(m_pDests);
         for( int i = 0; i < m_nDests; i++ )
             pDests[i].is_default = 0;
         pDests[ nit->second ].is_default = 1;
-        cupsSetDests( m_nDests, (cups_dest_t*)m_pDests );
+        cupsSetDests( m_nDests, static_cast<cups_dest_t*>(m_pDests) );
         m_aDefaultPrinter = rName;
         m_aCUPSMutex.release();
         bSuccess = true;
@@ -809,10 +861,10 @@ bool CUPSManager::writePrinterConfig()
     bool bDestModified = false;
     rtl_TextEncoding aEncoding = osl_getThreadTextEncoding();
 
-    for( boost::unordered_map< OUString, Printer, OUStringHash >::iterator prt =
+    for( std::unordered_map< OUString, Printer, OUStringHash >::iterator prt =
              m_aPrinters.begin(); prt != m_aPrinters.end(); ++prt )
     {
-        boost::unordered_map< OUString, int, OUStringHash >::iterator nit =
+        std::unordered_map< OUString, int, OUStringHash >::iterator nit =
             m_aCUPSDestMap.find( prt->first );
         if( nit == m_aCUPSDestMap.end() )
             continue;
@@ -823,12 +875,12 @@ bool CUPSManager::writePrinterConfig()
         if( m_aCUPSMutex.tryToAcquire() )
         {
             bDestModified = true;
-            cups_dest_t* pDest = ((cups_dest_t*)m_pDests) + nit->second;
+            cups_dest_t* pDest = static_cast<cups_dest_t*>(m_pDests) + nit->second;
             PrinterInfo& rInfo = prt->second.m_aInfo;
 
             // create new option list
             int nNewOptions = 0;
-            cups_option_t* pNewOptions = NULL;
+            cups_option_t* pNewOptions = nullptr;
             int nValues = rInfo.m_aContext.countValuesModified();
             for( int i = 0; i < nValues; i++ )
             {
@@ -850,50 +902,98 @@ bool CUPSManager::writePrinterConfig()
     }
     if( bDestModified && m_aCUPSMutex.tryToAcquire() )
     {
-        cupsSetDests( m_nDests, (cups_dest_t*)m_pDests );
+        cupsSetDests( m_nDests, static_cast<cups_dest_t*>(m_pDests) );
         m_aCUPSMutex.release();
     }
 
     return PrinterInfoManager::writePrinterConfig();
 }
 
-bool CUPSManager::addOrRemovePossible() const
+namespace
 {
-    return (m_nDests && m_pDests && ! isCUPSDisabled())? false : PrinterInfoManager::addOrRemovePossible();
+    class RTSPWDialog : public ModalDialog
+    {
+        VclPtr<FixedText> m_pText;
+        VclPtr<Edit>      m_pUserEdit;
+        VclPtr<Edit>      m_pPassEdit;
+
+    public:
+        RTSPWDialog(const OString& rServer, const OString& rUserName, vcl::Window* pParent);
+        virtual ~RTSPWDialog();
+        virtual void dispose() override;
+        OString getUserName() const;
+        OString getPassword() const;
+    };
+
+    RTSPWDialog::RTSPWDialog( const OString& rServer, const OString& rUserName, vcl::Window* pParent )
+        : ModalDialog(pParent, "CUPSPasswordDialog",
+            "vcl/ui/cupspassworddialog.ui")
+    {
+        get(m_pText, "text");
+        get(m_pUserEdit, "user");
+        get(m_pPassEdit, "pass");
+
+        OUString aText(m_pText->GetText());
+        aText = aText.replaceFirst("%s", OStringToOUString(rServer, osl_getThreadTextEncoding()));
+        m_pText->SetText(aText);
+        m_pUserEdit->SetText( OStringToOUString(rUserName, osl_getThreadTextEncoding()));
+    }
+
+    RTSPWDialog::~RTSPWDialog()
+    {
+        disposeOnce();
+    }
+
+    void RTSPWDialog::dispose()
+    {
+        m_pText.clear();
+        m_pUserEdit.clear();
+        m_pPassEdit.clear();
+        ModalDialog::dispose();
+    }
+
+    OString RTSPWDialog::getUserName() const
+    {
+        return OUStringToOString( m_pUserEdit->GetText(), osl_getThreadTextEncoding() );
+    }
+
+    OString RTSPWDialog::getPassword() const
+    {
+        return OUStringToOString( m_pPassEdit->GetText(), osl_getThreadTextEncoding() );
+    }
+
+    bool AuthenticateQuery(const OString& rServer, OString& rUserName, OString& rPassword)
+    {
+        bool bRet = false;
+
+        ScopedVclPtrInstance<RTSPWDialog> aDialog(rServer, rUserName, nullptr);
+        if (aDialog->Execute())
+        {
+            rUserName = aDialog->getUserName();
+            rPassword = aDialog->getPassword();
+            bRet = true;
+        }
+
+        return bRet;
+    }
 }
 
 const char* CUPSManager::authenticateUser( const char* /*pIn*/ )
 {
-    const char* pRet = NULL;
-    oslModule pLib = osl_loadModuleAscii( _XSALSET_LIBNAME, SAL_LOADMODULE_LAZY );
-    if( pLib )
-    {
-        OUString aSym( "Sal_authenticateQuery"  );
-        bool (*getpw)( const OString& rServer, OString& rUser, OString& rPw) =
-            (bool(*)(const OString&,OString&,OString&))osl_getFunctionSymbol( pLib, aSym.pData );
-        if( getpw )
-        {
-            osl::MutexGuard aGuard( m_aCUPSMutex );
+    const char* pRet = nullptr;
 
-            OString aUser = cupsUser();
-            OString aServer = cupsServer();
-            OString aPassword;
-            if( getpw( aServer, aUser, aPassword ) )
-            {
-                m_aPassword = aPassword;
-                m_aUser = aUser;
-                cupsSetUser( m_aUser.getStr() );
-                pRet = m_aPassword.getStr();
-            }
-        }
-        osl_unloadModule( pLib );
-    }
-#if OSL_DEBUG_LEVEL > 1
-    else
+    osl::MutexGuard aGuard( m_aCUPSMutex );
+
+    OString aUser = cupsUser();
+    OString aServer = cupsServer();
+    OString aPassword;
+    if (AuthenticateQuery(aServer, aUser, aPassword))
     {
-        fprintf( stderr, "loading of module %s failed\n", _XSALSET_LIBNAME );
+        m_aPassword = aPassword;
+        m_aUser = aUser;
+        cupsSetUser( m_aUser.getStr() );
+        pRet = m_aPassword.getStr();
     }
-#endif
 
     return pRet;
 }
