@@ -17,7 +17,6 @@
  *   the License at http://www.apache.org/licenses/LICENSE-2.0 .
  */
 
-
 #include <com/sun/star/uno/Any.hxx>
 #include <com/sun/star/uno/Type.hxx>
 #include <com/sun/star/uno/Sequence.hxx>
@@ -39,6 +38,7 @@
 #include <com/sun/star/accessibility/XAccessibleRelationSet.hpp>
 #include <com/sun/star/accessibility/XAccessibleTable.hpp>
 #include <com/sun/star/accessibility/XAccessibleEditableText.hpp>
+#include <com/sun/star/accessibility/XAccessibleExtendedAttributes.hpp>
 #include <com/sun/star/accessibility/XAccessibleImage.hpp>
 #include <com/sun/star/accessibility/XAccessibleHyperlink.hpp>
 #include <com/sun/star/accessibility/XAccessibleHypertext.hpp>
@@ -55,22 +55,21 @@
 #include <com/sun/star/beans/Property.hpp>
 
 #include <rtl/ref.hxx>
+#include <osl/diagnose.h>
+#include <sal/alloca.h>
 #include <cppuhelper/factory.hxx>
 #include <cppuhelper/queryinterface.hxx>
 
 #include "atkwrapper.hxx"
 #include "atkregistry.hxx"
 #include "atklistener.hxx"
-
-#ifdef ENABLE_TRACING
-#include <stdio.h>
-#endif
+#include "atktextattributes.hxx"
 
 #include <string.h>
 
 using namespace ::com::sun::star;
 
-static GObjectClass *parent_class = NULL;
+static GObjectClass *parent_class = nullptr;
 
 static AtkRelationType mapRelationType( sal_Int16 nRelation )
 {
@@ -121,7 +120,6 @@ static AtkRelationType mapRelationType( sal_Int16 nRelation )
     return type;
 }
 
-
 AtkStateType mapAtkState( sal_Int16 nState )
 {
     AtkStateType type = ATK_STATE_INVALID;
@@ -162,12 +160,16 @@ AtkStateType mapAtkState( sal_Int16 nState )
         MAP_DIRECT( TRANSIENT );
         MAP_DIRECT( VERTICAL );
         MAP_DIRECT( VISIBLE );
+        MAP_DIRECT( DEFAULT );
         // a spelling error ...
         case accessibility::AccessibleStateType::DEFUNC:
             type = ATK_STATE_DEFUNCT; break;
         case accessibility::AccessibleStateType::MULTI_SELECTABLE:
             type = ATK_STATE_MULTISELECTABLE; break;
     default:
+        //Mis-use ATK_STATE_LAST_DEFINED to check if a state is unmapped
+        //NOTE! Do not report it
+        type = ATK_STATE_LAST_DEFINED;
         break;
     }
 
@@ -178,7 +180,11 @@ static inline AtkRole registerRole( const gchar * name )
 {
     AtkRole ret = atk_role_for_name( name );
     if( ATK_ROLE_INVALID == ret )
+    {
+        SAL_WNODEPRECATED_DECLARATIONS_PUSH
         ret = atk_role_register( name );
+        SAL_WNODEPRECATED_DECLARATIONS_POP
+    }
 
     return ret;
 }
@@ -208,13 +214,13 @@ static AtkRole mapToAtkRole( sal_Int16 nRole )
         ATK_ROLE_FILLER,
         ATK_ROLE_FONT_CHOOSER,
         ATK_ROLE_FOOTER,
-        ATK_ROLE_TEXT,            // FOOTNOTE - registered below
+        ATK_ROLE_UNKNOWN,         // FOOTNOTE - registered below
         ATK_ROLE_FRAME,
         ATK_ROLE_GLASS_PANE,
         ATK_ROLE_IMAGE,           // GRAPHIC
         ATK_ROLE_UNKNOWN,         // GROUP_BOX - registered below
         ATK_ROLE_HEADER,
-        ATK_ROLE_PARAGRAPH,       // HEADING - registered below
+        ATK_ROLE_HEADING,         // HEADING - registered below
         ATK_ROLE_TEXT,            // HYPER_LINK - registered below
         ATK_ROLE_ICON,
         ATK_ROLE_INTERNAL_FRAME,
@@ -240,16 +246,16 @@ static AtkRole mapToAtkRole( sal_Int16 nRole )
         ATK_ROLE_ROOT_PANE,
         ATK_ROLE_SCROLL_BAR,
         ATK_ROLE_SCROLL_PANE,
-        ATK_ROLE_UNKNOWN,        // SHAPE - registered below
+        ATK_ROLE_PANEL,         // SHAPE
         ATK_ROLE_SEPARATOR,
         ATK_ROLE_SLIDER,
-        ATK_ROLE_SPIN_BUTTON,    // SPIN_BOX ?
+        ATK_ROLE_SPIN_BUTTON,   // SPIN_BOX ?
         ATK_ROLE_SPLIT_PANE,
         ATK_ROLE_STATUSBAR,
         ATK_ROLE_TABLE,
         ATK_ROLE_TABLE_CELL,
         ATK_ROLE_TEXT,
-        ATK_ROLE_INTERNAL_FRAME, // TEXT_FRAME - registered below
+        ATK_ROLE_PANEL,         // TEXT_FRAME
         ATK_ROLE_TOGGLE_BUTTON,
         ATK_ROLE_TOOL_BAR,
         ATK_ROLE_TOOL_TIP,
@@ -271,6 +277,17 @@ static AtkRole mapToAtkRole( sal_Int16 nRole )
         ATK_ROLE_TREE_TABLE,
         ATK_ROLE_SCROLL_PANE,   // COMMENT - mapped to atk_role_scroll_pane
         ATK_ROLE_UNKNOWN        // COMMENT_END - mapped to atk_role_unknown
+#if defined(ATK_CHECK_VERSION)
+        //older ver that doesn't define ATK_CHECK_VERSION doesn't have the following
+        , ATK_ROLE_DOCUMENT_PRESENTATION
+        , ATK_ROLE_DOCUMENT_SPREADSHEET
+        , ATK_ROLE_DOCUMENT_TEXT
+#else
+        //older version should fallback to DOCUMENT_FRAME role
+        , ATK_ROLE_DOCUMENT_FRAME
+        , ATK_ROLE_DOCUMENT_FRAME
+        , ATK_ROLE_DOCUMENT_FRAME
+#endif
     };
 
     static bool initialized = false;
@@ -292,13 +309,9 @@ static AtkRole mapToAtkRole( sal_Int16 nRole )
         roleMap[accessibility::AccessibleRole::IMAGE_MAP] = registerRole("image map");
         roleMap[accessibility::AccessibleRole::TREE_ITEM] = registerRole("tree item");
         roleMap[accessibility::AccessibleRole::HYPER_LINK] = registerRole("link");
-
-        // these don't exist in ATK yet
-        roleMap[accessibility::AccessibleRole::END_NOTE] = registerRole("end note");
-        roleMap[accessibility::AccessibleRole::FOOTNOTE] = registerRole("foot note");
-        roleMap[accessibility::AccessibleRole::SHAPE] = registerRole("shape");
-        roleMap[accessibility::AccessibleRole::TEXT_FRAME] = registerRole("text frame");
-        roleMap[accessibility::AccessibleRole::NOTE] = registerRole("note");
+        roleMap[accessibility::AccessibleRole::END_NOTE] = registerRole("comment");
+        roleMap[accessibility::AccessibleRole::FOOTNOTE] = registerRole("comment");
+        roleMap[accessibility::AccessibleRole::NOTE] = registerRole("comment");
 
         initialized = true;
     }
@@ -310,7 +323,6 @@ static AtkRole mapToAtkRole( sal_Int16 nRole )
     return role;
 }
 
-
 /*****************************************************************************/
 
 extern "C" {
@@ -322,13 +334,12 @@ wrapper_get_name( AtkObject *atk_obj )
 {
     AtkObjectWrapper *obj = ATK_OBJECT_WRAPPER (atk_obj);
 
-    if( obj->mpContext )
+    if( obj->mpContext.is() )
     {
-        uno::Reference< accessibility::XAccessibleContext > xContext(obj->mpContext);
         try {
             OString aName =
                 OUStringToOString(
-                    xContext->getAccessibleName(),
+                    obj->mpContext->getAccessibleName(),
                     RTL_TEXTENCODING_UTF8);
 
             int nCmp = atk_obj->name ? rtl_str_compare( atk_obj->name, aName.getStr() ) : -1;
@@ -354,13 +365,12 @@ wrapper_get_description( AtkObject *atk_obj )
 {
     AtkObjectWrapper *obj = ATK_OBJECT_WRAPPER (atk_obj);
 
-    if( obj->mpContext )
+    if( obj->mpContext.is() )
     {
-        uno::Reference< accessibility::XAccessibleContext > xContext(obj->mpContext);
         try {
             OString aDescription =
                 OUStringToOString(
-                    xContext->getAccessibleDescription(),
+                    obj->mpContext->getAccessibleDescription(),
                     RTL_TEXTENCODING_UTF8);
 
             g_free(atk_obj->description);
@@ -377,17 +387,39 @@ wrapper_get_description( AtkObject *atk_obj )
 
 /*****************************************************************************/
 
+static AtkAttributeSet *
+wrapper_get_attributes( AtkObject *atk_obj )
+{
+    AtkObjectWrapper *obj = ATK_OBJECT_WRAPPER( atk_obj );
+    AtkAttributeSet *pSet = nullptr;
+
+    try
+    {
+        uno::Reference< accessibility::XAccessibleExtendedAttributes >
+            xExtendedAttrs( obj->mpContext, uno::UNO_QUERY );
+        if( xExtendedAttrs.is() )
+            pSet = attribute_set_new_from_extended_attributes( xExtendedAttrs );
+    }
+    catch(const uno::Exception&)
+    {
+        g_warning( "Exception in getAccessibleAttributes()" );
+    }
+
+    return pSet;
+}
+
+/*****************************************************************************/
+
 static gint
 wrapper_get_n_children( AtkObject *atk_obj )
 {
     AtkObjectWrapper *obj = ATK_OBJECT_WRAPPER (atk_obj);
     gint n = 0;
 
-    if( obj->mpContext )
+    if( obj->mpContext.is() )
     {
-        uno::Reference< accessibility::XAccessibleContext > xContext(obj->mpContext);
         try {
-            n = xContext->getAccessibleChildCount();
+            n = obj->mpContext->getAccessibleChildCount();
         }
         catch(const uno::Exception&) {
             OSL_FAIL("Exception in getAccessibleChildCount()" );
@@ -404,7 +436,7 @@ wrapper_ref_child( AtkObject *atk_obj,
                    gint       i )
 {
     AtkObjectWrapper *obj = ATK_OBJECT_WRAPPER (atk_obj);
-    AtkObject* child = NULL;
+    AtkObject* child = nullptr;
 
     // see comments above atk_object_wrapper_remove_child
     if( -1 < i && obj->index_of_child_about_to_be_removed == i )
@@ -413,12 +445,11 @@ wrapper_ref_child( AtkObject *atk_obj,
         return obj->child_about_to_be_removed;
     }
 
-    if( obj->mpContext )
+    if( obj->mpContext.is() )
     {
-        uno::Reference< accessibility::XAccessibleContext > xContext(obj->mpContext);
         try {
             uno::Reference< accessibility::XAccessible > xAccessible =
-                xContext->getAccessibleChild( i );
+                obj->mpContext->getAccessibleChild( i );
 
             child = atk_object_wrapper_ref( xAccessible );
         }
@@ -438,16 +469,10 @@ wrapper_get_index_in_parent( AtkObject *atk_obj )
     AtkObjectWrapper *obj = ATK_OBJECT_WRAPPER (atk_obj);
     gint i = -1;
 
-    if( obj->mpContext )
+    if( obj->mpContext.is() )
     {
-        uno::Reference< accessibility::XAccessibleContext > xContext(obj->mpContext);
         try {
-            i = xContext->getAccessibleIndexInParent();
-
-#ifdef ENABLE_TRACING
-            fprintf(stderr, "%p->getAccessibleIndexInParent() returned: %u\n",
-                obj->mpAccessible, i);
-#endif
+            i = obj->mpContext->getAccessibleIndexInParent();
         }
         catch(const uno::Exception&) {
             g_warning( "Exception in getAccessibleIndexInParent()" );
@@ -464,12 +489,11 @@ wrapper_ref_relation_set( AtkObject *atk_obj )
     AtkObjectWrapper *obj = ATK_OBJECT_WRAPPER (atk_obj);
     AtkRelationSet *pSet = atk_relation_set_new();
 
-    if( obj->mpContext )
+    if( obj->mpContext.is() )
     {
-        uno::Reference< accessibility::XAccessibleContext > xContext(obj->mpContext);
         try {
             uno::Reference< accessibility::XAccessibleRelationSet > xRelationSet(
-                    xContext->getAccessibleRelationSet()
+                    obj->mpContext->getAccessibleRelationSet()
             );
 
             sal_Int32 nRelations = xRelationSet.is() ? xRelationSet->getRelationCount() : 0;
@@ -477,7 +501,7 @@ wrapper_ref_relation_set( AtkObject *atk_obj )
             {
                 accessibility::AccessibleRelation aRelation = xRelationSet->getRelation( n );
                 sal_uInt32 nTargetCount = aRelation.TargetSet.getLength();
-                AtkObject **pTargets = (AtkObject **) alloca( nTargetCount * sizeof(AtkObject *) );
+                AtkObject **pTargets = static_cast<AtkObject **>(alloca( nTargetCount * sizeof(AtkObject *) ));
 
                 for( sal_uInt32 i = 0; i < nTargetCount; i++ )
                 {
@@ -497,7 +521,7 @@ wrapper_ref_relation_set( AtkObject *atk_obj )
         }
         catch(const uno::Exception &) {
             g_object_unref( G_OBJECT( pSet ) );
-            pSet = NULL;
+            pSet = nullptr;
         }
     }
 
@@ -510,19 +534,23 @@ wrapper_ref_state_set( AtkObject *atk_obj )
     AtkObjectWrapper *obj = ATK_OBJECT_WRAPPER (atk_obj);
     AtkStateSet *pSet = atk_state_set_new();
 
-    if( obj->mpContext )
+    if( obj->mpContext.is() )
     {
-        uno::Reference< accessibility::XAccessibleContext > xContext(obj->mpContext);
         try {
             uno::Reference< accessibility::XAccessibleStateSet > xStateSet(
-                xContext->getAccessibleStateSet());
+                obj->mpContext->getAccessibleStateSet());
 
             if( xStateSet.is() )
             {
                 uno::Sequence< sal_Int16 > aStates = xStateSet->getStates();
 
                 for( sal_Int32 n = 0; n < aStates.getLength(); n++ )
-                    atk_state_set_add_state( pSet, mapAtkState( aStates[n] ) );
+                {
+                    // ATK_STATE_LAST_DEFINED is used to check if the state
+                    // is unmapped, do not report it to Atk
+                    if ( mapAtkState( aStates[n] ) != ATK_STATE_LAST_DEFINED )
+                        atk_state_set_add_state( pSet, mapAtkState( aStates[n] ) );
+                }
 
                 // We need to emulate FOCUS state for menus, menu-items etc.
                 if( atk_obj == atk_get_focus_object() )
@@ -547,17 +575,15 @@ wrapper_ref_state_set( AtkObject *atk_obj )
 
 /*****************************************************************************/
 
-
 static void
 atk_object_wrapper_finalize (GObject *obj)
 {
     AtkObjectWrapper *pWrap = ATK_OBJECT_WRAPPER (obj);
 
-    if( pWrap->mpAccessible )
+    if( pWrap->mpAccessible.is() )
     {
         ooo_wrapper_registry_remove( pWrap->mpAccessible );
-        pWrap->mpAccessible->release();
-        pWrap->mpAccessible = NULL;
+        pWrap->mpAccessible.clear();
     }
 
     atk_object_wrapper_dispose( pWrap );
@@ -571,7 +597,7 @@ atk_object_wrapper_class_init (AtkObjectWrapperClass *klass)
   GObjectClass *gobject_class = G_OBJECT_CLASS( klass );
   AtkObjectClass *atk_class = ATK_OBJECT_CLASS( klass );
 
-  parent_class = (GObjectClass *) g_type_class_peek_parent (klass);
+  parent_class = static_cast<GObjectClass *>(g_type_class_peek_parent (klass));
 
   // GObject methods
   gobject_class->finalize = atk_object_wrapper_finalize;
@@ -579,6 +605,7 @@ atk_object_wrapper_class_init (AtkObjectWrapperClass *klass)
   // AtkObject methods
   atk_class->get_name = wrapper_get_name;
   atk_class->get_description = wrapper_get_description;
+  atk_class->get_attributes = wrapper_get_attributes;
   atk_class->get_n_children = wrapper_get_n_children;
   atk_class->ref_child = wrapper_ref_child;
   atk_class->get_index_in_parent = wrapper_get_index_in_parent;
@@ -588,23 +615,23 @@ atk_object_wrapper_class_init (AtkObjectWrapperClass *klass)
 
 static void
 atk_object_wrapper_init (AtkObjectWrapper      *wrapper,
-                         AtkObjectWrapperClass)
+                         AtkObjectWrapperClass*)
 {
-   wrapper->mpAction = NULL;
-   wrapper->mpComponent = NULL;
-   wrapper->mpEditableText = NULL;
-   wrapper->mpHypertext = NULL;
-   wrapper->mpImage = NULL;
-   wrapper->mpSelection = NULL;
-   wrapper->mpTable = NULL;
-   wrapper->mpText = NULL;
-   wrapper->mpValue = NULL;
+   wrapper->mpAction = nullptr;
+   wrapper->mpComponent = nullptr;
+   wrapper->mpEditableText = nullptr;
+   wrapper->mpHypertext = nullptr;
+   wrapper->mpImage = nullptr;
+   wrapper->mpSelection = nullptr;
+   wrapper->mpTable = nullptr;
+   wrapper->mpText = nullptr;
+   wrapper->mpValue = nullptr;
 }
 
 } // extern "C"
 
 GType
-atk_object_wrapper_get_type (void)
+atk_object_wrapper_get_type()
 {
   static GType type = 0;
 
@@ -613,15 +640,15 @@ atk_object_wrapper_get_type (void)
       static const GTypeInfo typeInfo =
       {
         sizeof (AtkObjectWrapperClass),
-        (GBaseInitFunc) NULL,
-        (GBaseFinalizeFunc) NULL,
-        (GClassInitFunc) atk_object_wrapper_class_init,
-        (GClassFinalizeFunc) NULL,
-        NULL,
+        nullptr,
+        nullptr,
+        reinterpret_cast<GClassInitFunc>(atk_object_wrapper_class_init),
+        nullptr,
+        nullptr,
         sizeof (AtkObjectWrapper),
         0,
-        (GInstanceInitFunc) atk_object_wrapper_init,
-        NULL
+        reinterpret_cast<GInstanceInitFunc>(atk_object_wrapper_init),
+        nullptr
       } ;
       type = g_type_register_static (ATK_TYPE_OBJECT,
                                      "OOoAtkObj",
@@ -633,14 +660,14 @@ atk_object_wrapper_get_type (void)
 static bool
 isOfType( uno::XInterface *pInterface, const uno::Type & rType )
 {
-    g_return_val_if_fail( pInterface != NULL, false );
+    g_return_val_if_fail( pInterface != nullptr, false );
 
     bool bIs = false;
     try {
         uno::Any aRet = pInterface->queryInterface( rType );
 
         bIs = ( ( typelib_TypeClass_INTERFACE == aRet.pType->eTypeClass ) &&
-                ( aRet.pReserved != NULL ) );
+                ( aRet.pReserved != nullptr ) );
     } catch( const uno::Exception &) { }
 
     return bIs;
@@ -653,53 +680,53 @@ const struct {
         const char          *name;
         GInterfaceInitFunc   aInit;
         GetGIfaceType        aGetGIfaceType;
-        const uno::Type &  (*aGetUnoType) (void *);
+        const uno::Type &  (*aGetUnoType) ();
 } aTypeTable[] = {
 // re-location heaven:
     {
-        "Comp", (GInterfaceInitFunc) componentIfaceInit,
+        "Comp", reinterpret_cast<GInterfaceInitFunc>(componentIfaceInit),
         atk_component_get_type,
-        accessibility::XAccessibleComponent::static_type
+        cppu::UnoType<accessibility::XAccessibleComponent>::get
     },
     {
-        "Act",  (GInterfaceInitFunc) actionIfaceInit,
+        "Act",  reinterpret_cast<GInterfaceInitFunc>(actionIfaceInit),
         atk_action_get_type,
-        accessibility::XAccessibleAction::static_type
+        cppu::UnoType<accessibility::XAccessibleAction>::get
     },
     {
-        "Txt",  (GInterfaceInitFunc) textIfaceInit,
+        "Txt",  reinterpret_cast<GInterfaceInitFunc>(textIfaceInit),
         atk_text_get_type,
-        accessibility::XAccessibleText::static_type
+        cppu::UnoType<accessibility::XAccessibleText>::get
     },
     {
-        "Val",  (GInterfaceInitFunc) valueIfaceInit,
+        "Val",  reinterpret_cast<GInterfaceInitFunc>(valueIfaceInit),
         atk_value_get_type,
-        accessibility::XAccessibleValue::static_type
+        cppu::UnoType<accessibility::XAccessibleValue>::get
     },
     {
-        "Tab",  (GInterfaceInitFunc) tableIfaceInit,
+        "Tab",  reinterpret_cast<GInterfaceInitFunc>(tableIfaceInit),
         atk_table_get_type,
-        accessibility::XAccessibleTable::static_type
+        cppu::UnoType<accessibility::XAccessibleTable>::get
     },
     {
-        "Edt",  (GInterfaceInitFunc) editableTextIfaceInit,
+        "Edt",  reinterpret_cast<GInterfaceInitFunc>(editableTextIfaceInit),
         atk_editable_text_get_type,
-        accessibility::XAccessibleEditableText::static_type
+        cppu::UnoType<accessibility::XAccessibleEditableText>::get
     },
     {
-        "Img",  (GInterfaceInitFunc) imageIfaceInit,
+        "Img",  reinterpret_cast<GInterfaceInitFunc>(imageIfaceInit),
         atk_image_get_type,
-        accessibility::XAccessibleImage::static_type
+        cppu::UnoType<accessibility::XAccessibleImage>::get
     },
     {
-        "Hyp",  (GInterfaceInitFunc) hypertextIfaceInit,
+        "Hyp",  reinterpret_cast<GInterfaceInitFunc>(hypertextIfaceInit),
         atk_hypertext_get_type,
-        accessibility::XAccessibleHypertext::static_type
+        cppu::UnoType<accessibility::XAccessibleHypertext>::get
     },
     {
-        "Sel",  (GInterfaceInitFunc) selectionIfaceInit,
+        "Sel",  reinterpret_cast<GInterfaceInitFunc>(selectionIfaceInit),
         atk_selection_get_type,
-        accessibility::XAccessibleSelection::static_type
+        cppu::UnoType<accessibility::XAccessibleSelection>::get
     }
     // AtkDocument is a nastily broken interface (so far)
     //  we could impl. get_document_type perhaps though.
@@ -711,15 +738,15 @@ static GType
 ensureTypeFor( uno::XInterface *pAccessible )
 {
     int i;
-    int bTypes[ aTypeTableSize ] = { 0, };
+    bool bTypes[ aTypeTableSize ] = { false, };
     OString aTypeName( "OOoAtkObj" );
 
     for( i = 0; i < aTypeTableSize; i++ )
     {
-        if( isOfType( pAccessible, aTypeTable[i].aGetUnoType(0) ) )
+        if( isOfType( pAccessible, aTypeTable[i].aGetUnoType() ) )
         {
             aTypeName += aTypeTable[i].name;
-            bTypes[i] = TRUE;
+            bTypes[i] = true;
         }
     }
 
@@ -728,9 +755,9 @@ ensureTypeFor( uno::XInterface *pAccessible )
     {
         GTypeInfo aTypeInfo = {
             sizeof( AtkObjectWrapperClass ),
-            NULL, NULL, NULL, NULL, NULL,
+            nullptr, nullptr, nullptr, nullptr, nullptr,
             sizeof( AtkObjectWrapper ),
-            0, NULL, NULL
+            0, nullptr, nullptr
         } ;
         nType = g_type_register_static( ATK_TYPE_OBJECT_WRAPPER,
                                         aTypeName.getStr(), &aTypeInfo,
@@ -739,7 +766,7 @@ ensureTypeFor( uno::XInterface *pAccessible )
         for( int j = 0; j < aTypeTableSize; j++ )
             if( bTypes[j] )
             {
-                GInterfaceInfo aIfaceInfo = { NULL, NULL, NULL };
+                GInterfaceInfo aIfaceInfo = { nullptr, nullptr, nullptr };
                 aIfaceInfo.interface_init = aTypeTable[j].aInit;
                 g_type_add_interface_static (nType, aTypeTable[j].aGetGIfaceType(),
                                              &aIfaceInfo);
@@ -751,7 +778,7 @@ ensureTypeFor( uno::XInterface *pAccessible )
 AtkObject *
 atk_object_wrapper_ref( const uno::Reference< accessibility::XAccessible > &rxAccessible, bool create )
 {
-    g_return_val_if_fail( rxAccessible.get() != NULL, NULL );
+    g_return_val_if_fail( rxAccessible.get() != nullptr, NULL );
 
     AtkObject *obj = ooo_wrapper_registry_get(rxAccessible);
     if( obj )
@@ -763,35 +790,32 @@ atk_object_wrapper_ref( const uno::Reference< accessibility::XAccessible > &rxAc
     if( create )
         return atk_object_wrapper_new( rxAccessible );
 
-    return NULL;
+    return nullptr;
 }
 
-
 AtkObject *
-atk_object_wrapper_new( const ::com::sun::star::uno::Reference< ::com::sun::star::accessibility::XAccessible >& rxAccessible,
+atk_object_wrapper_new( const css::uno::Reference< css::accessibility::XAccessible >& rxAccessible,
                         AtkObject* parent )
 {
-    g_return_val_if_fail( rxAccessible.get() != NULL, NULL );
+    g_return_val_if_fail( rxAccessible.get() != nullptr, NULL );
 
-    AtkObjectWrapper *pWrap = NULL;
+    AtkObjectWrapper *pWrap = nullptr;
 
     try {
         uno::Reference< accessibility::XAccessibleContext > xContext(rxAccessible->getAccessibleContext());
 
-        g_return_val_if_fail( xContext.get() != NULL, NULL );
+        g_return_val_if_fail( xContext.get() != nullptr, NULL );
 
         GType nType = ensureTypeFor( xContext.get() );
-        gpointer obj = g_object_new( nType, NULL);
+        gpointer obj = g_object_new( nType, nullptr);
 
         pWrap = ATK_OBJECT_WRAPPER( obj );
-        pWrap->mpAccessible = rxAccessible.get();
-        rxAccessible->acquire();
+        pWrap->mpAccessible = rxAccessible;
 
         pWrap->index_of_child_about_to_be_removed = -1;
-        pWrap->child_about_to_be_removed = NULL;
+        pWrap->child_about_to_be_removed = nullptr;
 
-        xContext->acquire();
-        pWrap->mpContext = xContext.get();
+        pWrap->mpContext = xContext;
 
         AtkObject* atk_obj = ATK_OBJECT(pWrap);
         atk_obj->role = mapToAtkRole( xContext->getAccessibleRole() );
@@ -804,9 +828,9 @@ atk_object_wrapper_new( const ::com::sun::star::uno::Reference< ::com::sun::star
         else
         {
             /* gail_focus_tracker remembers the focused object at the first
-             * parent in the hierachy that is a Gtk+ widget, but at the time the
+             * parent in the hierarchy that is a Gtk+ widget, but at the time the
              * event gets processed (at idle), it may be too late to create the
-             * hierachy, so doing it now ..
+             * hierarchy, so doing it now ..
              */
             uno::Reference< accessibility::XAccessible > xParent( xContext->getAccessibleParent() );
 
@@ -821,7 +845,7 @@ atk_object_wrapper_new( const ::com::sun::star::uno::Reference< ::com::sun::star
             uno::Reference< accessibility::XAccessibleEventBroadcaster > xBroadcaster(xContext, uno::UNO_QUERY);
             if( xBroadcaster.is() )
                 xBroadcaster->addAccessibleEventListener( static_cast< accessibility::XAccessibleEventListener * > ( new AtkListener(pWrap) ) );
-        else
+            else
                 OSL_ASSERT( false );
         }
 
@@ -832,11 +856,10 @@ atk_object_wrapper_new( const ::com::sun::star::uno::Reference< ::com::sun::star
         if( pWrap )
             g_object_unref( pWrap );
 
-        return NULL;
+        return nullptr;
     }
 }
 
-
 /*****************************************************************************/
 
 void atk_object_wrapper_add_child(AtkObjectWrapper* wrapper, AtkObject *child, gint index)
@@ -861,28 +884,34 @@ void atk_object_wrapper_remove_child(AtkObjectWrapper* wrapper, AtkObject *child
     g_signal_emit_by_name( ATK_OBJECT( wrapper ), "children_changed::remove", index, child, NULL );
 
     wrapper->index_of_child_about_to_be_removed = -1;
-    wrapper->child_about_to_be_removed = NULL;
+    wrapper->child_about_to_be_removed = nullptr;
 }
 
 /*****************************************************************************/
 
-#define RELEASE(i) if( i ) { i->release(); i = NULL; }
+void atk_object_wrapper_set_role(AtkObjectWrapper* wrapper, sal_Int16 role)
+{
+    AtkObject *atk_obj = ATK_OBJECT( wrapper );
+    atk_object_set_role( atk_obj, mapToAtkRole( role ) );
+}
+
+/*****************************************************************************/
 
 void atk_object_wrapper_dispose(AtkObjectWrapper* wrapper)
 {
-    RELEASE( wrapper->mpContext )
-    RELEASE( wrapper->mpAction )
-    RELEASE( wrapper->mpComponent )
-    RELEASE( wrapper->mpEditableText )
-    RELEASE( wrapper->mpHypertext )
-    RELEASE( wrapper->mpImage )
-    RELEASE( wrapper->mpSelection )
-    RELEASE( wrapper->mpMultiLineText )
-    RELEASE( wrapper->mpTable )
-    RELEASE( wrapper->mpText )
-    RELEASE( wrapper->mpTextMarkup )
-    RELEASE( wrapper->mpTextAttributes )
-    RELEASE( wrapper->mpValue )
+    wrapper->mpContext.clear();
+    wrapper->mpAction.clear();
+    wrapper->mpComponent.clear();
+    wrapper->mpEditableText.clear();
+    wrapper->mpHypertext.clear();
+    wrapper->mpImage.clear();
+    wrapper->mpSelection.clear();
+    wrapper->mpMultiLineText.clear();
+    wrapper->mpTable.clear();
+    wrapper->mpText.clear();
+    wrapper->mpTextMarkup.clear();
+    wrapper->mpTextAttributes.clear();
+    wrapper->mpValue.clear();
 }
 
 /* vim:set shiftwidth=4 softtabstop=4 expandtab: */
