@@ -17,7 +17,6 @@
  *   the License at http://www.apache.org/licenses/LICENSE-2.0 .
  */
 
-
 #include <string.h>
 #include <svsys.h>
 #include <process.h>
@@ -25,12 +24,12 @@
 #include <osl/file.hxx>
 #include <comphelper/solarmutex.hxx>
 
-#include <tools/solarmutex.hxx>
-
-#include <vcl/timer.hxx>
 #include <vcl/apptypes.hxx>
+#include <vcl/opengl/OpenGLHelper.hxx>
+#include <vcl/opengl/OpenGLContext.hxx>
+#include <vcl/timer.hxx>
 
-#include <vcl/solarmutex.hxx>
+#include <opengl/salbmp.hxx>
 #include <win/wincomp.hxx>
 #include <win/salids.hrc>
 #include <win/saldata.hxx>
@@ -64,11 +63,18 @@
 #define GetObject GetObjectA
 #endif
 
+#include "prewin.h"
+
 #include <gdiplus.h>
 #include <gdiplusenums.h>
 #include <gdipluscolor.h>
 #include <shlobj.h>
 
+#ifdef _WIN32_WINNT_WINBLUE
+#include <VersionHelpers.h>
+#endif
+#include "postwin.h"
+
 #ifdef __MINGW32__
 #ifdef GetObject
 #undef GetObject
@@ -83,8 +89,6 @@
 #include <sehandler.hxx>
 #endif
 
-// =======================================================================
-
 void SalAbort( const OUString& rErrorText, bool )
 {
     ImplFreeSalGDI();
@@ -103,32 +107,27 @@ void SalAbort( const OUString& rErrorText, bool )
     }
 }
 
-// =======================================================================
-
-LRESULT CALLBACK SalComWndProcA( HWND hWnd, UINT nMsg, WPARAM wParam, LPARAM lParam );
 LRESULT CALLBACK SalComWndProcW( HWND hWnd, UINT nMsg, WPARAM wParam, LPARAM lParam );
 
-// =======================================================================
-
-class SalYieldMutex : public vcl::SolarMutexObject
+class SalYieldMutex : public comphelper::SolarMutex
 {
-public: // for ImplSalYield()
+public: // for ImplSalYield() and ImplSalYieldMutexAcquireWithWait()
+    osl::Mutex                  m_mutex;
+    osl::Condition              m_condition; /// for MsgWaitForMultipleObjects()
     WinSalInstance*             mpInstData;
-    sal_uLong                       mnCount;
+    sal_uLong                   mnCount;
     DWORD                       mnThreadId;
 
 public:
-                                SalYieldMutex( WinSalInstance* pInstData );
+    explicit SalYieldMutex( WinSalInstance* pInstData );
 
     virtual void                acquire();
     virtual void                release();
     virtual bool                tryToAcquire();
 
-    sal_uLong                       GetAcquireCount( sal_uLong nThreadId );
+    sal_uLong                   GetAcquireCount( sal_uLong nThreadId );
 };
 
-// -----------------------------------------------------------------------
-
 SalYieldMutex::SalYieldMutex( WinSalInstance* pInstData )
 {
     mpInstData  = pInstData;
@@ -136,62 +135,54 @@ SalYieldMutex::SalYieldMutex( WinSalInstance* pInstData )
     mnThreadId  = 0;
 }
 
-// -----------------------------------------------------------------------
-
 void SalYieldMutex::acquire()
 {
-    SolarMutexObject::acquire();
+    m_mutex.acquire();
     mnCount++;
     mnThreadId = GetCurrentThreadId();
 }
 
-// -----------------------------------------------------------------------
-
 void SalYieldMutex::release()
 {
     DWORD nThreadId = GetCurrentThreadId();
     if ( mnThreadId != nThreadId )
-        SolarMutexObject::release();
+        m_mutex.release();
     else
     {
-        SalData* pSalData = GetSalData();
-        if ( pSalData->mnAppThreadId != nThreadId )
+        bool isRelease(1 == mnCount);
+        if ( isRelease )
         {
-            if ( mnCount == 1 )
+            SalData* pSalData = GetSalData();
+            if ( pSalData->mnAppThreadId != nThreadId )
             {
+                OpenGLContext::prepareForYield();
+
                 // If we don't call these message, the Output from the
                 // Java clients doesn't come in the right order
                 GdiFlush();
 
-                mpInstData->mpSalWaitMutex->acquire();
-                if ( mpInstData->mnYieldWaitCount )
-                    ImplPostMessage( mpInstData->mhComWnd, SAL_MSG_RELEASEWAITYIELD, 0, 0 );
                 mnThreadId = 0;
-                mnCount--;
-                SolarMutexObject::release();
-                mpInstData->mpSalWaitMutex->release();
             }
             else
             {
-                mnCount--;
-                SolarMutexObject::release();
+                mnThreadId = 0;
+                OpenGLContext::prepareForYield();
             }
         }
-        else
-        {
-            if ( mnCount == 1 )
-                mnThreadId = 0;
-            mnCount--;
-            SolarMutexObject::release();
+
+        mnCount--;
+        m_mutex.release();
+
+        if ( isRelease )
+        {   // do this *after* release
+            m_condition.set(); // wake up ImplSalYieldMutexAcquireWithWait()
         }
     }
 }
 
-// -----------------------------------------------------------------------
-
 bool SalYieldMutex::tryToAcquire()
 {
-    if( SolarMutexObject::tryToAcquire() )
+    if( m_mutex.tryToAcquire() )
     {
         mnCount++;
         mnThreadId = GetCurrentThreadId();
@@ -201,8 +192,6 @@ bool SalYieldMutex::tryToAcquire()
         return false;
 }
 
-// -----------------------------------------------------------------------
-
 sal_uLong SalYieldMutex::GetAcquireCount( sal_uLong nThreadId )
 {
     if ( nThreadId == mnThreadId )
@@ -211,76 +200,53 @@ sal_uLong SalYieldMutex::GetAcquireCount( sal_uLong nThreadId )
         return 0;
 }
 
-// -----------------------------------------------------------------------
-
+/// note: while VCL is fully up and running (other threads started and
+/// before shutdown), the main thread must acquire SolarMutex only via
+/// this function to avoid deadlock
 void ImplSalYieldMutexAcquireWithWait()
 {
     WinSalInstance* pInst = GetSalData()->mpFirstInstance;
     if ( !pInst )
         return;
 
-    // If we are the main thread, then we must wait with wait, because
-    // in if we don't reschedule, then we create deadlocks if a Windows
-    // Function is called from another thread. If we arn't the main thread,
-    // than we call qcquire directly.
     DWORD nThreadId = GetCurrentThreadId();
     SalData* pSalData = GetSalData();
+
     if ( pSalData->mnAppThreadId == nThreadId )
     {
-        // wait till we get the Mutex
-        sal_Bool bAcquire = FALSE;
-        do
+        // tdf#96887 If this is the main thread, then we must wait for two things:
+        // - the mpSalYieldMutex being freed
+        // - SendMessage() being triggered
+        // This can nicely be done using MsgWaitForMultipleObjects. The 2nd one is
+        // needed because if we don't reschedule, then we create deadlocks if a
+        // Window's create/destroy is called via SendMessage() from another thread.
+        // Have a look at the osl_waitCondition implementation for more info.
+        pInst->mpSalYieldMutex->m_condition.reset();
+        while (!pInst->mpSalYieldMutex->tryToAcquire())
         {
-            if ( pInst->mpSalYieldMutex->tryToAcquire() )
-                bAcquire = TRUE;
-            else
-            {
-                pInst->mpSalWaitMutex->acquire();
-                if ( pInst->mpSalYieldMutex->tryToAcquire() )
-                {
-                    bAcquire = TRUE;
-                    pInst->mpSalWaitMutex->release();
-                }
-                else
-                {
-                    pInst->mnYieldWaitCount++;
-                    pInst->mpSalWaitMutex->release();
-                    MSG aTmpMsg;
-                    ImplGetMessage( &aTmpMsg, pInst->mhComWnd, SAL_MSG_RELEASEWAITYIELD, SAL_MSG_RELEASEWAITYIELD );
-                    pInst->mnYieldWaitCount--;
-                    if ( pInst->mnYieldWaitCount )
-                        ImplPostMessage( pInst->mhComWnd, SAL_MSG_RELEASEWAITYIELD, 0, 0 );
-                }
-            }
+            // wait for SalYieldMutex::release() to set the condition
+            osl::Condition::Result res = pInst->mpSalYieldMutex->m_condition.wait();
+            assert(osl::Condition::Result::result_ok == res);
+            // reset condition *before* acquiring!
+            pInst->mpSalYieldMutex->m_condition.reset();
         }
-        while ( !bAcquire );
     }
     else
+    {
+        // If this is not the main thread, call acquire directly.
         pInst->mpSalYieldMutex->acquire();
+    }
 }
 
-// -----------------------------------------------------------------------
-
-sal_Bool ImplSalYieldMutexTryToAcquire()
+bool ImplSalYieldMutexTryToAcquire()
 {
     WinSalInstance* pInst = GetSalData()->mpFirstInstance;
     if ( pInst )
         return pInst->mpSalYieldMutex->tryToAcquire();
     else
-        return FALSE;
+        return false;
 }
 
-// -----------------------------------------------------------------------
-
-void ImplSalYieldMutexAcquire()
-{
-    WinSalInstance* pInst = GetSalData()->mpFirstInstance;
-    if ( pInst )
-        pInst->mpSalYieldMutex->acquire();
-}
-
-// -----------------------------------------------------------------------
-
 void ImplSalYieldMutexRelease()
 {
     WinSalInstance* pInst = GetSalData()->mpFirstInstance;
@@ -291,8 +257,6 @@ void ImplSalYieldMutexRelease()
     }
 }
 
-// -----------------------------------------------------------------------
-
 sal_uLong ImplSalReleaseYieldMutex()
 {
     WinSalInstance* pInst = GetSalData()->mpFirstInstance;
@@ -311,8 +275,6 @@ sal_uLong ImplSalReleaseYieldMutex()
     return nCount;
 }
 
-// -----------------------------------------------------------------------
-
 void ImplSalAcquireYieldMutex( sal_uLong nCount )
 {
     WinSalInstance* pInst = GetSalData()->mpFirstInstance;
@@ -327,8 +289,6 @@ void ImplSalAcquireYieldMutex( sal_uLong nCount )
     }
 }
 
-// -----------------------------------------------------------------------
-
 bool WinSalInstance::CheckYieldMutex()
 {
     SalData*    pSalData = GetSalData();
@@ -340,11 +300,9 @@ bool WinSalInstance::CheckYieldMutex()
     return true;
 }
 
-// =======================================================================
-
 void SalData::initKeyCodeMap()
 {
-    UINT nKey = 0xffffffff;
+    UINT nKey;
     #define initKey( a, b )\
         nKey = LOWORD( VkKeyScan( a ) );\
         if( nKey < 0xffff )\
@@ -364,17 +322,14 @@ void SalData::initKeyCodeMap()
     initKey( '[', KEY_BRACKETLEFT );
     initKey( ']', KEY_BRACKETRIGHT );
     initKey( ';', KEY_SEMICOLON );
+    initKey( '\'', KEY_QUOTERIGHT );
 }
 
-// =======================================================================
-// -------
 // SalData
-// -------
 
 SalData::SalData()
 {
     mhInst = 0;                 // default instance handle
-    mhPrevInst = 0;             // previous instance handle
     mnCmdShow = 0;              // default frame show style
     mhDitherPal = 0;            // dither palette
     mhDitherDIB = 0;            // dither memory handle
@@ -388,7 +343,6 @@ SalData::SalData()
     mnNextTimerTime = 0;
     mnLastEventTime = 0;
     mnTimerId = 0;              // windows timer id
-    mbInTimerProc = FALSE;      // timer event is currently being dispatched
     mhSalObjMsgHook = 0;        // hook to get interesting msg for SalObject
     mhWantLeaveMsg = 0;         // window handle, that want a MOUSELEAVE message
     mpMouseLeaveTimer = 0;      // Timer for MouseLeave Test
@@ -415,16 +369,16 @@ SalData::SalData()
     mnStockBrushCount = 0;      // count of static brushes
     mnSalObjWantKeyEvt = 0;     // KeyEvent for the SalObj hook
     mnCacheDCInUse = 0;         // count of CacheDC in use
-    mbObjClassInit = FALSE;     // is SALOBJECTCLASS initialised
-    mbInPalChange = FALSE;      // is in WM_QUERYNEWPALETTE
+    mbObjClassInit = false;     // is SALOBJECTCLASS initialised
+    mbInPalChange = false;      // is in WM_QUERYNEWPALETTE
     mnAppThreadId = 0;          // Id from Applikation-Thread
     mbScrSvrEnabled = FALSE;    // ScreenSaver enabled
     mnSageStatus = 0;           // status of Sage-DLL (DISABLE_AGENT == not available)
     mpSageEnableProc = 0;       // funktion to deactivate the system agent
     mpFirstIcon = 0;            // icon cache, points to first icon, NULL if none
     mpTempFontItem = 0;
-    mbThemeChanged = FALSE;     // true if visual theme was changed: throw away theme handles
-    mbThemeMenuSupport = FALSE;
+    mbThemeChanged = false;     // true if visual theme was changed: throw away theme handles
+    mbThemeMenuSupport = false;
 
     // init with NULL
     gdiplusToken = 0;
@@ -446,14 +400,13 @@ SalData::~SalData()
 void InitSalData()
 {
     SalData* pSalData = new SalData;
-    CoInitialize(0);
+    CoInitialize(0); // put main thread in Single Threaded Apartment (STA)
 
     // init GDIPlus
     static Gdiplus::GdiplusStartupInput gdiplusStartupInput;
     Gdiplus::GdiplusStartup(&pSalData->gdiplusToken, &gdiplusStartupInput, NULL);
 }
 
-
 void DeInitSalData()
 {
     CoUninitialize();
@@ -468,8 +421,6 @@ void DeInitSalData()
     delete pSalData;
 }
 
-// -----------------------------------------------------------------------
-
 void InitSalMain()
 {
     // remember data, copied from WinMain
@@ -480,75 +431,81 @@ void InitSalMain()
         aSI.cb = sizeof( aSI );
         GetStartupInfo( &aSI );
         pData->mhInst                   = GetModuleHandle( NULL );
-        pData->mhPrevInst               = NULL;
         pData->mnCmdShow                = aSI.wShowWindow;
     }
 }
 
-// -----------------------------------------------------------------------
-
 SalInstance* CreateSalInstance()
 {
     SalData* pSalData = GetSalData();
 
     // determine the windows version
     aSalShlData.mbWXP        = 0;
+    aSalShlData.mbWVista     = 0;
     aSalShlData.mbW7         = 0;
-    memset( &aSalShlData.maVersionInfo, 0, sizeof(aSalShlData.maVersionInfo) );
-    aSalShlData.maVersionInfo.dwOSVersionInfoSize = sizeof( aSalShlData.maVersionInfo );
-    if ( GetVersionEx( &aSalShlData.maVersionInfo ) )
+// the Win32 SDK 8.1 deprecates GetVersionEx()
+#ifdef _WIN32_WINNT_WINBLUE
+    aSalShlData.mbWXP = IsWindowsXPOrGreater() ? 1 : 0;
+    aSalShlData.mbWVista = IsWindowsVistaOrGreater() ? 1 : 0;
+    aSalShlData.mbW7 = IsWindows7OrGreater() ? 1 : 0;
+#else
+    OSVERSIONINFO aVersionInfo;
+    memset( &aVersionInfo, 0, sizeof(aVersionInfo) );
+    aVersionInfo.dwOSVersionInfoSize = sizeof( aVersionInfo );
+    if (GetVersionEx( &aVersionInfo ))
     {
         // Windows XP ?
-        if ( aSalShlData.maVersionInfo.dwMajorVersion > 5 ||
-           ( aSalShlData.maVersionInfo.dwMajorVersion == 5 && aSalShlData.maVersionInfo.dwMinorVersion >= 1 ) )
+        if (aVersionInfo.dwMajorVersion > 5 ||
+           (aVersionInfo.dwMajorVersion == 5 && aVersionInfo.dwMinorVersion >= 1))
             aSalShlData.mbWXP = 1;
-    // Windows 7 ?
-    if ( aSalShlData.maVersionInfo.dwMajorVersion > 6 ||
-       ( aSalShlData.maVersionInfo.dwMajorVersion == 6 && aSalShlData.maVersionInfo.dwMinorVersion >= 1 ) )
-        aSalShlData.mbW7 = 1;
+        // Windows Vista ?
+        if (aVersionInfo.dwMajorVersion >= 6)
+            aSalShlData.mbWVista = 1;
+        // Windows 7 ?
+        if (aVersionInfo.dwMajorVersion > 6 ||
+           (aVersionInfo.dwMajorVersion == 6 && aVersionInfo.dwMinorVersion >= 1))
+            aSalShlData.mbW7 = 1;
     }
+#endif
 
     pSalData->mnAppThreadId = GetCurrentThreadId();
 
     // register frame class
-    if ( !pSalData->mhPrevInst )
-    {
-        WNDCLASSEXW aWndClassEx;
-        aWndClassEx.cbSize          = sizeof( aWndClassEx );
-        aWndClassEx.style           = CS_OWNDC;
-        aWndClassEx.lpfnWndProc     = SalFrameWndProcW;
-        aWndClassEx.cbClsExtra      = 0;
-        aWndClassEx.cbWndExtra      = SAL_FRAME_WNDEXTRA;
-        aWndClassEx.hInstance       = pSalData->mhInst;
-        aWndClassEx.hCursor         = 0;
-        aWndClassEx.hbrBackground   = 0;
-        aWndClassEx.lpszMenuName    = 0;
-        aWndClassEx.lpszClassName   = SAL_FRAME_CLASSNAMEW;
-        ImplLoadSalIcon( SAL_RESID_ICON_DEFAULT, aWndClassEx.hIcon, aWndClassEx.hIconSm );
-        if ( !RegisterClassExW( &aWndClassEx ) )
-            return NULL;
+    WNDCLASSEXW aWndClassEx;
+    aWndClassEx.cbSize          = sizeof( aWndClassEx );
+    aWndClassEx.style           = CS_OWNDC;
+    aWndClassEx.lpfnWndProc     = SalFrameWndProcW;
+    aWndClassEx.cbClsExtra      = 0;
+    aWndClassEx.cbWndExtra      = SAL_FRAME_WNDEXTRA;
+    aWndClassEx.hInstance       = pSalData->mhInst;
+    aWndClassEx.hCursor         = 0;
+    aWndClassEx.hbrBackground   = 0;
+    aWndClassEx.lpszMenuName    = 0;
+    aWndClassEx.lpszClassName   = SAL_FRAME_CLASSNAMEW;
+    ImplLoadSalIcon( SAL_RESID_ICON_DEFAULT, aWndClassEx.hIcon, aWndClassEx.hIconSm );
+    if ( !RegisterClassExW( &aWndClassEx ) )
+        return NULL;
 
-        aWndClassEx.hIcon           = 0;
-        aWndClassEx.hIconSm         = 0;
-        aWndClassEx.style          |= CS_SAVEBITS;
-        aWndClassEx.lpszClassName   = SAL_SUBFRAME_CLASSNAMEW;
-        if ( !RegisterClassExW( &aWndClassEx ) )
-            return NULL;
+    aWndClassEx.hIcon           = 0;
+    aWndClassEx.hIconSm         = 0;
+    aWndClassEx.style          |= CS_SAVEBITS;
+    aWndClassEx.lpszClassName   = SAL_SUBFRAME_CLASSNAMEW;
+    if ( !RegisterClassExW( &aWndClassEx ) )
+        return NULL;
 
-        // shadow effect for popups on XP
-        if( aSalShlData.mbWXP )
-            aWndClassEx.style       |= CS_DROPSHADOW;
-        aWndClassEx.lpszClassName   = SAL_TMPSUBFRAME_CLASSNAMEW;
-        if ( !RegisterClassExW( &aWndClassEx ) )
-            return NULL;
+    // shadow effect for popups on XP
+    if( aSalShlData.mbWXP )
+        aWndClassEx.style       |= CS_DROPSHADOW;
+    aWndClassEx.lpszClassName   = SAL_TMPSUBFRAME_CLASSNAMEW;
+    if ( !RegisterClassExW( &aWndClassEx ) )
+        return NULL;
 
-        aWndClassEx.style           = 0;
-        aWndClassEx.lpfnWndProc     = SalComWndProcW;
-        aWndClassEx.cbWndExtra      = 0;
-        aWndClassEx.lpszClassName   = SAL_COM_CLASSNAMEW;
-        if ( !RegisterClassExW( &aWndClassEx ) )
-            return NULL;
-    }
+    aWndClassEx.style           = 0;
+    aWndClassEx.lpfnWndProc     = SalComWndProcW;
+    aWndClassEx.cbWndExtra      = 0;
+    aWndClassEx.lpszClassName   = SAL_COM_CLASSNAMEW;
+    if ( !RegisterClassExW( &aWndClassEx ) )
+        return NULL;
 
     HWND hComWnd = CreateWindowExW( WS_EX_TOOLWINDOW, SAL_COM_CLASSNAMEW,
                                L"", WS_POPUP, 0, 0, 0, 0, 0, 0,
@@ -569,8 +526,6 @@ SalInstance* CreateSalInstance()
     return pInst;
 }
 
-// -----------------------------------------------------------------------
-
 void DestroySalInstance( SalInstance* pInst )
 {
     SalData* pSalData = GetSalData();
@@ -586,52 +541,37 @@ void DestroySalInstance( SalInstance* pInst )
     delete pInst;
 }
 
-// -----------------------------------------------------------------------
-
 WinSalInstance::WinSalInstance()
 {
     mhComWnd                 = 0;
     mpSalYieldMutex          = new SalYieldMutex( this );
-    mpSalWaitMutex           = new osl::Mutex;
-    mnYieldWaitCount         = 0;
     mpSalYieldMutex->acquire();
-    ::tools::SolarMutex::SetSolarMutex( mpSalYieldMutex );
+    ::comphelper::SolarMutex::setSolarMutex( mpSalYieldMutex );
 }
 
-// -----------------------------------------------------------------------
-
 WinSalInstance::~WinSalInstance()
 {
-    ::tools::SolarMutex::SetSolarMutex( 0 );
+    ::comphelper::SolarMutex::setSolarMutex( 0 );
     mpSalYieldMutex->release();
     delete mpSalYieldMutex;
-    delete mpSalWaitMutex;
     DestroyWindow( mhComWnd );
 }
 
-// -----------------------------------------------------------------------
-
 comphelper::SolarMutex* WinSalInstance::GetYieldMutex()
 {
     return mpSalYieldMutex;
 }
 
-// -----------------------------------------------------------------------
-
 sal_uLong WinSalInstance::ReleaseYieldMutex()
 {
     return ImplSalReleaseYieldMutex();
 }
 
-// -----------------------------------------------------------------------
-
 void WinSalInstance::AcquireYieldMutex( sal_uLong nCount )
 {
     ImplSalAcquireYieldMutex( nCount );
 }
 
-// -----------------------------------------------------------------------
-
 static void ImplSalDispatchMessage( MSG* pMsg )
 {
     SalData* pSalData = GetSalData();
@@ -640,14 +580,13 @@ static void ImplSalDispatchMessage( MSG* pMsg )
         if ( ImplSalPreDispatchMsg( pMsg ) )
             return;
     }
-    LRESULT lResult = ImplDispatchMessage( pMsg );
+    LRESULT lResult = DispatchMessageW( pMsg );
     if ( pSalData->mpFirstObject )
         ImplSalPostDispatchMsg( pMsg, lResult );
 }
 
-// -----------------------------------------------------------------------
-
-void ImplSalYield( sal_Bool bWait, sal_Bool bHandleAllCurrentEvents )
+SalYieldResult
+ImplSalYield( bool bWait, bool bHandleAllCurrentEvents )
 {
     MSG aMsg;
     bool bWasMsg = false, bOneEvent = false;
@@ -655,7 +594,7 @@ void ImplSalYield( sal_Bool bWait, sal_Bool bHandleAllCurrentEvents )
     int nMaxEvents = bHandleAllCurrentEvents ? 100 : 1;
     do
     {
-        if ( ImplPeekMessage( &aMsg, 0, 0, 0, PM_REMOVE ) )
+        if ( PeekMessageW( &aMsg, 0, 0, 0, PM_REMOVE ) )
         {
             TranslateMessage( &aMsg );
             ImplSalDispatchMessage( &aMsg );
@@ -668,23 +607,28 @@ void ImplSalYield( sal_Bool bWait, sal_Bool bHandleAllCurrentEvents )
 
     if ( bWait && ! bWasMsg )
     {
-        if ( ImplGetMessage( &aMsg, 0, 0, 0 ) )
+        if ( GetMessageW( &aMsg, 0, 0, 0 ) )
         {
             TranslateMessage( &aMsg );
             ImplSalDispatchMessage( &aMsg );
         }
     }
+    return bWasMsg ? SalYieldResult::EVENT :
+                     SalYieldResult::TIMEOUT;
 }
 
-// -----------------------------------------------------------------------
-
-void WinSalInstance::Yield( bool bWait, bool bHandleAllCurrentEvents )
+SalYieldResult WinSalInstance::DoYield(bool bWait, bool bHandleAllCurrentEvents, sal_uLong const nReleased)
 {
+    SalYieldResult eDidWork = SalYieldResult::TIMEOUT;
+    // NOTE: if nReleased != 0 this will be called without SolarMutex
+    //       so don't do anything dangerous before releasing it here
     SalYieldMutex*  pYieldMutex = mpSalYieldMutex;
     SalData*        pSalData = GetSalData();
     DWORD           nCurThreadId = GetCurrentThreadId();
-    sal_uLong           nCount = pYieldMutex->GetAcquireCount( nCurThreadId );
-    sal_uLong           n = nCount;
+    sal_uLong const nCount = (nReleased != 0)
+                                ? nReleased
+                                : pYieldMutex->GetAcquireCount(nCurThreadId);
+    sal_uLong       n = (nReleased != 0) ? 0 : nCount;
     while ( n )
     {
         pYieldMutex->release();
@@ -705,7 +649,7 @@ void WinSalInstance::Yield( bool bWait, bool bHandleAllCurrentEvents )
         if( ImplGetSVData()->maAppData.mnModalMode )
             Sleep(1);
         else
-            ImplSendMessage( mhComWnd, SAL_MSG_THREADYIELD, (WPARAM)bWait, (LPARAM)bHandleAllCurrentEvents );
+            SendMessageW( mhComWnd, SAL_MSG_THREADYIELD, (WPARAM)bWait, (LPARAM)bHandleAllCurrentEvents );
 
         n = nCount;
         while ( n )
@@ -716,7 +660,10 @@ void WinSalInstance::Yield( bool bWait, bool bHandleAllCurrentEvents )
     }
     else
     {
-        ImplSalYield( bWait, bHandleAllCurrentEvents );
+        if (nReleased == 0) // tdf#99383 ReAcquireSolarMutex shouldn't Yield
+        {
+            eDidWork = ImplSalYield( bWait, bHandleAllCurrentEvents );
+        }
 
         n = nCount;
         while ( n )
@@ -725,42 +672,29 @@ void WinSalInstance::Yield( bool bWait, bool bHandleAllCurrentEvents )
             n--;
         }
     }
+    return eDidWork;
 }
 
-// -----------------------------------------------------------------------
-
-LRESULT CALLBACK SalComWndProc( HWND hWnd, UINT nMsg, WPARAM wParam, LPARAM lParam, int& rDef )
+LRESULT CALLBACK SalComWndProc( HWND, UINT nMsg, WPARAM wParam, LPARAM lParam, int& rDef )
 {
     LRESULT nRet = 0;
 
-
     switch ( nMsg )
     {
-        case SAL_MSG_PRINTABORTJOB:
-            ImplSalPrinterAbortJobAsync( (HDC)wParam );
-            rDef = FALSE;
-            break;
         case SAL_MSG_THREADYIELD:
-            ImplSalYield( (sal_Bool)wParam, (sal_Bool)lParam );
-            rDef = FALSE;
-            break;
-        // If we get this message, because another GetMessage() call
-        // has received this message, we must post this message to
-        // us again, because in the other case we wait forever.
-        case SAL_MSG_RELEASEWAITYIELD:
-            {
-            WinSalInstance* pInst = GetSalData()->mpFirstInstance;
-            if ( pInst && pInst->mnYieldWaitCount )
-                ImplPostMessage( hWnd, SAL_MSG_RELEASEWAITYIELD, wParam, lParam );
-            }
+            ImplSalYield( (bool)wParam, (bool)lParam );
             rDef = FALSE;
             break;
         case SAL_MSG_STARTTIMER:
             ImplSalStartTimer( (sal_uLong) lParam, FALSE );
             rDef = FALSE;
             break;
+        case SAL_MSG_STOPTIMER:
+            ImplSalStopTimer();
+            rDef = FALSE;
+            break;
         case SAL_MSG_CREATEFRAME:
-            nRet = (LRESULT)ImplSalCreateFrame( GetSalData()->mpFirstInstance, (HWND)lParam, (sal_uLong)wParam );
+            nRet = (LRESULT)ImplSalCreateFrame( GetSalData()->mpFirstInstance, (HWND)lParam, (SalFrameStyleFlags)wParam );
             rDef = FALSE;
             break;
         case SAL_MSG_RECREATEHWND:
@@ -804,44 +738,28 @@ LRESULT CALLBACK SalComWndProc( HWND hWnd, UINT nMsg, WPARAM wParam, LPARAM lPar
             rDef = FALSE;
             break;
         case SAL_MSG_POSTTIMER:
-            SalTimerProc( 0, 0, SALTIMERPROC_RECURSIVE, lParam );
+            EmitTimerCallback();
+            break;
+        case SAL_MSG_TIMER_CALLBACK:
+            EmitTimerCallback();
+            MSG aMsg;
+            while (PeekMessageW(&aMsg, 0, SAL_MSG_TIMER_CALLBACK, SAL_MSG_TIMER_CALLBACK, PM_REMOVE))
+            {
+                // nothing; just remove all the SAL_MSG_TIMER_CALLBACKs that
+                // accumulated in the queue during the EmitTimerCallback(),
+                // otherwise it happens with short timeouts and long callbacks
+                // that no other events will ever be processed, as the queue
+                // is full of SAL_MSG_TIMER_CALLBACKs.
+                // It is impossible to limit the amount of them being emitted
+                // in the first place, as they are emitted asynchronously, but
+                // here we are already fully synchronized.
+            }
             break;
     }
 
     return nRet;
 }
 
-LRESULT CALLBACK SalComWndProcA( HWND hWnd, UINT nMsg, WPARAM wParam, LPARAM lParam )
-{
-    int bDef = TRUE;
-    LRESULT nRet = 0;
-#if defined ( __MINGW32__ ) && !defined ( _WIN64 )
-    jmp_buf jmpbuf;
-    __SEHandler han;
-    if (__builtin_setjmp(jmpbuf) == 0)
-    {
-        han.Set(jmpbuf, NULL, (__SEHandler::PF)EXCEPTION_EXECUTE_HANDLER);
-#else
-    __try
-    {
-#endif
-        nRet = SalComWndProc( hWnd, nMsg, wParam, lParam, bDef );
-    }
-#if defined ( __MINGW32__ ) && !defined ( _WIN64 )
-    han.Reset();
-#else
-    __except(WinSalInstance::WorkaroundExceptionHandlingInUSER32Lib(GetExceptionCode(), GetExceptionInformation()))
-    {
-    }
-#endif
-    if ( bDef )
-    {
-        if ( !ImplHandleGlobalMsg( hWnd, nMsg, wParam, lParam, nRet ) )
-            nRet = DefWindowProcA( hWnd, nMsg, wParam, lParam );
-    }
-    return nRet;
-}
-
 LRESULT CALLBACK SalComWndProcW( HWND hWnd, UINT nMsg, WPARAM wParam, LPARAM lParam )
 {
     int bDef = TRUE;
@@ -873,33 +791,31 @@ LRESULT CALLBACK SalComWndProcW( HWND hWnd, UINT nMsg, WPARAM wParam, LPARAM lPa
     return nRet;
 }
 
-// -----------------------------------------------------------------------
-
-bool WinSalInstance::AnyInput( sal_uInt16 nType )
+bool WinSalInstance::AnyInput( VclInputFlags nType )
 {
     MSG aMsg;
 
-    if ( (nType & (VCL_INPUT_ANY)) == (VCL_INPUT_ANY) )
+    if ( (nType & VCL_INPUT_ANY) == VCL_INPUT_ANY )
     {
         // revert bugfix for #108919# which never reported timeouts when called from the timer handler
         // which made the application completely unresponsive during background formatting
-        if ( ImplPeekMessage( &aMsg, 0, 0, 0, PM_NOREMOVE | PM_NOYIELD ) )
+        if ( PeekMessageW( &aMsg, 0, 0, 0, PM_NOREMOVE | PM_NOYIELD ) )
             return true;
     }
     else
     {
-        if ( nType & VCL_INPUT_MOUSE )
+        if ( nType & VclInputFlags::MOUSE )
         {
             // Test for mouse input
-            if ( ImplPeekMessage( &aMsg, 0, WM_MOUSEFIRST, WM_MOUSELAST,
+            if ( PeekMessageW( &aMsg, 0, WM_MOUSEFIRST, WM_MOUSELAST,
                                   PM_NOREMOVE | PM_NOYIELD ) )
                 return true;
         }
 
-        if ( nType & VCL_INPUT_KEYBOARD )
+        if ( nType & VclInputFlags::KEYBOARD )
         {
             // Test for key input
-            if ( ImplPeekMessage( &aMsg, 0, WM_KEYDOWN, WM_KEYDOWN,
+            if ( PeekMessageW( &aMsg, 0, WM_KEYDOWN, WM_KEYDOWN,
                                   PM_NOREMOVE | PM_NOYIELD ) )
             {
                 if ( (aMsg.wParam == VK_SHIFT)   ||
@@ -911,52 +827,50 @@ bool WinSalInstance::AnyInput( sal_uInt16 nType )
             }
         }
 
-        if ( nType & VCL_INPUT_PAINT )
+        if ( nType & VclInputFlags::PAINT )
         {
             // Test for paint input
-            if ( ImplPeekMessage( &aMsg, 0, WM_PAINT, WM_PAINT,
+            if ( PeekMessageW( &aMsg, 0, WM_PAINT, WM_PAINT,
                                   PM_NOREMOVE | PM_NOYIELD ) )
                 return true;
 
-            if ( ImplPeekMessage( &aMsg, 0, WM_SIZE, WM_SIZE,
+            if ( PeekMessageW( &aMsg, 0, WM_SIZE, WM_SIZE,
                                   PM_NOREMOVE | PM_NOYIELD ) )
                 return true;
 
-            if ( ImplPeekMessage( &aMsg, 0, SAL_MSG_POSTCALLSIZE, SAL_MSG_POSTCALLSIZE,
+            if ( PeekMessageW( &aMsg, 0, SAL_MSG_POSTCALLSIZE, SAL_MSG_POSTCALLSIZE,
                                   PM_NOREMOVE | PM_NOYIELD ) )
                 return true;
 
-            if ( ImplPeekMessage( &aMsg, 0, WM_MOVE, WM_MOVE,
+            if ( PeekMessageW( &aMsg, 0, WM_MOVE, WM_MOVE,
                                   PM_NOREMOVE | PM_NOYIELD ) )
                 return true;
 
-            if ( ImplPeekMessage( &aMsg, 0, SAL_MSG_POSTMOVE, SAL_MSG_POSTMOVE,
+            if ( PeekMessageW( &aMsg, 0, SAL_MSG_POSTMOVE, SAL_MSG_POSTMOVE,
                                   PM_NOREMOVE | PM_NOYIELD ) )
                 return true;
         }
 
-        if ( nType & VCL_INPUT_TIMER )
+        if ( nType & VclInputFlags::TIMER )
         {
             // Test for timer input
-            if ( ImplPeekMessage( &aMsg, 0, WM_TIMER, WM_TIMER,
+            if ( PeekMessageW( &aMsg, 0, WM_TIMER, WM_TIMER,
                                   PM_NOREMOVE | PM_NOYIELD ) )
                 return true;
 
         }
 
-        if ( nType & VCL_INPUT_OTHER )
+        if ( nType & VclInputFlags::OTHER )
         {
             // Test for any input
-            if ( ImplPeekMessage( &aMsg, 0, 0, 0, PM_NOREMOVE | PM_NOYIELD ) )
+            if ( PeekMessageW( &aMsg, 0, 0, 0, PM_NOREMOVE | PM_NOYIELD ) )
                 return true;
         }
     }
 
-    return FALSE;
+    return false;
 }
 
-// -----------------------------------------------------------------------
-
 void SalTimer::Start( sal_uLong nMS )
 {
     // to switch to Main-Thread
@@ -964,25 +878,21 @@ void SalTimer::Start( sal_uLong nMS )
     if ( pSalData->mpFirstInstance )
     {
         if ( pSalData->mnAppThreadId != GetCurrentThreadId() )
-            ImplPostMessage( pSalData->mpFirstInstance->mhComWnd, SAL_MSG_STARTTIMER, 0, (LPARAM)nMS );
+            PostMessageW( pSalData->mpFirstInstance->mhComWnd, SAL_MSG_STARTTIMER, 0, (LPARAM)nMS );
         else
-            ImplSendMessage( pSalData->mpFirstInstance->mhComWnd, SAL_MSG_STARTTIMER, 0, (LPARAM)nMS );
+            SendMessageW( pSalData->mpFirstInstance->mhComWnd, SAL_MSG_STARTTIMER, 0, (LPARAM)nMS );
     }
     else
         ImplSalStartTimer( nMS, FALSE );
 }
 
-// -----------------------------------------------------------------------
-
-SalFrame* WinSalInstance::CreateChildFrame( SystemParentData* pSystemParentData, sal_uLong nSalFrameStyle )
+SalFrame* WinSalInstance::CreateChildFrame( SystemParentData* pSystemParentData, SalFrameStyleFlags nSalFrameStyle )
 {
     // to switch to Main-Thread
-    return (SalFrame*)(sal_IntPtr)ImplSendMessage( mhComWnd, SAL_MSG_CREATEFRAME, nSalFrameStyle, (LPARAM)pSystemParentData->hWnd );
+    return (SalFrame*)(sal_IntPtr)SendMessageW( mhComWnd, SAL_MSG_CREATEFRAME, static_cast<WPARAM>(nSalFrameStyle), (LPARAM)pSystemParentData->hWnd );
 }
 
-// -----------------------------------------------------------------------
-
-SalFrame* WinSalInstance::CreateFrame( SalFrame* pParent, sal_uLong nSalFrameStyle )
+SalFrame* WinSalInstance::CreateFrame( SalFrame* pParent, SalFrameStyleFlags nSalFrameStyle )
 {
     // to switch to Main-Thread
     HWND hWndParent;
@@ -990,35 +900,28 @@ SalFrame* WinSalInstance::CreateFrame( SalFrame* pParent, sal_uLong nSalFrameSty
         hWndParent = static_cast<WinSalFrame*>(pParent)->mhWnd;
     else
         hWndParent = 0;
-    return (SalFrame*)(sal_IntPtr)ImplSendMessage( mhComWnd, SAL_MSG_CREATEFRAME, nSalFrameStyle, (LPARAM)hWndParent );
+    return (SalFrame*)(sal_IntPtr)SendMessageW( mhComWnd, SAL_MSG_CREATEFRAME, static_cast<WPARAM>(nSalFrameStyle), (LPARAM)hWndParent );
 }
 
-// -----------------------------------------------------------------------
-
 void WinSalInstance::DestroyFrame( SalFrame* pFrame )
 {
-    ImplSendMessage( mhComWnd, SAL_MSG_DESTROYFRAME, 0, (LPARAM)pFrame );
+    OpenGLContext::prepareForYield();
+    SendMessageW( mhComWnd, SAL_MSG_DESTROYFRAME, 0, (LPARAM)pFrame );
 }
 
-// -----------------------------------------------------------------------
-
 SalObject* WinSalInstance::CreateObject( SalFrame* pParent,
                                          SystemWindowData* /*pWindowData*/, // SystemWindowData meaningless on Windows
-                                         sal_Bool /*bShow*/ )
+                                         bool /*bShow*/ )
 {
     // to switch to Main-Thread
-    return (SalObject*)(sal_IntPtr)ImplSendMessage( mhComWnd, SAL_MSG_CREATEOBJECT, 0, (LPARAM)static_cast<WinSalFrame*>(pParent) );
+    return (SalObject*)(sal_IntPtr)SendMessageW( mhComWnd, SAL_MSG_CREATEOBJECT, 0, (LPARAM)static_cast<WinSalFrame*>(pParent) );
 }
 
-// -----------------------------------------------------------------------
-
 void WinSalInstance::DestroyObject( SalObject* pObject )
 {
-    ImplSendMessage( mhComWnd, SAL_MSG_DESTROYOBJECT, 0, (LPARAM)pObject );
+    SendMessageW( mhComWnd, SAL_MSG_DESTROYOBJECT, 0, (LPARAM)pObject );
 }
 
-// -----------------------------------------------------------------------
-
 void* WinSalInstance::GetConnectionIdentifier( ConnectionIdentifierType& rReturnedType, int& rReturnedBytes )
 {
     rReturnedBytes  = 1;
@@ -1026,8 +929,6 @@ void* WinSalInstance::GetConnectionIdentifier( ConnectionIdentifierType& rReturn
     return const_cast<char *>("");
 }
 
-// -----------------------------------------------------------------------
-
 /** Add a file to the system shells recent document list if there is any.
       This function may have no effect under Unix because there is no
       standard API among the different desktop managers.
@@ -1088,6 +989,11 @@ void WinSalInstance::AddToRecentDocumentList(const OUString& rFileUrl, const OUS
                         OUString sApplicationID("TheDocumentFoundation.LibreOffice.");
                         sApplicationID += sApplicationName;
 
+#if _WIN32_WINNT < _WIN32_WINNT_WIN7
+// just define Windows 7 only constant locally...
+#define SHARD_APPIDINFO  0x00000004
+#endif
+
                         typedef struct {
                             IShellItem *psi;
                             PCWSTR     pszAppID;
@@ -1108,18 +1014,17 @@ void WinSalInstance::AddToRecentDocumentList(const OUString& rFileUrl, const OUS
     }
 }
 
-// -----------------------------------------------------------------------
-
 SalTimer* WinSalInstance::CreateSalTimer()
 {
     return new WinSalTimer();
 }
 
-// -----------------------------------------------------------------------
-
 SalBitmap* WinSalInstance::CreateSalBitmap()
 {
-    return new WinSalBitmap();
+    if (OpenGLHelper::isVCLOpenGLEnabled())
+        return new OpenGLSalBitmap();
+    else
+        return new WinSalBitmap();
 }
 
 class WinImeStatus : public SalI18NImeStatus
@@ -1139,8 +1044,6 @@ SalI18NImeStatus* WinSalInstance::CreateI18NImeStatus()
     return new WinImeStatus();
 }
 
-// -----------------------------------------------------------------------
-
 const OUString& SalGetDesktopEnvironment()
 {
     static OUString aDesktopEnvironment( "Windows" );
@@ -1153,7 +1056,7 @@ SalSession* WinSalInstance::CreateSalSession()
 }
 
 #if !defined ( __MINGW32__ ) || defined ( _WIN64 )
-// -----------------------------------------------------------------------
+
 int WinSalInstance::WorkaroundExceptionHandlingInUSER32Lib(int, LPEXCEPTION_POINTERS pExceptionInfo)
 {
     // Decide if an exception is a c++ (mostly UNO) exception or a process violation.
@@ -1162,7 +1065,7 @@ int WinSalInstance::WorkaroundExceptionHandlingInUSER32Lib(int, LPEXCEPTION_POIN
     // Problem behind: user32.dll sometime consumes exceptions/process violations .-)
     // see also #112221#
 
-    static DWORD EXCEPTION_MSC_CPP_EXCEPTION = 0xE06D7363;
+    static const DWORD EXCEPTION_MSC_CPP_EXCEPTION = 0xE06D7363;
 
     if (pExceptionInfo->ExceptionRecord->ExceptionCode == EXCEPTION_MSC_CPP_EXCEPTION)
         return EXCEPTION_CONTINUE_SEARCH;
@@ -1171,4 +1074,40 @@ int WinSalInstance::WorkaroundExceptionHandlingInUSER32Lib(int, LPEXCEPTION_POIN
 }
 #endif
 
+OUString WinSalInstance::getOSVersion()
+{
+    SalData* pSalData = GetSalData();
+    if ( !pSalData )
+        return OUString("unknown");
+
+    WORD nMajor = 0, nMinor = 0;
+#ifdef _WIN32_WINNT_WINBLUE
+    // Trying to hide the real version info behind an
+    // uber-lame non-forward-compatible, 'compatibility' API
+    // seems unlikely to help OS designers, or API users.
+    nMajor = 30;
+    while( !IsWindowsVersionOrGreater( nMajor, 0, 0 ) && nMajor > 0)
+        nMajor--;
+    nMinor = 30;
+    while( !IsWindowsVersionOrGreater( nMajor, nMinor, 0 ) && nMinor > 0)
+        nMinor--;
+#else
+    OSVERSIONINFO aVersionInfo;
+    memset( &aVersionInfo, 0, sizeof( aVersionInfo ) );
+    aVersionInfo.dwOSVersionInfoSize = sizeof( aVersionInfo );
+    if ( GetVersionEx( &aVersionInfo ) )
+    {
+        nMajor = aVersionInfo.dwMajorVersion;
+        nMinor = aVersionInfo.dwMinorVersion;
+    }
+#endif
+    OUStringBuffer aVer;
+    aVer.append( "Windows " );
+    aVer.append( (sal_Int32)nMajor );
+    aVer.append( "." );
+    aVer.append( (sal_Int32)nMinor );
+
+    return aVer.makeStringAndClear();
+}
+
 /* vim:set shiftwidth=4 softtabstop=4 expandtab: */
