@@ -20,14 +20,14 @@
 // General info:
 //   http://msdn.microsoft.com/en-us/library/windows/desktop/hh270423%28v=vs.85%29.aspx
 //   http://msdn.microsoft.com/en-us/library/windows/desktop/bb773178%28v=vs.85%29.aspx
-//
+
 // Useful tool to explore the themes & their rendering:
 //   http://privat.rejbrand.se/UxExplore.exe
 // (found at http://stackoverflow.com/questions/4009701/windows-visual-themes-gallery-of-parts-and-states/4009712#4009712)
-//
+
 // Theme subclasses:
 //   http://msdn.microsoft.com/en-us/library/windows/desktop/bb773218%28v=vs.85%29.aspx
-//
+
 // Drawing in non-client area (general DWM-related info):
 //   http://msdn.microsoft.com/en-us/library/windows/desktop/bb688195%28v=vs.85%29.aspx
 
@@ -35,7 +35,9 @@
 
 #include "osl/module.h"
 
+#include <opengl/win/gdiimpl.hxx>
 #include "vcl/svapp.hxx"
+#include <vcl/settings.hxx>
 
 #include "win/svsys.h"
 #include "win/salgdi.h"
@@ -46,14 +48,13 @@
 
 #include <map>
 #include <string>
+#include <boost/optional.hpp>
 
 using namespace std;
 
-
 typedef map< wstring, HTHEME > ThemeMap;
 static ThemeMap aThemeMap;
 
-
 /****************************************************
  wrap visual styles API to avoid linking against it
  it is not available on all Windows platforms
@@ -83,7 +84,7 @@ private:
 public:
     VisualStylesAPI();
     ~VisualStylesAPI();
-    sal_Bool IsAvailable()  { return (mhModule != NULL); }
+    bool IsAvailable()  { return (mhModule != NULL); }
 
     HTHEME OpenThemeData( HWND hwnd, LPCWSTR pszClassList );
     HRESULT CloseThemeData( HTHEME hTheme );
@@ -91,7 +92,7 @@ public:
     HRESULT DrawThemeBackground( HTHEME hTheme, HDC hdc, int iPartId, int iStateId, const RECT *pRect, const RECT *pClipRect );
     HRESULT DrawThemeText( HTHEME hTheme, HDC hdc, int iPartId, int iStateId, LPCWSTR pszText, int iCharCount, DWORD dwTextFlags, DWORD dwTextFlags2, const RECT *pRect );
     HRESULT GetThemePartSize( HTHEME hTheme, HDC hdc, int iPartId, int iStateId, RECT *prc, THEMESIZE eSize, SIZE *psz );
-    BOOL IsThemeActive( void );
+    BOOL IsThemeActive();
 };
 
 static VisualStylesAPI vsAPI;
@@ -174,7 +175,7 @@ HRESULT VisualStylesAPI::GetThemePartSize( HTHEME hTheme, HDC hdc, int iPartId,
         return S_FALSE;
 }
 
-BOOL VisualStylesAPI::IsThemeActive( void )
+BOOL VisualStylesAPI::IsThemeActive()
 {
     if(lpfnIsThemeActive)
         return (*lpfnIsThemeActive) ();
@@ -185,7 +186,7 @@ BOOL VisualStylesAPI::IsThemeActive( void )
 /*********************************************************
  * Initialize XP theming and local stuff
  *********************************************************/
-void SalData::initNWF( void )
+void SalData::initNWF()
 {
     ImplSVData* pSVData = ImplGetSVData();
 
@@ -193,11 +194,10 @@ void SalData::initNWF( void )
     pSVData->maNWFData.mbMenuBarDockingAreaCommonBG = true;
 }
 
-
 // *********************************************************
 // * Release theming handles
 // ********************************************************
-void SalData::deInitNWF( void )
+void SalData::deInitNWF()
 {
     ThemeMap::iterator iter = aThemeMap.begin();
     while( iter != aThemeMap.end() )
@@ -235,7 +235,7 @@ static HTHEME getThemeHandle( HWND hWnd, LPCWSTR name )
  *  Returns TRUE if the platform supports native
  *  drawing of the control defined by nPart
  */
-sal_Bool WinSalGraphics::IsNativeControlSupported( ControlType nType, ControlPart nPart )
+bool WinSalGraphics::IsNativeControlSupported( ControlType nType, ControlPart nPart )
 {
     HTHEME hTheme = NULL;
 
@@ -342,7 +342,6 @@ sal_Bool WinSalGraphics::IsNativeControlSupported( ControlType nType, ControlPar
     return (hTheme != NULL);
 }
 
-
 /*
  * HitTestNativeControl()
  *
@@ -350,16 +349,16 @@ sal_Bool WinSalGraphics::IsNativeControlSupported( ControlType nType, ControlPar
  *  aPos was or was not inside the native widget specified by the
  *  nType/nPart combination.
  */
-sal_Bool WinSalGraphics::hitTestNativeControl( ControlType,
+bool WinSalGraphics::hitTestNativeControl( ControlType,
                               ControlPart,
                               const Rectangle&,
                               const Point&,
-                              sal_Bool& )
+                              bool& )
 {
     return FALSE;
 }
 
-sal_Bool ImplDrawTheme( HTHEME hTheme, HDC hDC, int iPart, int iState, RECT rc, const OUString& aStr)
+bool ImplDrawTheme( HTHEME hTheme, HDC hDC, int iPart, int iState, RECT rc, const OUString& aStr)
 {
     HRESULT hr = vsAPI.DrawThemeBackground( hTheme, hDC, iPart, iState, &rc, 0);
 
@@ -375,7 +374,6 @@ sal_Bool ImplDrawTheme( HTHEME hTheme, HDC hDC, int iPart, int iState, RECT rc,
     return (hr == S_OK);
 }
 
-
 Rectangle ImplGetThemeRect( HTHEME hTheme, HDC hDC, int iPart, int iState, const Rectangle& /* aRect */, THEMESIZE eTS = TS_TRUE )
 {
     SIZE aSz;
@@ -387,7 +385,6 @@ Rectangle ImplGetThemeRect( HTHEME hTheme, HDC hDC, int iPart, int iState, const
 }
 
 // Helper functions
-// ----
 
 void ImplConvertSpinbuttonValues( int nControlPart, const ControlState& rState, const Rectangle& rRect,
                                  int* pLunaPart, int *pLunaState, RECT *pRect )
@@ -395,11 +392,11 @@ void ImplConvertSpinbuttonValues( int nControlPart, const ControlState& rState,
     if( nControlPart == PART_BUTTON_DOWN )
     {
         *pLunaPart = SPNP_DOWN;
-        if( rState & CTRL_STATE_PRESSED )
+        if( rState & ControlState::PRESSED )
             *pLunaState = DNS_PRESSED;
-        else if( !(rState & CTRL_STATE_ENABLED) )
+        else if( !(rState & ControlState::ENABLED) )
             *pLunaState = DNS_DISABLED;
-        else if( rState & CTRL_STATE_ROLLOVER )
+        else if( rState & ControlState::ROLLOVER )
             *pLunaState = DNS_HOT;
         else
             *pLunaState = DNS_NORMAL;
@@ -407,11 +404,11 @@ void ImplConvertSpinbuttonValues( int nControlPart, const ControlState& rState,
     if( nControlPart == PART_BUTTON_UP )
     {
         *pLunaPart = SPNP_UP;
-        if( rState & CTRL_STATE_PRESSED )
+        if( rState & ControlState::PRESSED )
             *pLunaState = UPS_PRESSED;
-        else if( !(rState & CTRL_STATE_ENABLED) )
+        else if( !(rState & ControlState::ENABLED) )
             *pLunaState = UPS_DISABLED;
-        else if( rState & CTRL_STATE_ROLLOVER )
+        else if( rState & ControlState::ROLLOVER )
             *pLunaState = UPS_HOT;
         else
             *pLunaState = UPS_NORMAL;
@@ -419,11 +416,11 @@ void ImplConvertSpinbuttonValues( int nControlPart, const ControlState& rState,
     if( nControlPart == PART_BUTTON_RIGHT )
     {
         *pLunaPart = SPNP_UPHORZ;
-        if( rState & CTRL_STATE_PRESSED )
+        if( rState & ControlState::PRESSED )
             *pLunaState = DNHZS_PRESSED;
-        else if( !(rState & CTRL_STATE_ENABLED) )
+        else if( !(rState & ControlState::ENABLED) )
             *pLunaState = DNHZS_DISABLED;
-        else if( rState & CTRL_STATE_ROLLOVER )
+        else if( rState & ControlState::ROLLOVER )
             *pLunaState = DNHZS_HOT;
         else
             *pLunaState = DNHZS_NORMAL;
@@ -431,11 +428,11 @@ void ImplConvertSpinbuttonValues( int nControlPart, const ControlState& rState,
     if( nControlPart == PART_BUTTON_LEFT )
     {
         *pLunaPart = SPNP_DOWNHORZ;
-        if( rState & CTRL_STATE_PRESSED )
+        if( rState & ControlState::PRESSED )
             *pLunaState = UPHZS_PRESSED;
-        else if( !(rState & CTRL_STATE_ENABLED) )
+        else if( !(rState & ControlState::ENABLED) )
             *pLunaState = UPHZS_DISABLED;
-        else if( rState & CTRL_STATE_ROLLOVER )
+        else if( rState & ControlState::ROLLOVER )
             *pLunaState = UPHZS_HOT;
         else
             *pLunaState = UPHZS_NORMAL;
@@ -478,13 +475,14 @@ static void impl_drawAeroToolbar( HDC hDC, RECT rc, bool bHorizontal )
         GradientFill( hDC, vert, 2, g_rect, 1, GRADIENT_FILL_RECT_V );
 
         // and a darker horizontal line under that
-        HPEN hpen = CreatePen( PS_SOLID, 1, RGB( 0xa0, 0xa0, 0xa0 ) );
-        SelectObject( hDC, hpen );
+        HPEN hpen = CreatePen( PS_SOLID, 1, RGB( 0xb0, 0xb0, 0xb0 ) );
+        HPEN hOrigPen = (HPEN) SelectObject(hDC, hpen);
 
         MoveToEx( hDC, rc.left, gradient_bottom, NULL );
         LineTo( hDC, rc.right, gradient_bottom );
 
-        DeleteObject( hpen );
+        SelectObject(hDC, hOrigPen);
+        DeleteObject(hpen);
     }
     else
     {
@@ -503,18 +501,19 @@ static void impl_drawAeroToolbar( HDC hDC, RECT rc, bool bHorizontal )
             to_x = rc.right;
             from_y = to_y = rc.top;
 
-            HPEN hpen = CreatePen( PS_SOLID, 1, RGB( 0xa0, 0xa0, 0xa0 ) );
-            SelectObject( hDC, hpen );
+            HPEN hpen = CreatePen( PS_SOLID, 1, RGB( 0xb0, 0xb0, 0xb0 ) );
+            HPEN hOrigPen = (HPEN) SelectObject(hDC, hpen);
 
             MoveToEx( hDC, from_x, from_y, NULL );
             LineTo( hDC, to_x, to_y );
 
-            DeleteObject( hpen );
+            SelectObject(hDC, hOrigPen);
+            DeleteObject(hpen);
         }
     }
 }
 
-sal_Bool ImplDrawNativeControl( HDC hDC, HTHEME hTheme, RECT rc,
+bool ImplDrawNativeControl( HDC hDC, HTHEME hTheme, RECT rc,
                             ControlType nType,
                             ControlPart nPart,
                             ControlState nState,
@@ -543,11 +542,11 @@ sal_Bool ImplDrawNativeControl( HDC hDC, HTHEME hTheme, RECT rc,
         if( nPart == PART_BUTTON_UP )
         {
             iPart = SBP_ARROWBTN;
-            if( nState & CTRL_STATE_PRESSED )
+            if( nState & ControlState::PRESSED )
                 iState = ABS_UPPRESSED;
-            else if( !(nState & CTRL_STATE_ENABLED) )
+            else if( !(nState & ControlState::ENABLED) )
                 iState = ABS_UPDISABLED;
-            else if( nState & CTRL_STATE_ROLLOVER )
+            else if( nState & ControlState::ROLLOVER )
                 iState = ABS_UPHOT;
             else
                 iState = ABS_UPNORMAL;
@@ -557,11 +556,11 @@ sal_Bool ImplDrawNativeControl( HDC hDC, HTHEME hTheme, RECT rc,
         if( nPart == PART_BUTTON_DOWN )
         {
             iPart = SBP_ARROWBTN;
-            if( nState & CTRL_STATE_PRESSED )
+            if( nState & ControlState::PRESSED )
                 iState = ABS_DOWNPRESSED;
-            else if( !(nState & CTRL_STATE_ENABLED) )
+            else if( !(nState & ControlState::ENABLED) )
                 iState = ABS_DOWNDISABLED;
-            else if( nState & CTRL_STATE_ROLLOVER )
+            else if( nState & ControlState::ROLLOVER )
                 iState = ABS_DOWNHOT;
             else
                 iState = ABS_DOWNNORMAL;
@@ -571,11 +570,11 @@ sal_Bool ImplDrawNativeControl( HDC hDC, HTHEME hTheme, RECT rc,
         if( nPart == PART_BUTTON_LEFT )
         {
             iPart = SBP_ARROWBTN;
-            if( nState & CTRL_STATE_PRESSED )
+            if( nState & ControlState::PRESSED )
                 iState = ABS_LEFTPRESSED;
-            else if( !(nState & CTRL_STATE_ENABLED) )
+            else if( !(nState & ControlState::ENABLED) )
                 iState = ABS_LEFTDISABLED;
-            else if( nState & CTRL_STATE_ROLLOVER )
+            else if( nState & ControlState::ROLLOVER )
                 iState = ABS_LEFTHOT;
             else
                 iState = ABS_LEFTNORMAL;
@@ -585,11 +584,11 @@ sal_Bool ImplDrawNativeControl( HDC hDC, HTHEME hTheme, RECT rc,
         if( nPart == PART_BUTTON_RIGHT )
         {
             iPart = SBP_ARROWBTN;
-            if( nState & CTRL_STATE_PRESSED )
+            if( nState & ControlState::PRESSED )
                 iState = ABS_RIGHTPRESSED;
-            else if( !(nState & CTRL_STATE_ENABLED) )
+            else if( !(nState & ControlState::ENABLED) )
                 iState = ABS_RIGHTDISABLED;
-            else if( nState & CTRL_STATE_ROLLOVER )
+            else if( nState & ControlState::ROLLOVER )
                 iState = ABS_RIGHTHOT;
             else
                 iState = ABS_RIGHTNORMAL;
@@ -599,11 +598,11 @@ sal_Bool ImplDrawNativeControl( HDC hDC, HTHEME hTheme, RECT rc,
         if( nPart == PART_THUMB_HORZ || nPart == PART_THUMB_VERT )
         {
             iPart = (nPart == PART_THUMB_HORZ) ? SBP_THUMBBTNHORZ : SBP_THUMBBTNVERT;
-            if( nState & CTRL_STATE_PRESSED )
+            if( nState & ControlState::PRESSED )
                 iState = SCRBS_PRESSED;
-            else if( !(nState & CTRL_STATE_ENABLED) )
+            else if( !(nState & ControlState::ENABLED) )
                 iState = SCRBS_DISABLED;
-            else if( nState & CTRL_STATE_ROLLOVER )
+            else if( nState & ControlState::ROLLOVER )
                 iState = SCRBS_HOT;
             else
                 iState = SCRBS_NORMAL;
@@ -634,11 +633,11 @@ sal_Bool ImplDrawNativeControl( HDC hDC, HTHEME hTheme, RECT rc,
                 case PART_TRACK_VERT_LOWER: iPart = SBP_LOWERTRACKVERT; break;
             }
 
-            if( nState & CTRL_STATE_PRESSED )
+            if( nState & ControlState::PRESSED )
                 iState = SCRBS_PRESSED;
-            else if( !(nState & CTRL_STATE_ENABLED) )
+            else if( !(nState & ControlState::ENABLED) )
                 iState = SCRBS_DISABLED;
-            else if( nState & CTRL_STATE_ROLLOVER )
+            else if( nState & ControlState::ROLLOVER )
                 iState = SCRBS_HOT;
             else
                 iState = SCRBS_NORMAL;
@@ -651,11 +650,10 @@ sal_Bool ImplDrawNativeControl( HDC hDC, HTHEME hTheme, RECT rc,
         if( aValue.getType() == CTRL_SPINBUTTONS )
         {
             const SpinbuttonValue* pValue = (aValue.getType() == CTRL_SPINBUTTONS) ? static_cast<const SpinbuttonValue*>(&aValue) : NULL;
-            sal_Bool bOk = sal_False;
 
             RECT rect;
             ImplConvertSpinbuttonValues( pValue->mnUpperPart, pValue->mnUpperState, pValue->maUpperRect, &iPart, &iState, &rect );
-            bOk = ImplDrawTheme( hTheme, hDC, iPart, iState, rect, aCaption);
+            bool bOk = ImplDrawTheme( hTheme, hDC, iPart, iState, rect, aCaption);
 
             if( bOk )
             {
@@ -676,11 +674,10 @@ sal_Bool ImplDrawNativeControl( HDC hDC, HTHEME hTheme, RECT rc,
             if( aValue.getType() == CTRL_SPINBUTTONS )
             {
                 const SpinbuttonValue *pValue = static_cast<const SpinbuttonValue*>(&aValue);
-                sal_Bool bOk = sal_False;
 
                 RECT rect;
                 ImplConvertSpinbuttonValues( pValue->mnUpperPart, pValue->mnUpperState, pValue->maUpperRect, &iPart, &iState, &rect );
-                bOk = ImplDrawTheme( hTheme, hDC, iPart, iState, rect, aCaption);
+                bool bOk = ImplDrawTheme( hTheme, hDC, iPart, iState, rect, aCaption);
 
                 if( bOk )
                 {
@@ -695,11 +692,11 @@ sal_Bool ImplDrawNativeControl( HDC hDC, HTHEME hTheme, RECT rc,
         if( nPart == PART_BUTTON_DOWN )
         {
             iPart = SPNP_DOWN;
-            if( nState & CTRL_STATE_PRESSED )
+            if( nState & ControlState::PRESSED )
                 iState = DNS_PRESSED;
-            else if( !(nState & CTRL_STATE_ENABLED) )
+            else if( !(nState & ControlState::ENABLED) )
                 iState = DNS_DISABLED;
-            else if( nState & CTRL_STATE_ROLLOVER )
+            else if( nState & ControlState::ROLLOVER )
                 iState = DNS_HOT;
             else
                 iState = DNS_NORMAL;
@@ -707,11 +704,11 @@ sal_Bool ImplDrawNativeControl( HDC hDC, HTHEME hTheme, RECT rc,
         if( nPart == PART_BUTTON_UP )
         {
             iPart = SPNP_UP;
-            if( nState & CTRL_STATE_PRESSED )
+            if( nState & ControlState::PRESSED )
                 iState = UPS_PRESSED;
-            else if( !(nState & CTRL_STATE_ENABLED) )
+            else if( !(nState & ControlState::ENABLED) )
                 iState = UPS_DISABLED;
-            else if( nState & CTRL_STATE_ROLLOVER )
+            else if( nState & ControlState::ROLLOVER )
                 iState = UPS_HOT;
             else
                 iState = UPS_NORMAL;
@@ -719,11 +716,11 @@ sal_Bool ImplDrawNativeControl( HDC hDC, HTHEME hTheme, RECT rc,
         if( nPart == PART_BUTTON_RIGHT )
         {
             iPart = SPNP_DOWNHORZ;
-            if( nState & CTRL_STATE_PRESSED )
+            if( nState & ControlState::PRESSED )
                 iState = DNHZS_PRESSED;
-            else if( !(nState & CTRL_STATE_ENABLED) )
+            else if( !(nState & ControlState::ENABLED) )
                 iState = DNHZS_DISABLED;
-            else if( nState & CTRL_STATE_ROLLOVER )
+            else if( nState & ControlState::ROLLOVER )
                 iState = DNHZS_HOT;
             else
                 iState = DNHZS_NORMAL;
@@ -731,11 +728,11 @@ sal_Bool ImplDrawNativeControl( HDC hDC, HTHEME hTheme, RECT rc,
         if( nPart == PART_BUTTON_LEFT )
         {
             iPart = SPNP_UPHORZ;
-            if( nState & CTRL_STATE_PRESSED )
+            if( nState & ControlState::PRESSED )
                 iState = UPHZS_PRESSED;
-            else if( !(nState & CTRL_STATE_ENABLED) )
+            else if( !(nState & ControlState::ENABLED) )
                 iState = UPHZS_DISABLED;
-            else if( nState & CTRL_STATE_ROLLOVER )
+            else if( nState & ControlState::ROLLOVER )
                 iState = UPHZS_HOT;
             else
                 iState = UPHZS_NORMAL;
@@ -748,11 +745,11 @@ sal_Bool ImplDrawNativeControl( HDC hDC, HTHEME hTheme, RECT rc,
         if( nPart == PART_BUTTON_DOWN )
         {
             iPart = CP_DROPDOWNBUTTON;
-            if( nState & CTRL_STATE_PRESSED )
+            if( nState & ControlState::PRESSED )
                 iState = CBXS_PRESSED;
-            else if( !(nState & CTRL_STATE_ENABLED) )
+            else if( !(nState & ControlState::ENABLED) )
                 iState = CBXS_DISABLED;
-            else if( nState & CTRL_STATE_ROLLOVER )
+            else if( nState & ControlState::ROLLOVER )
                 iState = CBXS_HOT;
             else
                 iState = CBXS_NORMAL;
@@ -762,15 +759,15 @@ sal_Bool ImplDrawNativeControl( HDC hDC, HTHEME hTheme, RECT rc,
     if( nType == CTRL_PUSHBUTTON )
     {
         iPart = BP_PUSHBUTTON;
-        if( nState & CTRL_STATE_PRESSED )
+        if( nState & ControlState::PRESSED )
             iState = PBS_PRESSED;
-        else if( !(nState & CTRL_STATE_ENABLED) )
+        else if( !(nState & ControlState::ENABLED) )
             iState = PBS_DISABLED;
-        else if( nState & CTRL_STATE_ROLLOVER )
+        else if( nState & ControlState::ROLLOVER )
             iState = PBS_HOT;
-        else if( nState & CTRL_STATE_DEFAULT )
+        else if( nState & ControlState::DEFAULT )
             iState = PBS_DEFAULTED;
-        //else if( nState & CTRL_STATE_FOCUSED )
+        //else if( nState & ControlState::FOCUSED )
         //    iState = PBS_DEFAULTED;    // may need to draw focus rect
         else
             iState = PBS_NORMAL;
@@ -781,18 +778,18 @@ sal_Bool ImplDrawNativeControl( HDC hDC, HTHEME hTheme, RECT rc,
     if( nType == CTRL_RADIOBUTTON )
     {
         iPart = BP_RADIOBUTTON;
-        sal_Bool bChecked = ( aValue.getTristateVal() == BUTTONVALUE_ON );
+        bool bChecked = ( aValue.getTristateVal() == BUTTONVALUE_ON );
 
-        if( nState & CTRL_STATE_PRESSED )
+        if( nState & ControlState::PRESSED )
             iState = bChecked ? RBS_CHECKEDPRESSED : RBS_UNCHECKEDPRESSED;
-        else if( !(nState & CTRL_STATE_ENABLED) )
+        else if( !(nState & ControlState::ENABLED) )
             iState = bChecked ? RBS_CHECKEDDISABLED : RBS_UNCHECKEDDISABLED;
-        else if( nState & CTRL_STATE_ROLLOVER )
+        else if( nState & ControlState::ROLLOVER )
             iState = bChecked ? RBS_CHECKEDHOT : RBS_UNCHECKEDHOT;
         else
             iState = bChecked ? RBS_CHECKEDNORMAL : RBS_UNCHECKEDNORMAL;
 
-        //if( nState & CTRL_STATE_FOCUSED )
+        //if( nState & ControlState::FOCUSED )
         //    iState |= PBS_DEFAULTED;    // may need to draw focus rect
 
         return ImplDrawTheme( hTheme, hDC, iPart, iState, rc, aCaption);
@@ -803,20 +800,20 @@ sal_Bool ImplDrawNativeControl( HDC hDC, HTHEME hTheme, RECT rc,
         iPart = BP_CHECKBOX;
         ButtonValue v = aValue.getTristateVal();
 
-        if( nState & CTRL_STATE_PRESSED )
+        if( nState & ControlState::PRESSED )
             iState = (v == BUTTONVALUE_ON)  ? CBS_CHECKEDPRESSED :
                     ( (v == BUTTONVALUE_OFF) ? CBS_UNCHECKEDPRESSED : CBS_MIXEDPRESSED );
-        else if( !(nState & CTRL_STATE_ENABLED) )
+        else if( !(nState & ControlState::ENABLED) )
             iState = (v == BUTTONVALUE_ON)  ? CBS_CHECKEDDISABLED :
                     ( (v == BUTTONVALUE_OFF) ? CBS_UNCHECKEDDISABLED : CBS_MIXEDDISABLED );
-        else if( nState & CTRL_STATE_ROLLOVER )
+        else if( nState & ControlState::ROLLOVER )
             iState = (v == BUTTONVALUE_ON)  ? CBS_CHECKEDHOT :
                     ( (v == BUTTONVALUE_OFF) ? CBS_UNCHECKEDHOT : CBS_MIXEDHOT );
         else
             iState = (v == BUTTONVALUE_ON)  ? CBS_CHECKEDNORMAL :
                     ( (v == BUTTONVALUE_OFF) ? CBS_UNCHECKEDNORMAL : CBS_MIXEDNORMAL );
 
-        //if( nState & CTRL_STATE_FOCUSED )
+        //if( nState & ControlState::FOCUSED )
         //    iState |= PBS_DEFAULTED;    // may need to draw focus rect
 
         //SIZE sz;
@@ -829,11 +826,11 @@ sal_Bool ImplDrawNativeControl( HDC hDC, HTHEME hTheme, RECT rc,
     if( ( nType == CTRL_EDITBOX ) || ( nType == CTRL_MULTILINE_EDITBOX ) )
     {
         iPart = EP_EDITTEXT;
-        if( !(nState & CTRL_STATE_ENABLED) )
+        if( !(nState & ControlState::ENABLED) )
             iState = ETS_DISABLED;
-        else if( nState & CTRL_STATE_FOCUSED )
+        else if( nState & ControlState::FOCUSED )
             iState = ETS_FOCUSED;
-        else if( nState & CTRL_STATE_ROLLOVER )
+        else if( nState & ControlState::ROLLOVER )
             iState = ETS_HOT;
         else
             iState = ETS_NORMAL;
@@ -881,9 +878,9 @@ sal_Bool ImplDrawNativeControl( HDC hDC, HTHEME hTheme, RECT rc,
             iPart = TABP_TABITEMRIGHTEDGE;
         else iPart = TABP_TABITEM;
 
-        if( !(nState & CTRL_STATE_ENABLED) )
+        if( !(nState & ControlState::ENABLED) )
             iState = TILES_DISABLED;
-        else if( nState & CTRL_STATE_SELECTED )
+        else if( nState & ControlState::SELECTED )
         {
             iState = TILES_SELECTED;
             // increase the selected tab
@@ -898,9 +895,9 @@ sal_Bool ImplDrawNativeControl( HDC hDC, HTHEME hTheme, RECT rc,
             rc.top-=2;
             rc.bottom+=2;
         }
-        else if( nState & CTRL_STATE_ROLLOVER )
+        else if( nState & ControlState::ROLLOVER )
             iState = TILES_HOT;
-        else if( nState & CTRL_STATE_FOCUSED )
+        else if( nState & ControlState::FOCUSED )
             iState = TILES_FOCUSED;    // may need to draw focus rect
         else
             iState = TILES_NORMAL;
@@ -912,15 +909,15 @@ sal_Bool ImplDrawNativeControl( HDC hDC, HTHEME hTheme, RECT rc,
         if( nPart == PART_BUTTON )
         {
             iPart = TP_BUTTON;
-            sal_Bool bChecked = ( aValue.getTristateVal() == BUTTONVALUE_ON );
-            if( !(nState & CTRL_STATE_ENABLED) )
+            bool bChecked = ( aValue.getTristateVal() == BUTTONVALUE_ON );
+            if( !(nState & ControlState::ENABLED) )
                 //iState = TS_DISABLED;
                 // disabled buttons are typically not painted at all but we need visual
                 // feedback when travelling by keyboard over disabled entries
                 iState = TS_HOT;
-            else if( nState & CTRL_STATE_PRESSED )
+            else if( nState & ControlState::PRESSED )
                 iState = TS_PRESSED;
-            else if( nState & CTRL_STATE_ROLLOVER )
+            else if( nState & ControlState::ROLLOVER )
                 iState = bChecked ? TS_HOTCHECKED : TS_HOT;
             else
                 iState = bChecked ? TS_CHECKED : TS_NORMAL;
@@ -946,7 +943,7 @@ sal_Bool ImplDrawNativeControl( HDC hDC, HTHEME hTheme, RECT rc,
             if( ImplGetSVData()->maNWFData.mbDockingAreaAvoidTBFrames )
             {
                 impl_drawAeroToolbar( hDC, rc, nPart == PART_DRAW_BACKGROUND_HORZ );
-                return sal_True;
+                return true;
             }
 
             return ImplDrawTheme( hTheme, hDC, iPart, iState, rc, aCaption);
@@ -966,27 +963,27 @@ sal_Bool ImplDrawNativeControl( HDC hDC, HTHEME hTheme, RECT rc,
                 if( ImplGetSVData()->maNWFData.mbDockingAreaAvoidTBFrames )
                 {
                     impl_drawAeroToolbar( hDC, rc, true );
-                    return sal_True;
+                    return true;
                 }
             }
             return ImplDrawTheme( hTheme, hDC, iPart, iState, rc, aCaption);
         }
         else if( nPart == PART_MENU_ITEM )
         {
-            if( nState & CTRL_STATE_ENABLED )
+            if( nState & ControlState::ENABLED )
             {
-                if( nState & CTRL_STATE_SELECTED )
+                if( nState & ControlState::SELECTED )
                     iState = MBI_PUSHED;
-                else if( nState & CTRL_STATE_ROLLOVER )
+                else if( nState & ControlState::ROLLOVER )
                     iState = MBI_HOT;
                 else
                     iState = MBI_NORMAL;
             }
             else
             {
-                if( nState & CTRL_STATE_SELECTED )
+                if( nState & ControlState::SELECTED )
                     iState = MBI_DISABLEDPUSHED;
-                else if( nState & CTRL_STATE_ROLLOVER )
+                else if( nState & ControlState::ROLLOVER )
                     iState = MBI_DISABLEDHOT;
                 else
                     iState = MBI_DISABLED;
@@ -1009,7 +1006,7 @@ sal_Bool ImplDrawNativeControl( HDC hDC, HTHEME hTheme, RECT rc,
         long nProgressWidth = aValue.getNumericVal();
         nProgressWidth *= (aProgressRect.right - aProgressRect.left);
         nProgressWidth /= (rc.right - rc.left);
-        if( Application::GetSettings().GetLayoutRTL() )
+        if( AllSettings::GetLayoutRTL() )
             aProgressRect.left = aProgressRect.right - nProgressWidth;
         else
             aProgressRect.right = aProgressRect.left + nProgressWidth;
@@ -1046,7 +1043,7 @@ sal_Bool ImplDrawNativeControl( HDC hDC, HTHEME hTheme, RECT rc,
         aThumbRect.right  = pVal->maThumbRect.Right();
         aThumbRect.bottom = pVal->maThumbRect.Bottom();
         iPart = (nPart == PART_TRACK_HORZ_AREA) ? TKP_THUMB : TKP_THUMBVERT;
-        iState = (nState & CTRL_STATE_ENABLED) ? TUS_NORMAL : TUS_DISABLED;
+        iState = (nState & ControlState::ENABLED) ? TUS_NORMAL : TUS_DISABLED;
         return ImplDrawTheme( hTheme, hDC, iPart, iState, aThumbRect, aCaption );
     }
 
@@ -1078,7 +1075,7 @@ sal_Bool ImplDrawNativeControl( HDC hDC, HTHEME hTheme, RECT rc,
             if( nPart == PART_ENTIRE_CONTROL )
             {
                 RECT aGutterRC = rc;
-                if( Application::GetSettings().GetLayoutRTL() )
+                if( AllSettings::GetLayoutRTL() )
                 {
                     aGutterRC.right -= aValue.getNumericVal()+1;
                     aGutterRC.left = aGutterRC.right-3;
@@ -1095,15 +1092,15 @@ sal_Bool ImplDrawNativeControl( HDC hDC, HTHEME hTheme, RECT rc,
             }
             else if( nPart == PART_MENU_ITEM )
             {
-                if( (nState & CTRL_STATE_ENABLED) )
-                    iState = (nState & CTRL_STATE_SELECTED) ? MPI_HOT : MPI_NORMAL;
+                if( (nState & ControlState::ENABLED) )
+                    iState = (nState & ControlState::SELECTED) ? MPI_HOT : MPI_NORMAL;
                 else
-                    iState = (nState & CTRL_STATE_SELECTED) ? MPI_DISABLEDHOT : MPI_DISABLED;
+                    iState = (nState & ControlState::SELECTED) ? MPI_DISABLEDHOT : MPI_DISABLED;
                 return ImplDrawTheme( hTheme, hDC, MENU_POPUPITEM, iState, rc, aCaption );
             }
             else if( nPart == PART_MENU_ITEM_CHECK_MARK || nPart == PART_MENU_ITEM_RADIO_MARK )
             {
-                if( (nState & CTRL_STATE_PRESSED) )
+                if( (nState & ControlState::PRESSED) )
                 {
                     RECT aBGRect = rc;
                     if( aValue.getType() == CTRL_MENU_POPUP )
@@ -1111,7 +1108,7 @@ sal_Bool ImplDrawNativeControl( HDC hDC, HTHEME hTheme, RECT rc,
                         const MenupopupValue& rMVal( static_cast<const MenupopupValue&>(aValue) );
                         aBGRect.top    = rMVal.maItemRect.Top();
                         aBGRect.bottom = rMVal.maItemRect.Bottom()+1; // see below in drawNativeControl
-                        if( Application::GetSettings().GetLayoutRTL() )
+                        if( AllSettings::GetLayoutRTL() )
                         {
                             aBGRect.right = rMVal.maItemRect.Right()+1;
                             aBGRect.left = aBGRect.right - (rMVal.getNumericVal()-rMVal.maItemRect.Left());
@@ -1123,12 +1120,12 @@ sal_Bool ImplDrawNativeControl( HDC hDC, HTHEME hTheme, RECT rc,
                         }
                         rc = aBGRect;
                     }
-                    iState = (nState & CTRL_STATE_ENABLED) ? MCB_NORMAL : MCB_DISABLED;
+                    iState = (nState & ControlState::ENABLED) ? MCB_NORMAL : MCB_DISABLED;
                     ImplDrawTheme( hTheme, hDC, MENU_POPUPCHECKBACKGROUND, iState, aBGRect, aCaption );
                     if( nPart == PART_MENU_ITEM_CHECK_MARK )
-                        iState = (nState & CTRL_STATE_ENABLED) ? MC_CHECKMARKNORMAL : MC_CHECKMARKDISABLED;
+                        iState = (nState & ControlState::ENABLED) ? MC_CHECKMARKNORMAL : MC_CHECKMARKDISABLED;
                     else
-                        iState = (nState & CTRL_STATE_ENABLED) ? MC_BULLETNORMAL : MC_BULLETDISABLED;
+                        iState = (nState & ControlState::ENABLED) ? MC_BULLETNORMAL : MC_BULLETDISABLED;
                     return ImplDrawTheme( hTheme, hDC, MENU_POPUPCHECK, iState, rc, aCaption );
                 }
                 else
@@ -1137,7 +1134,7 @@ sal_Bool ImplDrawNativeControl( HDC hDC, HTHEME hTheme, RECT rc,
             else if( nPart == PART_MENU_SEPARATOR )
             {
                 // adjust for gutter position
-                if( Application::GetSettings().GetLayoutRTL() )
+                if( AllSettings::GetLayoutRTL() )
                     rc.right -= aValue.getNumericVal()+1;
                 else
                     rc.left += aValue.getNumericVal()+1;
@@ -1164,16 +1161,41 @@ sal_Bool ImplDrawNativeControl( HDC hDC, HTHEME hTheme, RECT rc,
  *  aValue:         An optional value (tristate/numerical/string)
  *  aCaption:   A caption or title string (like button text etc)
  */
-sal_Bool WinSalGraphics::drawNativeControl( ControlType nType,
-                            ControlPart nPart,
-                            const Rectangle& rControlRegion,
-                            ControlState nState,
-                            const ImplControlValue& aValue,
-                            const OUString& aCaption )
+bool WinSalGraphics::drawNativeControl( ControlType nType,
+                                        ControlPart nPart,
+                                        const Rectangle& rControlRegion,
+                                        ControlState nState,
+                                        const ImplControlValue& aValue,
+                                        const OUString& aCaption )
 {
-    sal_Bool bOk = false;
+    bool bOk = false;
     HTHEME hTheme = NULL;
 
+    Rectangle buttonRect = rControlRegion;
+    Rectangle cacheRect = rControlRegion;
+    Size keySize = cacheRect.GetSize();
+
+    WinOpenGLSalGraphicsImpl* pImpl = dynamic_cast<WinOpenGLSalGraphicsImpl*>(mpImpl.get());
+
+    // tdf#95618 - A few controls render outside the region they're given.
+    if (pImpl && nType == CTRL_TAB_ITEM)
+    {
+        Rectangle rNativeBoundingRegion;
+        Rectangle rNativeContentRegion;
+        if (getNativeControlRegion(nType, nPart, rControlRegion, nState, aValue, aCaption,
+                                   rNativeBoundingRegion, rNativeContentRegion))
+        {
+            cacheRect = rNativeBoundingRegion;
+            keySize = rNativeBoundingRegion.GetSize();
+        }
+    }
+
+    ControlCacheKey aControlCacheKey(nType, nPart, nState, keySize);
+    if (pImpl != NULL && pImpl->TryRenderCachedNativeControl(aControlCacheKey, buttonRect.Left(), buttonRect.Top()))
+    {
+        return true;
+    }
+
     switch( nType )
     {
         case CTRL_PUSHBUTTON:
@@ -1260,26 +1282,41 @@ sal_Bool WinSalGraphics::drawNativeControl( ControlType nType,
     if( !hTheme )
         return false;
 
-    Rectangle buttonRect = rControlRegion;
     RECT rc;
     rc.left   = buttonRect.Left();
     rc.right  = buttonRect.Right()+1;
     rc.top    = buttonRect.Top();
     rc.bottom = buttonRect.Bottom()+1;
 
-    // set default text alignment
-    int ta = SetTextAlign( getHDC(), TA_LEFT|TA_TOP|TA_NOUPDATECP );
+    OUString aCaptionStr(aCaption.replace('~', '&')); // translate mnemonics
 
-    OUString aCaptionStr( aCaption.replace('~', '&') ); // translate mnemonics
-    bOk = ImplDrawNativeControl(getHDC(), hTheme, rc,
-                            nType, nPart, nState, aValue,
-                            aCaptionStr );
+    if (pImpl == NULL)
+    {
+        // set default text alignment
+        int ta = SetTextAlign(getHDC(), TA_LEFT|TA_TOP|TA_NOUPDATECP);
 
-    // restore alignment
-    SetTextAlign( getHDC(), ta );
+        bOk = ImplDrawNativeControl(getHDC(), hTheme, rc, nType, nPart, nState, aValue, aCaptionStr);
 
+        // restore alignment
+        SetTextAlign(getHDC(), ta);
+    }
+    else
+    {
+        // We can do OpenGL
+        OpenGLCompatibleDC aBlackDC(*this, cacheRect.Left(), cacheRect.Top(), cacheRect.GetWidth()+1, cacheRect.GetHeight()+1);
+        SetTextAlign(aBlackDC.getCompatibleHDC(), TA_LEFT|TA_TOP|TA_NOUPDATECP);
+        aBlackDC.fill(MAKE_SALCOLOR(0, 0, 0));
 
-    //GdiFlush();
+        OpenGLCompatibleDC aWhiteDC(*this, cacheRect.Left(), cacheRect.Top(), cacheRect.GetWidth()+1, cacheRect.GetHeight()+1);
+        SetTextAlign(aWhiteDC.getCompatibleHDC(), TA_LEFT|TA_TOP|TA_NOUPDATECP);
+        aWhiteDC.fill(MAKE_SALCOLOR(0xff, 0xff, 0xff));
+
+        if (ImplDrawNativeControl(aBlackDC.getCompatibleHDC(), hTheme, rc, nType, nPart, nState, aValue, aCaptionStr) &&
+            ImplDrawNativeControl(aWhiteDC.getCompatibleHDC(), hTheme, rc, nType, nPart, nState, aValue, aCaptionStr))
+        {
+            bOk = pImpl->RenderAndCacheNativeControl(aWhiteDC, aBlackDC, cacheRect.Left(), cacheRect.Top(), aControlCacheKey);
+        }
+    }
 
     return bOk;
 }
@@ -1297,7 +1334,7 @@ sal_Bool WinSalGraphics::drawNativeControl( ControlType nType,
  *  aValue:     An optional value (tristate/numerical/string)
  *  aCaption:       A caption or title string (like button text etc)
  */
-sal_Bool WinSalGraphics::getNativeControlRegion(  ControlType nType,
+bool WinSalGraphics::getNativeControlRegion(  ControlType nType,
                                 ControlPart nPart,
                                 const Rectangle& rControlRegion,
                                 ControlState nState,
@@ -1306,7 +1343,10 @@ sal_Bool WinSalGraphics::getNativeControlRegion(  ControlType nType,
                                 Rectangle &rNativeBoundingRegion,
                                 Rectangle &rNativeContentRegion )
 {
-    sal_Bool bRet = FALSE;
+    bool bRet = FALSE;
+
+    // FIXME: rNativeBoundingRegion has a different origin
+    //        depending on which part is used; horrors.
 
     HDC hDC = GetDC( mhWnd );
     if( nType == CTRL_TOOLBAR )
@@ -1479,7 +1519,7 @@ sal_Bool WinSalGraphics::getNativeControlRegion(  ControlType nType,
             if ( pValue->isBothAligned() )
                 --aControlRect.Right();
 
-            if ( nState & CTRL_STATE_SELECTED )
+            if ( nState & ControlState::SELECTED )
             {
                 aControlRect.Left() -= 2;
                 if ( pValue && !pValue->isBothAligned() )
@@ -1498,7 +1538,7 @@ sal_Bool WinSalGraphics::getNativeControlRegion(  ControlType nType,
     }
 
     ReleaseDC( mhWnd, hDC );
-    return( bRet );
+    return bRet;
 }
 
 void WinSalGraphics::updateSettingsNative( AllSettings& rSettings )
@@ -1516,14 +1556,16 @@ void WinSalGraphics::updateSettingsNative( AllSettings& rSettings )
     // in Aero theme (and similar ?) the menu text color does not change
     // for selected items; also on WinXP and earlier menus are not themed
     // FIXME get the color directly from the theme, not from the settings
-    if( aSalShlData.maVersionInfo.dwMajorVersion >= 6 )
+    if (aSalShlData.mbWVista)
     {
+        Color aMenuBarTextColor = aStyleSettings.GetPersonaMenuBarTextColor().get_value_or( aStyleSettings.GetMenuTextColor() );
         // in aero menuitem highlight text is drawn in the same color as normal
         aStyleSettings.SetMenuHighlightTextColor( aStyleSettings.GetMenuTextColor() );
-        aStyleSettings.SetMenuBarRolloverTextColor( aStyleSettings.GetMenuTextColor() );
+        aStyleSettings.SetMenuBarRolloverTextColor( aMenuBarTextColor );
+        aStyleSettings.SetMenuBarHighlightTextColor( aMenuBarTextColor );
         pSVData->maNWFData.mnMenuFormatBorderX = 2;
         pSVData->maNWFData.mnMenuFormatBorderY = 2;
-        pSVData->maNWFData.maMenuBarHighlightTextColor = aStyleSettings.GetMenuTextColor();
+        pSVData->maNWFData.maMenuBarHighlightTextColor = aMenuBarTextColor;
         GetSalData()->mbThemeMenuSupport = TRUE;
     }
 
