@@ -1239,20 +1239,20 @@ OUString WinSalInfoPrinter::GetPaperBinName( const ImplJobSetup* pSetupData, sal
     return aPaperBinName;
 }
 
-sal_uLong WinSalInfoPrinter::GetCapabilities( const ImplJobSetup* pSetupData, sal_uInt16 nType )
+sal_uLong WinSalInfoPrinter::GetCapabilities( const ImplJobSetup* pSetupData, PrinterCapType nType )
 {
     DWORD nRet;
 
     switch ( nType )
     {
-        case PRINTER_CAPABILITIES_SUPPORTDIALOG:
+        case PrinterCapType::SupportDialog:
             return TRUE;
-        case PRINTER_CAPABILITIES_COPIES:
+        case PrinterCapType::Copies:
             nRet = ImplDeviceCaps( this, DC_COPIES, NULL, pSetupData );
             if ( nRet && (nRet != GDI_ERROR) )
                 return nRet;
             return 0;
-        case PRINTER_CAPABILITIES_COLLATECOPIES:
+        case PrinterCapType::CollateCopies:
             nRet = ImplDeviceCaps( this, DC_COLLATE, NULL, pSetupData );
             if ( nRet && (nRet != GDI_ERROR) )
             {
@@ -1262,20 +1262,20 @@ sal_uLong WinSalInfoPrinter::GetCapabilities( const ImplJobSetup* pSetupData, sa
             }
             return 0;
 
-        case PRINTER_CAPABILITIES_SETORIENTATION:
+        case PrinterCapType::SetOrientation:
             nRet = ImplDeviceCaps( this, DC_ORIENTATION, NULL, pSetupData );
             if ( nRet && (nRet != GDI_ERROR) )
                 return TRUE;
             return FALSE;
 
-        case PRINTER_CAPABILITIES_SETPAPERBIN:
+        case PrinterCapType::SetPaperBin:
             nRet = ImplDeviceCaps( this, DC_BINS, NULL, pSetupData );
             if ( nRet && (nRet != GDI_ERROR) )
                 return TRUE;
             return FALSE;
 
-        case PRINTER_CAPABILITIES_SETPAPERSIZE:
-        case PRINTER_CAPABILITIES_SETPAPER:
+        case PrinterCapType::SetPaperSize:
+        case PrinterCapType::SetPaper:
             nRet = ImplDeviceCaps( this, DC_PAPERS, NULL, pSetupData );
             if ( nRet && (nRet != GDI_ERROR) )
                 return TRUE;
@@ -1498,7 +1498,7 @@ bool WinSalPrinter::StartJob( const OUString* pFileName,
     mnError = 0;
     mbAbort = FALSE;
 
-    // As the Telocom Balloon Fax driver tends to send messages repeatedly
+    // As the Telecom Balloon Fax driver tends to send messages repeatedly
     // we try to process first all, and then insert a dummy message
     bool bWhile = TRUE;
     int  i = 0;
@@ -1521,7 +1521,7 @@ bool WinSalPrinter::StartJob( const OUString* pFileName,
     while ( bWhile );
     PostMessageW( GetSalData()->mpFirstInstance->mhComWnd, SAL_MSG_DUMMY, 0, 0 );
 
-    // bring up a file choser if printing to file port but no file name given
+    // bring up a file chooser if printing to file port but no file name given
     OUString aOutFileName;
     if( mpInfoPrinter->maPortName.equalsIgnoreAsciiCase( "FILE:" ) && !(pFileName && !pFileName->isEmpty()) )
     {
@@ -1531,7 +1531,7 @@ bool WinSalPrinter::StartJob( const OUString* pFileName,
 
         if( xFilePicker->execute() == ExecutableDialogResults::OK )
         {
-            Sequence< OUString > aPathSeq( xFilePicker->getFiles() );
+            Sequence< OUString > aPathSeq( xFilePicker->getSelectedFiles() );
             INetURLObject aObj( aPathSeq[0] );
             // we're using ansi calls (StartDocA) so convert the string
             aOutFileName = aObj.PathToFileName();
@@ -1607,59 +1607,6 @@ bool WinSalPrinter::EndJob()
     return TRUE;
 }
 
-bool WinSalPrinter::AbortJob()
-{
-    mbAbort = TRUE;
-
-    // trigger Abort asynchronously
-    HDC hDC = mhDC;
-    if ( hDC )
-    {
-        SalData* pSalData = GetSalData();
-        PostMessageW( pSalData->mpFirstInstance->mhComWnd,
-                         SAL_MSG_PRINTABORTJOB, (WPARAM)hDC, 0 );
-    }
-
-    return TRUE;
-}
-
-void ImplSalPrinterAbortJobAsync( HDC hPrnDC )
-{
-    SalData*    pSalData = GetSalData();
-    WinSalPrinter* pPrinter = pSalData->mpFirstPrinter;
-
-    // check if printer still exists
-    while ( pPrinter )
-    {
-        if ( pPrinter->mhDC == hPrnDC )
-            break;
-
-        pPrinter = pPrinter->mpNextPrinter;
-    }
-
-    // if printer still exists, cancel the job
-    if ( pPrinter )
-    {
-        HDC hDC = pPrinter->mhDC;
-        if ( hDC )
-        {
-            if ( pPrinter->mpGraphics )
-            {
-                pPrinter->mpGraphics->DeInitGraphics();
-                delete pPrinter->mpGraphics;
-                pPrinter->mpGraphics = NULL;
-            }
-
-            CATCH_DRIVER_EX_BEGIN;
-            ::AbortDoc( hDC );
-            CATCH_DRIVER_EX_END( "exception in AbortDoc", pPrinter );
-
-            DeleteDC( hDC );
-            pPrinter->mhDC = 0;
-        }
-    }
-}
-
 SalGraphics* WinSalPrinter::StartPage( ImplJobSetup* pSetupData, bool bNewJobData )
 {
     if( ! isValid() || mhDC == 0 )
