@@ -17,9 +17,9 @@
  *   the License at http://www.apache.org/licenses/LICENSE-2.0 .
  */
 
-//////////////////////////////////////////////////////////////////////
+
 // AccTextBase.cpp: implementation of the CAccTextBase class.
-//////////////////////////////////////////////////////////////////////
+
 #include "stdafx.h"
 #include <string>
 
@@ -34,15 +34,14 @@
 #include <com/sun/star/accessibility/XAccessibleTextSelection.hpp>
 #include "MAccessible.h"
 
-using namespace com::sun::star::accessibility;
-using namespace com::sun::star::uno;
-using namespace rtl;
+using namespace css::accessibility;
+using namespace css::uno;
+
 
-//////////////////////////////////////////////////////////////////////
 // Construction/Destruction
-//////////////////////////////////////////////////////////////////////
 
-OUString ReplaceFourChar(OUString oldOUString);
+
+static OUString ReplaceFourChar(OUString oldOUString);
 
 CAccTextBase::CAccTextBase()
 {}
@@ -115,7 +114,7 @@ STDMETHODIMP CAccTextBase::get_attributes(long offset, long * startOffset, long
 
     strAttrs += L"Version:1;";
 
-    Sequence< ::com::sun::star::beans::PropertyValue > pValues = GetXInterface()->getCharacterAttributes(offset, Sequence< rtl::OUString >());
+    Sequence< css::beans::PropertyValue > pValues = GetXInterface()->getCharacterAttributes(offset, Sequence< rtl::OUString >());
     int nCount = pValues.getLength();
 
     short numberingLevel = 0;
@@ -127,8 +126,8 @@ STDMETHODIMP CAccTextBase::get_attributes(long offset, long * startOffset, long
     for(int i =0; i<nCount; i++)
     {
 
-        ::com::sun::star::beans::PropertyValue &pValue = pValues[i];
-        if(pValue.Name.compareTo(OUString::createFromAscii("NumberingLevel"))==0)
+        css::beans::PropertyValue &pValue = pValues[i];
+        if(pValue.Name == "NumberingLevel")
         {
             if (pValue.Value != Any())
                 pValue.Value >>= numberingLevel;
@@ -137,13 +136,13 @@ STDMETHODIMP CAccTextBase::get_attributes(long offset, long * startOffset, long
             bHaveNumberingLevel = true;
             continue;
         }
-        if(pValue.Name.compareTo(OUString::createFromAscii("NumberingPrefix"))==0)
+        if(pValue.Name == "NumberingPrefix")
         {
             pValue.Value >>=numberingPrefix;
             bHaveNumberingPrefixAttr = true;
             continue;
         }
-        if(pValue.Name.compareTo(OUString::createFromAscii("NumberingRules"))==0)
+        if(pValue.Name == "NumberingRules")
         {
             bHaveNumberingRules = true;
             anyNumRule = pValue.Value;
@@ -169,9 +168,9 @@ STDMETHODIMP CAccTextBase::get_attributes(long offset, long * startOffset, long
 
         OLECHAR pTemp[2048] = {0};
 
-        if (pValue.Name.compareTo(OUString::createFromAscii("CharBackColor"))==0 ||
-                pValue.Name.compareTo(OUString::createFromAscii("CharColor"))==0 ||
-                pValue.Name.compareTo(OUString::createFromAscii("CharUnderlineColor"))==0 )
+        if (pValue.Name == "CharBackColor" ||
+                pValue.Name == "CharColor" ||
+                pValue.Name == "CharUnderlineColor" )
         {
             unsigned long nColor;
             pValue.Value >>= nColor;
@@ -287,11 +286,11 @@ STDMETHODIMP CAccTextBase::get_characterExtents(long offset, IA2CoordinateType c
     if(offset < 0 || offset > GetXInterface()->getCharacterCount() )
         return E_FAIL;
 
-    com::sun::star::awt::Rectangle rectangle;
+    css::awt::Rectangle rectangle;
     rectangle = GetXInterface()->getCharacterBounds(offset);
 
     //IA2Point aPoint;
-    com::sun::star::awt::Point aPoint;
+    css::awt::Point aPoint;
 
     Reference<XAccessibleContext> pRContext = pUNOInterface->getAccessibleContext();
     if( !pRContext.is() )
@@ -303,13 +302,13 @@ STDMETHODIMP CAccTextBase::get_characterExtents(long offset, IA2CoordinateType c
     {
         if(coordType == IA2_COORDTYPE_SCREEN_RELATIVE)
         {
-            ::com::sun::star::awt::Point pt = pRComp->getLocationOnScreen();
+            css::awt::Point pt = pRComp->getLocationOnScreen();
             aPoint.X = pt.X;
             aPoint.Y = pt.Y;
         }
         else if(coordType == IA2_COORDTYPE_PARENT_RELATIVE)
         {
-            ::com::sun::star::awt::Point pt = pRComp->getLocation();
+            css::awt::Point pt = pRComp->getLocation();
             aPoint.X = pt.X;
             aPoint.Y = pt.Y;
         }
@@ -402,7 +401,7 @@ STDMETHODIMP CAccTextBase::get_offsetAtPoint(long x, long y, IA2CoordinateType,
     if(!pRXText.is())
         return E_FAIL;
 
-    com::sun::star::awt::Point point;
+    css::awt::Point point;
     point.X = x;
     point.Y = y;
     *offset = GetXInterface()->getIndexAtPoint(point);
@@ -529,7 +528,7 @@ STDMETHODIMP CAccTextBase::get_textBeforeOffset(long offset, IA2TextBoundaryType
         return E_FAIL;
 
     // In New UNO IAccessibleText.idl these constant values are defined as follows:
-    //
+
     //  const long TEXT_BOUNDARY_CHAR = -1;
     //  const long TEXT_BOUNDARY_TO_CURSOR_POS = -2;
     //  const long TEXT_BOUNDARY_START_OF_WORD = -3;
@@ -538,9 +537,9 @@ STDMETHODIMP CAccTextBase::get_textBeforeOffset(long offset, IA2TextBoundaryType
     //  const long TEXT_BOUNDARY_END_OF_SENTENCE = -6;
     //  const long TEXT_BOUNDARY_START_OF_LINE = -7;
     //  const long TEXT_BOUNDARY_END_OF_LINE = -8;
-    //
+
     // In UNO, the corresponding values are as follows:
-    //
+
     //  const short CHARACTER = 1;
     //  const short WORD = 2;
     //  const short SENTENCE = 3;
@@ -548,7 +547,7 @@ STDMETHODIMP CAccTextBase::get_textBeforeOffset(long offset, IA2TextBoundaryType
     //  const short LINE = 5;
     //  const short GLYPH = 6;
     //  const short ATTRIBUTE_RUN = 7;
-    //
+
 
     long            lUnoBoundaryType;
 
@@ -616,7 +615,7 @@ STDMETHODIMP CAccTextBase::get_textAfterOffset(long offset, IA2TextBoundaryType
         return E_FAIL;
 
     // In New UNO IAccessibleText.idl these constant values are defined as follows:
-    //
+
     //  const long TEXT_BOUNDARY_CHAR = -1;
     //  const long TEXT_BOUNDARY_TO_CURSOR_POS = -2;
     //  const long TEXT_BOUNDARY_START_OF_WORD = -3;
@@ -625,9 +624,9 @@ STDMETHODIMP CAccTextBase::get_textAfterOffset(long offset, IA2TextBoundaryType
     //  const long TEXT_BOUNDARY_END_OF_SENTENCE = -6;
     //  const long TEXT_BOUNDARY_START_OF_LINE = -7;
     //  const long TEXT_BOUNDARY_END_OF_LINE = -8;
-    //
+
     // In UNO, the corresponding values are as follows:
-    //
+
     //  const short CHARACTER = 1;
     //  const short WORD = 2;
     //  const short SENTENCE = 3;
@@ -635,7 +634,7 @@ STDMETHODIMP CAccTextBase::get_textAfterOffset(long offset, IA2TextBoundaryType
     //  const short LINE = 5;
     //  const short GLYPH = 6;
     //  const short ATTRIBUTE_RUN = 7;
-    //
+
 
     long            lUnoBoundaryType;
     switch(boundaryType)
@@ -702,7 +701,7 @@ STDMETHODIMP CAccTextBase::get_textAtOffset(long offset, IA2TextBoundaryType bou
         return E_FAIL;
 
     // In New UNO IAccessibleText.idl these constant values are defined as follows:
-    //
+
     //  const long TEXT_BOUNDARY_CHAR = -1;
     //  const long TEXT_BOUNDARY_TO_CURSOR_POS = -2;
     //  const long TEXT_BOUNDARY_START_OF_WORD = -3;
@@ -711,9 +710,9 @@ STDMETHODIMP CAccTextBase::get_textAtOffset(long offset, IA2TextBoundaryType bou
     //  const long TEXT_BOUNDARY_END_OF_SENTENCE = -6;
     //  const long TEXT_BOUNDARY_START_OF_LINE = -7;
     //  const long TEXT_BOUNDARY_END_OF_LINE = -8;
-    //
+
     // In UNO, the corresponding values are as follows:
-    //
+
     //  const short CHARACTER = 1;
     //  const short WORD = 2;
     //  const short SENTENCE = 3;
@@ -721,7 +720,7 @@ STDMETHODIMP CAccTextBase::get_textAtOffset(long offset, IA2TextBoundaryType bou
     //  const short LINE = 5;
     //  const short GLYPH = 6;
     //  const short ATTRIBUTE_RUN = 7;
-    //
+
 
     long            lUnoBoundaryType;
 
@@ -937,10 +936,9 @@ STDMETHODIMP CAccTextBase::put_XInterface(hyper pXInterface)
     LEAVE_PROTECTED_BLOCK
 }
 
-OUString ReplaceOneChar(OUString oldOUString, OUString replacedChar, OUString replaceStr)
+static OUString ReplaceOneChar(OUString oldOUString, OUString replacedChar, OUString replaceStr)
 {
-    int iReplace = -1;
-    iReplace = oldOUString.lastIndexOf(replacedChar);
+    int iReplace = oldOUString.lastIndexOf(replacedChar);
     if (iReplace > -1)
     {
         for(;iReplace>-1;)
@@ -950,15 +948,15 @@ OUString ReplaceOneChar(OUString oldOUString, OUString replacedChar, OUString re
         }
     }
     return oldOUString;
-
 }
-OUString ReplaceFourChar(OUString oldOUString)
+
+static OUString ReplaceFourChar(OUString oldOUString)
 {
-    oldOUString = ReplaceOneChar(oldOUString,OUString::createFromAscii("\\"),OUString::createFromAscii("\\\\"));
-    oldOUString = ReplaceOneChar(oldOUString,OUString::createFromAscii(";"),OUString::createFromAscii("\\;"));
-    oldOUString = ReplaceOneChar(oldOUString,OUString::createFromAscii("="),OUString::createFromAscii("\\="));
-    oldOUString = ReplaceOneChar(oldOUString,OUString::createFromAscii(","),OUString::createFromAscii("\\,"));
-    oldOUString = ReplaceOneChar(oldOUString,OUString::createFromAscii(":"),OUString::createFromAscii("\\:"));
+    oldOUString = ReplaceOneChar(oldOUString, OUString("\\"), OUString("\\\\"));
+    oldOUString = ReplaceOneChar(oldOUString, OUString(";"), OUString("\\;"));
+    oldOUString = ReplaceOneChar(oldOUString, OUString("="), OUString("\\="));
+    oldOUString = ReplaceOneChar(oldOUString, OUString(","), OUString("\\,"));
+    oldOUString = ReplaceOneChar(oldOUString, OUString(":"), OUString("\\:"));
     return oldOUString;
 }
 
