@@ -26,9 +26,7 @@
 #include <com/sun/star/accessibility/AccessibleStateType.hpp>
 
 #include <oleacc.h>
-#ifndef _SV_AccObjectWinManager_HXX
 #include "AccObjectWinManager.hxx"
-#endif
 #include "AccEventListener.hxx"
 #include "AccComponentEventListener.hxx"
 #include "AccContainerEventListener.hxx"
@@ -176,8 +174,6 @@ sal_Bool AccObjectWinManager::NotifyAccEvent(XAccessible* pXAcc,short state)
     if(selfAccObj==NULL)
         return sal_False;
 
-    int selectNum =0;
-
     long dChildID = selfAccObj->GetResID();
     HWND hAcc = selfAccObj->GetParentHWND();
 
@@ -362,7 +358,7 @@ short AccObjectWinManager::GetParentRole( XAccessible* pXAcc )
 }
 
 /**
-   * Update focus objcet by new focused XAccessible interface.
+   * Update focus object by new focused XAccessible interface.
    * @param newFocus New XAccessible interface that gets focus.
    * @return
    */
@@ -381,13 +377,12 @@ void AccObjectWinManager::UpdateAccFocus(XAccessible* newFocus)
 }
 
 /**
-   * Update selected objcet by new focused XAccessible interface.
+   * Update selected object by new focused XAccessible interface.
    * @param pXAcc XAccessible interface that has selected child changed.
    * @return Selected children count.
    */
 int AccObjectWinManager::UpdateAccSelection(XAccessible* pXAcc)
 {
-    XAccessibleSelection* pSelection = NULL;
     Reference< XAccessibleContext > pRContext;
 
     if( pXAcc == NULL)
@@ -436,7 +431,6 @@ int AccObjectWinManager::UpdateAccSelection(XAccessible* pXAcc)
             continue;
         }
 
-        pAccChildObj = NULL;
         pAccChildObj = GetAccObjByXAcc(pRChild.get());
         if(!pAccChildObj)
         {
@@ -457,7 +451,7 @@ int AccObjectWinManager::UpdateAccSelection(XAccessible* pXAcc)
         pAccChildObj = (AccObject*)(iter->second);
         if(pAccChildObj != NULL)
             NotifyWinEvent(EVENT_OBJECT_SELECTIONREMOVE,pAccObj->GetParentHWND(), OBJID_CLIENT,pAccChildObj->GetResID());
-        iter++;
+        ++iter;
     }
     return 0;
 
@@ -490,12 +484,12 @@ void AccObjectWinManager::DeleteFromHwndXAcc(XAccessible* pXAcc )
             HwndXAcc.erase(iter);
             return;
         }
-        iter++;
+        ++iter;
     }
 }
 
 /**
-   * Delete Delete all children with the tree root of XAccessible pointer
+   * Delete all children with the tree root of XAccessible pointer
    * @param pXAcc Tree root XAccessible interface.
    * @return
    */
@@ -522,7 +516,7 @@ void AccObjectWinManager::DeleteChildrenAccObj(XAccessible* pXAcc)
 }
 
 /**
-   * Delete Delete Acc object self.
+   * Delete Acc object self.
    * @param pXAcc The XAccessible interface.
    * @return
    */
@@ -550,7 +544,10 @@ void AccObjectWinManager::DeleteAccObj( XAccessible* pXAcc )
     size_t i = XResIdAccList.erase(accObj.GetResID());
     assert(i != 0);
     DeleteFromHwndXAcc(pXAcc);
-    if (DOCUMENT == accObj.GetRole())
+    if( accObj.GetRole() == DOCUMENT ||
+        accObj.GetRole() == DOCUMENT_PRESENTATION ||
+        accObj.GetRole() == DOCUMENT_SPREADSHEET ||
+        accObj.GetRole() == DOCUMENT_TEXT )
     {
         XHWNDDocList.erase(accObj.GetParentHWND());
     }
@@ -587,7 +584,7 @@ inline long AccObjectWinManager::ImpleGenerateResID()
    * @param pWnd  Top Window handle
    * @return The calling result.
    */
-sal_Bool AccObjectWinManager::InsertChildrenAccObj( com::sun::star::accessibility::XAccessible* pXAcc,
+sal_Bool AccObjectWinManager::InsertChildrenAccObj( css::accessibility::XAccessible* pXAcc,
         HWND pWnd)
 {
     if(!IsContainer(pXAcc))
@@ -603,7 +600,10 @@ sal_Bool AccObjectWinManager::InsertChildrenAccObj( com::sun::star::accessibilit
 
     short role = pRContext->getAccessibleRole();
 
-    if(com::sun::star::accessibility::AccessibleRole::DOCUMENT == role )
+    if(css::accessibility::AccessibleRole::DOCUMENT == role ||
+            css::accessibility::AccessibleRole::DOCUMENT_PRESENTATION == role ||
+            css::accessibility::AccessibleRole::DOCUMENT_SPREADSHEET == role ||
+            css::accessibility::AccessibleRole::DOCUMENT_TEXT == role)
     {
         if(IsStateManageDescendant(pXAcc))
         {
@@ -709,7 +709,10 @@ sal_Bool AccObjectWinManager::InsertAccObj( XAccessible* pXAcc,XAccessible* pPar
     pObj.SetParentHWND( pWnd );
 
     //for file name support
-    if ( pObj.GetRole() == DOCUMENT )
+    if( pObj.GetRole() == DOCUMENT ||
+        pObj.GetRole() == DOCUMENT_PRESENTATION ||
+        pObj.GetRole() == DOCUMENT_SPREADSHEET ||
+        pObj.GetRole() == DOCUMENT_TEXT )
     {
         XHWNDToDocumentHash::iterator aIter = XHWNDDocList.find(pWnd);
         if ( aIter != XHWNDDocList.end() )
@@ -758,7 +761,7 @@ sal_Bool AccObjectWinManager::InsertAccObj( XAccessible* pXAcc,XAccessible* pPar
    * @param pXAcc XAccessible interface for top window
    * @return void
    */
-void AccObjectWinManager::SaveTopWindowHandle(HWND hWnd, com::sun::star::accessibility::XAccessible* pXAcc)
+void AccObjectWinManager::SaveTopWindowHandle(HWND hWnd, css::accessibility::XAccessible* pXAcc)
 {
     HwndXAcc.insert( XHWNDToXAccHash::value_type( hWnd,(void*)pXAcc ) );
 }
@@ -792,6 +795,9 @@ AccObjectWinManager::CreateAccEventListener(XAccessible* pXAcc)
         case /*AccessibleRole::*/CANVAS:
         case /*AccessibleRole::*/COMBO_BOX:
         case /*AccessibleRole::*/DOCUMENT:
+        case /*AccessibleRole::*/DOCUMENT_PRESENTATION:
+        case /*AccessibleRole::*/DOCUMENT_SPREADSHEET:
+        case /*AccessibleRole::*/DOCUMENT_TEXT:
         case /*AccessibleRole::*/END_NOTE:
         case /*AccessibleRole::*/FILLER:
         case /*AccessibleRole::*/FOOTNOTE:
@@ -900,7 +906,7 @@ void AccObjectWinManager::IncreaseState( XAccessible* pXAcc,unsigned short pStat
         pAccObj->IncreaseState( pState );
 }
 
-void  AccObjectWinManager::UpdateState( com::sun::star::accessibility::XAccessible* pXAcc )
+void  AccObjectWinManager::UpdateState( css::accessibility::XAccessible* pXAcc )
 {
     AccObject* pAccObj = GetAccObjByXAcc( pXAcc );
     if( pAccObj )
@@ -1036,6 +1042,9 @@ sal_Bool AccObjectWinManager::IsContainer(XAccessible* pAccessible)
                 case /*AccessibleRole::*/CANVAS:
                 case /*AccessibleRole::*/COMBO_BOX:
                 case /*AccessibleRole::*/DOCUMENT:
+                case /*AccessibleRole::*/DOCUMENT_PRESENTATION:
+                case /*AccessibleRole::*/DOCUMENT_SPREADSHEET:
+                case /*AccessibleRole::*/DOCUMENT_TEXT:
                 case /*AccessibleRole::*/EMBEDDED_OBJECT:
                 case /*AccessibleRole::*/END_NOTE:
                 case /*AccessibleRole::*/FILLER:
@@ -1160,9 +1169,9 @@ void AccObjectWinManager::NotifyDestroy(XAccessible* pXAcc)
 }
 
 
-void AccObjectWinManager::UpdateChildState(com::sun::star::accessibility::XAccessible* pAccSubMenu)
+void AccObjectWinManager::UpdateChildState(css::accessibility::XAccessible* pAccSubMenu)
 {
-    Reference<com::sun::star::accessibility::XAccessibleContext> xContext(pAccSubMenu,UNO_QUERY);
+    Reference<css::accessibility::XAccessibleContext> xContext(pAccSubMenu,UNO_QUERY);
     if (!xContext.is())
     {
         return;
@@ -1170,7 +1179,7 @@ void AccObjectWinManager::UpdateChildState(com::sun::star::accessibility::XAcces
     sal_Int32 nCount = xContext->getAccessibleChildCount();
     for (sal_Int32 i = 0 ; i < nCount ; ++i)
     {
-        Reference<com::sun::star::accessibility::XAccessible> xChild = xContext->getAccessibleChild(i);
+        Reference<css::accessibility::XAccessible> xChild = xContext->getAccessibleChild(i);
         if (xChild.is())
         {
             AccObject *pObj =  GetAccObjByXAcc(xChild.get());
@@ -1183,7 +1192,7 @@ void AccObjectWinManager::UpdateChildState(com::sun::star::accessibility::XAcces
 }
 
 
-bool AccObjectWinManager::IsSpecialToolboItem(com::sun::star::accessibility::XAccessible* pXAcc)
+bool AccObjectWinManager::IsSpecialToolboItem(css::accessibility::XAccessible* pXAcc)
 {
     if (pXAcc && oldFocus != pXAcc)
     {
@@ -1202,10 +1211,10 @@ bool AccObjectWinManager::IsSpecialToolboItem(com::sun::star::accessibility::XAc
     return false;
 }
 
-short AccObjectWinManager::GetRole(com::sun::star::accessibility::XAccessible* pXAcc)
+short AccObjectWinManager::GetRole(css::accessibility::XAccessible* pXAcc)
 {
     assert(pXAcc != NULL);
-    Reference<com::sun::star::accessibility::XAccessibleContext> xContext(pXAcc->getAccessibleContext(),UNO_QUERY);
+    Reference<css::accessibility::XAccessibleContext> xContext(pXAcc->getAccessibleContext(),UNO_QUERY);
     if(xContext.is())
     {
         return xContext->getAccessibleRole();
@@ -1232,7 +1241,7 @@ XAccessible* AccObjectWinManager::GetAccDocByAccTopWin( XAccessible* pXAcc )
     return GetAccDocByHWND(hWnd);
 }
 
-bool AccObjectWinManager::IsTopWinAcc( com::sun::star::accessibility::XAccessible* pXAcc )
+bool AccObjectWinManager::IsTopWinAcc( css::accessibility::XAccessible* pXAcc )
 {
     bool bRet = false;
     AccObject* pAccObj = GetAccObjByXAcc( pXAcc );
