@@ -164,7 +164,7 @@ abstract public class ReportBuilderLayouter implements IReportBuilderLayouter
     /**
      * Remove all Groups
      */
-    protected void clearGroups()
+    private void clearGroups()
     {
         final XGroups xGroups = getReportDefinition().getGroups();
         while (xGroups.hasElements())
@@ -233,7 +233,7 @@ abstract public class ReportBuilderLayouter implements IReportBuilderLayouter
         return nIndent;
     }
 
-    int m_nLeftIndent = -1;
+    private int m_nLeftIndent = -1;
 
     /**
      * Get left page indent.
@@ -250,7 +250,7 @@ abstract public class ReportBuilderLayouter implements IReportBuilderLayouter
         return m_nLeftIndent;
     }
 
-    int m_nRightIndent = -1;
+    private int m_nRightIndent = -1;
 
     /**
      * Get right page indent.
@@ -298,7 +298,7 @@ abstract public class ReportBuilderLayouter implements IReportBuilderLayouter
         return aUsedStyle;
     }
 
-    protected int getFromPageStyles(String _sStyleName, int _nDefault)
+    private int getFromPageStyles(String _sStyleName, int _nDefault)
     {
         int nValue = _nDefault;
         final XStyle xStyle = getUsedStyle("PageStyles");
@@ -311,7 +311,7 @@ abstract public class ReportBuilderLayouter implements IReportBuilderLayouter
         return nValue;
     }
 
-    protected void setToPageStyles(String _sStyleName, Object _aObj)
+    private void setToPageStyles(String _sStyleName, Object _aObj)
     {
         final XStyle xStyle = getUsedStyle("PageStyles");
         if (xStyle != null)
@@ -321,7 +321,7 @@ abstract public class ReportBuilderLayouter implements IReportBuilderLayouter
         }
     }
 
-    int m_nPageWidth = -1;
+    private int m_nPageWidth = -1;
 
     /**
      * Get page width. The default is 21000 1/100mm what is 21cm of DIN A4.
@@ -382,7 +382,7 @@ abstract public class ReportBuilderLayouter implements IReportBuilderLayouter
     }
 
 
-    protected int insertGroups()
+    private int insertGroups()
     {
         final XGroups xGroups = getReportDefinition().getGroups();
         int lastGroupPosition = -1;
@@ -474,7 +474,7 @@ abstract public class ReportBuilderLayouter implements IReportBuilderLayouter
     }
 
 
-    protected String getTitleFromFieldName(String _sField)
+    private String getTitleFromFieldName(String _sField)
     {
         for (int i = 0; i < m_aFieldNames.length; i++)
         {
@@ -486,7 +486,7 @@ abstract public class ReportBuilderLayouter implements IReportBuilderLayouter
         return PropertyNames.EMPTY_STRING;
     }
 
-    protected int getTypeFromFieldName(String _sField)
+    private int getTypeFromFieldName(String _sField)
     {
         for (int i = 0; i < m_aFieldNames.length; i++)
         {
@@ -498,7 +498,7 @@ abstract public class ReportBuilderLayouter implements IReportBuilderLayouter
         return 0;
     }
 
-    protected boolean listContains(String[] _aList, String _aValue)
+    private boolean listContains(String[] _aList, String _aValue)
     {
         for (int i = 0; i < _aList.length; i++)
         {
@@ -517,7 +517,7 @@ abstract public class ReportBuilderLayouter implements IReportBuilderLayouter
      * @param _aGetResultFrom
      * @return
      */
-    protected String[] getNamesWithoutGroupNames(String[] _aList, String[] _aGetResultFrom)
+    private String[] getNamesWithoutGroupNames(String[] _aList, String[] _aGetResultFrom)
     {
         if (_aList == null)
         {
@@ -695,7 +695,7 @@ abstract public class ReportBuilderLayouter implements IReportBuilderLayouter
 
     }
 
-    protected String convertFromFieldName(String _sName)
+    private String convertFromFieldName(String _sName)
     {
         if (_sName.startsWith("field:["))
         {
@@ -723,7 +723,7 @@ abstract public class ReportBuilderLayouter implements IReportBuilderLayouter
         return insertFormattedField(_xSection, _sFormattedfield, _aRect, _nWidth, _aSO, (short) com.sun.star.awt.TextAlign.LEFT);
     }
 
-    protected Rectangle insertFormattedField(XSection _xSection, String _sFormattedfield, Rectangle _aRect, int _nWidth, SectionObject _aSO, short _nAlignment)
+    private Rectangle insertFormattedField(XSection _xSection, String _sFormattedfield, Rectangle _aRect, int _nWidth, SectionObject _aSO, short _nAlignment)
     {
         if (_xSection != null)
         {
@@ -803,7 +803,6 @@ abstract public class ReportBuilderLayouter implements IReportBuilderLayouter
                         XNumberFormatsSupplier x = xFormattedField.getFormatsSupplier();
                         XNumberFormats xFormats = x.getNumberFormats();
                         XNumberFormatTypes x3 = UnoRuntime.queryInterface(XNumberFormatTypes.class, xFormats);
-                        Locale.getDefault();
                         com.sun.star.lang.Locale aLocale = new com.sun.star.lang.Locale();
                         aLocale.Country = Locale.getDefault().getCountry();
                         aLocale.Language = Locale.getDefault().getLanguage();
@@ -832,9 +831,9 @@ abstract public class ReportBuilderLayouter implements IReportBuilderLayouter
         getReportDefinition().setCommandType(_aType);
         getReportDefinition().setCommand(_sTableName);
     }
-    protected XMultiServiceFactory m_xMSF;
+    private XMultiServiceFactory m_xMSF;
 
-    protected XMultiServiceFactory getMSFofReportDefinition()
+    private XMultiServiceFactory getMSFofReportDefinition()
     {
         if (m_xMSF == null)
         {
@@ -844,17 +843,14 @@ abstract public class ReportBuilderLayouter implements IReportBuilderLayouter
     }
 
 
-    protected Rectangle insertVerticalLine(XSection _xSection, Rectangle _aRect, int _nWidth, int _nHeight)
-    {
-        return insertLine(_xSection, _aRect, _nWidth, _nHeight, 1);
-    }
 
-    protected Rectangle insertHorizontalLine(XSection _xSection, Rectangle _aRect, int _nWidth, int _nHeight)
+
+    private Rectangle insertHorizontalLine(XSection _xSection, Rectangle _aRect, int _nWidth, int _nHeight)
     {
         return insertLine(_xSection, _aRect, _nWidth, _nHeight, 0);
     }
 
-    protected Rectangle insertLine(XSection _xSection, Rectangle _aRect, int _nWidth, int _nHeight, int _nOrientation)
+    private Rectangle insertLine(XSection _xSection, Rectangle _aRect, int _nWidth, int _nHeight, int _nOrientation)
     {
         if (_xSection != null)
         {
@@ -884,7 +880,7 @@ abstract public class ReportBuilderLayouter implements IReportBuilderLayouter
     }
 
 
-    protected void clearReportHeader()
+    private void clearReportHeader()
     {
         XSection xSection;
         try
@@ -901,7 +897,7 @@ abstract public class ReportBuilderLayouter implements IReportBuilderLayouter
         }
     }
 
-    protected void insertReportHeader()
+    private void insertReportHeader()
     {
         if (getDesignTemplate() != null)
         {
@@ -934,7 +930,7 @@ abstract public class ReportBuilderLayouter implements IReportBuilderLayouter
         }
     }
 
-    protected void clearReportFooter()
+    private void clearReportFooter()
     {
         XSection xSection;
         try
@@ -951,7 +947,7 @@ abstract public class ReportBuilderLayouter implements IReportBuilderLayouter
         }
     }
 
-    protected void insertReportFooter()
+    private void insertReportFooter()
     {
         if (getDesignTemplate() != null)
         {
@@ -985,7 +981,7 @@ abstract public class ReportBuilderLayouter implements IReportBuilderLayouter
     }
 
 
-    protected void clearPageHeader()
+    private void clearPageHeader()
     {
         XSection xSection;
         try
@@ -1002,7 +998,7 @@ abstract public class ReportBuilderLayouter implements IReportBuilderLayouter
         }
     }
 
-    protected void clearPageFooter()
+    private void clearPageFooter()
     {
         XSection xSection;
         try
@@ -1054,7 +1050,7 @@ abstract public class ReportBuilderLayouter implements IReportBuilderLayouter
      * @param _aFont
      * @return width of given text in 1/100mm
      */
-    Size getPreferredSize(String _sText, FontDescriptor _aFont)
+    private Size getPreferredSize(String _sText, FontDescriptor _aFont)
     {
         Size aSizeMM_100TH = new Size(0, 0);
         try
@@ -1101,7 +1097,7 @@ abstract public class ReportBuilderLayouter implements IReportBuilderLayouter
         return aSizeMM_100TH;
     }
 
-    protected String getTableName()
+    private String getTableName()
     {
         if (m_sTableName != null)
         {
@@ -1110,7 +1106,7 @@ abstract public class ReportBuilderLayouter implements IReportBuilderLayouter
         return PropertyNames.EMPTY_STRING;
     }
 
-    protected String getUserNameFromConfiguration()
+    private String getUserNameFromConfiguration()
     {
         String sFirstName = PropertyNames.EMPTY_STRING;
         String sLastName = PropertyNames.EMPTY_STRING;
@@ -1203,7 +1199,7 @@ abstract public class ReportBuilderLayouter implements IReportBuilderLayouter
         }
     }
 
-    protected void insertPageHeader()
+    private void insertPageHeader()
     {
         if (getDesignTemplate() != null)
         {
@@ -1304,7 +1300,7 @@ abstract public class ReportBuilderLayouter implements IReportBuilderLayouter
         }
     }
 
-    protected void insertPageFooter()
+    private void insertPageFooter()
     {
         if (getDesignTemplate() != null)
         {
@@ -1398,13 +1394,13 @@ abstract public class ReportBuilderLayouter implements IReportBuilderLayouter
     {
         return m_aResource;
     }
-    protected int m_aCommandType; // Table or Query
-    protected String m_sTableName;
-    protected String[] m_aGroupNames;
-    protected String[] m_aFieldNames;
-    protected String[] m_aFieldTitleNames;
-    protected int[] m_aFieldWidths;
-    protected int[] m_aFieldTypes;
+    private int m_aCommandType; // Table or Query
+    private String m_sTableName;
+    private String[] m_aGroupNames;
+    private String[] m_aFieldNames;
+    private String[] m_aFieldTitleNames;
+    private int[] m_aFieldWidths;
+    private int[] m_aFieldTypes;
     private DesignTemplate m_xDesignTemplate = null;
 
     public void initializeData(IReportBuilderLayouter _aOther)
@@ -1463,14 +1459,14 @@ abstract public class ReportBuilderLayouter implements IReportBuilderLayouter
      * @param _sLabel
      * @return the width in 1/100mm
      */
-    protected int getLabelWidth(String _sLabel)
+    private int getLabelWidth(String _sLabel)
     {
         return getLabelWidth(_sLabel, 0.0f, 0.0f);
     }
-    XFixedText m_aFixedTextHelper = null;
-    HashMap<String, Integer> m_aLabelWidthMap;
+    private XFixedText m_aFixedTextHelper = null;
+    private HashMap<String, Integer> m_aLabelWidthMap;
 
-    protected int getLabelWidth(String _sLabel, FontDescriptor _aFD)
+    private int getLabelWidth(String _sLabel, FontDescriptor _aFD)
     {
         float fCharWeight = 0.0f;
         float fCharHeight = 0.0f;
@@ -1482,7 +1478,7 @@ abstract public class ReportBuilderLayouter implements IReportBuilderLayouter
         return getLabelWidth(_sLabel, fCharWeight, fCharHeight);
     }
 
-    protected int getLabelWidth(String _sLabel, float _nCharWeight, float _nCharHeight)
+    private int getLabelWidth(String _sLabel, float _nCharWeight, float _nCharHeight)
     {
         int nWidth = 0;
 
