@@ -17,53 +17,45 @@
  */
 package com.sun.star.wizards.ui;
 
-import java.beans.*;
-
-import com.sun.star.wizards.ui.event.CommonListener;
-import com.sun.star.wizards.ui.event.EventNames;
-import com.sun.star.wizards.ui.event.MethodInvocation;
-import com.sun.star.uno.UnoRuntime;
-import com.sun.star.awt.*;
-import com.sun.star.uno.AnyConverter;
-import com.sun.star.uno.XInterface;
-import com.sun.star.lang.EventObject;
-import com.sun.star.lang.XSingleServiceFactory;
-import com.sun.star.lang.XMultiServiceFactory;
-import com.sun.star.wizards.common.Desktop;
-import com.sun.star.wizards.common.Helper;
-import com.sun.star.wizards.common.Resource;
+import java.beans.VetoableChangeListener;
+import com.sun.star.awt.ActionEvent;
+import com.sun.star.awt.FontDescriptor;
+import com.sun.star.awt.PushButtonType;
+import com.sun.star.awt.XControl;
+import com.sun.star.awt.XItemEventBroadcaster;
+import com.sun.star.awt.XTopWindow;
+import com.sun.star.beans.XPropertySet;
 import com.sun.star.container.XIndexContainer;
-import com.sun.star.frame.XTerminateListener;
 import com.sun.star.frame.TerminationVetoException;
+import com.sun.star.frame.XTerminateListener;
+import com.sun.star.lang.EventObject;
 import com.sun.star.lang.IllegalArgumentException;
-import com.sun.star.beans.*;
+import com.sun.star.lang.XMultiServiceFactory;
+import com.sun.star.lang.XSingleServiceFactory;
+import com.sun.star.uno.AnyConverter;
+import com.sun.star.uno.UnoRuntime;
+import com.sun.star.uno.XInterface;
+import com.sun.star.wizards.common.Desktop;
 import com.sun.star.wizards.common.HelpIds;
+import com.sun.star.wizards.common.Helper;
 import com.sun.star.wizards.common.PropertyNames;
+import com.sun.star.wizards.common.Resource;
+import com.sun.star.wizards.ui.event.XActionListenerAdapter;
+import com.sun.star.wizards.ui.event.XItemListenerAdapter;
 
-public abstract class WizardDialog extends UnoDialog2 implements VetoableChangeListener, XTerminateListener, XCompletion
+public abstract class WizardDialog extends UnoDialog2 implements VetoableChangeListener, XTerminateListener
 {
 
-    private static final String NEXT_ACTION_PERFORMED = "gotoNextAvailableStep";
-    private static final String BACK_ACTION_PERFORMED = "gotoPreviousAvailableStep";
-    private static final String FINISH_ACTION_PERFORMED = "finishWizard_1";
-    private static final String CANCEL_ACTION_PERFORMED = "cancelWizard_1";
-    private static final String HELP_ACTION_PERFORMED = "callHelp";
-    public VetoableChangeSupport vetos = new VetoableChangeSupport(this);
-    private String[] sRightPaneHeaders;
-    private int iButtonWidth = 50;
+    private static final int iButtonWidth = 50;
     private int nNewStep = 1;
     private int nOldStep = 1;
     private int nMaxStep = 1;
-    protected XItemListener RoadmapItemListener;
-    protected XControl xRoadmapControl;
-    XItemEventBroadcaster xRoadmapBroadcaster;
-    String[] sRMItemLabels;
+    private String[] sRMItemLabels;
     private Object oRoadmap;
     private XSingleServiceFactory xSSFRoadmap;
     public XIndexContainer xIndexContRoadmap;
-    private Resource oWizardResource;
-    public String sMsgEndAutopilot;
-    private int hid;
+    private final Resource oWizardResource;
+    private final int hid;
     private boolean bTerminateListenermustberemoved = true;
 
     /** Creates a new instance of WizardDialog
@@ -74,29 +66,22 @@ public abstract class WizardDialog extends UnoDialog2 implements VetoableChangeL
      * "HID:(hid+3)" - the next button
      * "HID:(hid+4)" - the create button
      * "HID:(hid+5)" - the cancel button
-     * @param xMSF
-     * @param hid_
      */
     public WizardDialog(XMultiServiceFactory xMSF, int hid_)
     {
         super(xMSF);
         hid = hid_;
-        oWizardResource = new Resource(xMSF, "Common", "dbw");
-        sMsgEndAutopilot = oWizardResource.getResText(UIConsts.RID_DB_COMMON + 33);
-
-    //new Resource(xMSF,"Common","com");
+        oWizardResource = new Resource(xMSF, "dbw");
+        oWizardResource.getResText(UIConsts.RID_DB_COMMON + 33);
     }
 
-    /**
-     *
-     * @return
-     */
+    @Override
     public Resource getResource()
     {
         return oWizardResource;
     }
 
-    public void activate()
+    private void activate()
     {
         try
         {
@@ -117,26 +102,6 @@ public abstract class WizardDialog extends UnoDialog2 implements VetoableChangeL
         nMaxStep = i;
     }
 
-    public int getMaxStep()
-    {
-        return nMaxStep;
-    }
-
-    public void setOldStep(int i)
-    {
-        nOldStep = i;
-    }
-
-    public int getOldStep()
-    {
-        return nOldStep;
-    }
-
-    public void setNewStep(int i)
-    {
-        nNewStep = i;
-    }
-
     public int getNewStep()
     {
         return nNewStep;
@@ -150,23 +115,6 @@ public abstract class WizardDialog extends UnoDialog2 implements VetoableChangeL
         nNewStep = nOldStep;
     }
 
-    public void itemStateChanged(com.sun.star.awt.ItemEvent itemEvent)
-    {
-        try
-        {
-            nNewStep = itemEvent.ItemId;
-            nOldStep = AnyConverter.toInt(Helper.getUnoPropertyValue(xDialogModel, PropertyNames.PROPERTY_STEP));
-            if (nNewStep != nOldStep)
-            {
-                switchToStep();
-            }
-        }
-        catch (com.sun.star.lang.IllegalArgumentException exception)
-        {
-            exception.printStackTrace(System.err);
-        }
-    }
-
     public void setRoadmapInteractive(boolean _bInteractive)
     {
         Helper.setUnoPropertyValue(oRoadmap, "Activated", Boolean.valueOf(_bInteractive));
@@ -177,7 +125,7 @@ public abstract class WizardDialog extends UnoDialog2 implements VetoableChangeL
         Helper.setUnoPropertyValue(oRoadmap, "Complete", Boolean.valueOf(bComplete));
     }
 
-    public boolean isRoadmapComplete()
+    private boolean isRoadmapComplete()
     {
         try
         {
@@ -197,12 +145,12 @@ public abstract class WizardDialog extends UnoDialog2 implements VetoableChangeL
             int nCurItemID = getCurrentRoadmapItemID();
             if (nCurItemID != ID)
             {
-                Helper.setUnoPropertyValue(oRoadmap, "CurrentItemID", new Short(ID));
+                Helper.setUnoPropertyValue(oRoadmap, "CurrentItemID", Short.valueOf(ID));
             }
         }
     }
 
-    public int getCurrentRoadmapItemID()
+    private int getCurrentRoadmapItemID()
     {
         try
         {
@@ -237,11 +185,11 @@ public abstract class WizardDialog extends UnoDialog2 implements VetoableChangeL
                     },
                     new Object[]
                     {
-                        new Integer(iDialogHeight - 26),
+                    Integer.valueOf(iDialogHeight - 26),
                         0,
                         0,
                         0,
-                        new Short((short)0),
+                        Short.valueOf((short)0),
                         Boolean.TRUE,
                         85
                     });
@@ -250,23 +198,30 @@ public abstract class WizardDialog extends UnoDialog2 implements VetoableChangeL
 
             xSSFRoadmap = UnoRuntime.queryInterface(XSingleServiceFactory.class, oRoadmap);
             xIndexContRoadmap = UnoRuntime.queryInterface(XIndexContainer.class, oRoadmap);
-            //    XPropertySet xPropRoadmapModel = (XPropertySet) UnoRuntime.queryInterface(XPropertySet.class, oRoadmap);
-            //    xPropRoadmapModel.addPropertyChangeListener("CurrentItemID", new WizardDialog.RoadmapItemListener(this.xDialogModel));
 
-            MethodInvocation mi = new MethodInvocation("itemStateChanged", this, com.sun.star.awt.ItemEvent.class);
-            getGuiEventListener().add("rdmNavi", EventNames.EVENT_ITEM_CHANGED, mi);
-            xRoadmapControl = this.xDlgContainer.getControl("rdmNavi");
-            xRoadmapBroadcaster = UnoRuntime.queryInterface(XItemEventBroadcaster.class, xRoadmapControl);
-            xRoadmapBroadcaster.addItemListener((XItemListener) getGuiEventListener());
+            XControl xRoadmapControl = this.xDlgContainer.getControl("rdmNavi");
+            XItemEventBroadcaster xRoadmapBroadcaster = UnoRuntime.queryInterface(XItemEventBroadcaster.class, xRoadmapControl);
+            xRoadmapBroadcaster.addItemListener(new XItemListenerAdapter() {
+                @Override
+                public void itemStateChanged(com.sun.star.awt.ItemEvent itemEvent) {
+                    try
+                    {
+                        nNewStep = itemEvent.ItemId;
+                        nOldStep = AnyConverter.toInt(Helper.getUnoPropertyValue(xDialogModel, PropertyNames.PROPERTY_STEP));
+                        if (nNewStep != nOldStep)
+                        {
+                            switchToStep();
+                        }
+                    }
+                    catch (com.sun.star.lang.IllegalArgumentException exception)
+                    {
+                        exception.printStackTrace(System.err);
+                    }
+                }
+            });
 
-            //     xRoadmapControl = this.xDlgContainer.getControl("rdmNavi");
-            //     xRoadmapBroadcaster.addItemListener(new RoadmapItemListener());
             Helper.setUnoPropertyValue(oRoadmap, "Text", oWizardResource.getResText(UIConsts.RID_COMMON + 16));
         }
-        catch (NoSuchMethodException ex)
-        {
-            Resource.showCommonResourceError(xMSF);
-        }
         catch (java.lang.Exception jexception)
         {
             jexception.printStackTrace(System.err);
@@ -278,18 +233,6 @@ public abstract class WizardDialog extends UnoDialog2 implements VetoableChangeL
         sRMItemLabels = _oResource.getResArray(StartResID, nMaxStep);
     }
 
-    public String[] getRMItemLabels()
-    {
-        return sRMItemLabels;
-    }
-
-    /*    public void insertRoadmapItems(int StartIndex, int RMCount)
-    {
-    Object oRoadmapItem;
-    boolean bEnabled;
-    for (int i = StartIndex; i < (StartIndex + RMCount); i++)
-    insertSingleRoadmapItem(i, true, sRMItemLabels[i], i);
-    }*/
     public int insertRoadmapItem(int _Index, boolean _bEnabled, int _LabelID, int _CurItemID)
     {
         return insertRoadmapItem(_Index, _bEnabled, sRMItemLabels[_LabelID], _CurItemID);
@@ -302,7 +245,7 @@ public abstract class WizardDialog extends UnoDialog2 implements VetoableChangeL
             Object oRoadmapItem = xSSFRoadmap.createInstance();
             Helper.setUnoPropertyValue(oRoadmapItem, PropertyNames.PROPERTY_LABEL, _sLabel);
             Helper.setUnoPropertyValue(oRoadmapItem, PropertyNames.PROPERTY_ENABLED, Boolean.valueOf(_bEnabled));
-            Helper.setUnoPropertyValue(oRoadmapItem, "ID", new Integer(_CurItemID));
+            Helper.setUnoPropertyValue(oRoadmapItem, "ID", Integer.valueOf(_CurItemID));
             xIndexContRoadmap.insertByIndex(Index, oRoadmapItem);
             return Index + 1;
         }
@@ -375,75 +318,24 @@ public abstract class WizardDialog extends UnoDialog2 implements VetoableChangeL
 
     abstract protected void enterStep(int nOldStep, int nNewStep);
 
-    protected void changeToStep(int nNewStep)
+    private void changeToStep(int nNewStep)
     {
-        Helper.setUnoPropertyValue(xDialogModel, PropertyNames.PROPERTY_STEP, new Integer(nNewStep));
+        Helper.setUnoPropertyValue(xDialogModel, PropertyNames.PROPERTY_STEP, Integer.valueOf(nNewStep));
         setCurrentRoadmapItemID((short) (nNewStep));
         enableNextButton(getNextAvailableStep() > 0);
         enableBackButton(nNewStep != 1);
     }
 
 
-    /* (non-Javadoc)
-     * @see com.sun.star.wizards.ui.XCompletion#iscompleted(int)
-     */
-    /**
-     *
-     * @param _ndialogpage
-     * @return
-     */
-    public boolean iscompleted(int _ndialogpage)
-    {
-        return false;
-    }
-    /* (non-Javadoc)
-     * @see com.sun.star.wizards.ui.XCompletion#ismodified(int)
-     */
-
-    /**
-     *
-     * @param _ndialogpage
-     * @return
-     */
-    public boolean ismodified(int _ndialogpage)
-    {
-        return false;
-    }
-    /* (non-Javadoc)
-     * @see com.sun.star.wizards.ui.XCompletion#setcompleted(int, boolean)
-     */
-
-    /**
-     *
-     * @param _ndialogpage
-     * @param _biscompleted
-     */
-    public void setcompleted(int _ndialogpage, boolean _biscompleted)
-    {
-    }
-    /* (non-Javadoc)
-     * @see com.sun.star.wizards.ui.XCompletion#setmodified(int, java.lang.Object, java.lang.Object)
-     */
-
-    /**
-     *
-     * @param _ndialogpage
-     * @param ooldValue
-     * @param onewValue
-     */
-    public void setmodified(int _ndialogpage, Object ooldValue, Object onewValue)
-    {
-    }
-
     public void drawNaviBar()
     {
 
         try
         {
             short curtabindex = UIConsts.SOFIRSTWIZARDNAVITABINDEX;
-            Integer IButtonWidth = new Integer(iButtonWidth);
+            Integer IButtonWidth = Integer.valueOf(iButtonWidth);
             int iButtonHeight = 14;
-            Integer IButtonHeight = new Integer(iButtonHeight);
+            Integer IButtonHeight = Integer.valueOf(iButtonHeight);
             Integer ICurStep = 0;
             int iDialogHeight = ((Integer) Helper.getUnoPropertyValue(this.xDialogModel, PropertyNames.PROPERTY_HEIGHT)).intValue();
             int iDialogWidth = ((Integer) Helper.getUnoPropertyValue(this.xDialogModel, PropertyNames.PROPERTY_WIDTH)).intValue();
@@ -461,7 +353,7 @@ public abstract class WizardDialog extends UnoDialog2 implements VetoableChangeL
                     },
                     new Object[]
                     {
-                        1, 0, 0, new Integer(iDialogHeight - 26), ICurStep, new Integer(iDialogWidth)
+                        1, 0, 0, Integer.valueOf(iDialogHeight - 26), ICurStep, Integer.valueOf(iDialogWidth)
                     });
 
             insertControlModel("com.sun.star.awt.UnoControlFixedLineModel", "lnRoadSep",
@@ -471,7 +363,7 @@ public abstract class WizardDialog extends UnoDialog2 implements VetoableChangeL
                     },
                     new Object[]
                     {
-                        new Integer(iBtnPosY - 6), 1, 85, 0, ICurStep, 1
+                    Integer.valueOf(iBtnPosY - 6), 1, 85, 0, ICurStep, 1
                     });
 
             String[] propNames = new String[]
@@ -480,47 +372,64 @@ public abstract class WizardDialog extends UnoDialog2 implements VetoableChangeL
             };
 
             Helper.setUnoPropertyValue(super.xDialogModel, PropertyNames.PROPERTY_HELPURL, HelpIds.getHelpIdString(hid));
-            insertButton("btnWizardHelp", HELP_ACTION_PERFORMED, new String[]
+            insertButton("btnWizardHelp", new XActionListenerAdapter() {
+                        @Override
+                        public void actionPerformed(ActionEvent event) {
+                            callHelp();
+                        }
+                    }, new String[]
                     {
                         PropertyNames.PROPERTY_ENABLED, PropertyNames.PROPERTY_HEIGHT, PropertyNames.PROPERTY_LABEL, PropertyNames.PROPERTY_POSITION_X, PropertyNames.PROPERTY_POSITION_Y, "PushButtonType", PropertyNames.PROPERTY_STEP, PropertyNames.PROPERTY_TABINDEX, PropertyNames.PROPERTY_WIDTH
                     },
                     new Object[]
                     {
-                        true, IButtonHeight, oWizardResource.getResText(UIConsts.RID_COMMON + 15), new Integer(iHelpPosX), new Integer(iBtnPosY), new Short((short) PushButtonType.HELP_value), ICurStep, new Short(curtabindex++), IButtonWidth
+                        true, IButtonHeight, oWizardResource.getResText(UIConsts.RID_COMMON + 15), Integer.valueOf(iHelpPosX), Integer.valueOf(iBtnPosY), Short.valueOf((short) PushButtonType.HELP_value), ICurStep, Short.valueOf(curtabindex++), IButtonWidth
                     });
-            insertButton("btnWizardBack", BACK_ACTION_PERFORMED, propNames,
+            insertButton("btnWizardBack", new XActionListenerAdapter() {
+                        @Override
+                        public void actionPerformed(ActionEvent event) {
+                            gotoPreviousAvailableStep();
+                        }
+                    }, propNames,
                     new Object[]
                     {
-                        false, IButtonHeight, HelpIds.getHelpIdString(hid + 2), oWizardResource.getResText(UIConsts.RID_COMMON + 13), new Integer(iBackPosX), new Integer(iBtnPosY), new Short((short) PushButtonType.STANDARD_value), ICurStep, new Short(curtabindex++), IButtonWidth
+                        false, IButtonHeight, HelpIds.getHelpIdString(hid + 2), oWizardResource.getResText(UIConsts.RID_COMMON + 13), Integer.valueOf(iBackPosX), Integer.valueOf(iBtnPosY), Short.valueOf((short) PushButtonType.STANDARD_value), ICurStep, Short.valueOf(curtabindex++), IButtonWidth
                     });
 
-            insertButton("btnWizardNext", NEXT_ACTION_PERFORMED, propNames,
+            insertButton("btnWizardNext", new XActionListenerAdapter() {
+                        @Override
+                        public void actionPerformed(ActionEvent event) {
+                            gotoNextAvailableStep();
+                        }
+                    }, propNames,
                     new Object[]
                     {
-                        true, IButtonHeight, HelpIds.getHelpIdString(hid + 3), oWizardResource.getResText(UIConsts.RID_COMMON + 14), new Integer(iNextPosX), new Integer(iBtnPosY), new Short((short) PushButtonType.STANDARD_value), ICurStep, new Short(curtabindex++), IButtonWidth
+                        true, IButtonHeight, HelpIds.getHelpIdString(hid + 3), oWizardResource.getResText(UIConsts.RID_COMMON + 14), Integer.valueOf(iNextPosX), Integer.valueOf(iBtnPosY), Short.valueOf((short) PushButtonType.STANDARD_value), ICurStep, Short.valueOf(curtabindex++), IButtonWidth
                     });
 
-            insertButton("btnWizardFinish", FINISH_ACTION_PERFORMED, propNames,
+            insertButton("btnWizardFinish", new XActionListenerAdapter() {
+                        @Override
+                        public void actionPerformed(ActionEvent event) {
+                            finishWizard_1();
+                        }
+                    }, propNames,
                     new Object[]
                     {
-                        true, IButtonHeight, HelpIds.getHelpIdString(hid + 4), oWizardResource.getResText(UIConsts.RID_COMMON + 12), new Integer(iFinishPosX), new Integer(iBtnPosY), new Short((short) PushButtonType.STANDARD_value), ICurStep, new Short(curtabindex++), IButtonWidth
+                        true, IButtonHeight, HelpIds.getHelpIdString(hid + 4), oWizardResource.getResText(UIConsts.RID_COMMON + 12), Integer.valueOf(iFinishPosX), Integer.valueOf(iBtnPosY), Short.valueOf((short) PushButtonType.STANDARD_value), ICurStep, Short.valueOf(curtabindex++), IButtonWidth
                     });
 
-            insertButton("btnWizardCancel", CANCEL_ACTION_PERFORMED, propNames,
+            insertButton("btnWizardCancel", new XActionListenerAdapter() {
+                        @Override
+                        public void actionPerformed(ActionEvent event) {
+                            cancelWizard_1();
+                        }
+                    }, propNames,
                     new Object[]
                     {
-                        true, IButtonHeight, HelpIds.getHelpIdString(hid + 5), oWizardResource.getResText(UIConsts.RID_COMMON + 11), new Integer(iCancelPosX), new Integer(iBtnPosY), new Short((short) PushButtonType.STANDARD_value), ICurStep, new Short(curtabindex++), IButtonWidth
+                        true, IButtonHeight, HelpIds.getHelpIdString(hid + 5), oWizardResource.getResText(UIConsts.RID_COMMON + 11), Integer.valueOf(iCancelPosX), Integer.valueOf(iBtnPosY), Short.valueOf((short) PushButtonType.STANDARD_value), ICurStep, Short.valueOf(curtabindex++), IButtonWidth
                     });
 
             setControlProperty("btnWizardNext", "DefaultButton", Boolean.TRUE);
-            // add a window listener, to know
-            // if the user used "escape" key to
-            // close the dialog.
-            MethodInvocation windowHidden = new MethodInvocation("windowHidden", this);
-            xWindow.addWindowListener((CommonListener) getGuiEventListener());
-            String dialogName = (String) Helper.getUnoPropertyValue(xDialogModel, PropertyNames.PROPERTY_NAME);
-            getGuiEventListener().add(dialogName, EVENT_ACTION_PERFORMED, windowHidden);
-
         }
         catch (java.lang.Exception jexception)
         {
@@ -528,28 +437,7 @@ public abstract class WizardDialog extends UnoDialog2 implements VetoableChangeL
         }
     }
 
-    protected void insertRoadMapItems(String[] items, int[] steps, boolean[] enabled)
-    {
-        for (int i = 0; i < items.length; i++)
-        {
-            insertRoadmapItem(i, enabled[i], items[i], steps[i]);
-        }
-    }
 
-    /** This method also enables and disables the "next" button,
-     * if the step currently dis/enabled is the one of the next steps.
-     * @param _nStep
-     * @param bEnabled
-     * @param enableNextButton
-     */
-    public void setStepEnabled(int _nStep, boolean bEnabled, boolean enableNextButton)
-    {
-        setStepEnabled(_nStep, bEnabled);
-        if (getNextAvailableStep() > 0)
-        {
-            enableNextButton(bEnabled);
-        }
-    }
 
     public void enableNavigationButtons(boolean _bEnableBack, boolean _bEnableNext, boolean _bEnableFinish)
     {
@@ -558,7 +446,7 @@ public abstract class WizardDialog extends UnoDialog2 implements VetoableChangeL
         enableFinishButton(_bEnableFinish);
     }
 
-    public void enableBackButton(boolean enabled)
+    private void enableBackButton(boolean enabled)
     {
         setControlProperty("btnWizardBack", PropertyNames.PROPERTY_ENABLED, enabled ? Boolean.TRUE : Boolean.FALSE);
     }
@@ -597,12 +485,12 @@ public abstract class WizardDialog extends UnoDialog2 implements VetoableChangeL
             }
             else
             {
-                enableNextButton(!(getCurrentStep() == nMaxStep));
+                enableNextButton(getCurrentStep() != nMaxStep);
             }
         }
     }
 
-    public boolean isStepEnabled(int _nStep)
+    private boolean isStepEnabled(int _nStep)
     {
         try
         {
@@ -623,7 +511,7 @@ public abstract class WizardDialog extends UnoDialog2 implements VetoableChangeL
         }
     }
 
-    public synchronized void gotoPreviousAvailableStep()
+    private synchronized void gotoPreviousAvailableStep()
     {
         boolean bIsEnabled;
         if (nNewStep > 1)
@@ -648,7 +536,7 @@ public abstract class WizardDialog extends UnoDialog2 implements VetoableChangeL
     }
 
     //TODO discuss with rp
-    protected int getNextAvailableStep()
+    private int getNextAvailableStep()
     {
         if (isRoadmapComplete())
         {
@@ -663,7 +551,7 @@ public abstract class WizardDialog extends UnoDialog2 implements VetoableChangeL
         return -1;
     }
 
-    public synchronized void gotoNextAvailableStep()
+    private synchronized void gotoNextAvailableStep()
     {
         nOldStep = nNewStep;
         nNewStep = getNextAvailableStep();
@@ -678,7 +566,7 @@ public abstract class WizardDialog extends UnoDialog2 implements VetoableChangeL
     /**
      * This function will call if the finish button is pressed on the UI.
      */
-    public void finishWizard_1()
+    private void finishWizard_1()
     {
         enableFinishButton(false);
         boolean success = false;
@@ -695,11 +583,6 @@ public abstract class WizardDialog extends UnoDialog2 implements VetoableChangeL
             removeTerminateListener();
     }
 
-    public int getMaximalStep()
-    {
-        return this.nMaxStep;
-    }
-
     public int getCurrentStep()
     {
         try
@@ -728,36 +611,35 @@ public abstract class WizardDialog extends UnoDialog2 implements VetoableChangeL
     public void setRightPaneHeaders(String[] _sRightPaneHeaders)
     {
         this.nMaxStep = _sRightPaneHeaders.length;
-        this.sRightPaneHeaders = _sRightPaneHeaders;
         FontDescriptor oFontDesc = new FontDescriptor();
         oFontDesc.Weight = com.sun.star.awt.FontWeight.BOLD;
 
-        for (int i = 0; i < sRightPaneHeaders.length; i++)
+        for (int i = 0; i < _sRightPaneHeaders.length; i++)
         {
-            insertLabel("lblQueryTitle" + String.valueOf(i),
+            insertLabel("lblQueryTitle" + i,
                     new String[]
                     {
                         PropertyNames.FONT_DESCRIPTOR, PropertyNames.PROPERTY_HEIGHT, PropertyNames.PROPERTY_LABEL, PropertyNames.PROPERTY_MULTILINE, PropertyNames.PROPERTY_POSITION_X, PropertyNames.PROPERTY_POSITION_Y, PropertyNames.PROPERTY_STEP, PropertyNames.PROPERTY_TABINDEX, PropertyNames.PROPERTY_WIDTH
                     },
                     new Object[]
                     {
-                        oFontDesc, 16, sRightPaneHeaders[i], Boolean.TRUE, 91, 8, new Integer(i + 1), new Short((short) 12), 212
+                        oFontDesc, 16, _sRightPaneHeaders[i], Boolean.TRUE, 91, 8, Integer.valueOf(i + 1), Short.valueOf((short) 12), 212
                     });
         }
     }
 
     public void cancelWizard()
     {
-        //can be overwritten by extending class
+        //can be overridden by extending class
         xDialog.endExecute();
     }
 
-    public void callHelp()
+    private void callHelp()
     {
-        //should be overwritten by extending class
+        //should be overridden by extending class
     }
 
-    public void removeTerminateListener()
+    private void removeTerminateListener()
     {
         if (bTerminateListenermustberemoved)
         {
@@ -772,17 +654,12 @@ public abstract class WizardDialog extends UnoDialog2 implements VetoableChangeL
      * if this method was not called before,
      * perform a cancel.
      */
-    public void cancelWizard_1()
+    private void cancelWizard_1()
     {
         cancelWizard();
         removeTerminateListener();
     }
 
-    public void windowHidden()
-    {
-        cancelWizard_1();
-    }
-
     public void notifyTermination(EventObject arg0)
     {
         cancelWizard_1();
