@@ -25,12 +25,7 @@ from ..ui.event.CommonListener import StreamListenerProcAdapter
 from .ProcessErrors import ProcessErrors
 from .ExtensionVerifier import ExtensionVerifier
 from .ErrorHandler import ErrorHandler
-from .data.CGContent import CGContent
 from .data.CGDocument import CGDocument
-from .data.CGExporter import CGExporter
-from .data.CGLayout import CGLayout
-from .data.CGPublish import CGPublish
-from .data.CGSettings import CGSettings
 
 from com.sun.star.io import IOException
 from com.sun.star.uno import SecurityException
@@ -210,7 +205,7 @@ class Process(ProcessErrors):
         task.advance(True)
 
     # Copy "static" files (which are always the same,
-    # thus not user-input-dependant) to a target directory.
+    # thus not user-input-dependent) to a target directory.
     # Note that this method is static since it is
     # also used when displaying a "preview"
     # @param copy
@@ -380,6 +375,7 @@ class Process(ProcessErrors):
             self.tf.start()
             while (not self.tfCompleted):
                 pass
+            self.tf.terminate()
             task.advance(True)
 
 
@@ -405,7 +401,6 @@ class Process(ProcessErrors):
         print ("DEBUG !!! Stream 'error' event handler")
 
     def streamClosedHandler(self, parent):
-        parent.tf.terminate()
         parent.tfCompleted = True
 
     # I broke the export method to two methods
@@ -451,7 +446,7 @@ class Process(ProcessErrors):
                     #
                     # In present this is always the case.
                     # may be in the future, when
-                    # a tree is used, it will be abit different.
+                    # a tree is used, it will be a bit different.
                     if (isinstance (item, CGDocument)):
                         if (not self.export2(item, contentDir, task)):
                             return False
@@ -498,7 +493,7 @@ class Process(ProcessErrors):
 
         try:
              # here I calculate the destination filename.
-             # I take the original filename (docFilename), substract the extension, (docExt) -> (fn)
+             # I take the original filename (docFilename), subtract the extension, (docExt) -> (fn)
              # and find an available filename which starts with
              # this filename, but with the new extension. (destExt)
             docFilename = FileAccess.getFilename(doc.cp_URL)
@@ -523,7 +518,7 @@ class Process(ProcessErrors):
 
             # if two files with the same name
             # need to be exported ? So here
-            # i get a new filename, so I do not
+            # I get a new filename, so I do not
             # overwrite files...
             f = self.fileAccess.getNewFile(folder, fn, destExt)
 
@@ -605,7 +600,7 @@ class Process(ProcessErrors):
             self.exporters[export.cp_Name] = exp
         return exp
 
-    # @return tru if everything went smooth, false
+    # @return true if everything went smooth, false
     # if error(s) accured.
     def getResult(self):
         return (self.myTask.getFailed() == 0) and self.result
