@@ -33,13 +33,13 @@
 
 #include <osl/diagnose.h>
 #include <rtl/ustring.hxx>
-#include <comphelper/sequenceashashmap.hxx>
 #include <comphelper/sequence.hxx>
+#include <comphelper/propertyvalue.hxx>
 
 using namespace com::sun::star;
 
 #define MAKE_PROPVAL(NameId, Value) \
-    beans::PropertyValue(aPropNameSupplier.GetName(NameId), 0, uno::makeAny(Value), beans::PropertyState_DIRECT_VALUE )
+    beans::PropertyValue(getPropertyName(NameId), 0, uno::makeAny(Value), beans::PropertyState_DIRECT_VALUE )
 
 #define NUMBERING_MAX_LEVELS    10
 
@@ -49,24 +49,6 @@ namespace dmapper {
 
 //---------------------------------------------------  Utility functions
 
-#ifdef DEBUG_WRITERFILTER
-void lcl_printProperties( uno::Sequence< beans::PropertyValue > const & aProps )
-{
-    sal_Int32 nLen = aProps.getLength( );
-    for ( sal_Int32 i = 0; i < nLen; i++ )
-    {
-        uno::Any aValue = aProps[i].Value;
-        sal_Int32 nValue = 0;
-        OUString sValue;
-
-        if ( !( aValue >>= sValue ) && ( aValue >>= nValue ) )
-            sValue = OUString::number( nValue );
-
-        SAL_INFO("writerfilter", "Property " << aProps[i].Name << ": " << sValue);
-    }
-}
-#endif
-
 sal_Int32 lcl_findProperty( const uno::Sequence< beans::PropertyValue >& aProps, const OUString& sName )
 {
     sal_Int32 i = 0;
@@ -242,15 +224,7 @@ uno::Sequence< beans::PropertyValue > ListLevel::GetCharStyleProperties( )
             rProperties.push_back(beans::PropertyValue(aValIter->Name, 0, aValIter->Value, beans::PropertyState_DIRECT_VALUE));
     }
 
-    uno::Sequence< beans::PropertyValue > aRet( rProperties.size() );
-    beans::PropertyValue* pValues = aRet.getArray();
-    PropertyValueVector_t::const_iterator aIt = rProperties.begin();
-    PropertyValueVector_t::const_iterator aEndIt = rProperties.end();
-    for(sal_uInt32 nIndex = 0; aIt != aEndIt; ++aIt,++nIndex)
-    {
-        pValues[nIndex] = *aIt;
-    }
-    return aRet;
+    return comphelper::containerToSequence(rProperties);
 }
 
 uno::Sequence< beans::PropertyValue > ListLevel::GetLevelProperties( )
@@ -262,7 +236,6 @@ uno::Sequence< beans::PropertyValue > ListLevel::GetLevelProperties( )
         text::HoriOrientation::RIGHT,
     };
 
-    PropertyNameSupplier& aPropNameSupplier = PropertyNameSupplier::GetPropertyNameSupplier();
     std::vector<beans::PropertyValue> aNumberingProperties;
 
     if( m_nIStartAt >= 0)
@@ -337,14 +310,14 @@ uno::Sequence< beans::PropertyValue > ListLevel::GetLevelProperties( )
         boost::optional<PropertyMap::Property> aProp = getProperty(aReadIds[i]);
         if (aProp)
             aNumberingProperties.push_back(
-                    beans::PropertyValue( aPropNameSupplier.GetName(aProp->first), 0, aProp->second, beans::PropertyState_DIRECT_VALUE )
+                    beans::PropertyValue( getPropertyName(aProp->first), 0, aProp->second, beans::PropertyState_DIRECT_VALUE )
                     );
     }
 
     boost::optional<PropertyMap::Property> aPropFont = getProperty(PROP_CHAR_FONT_NAME);
     if(aPropFont && !isOutlineNumbering())
         aNumberingProperties.push_back(
-                beans::PropertyValue( aPropNameSupplier.GetName(PROP_BULLET_FONT_NAME), 0, aPropFont->second, beans::PropertyState_DIRECT_VALUE )
+                beans::PropertyValue( getPropertyName(PROP_BULLET_FONT_NAME), 0, aPropFont->second, beans::PropertyState_DIRECT_VALUE )
                 );
 
     return comphelper::containerToSequence(aNumberingProperties);
@@ -354,11 +327,10 @@ uno::Sequence< beans::PropertyValue > ListLevel::GetLevelProperties( )
 void ListLevel::AddParaProperties( uno::Sequence< beans::PropertyValue >* props )
 {
     uno::Sequence< beans::PropertyValue >& aProps = *props;
-    PropertyNameSupplier& aPropNameSupplier = PropertyNameSupplier::GetPropertyNameSupplier();
 
-    OUString sFirstLineIndent = aPropNameSupplier.GetName(
+    OUString sFirstLineIndent = getPropertyName(
             PROP_FIRST_LINE_INDENT );
-    OUString sIndentAt = aPropNameSupplier.GetName(
+    OUString sIndentAt = getPropertyName(
             PROP_INDENT_AT );
 
     bool hasFirstLineIndent = lcl_findProperty( aProps, sFirstLineIndent );
@@ -372,9 +344,9 @@ void ListLevel::AddParaProperties( uno::Sequence< beans::PropertyValue >* props
     // ParaFirstLineIndent -> FirstLineIndent
     // ParaLeftMargin -> IndentAt
 
-    OUString sParaIndent = aPropNameSupplier.GetName(
+    OUString sParaIndent = getPropertyName(
             PROP_PARA_FIRST_LINE_INDENT );
-    OUString sParaLeftMargin = aPropNameSupplier.GetName(
+    OUString sParaLeftMargin = getPropertyName(
             PROP_PARA_LEFT_MARGIN );
 
     sal_Int32 nLen = aParaProps.getLength( );
@@ -557,10 +529,8 @@ void ListDef::CreateNumberingRules( DomainMapper& rDMapper,
             uno::Any oStyle = xStyles->getByName( sStyleName );
             xStyle.set( oStyle, uno::UNO_QUERY_THROW );
 
-            PropertyNameSupplier& aPropNameSupplier = PropertyNameSupplier::GetPropertyNameSupplier();
-
             // Get the default OOo Numbering style rules
-            uno::Any aRules = xStyle->getPropertyValue( aPropNameSupplier.GetName( PROP_NUMBERING_RULES ) );
+            uno::Any aRules = xStyle->getPropertyValue( getPropertyName( PROP_NUMBERING_RULES ) );
             aRules >>= m_xNumRules;
 
             uno::Sequence< uno::Sequence< beans::PropertyValue > > aProps = GetPropertyValues( );
@@ -573,11 +543,7 @@ void ListDef::CreateNumberingRules( DomainMapper& rDMapper,
                 ListLevel::Pointer pLevel = GetLevel( nLevel );
 
                 // Get the merged level properties
-                uno::Sequence< beans::PropertyValue > aLvlProps = aProps[sal_Int32( nLevel )];
-
-#ifdef DEBUG_WRITERFILTER
-                lcl_printProperties( aLvlProps );
-#endif
+                auto aLvlProps = comphelper::sequenceToContainer< std::vector<beans::PropertyValue> >(aProps[sal_Int32(nLevel)]);
 
                 // Get the char style
                 uno::Sequence< beans::PropertyValue > aAbsCharStyleProps = pAbsLevel->GetCharStyleProperties( );
@@ -602,9 +568,7 @@ void ListDef::CreateNumberingRules( DomainMapper& rDMapper,
                     //create (or find) a character style containing the character
                     // attributes of the symbol and apply it to the numbering level
                     OUString sStyle = rDMapper.getOrCreateCharStyle( aStyleProps, /*bAlwaysCreate=*/true );
-                    aLvlProps.realloc( aLvlProps.getLength() + 1);
-                    aLvlProps[sal::static_int_cast<sal_uInt32>(aLvlProps.getLength()) - 1].Name = aPropNameSupplier.GetName( PROP_CHAR_STYLE_NAME );
-                    aLvlProps[sal::static_int_cast<sal_uInt32>(aLvlProps.getLength()) - 1].Value <<= sStyle;
+                    aLvlProps.push_back(comphelper::makePropertyValue(getPropertyName(PROP_CHAR_STYLE_NAME), sStyle));
                 }
 
                 // Get the prefix / suffix / Parent numbering
@@ -621,21 +585,20 @@ void ListDef::CreateNumberingRules( DomainMapper& rDMapper,
                 sal_Int16 nParentNum = ListLevel::GetParentNumbering(
                        sText, nLevel, rPrefix, rSuffix );
 
-                aLvlProps.realloc( aLvlProps.getLength( ) + 4 );
-                aLvlProps[sal::static_int_cast<sal_uInt32>(aLvlProps.getLength()) - 4] = MAKE_PROPVAL( PROP_PREFIX, rPrefix );
+                aLvlProps.push_back(comphelper::makePropertyValue(getPropertyName(PROP_PREFIX), rPrefix));
 
                 if (sText.isEmpty())
                 {
                     // Empty <w:lvlText>? Then put a Unicode "zero width space" as a suffix, so LabelFollowedBy is still shown, as in Word.
                     // With empty suffix, Writer does not show LabelFollowedBy, either.
-                    comphelper::SequenceAsHashMap aMap(aLvlProps);
-                    if (aMap.find("NumberingType") != aMap.end())
+                    auto it = std::find_if(aLvlProps.begin(), aLvlProps.end(), [](const beans::PropertyValue& rValue) { return rValue.Name == "NumberingType"; });
+                    if (it != aLvlProps.end())
                     {
-                        sal_Int16 nNumberFormat = aMap["NumberingType"].get<sal_Int16>();
+                        sal_Int16 nNumberFormat = it->Value.get<sal_Int16>();
 
                         // No need for a zero width space without a real LabelFollowedBy.
                         bool bLabelFollowedBy = true;
-                        auto it = std::find_if(aLvlProps.begin(), aLvlProps.end(), [](const beans::PropertyValue& rValue) { return rValue.Name == "LabelFollowedBy"; });
+                        it = std::find_if(aLvlProps.begin(), aLvlProps.end(), [](const beans::PropertyValue& rValue) { return rValue.Name == "LabelFollowedBy"; });
                         if (it != aLvlProps.end())
                         {
                             sal_Int16 nValue;
@@ -648,15 +611,14 @@ void ListDef::CreateNumberingRules( DomainMapper& rDMapper,
                     }
                 }
 
-                aLvlProps[sal::static_int_cast<sal_uInt32>(aLvlProps.getLength()) - 3] = MAKE_PROPVAL( PROP_SUFFIX, rSuffix );
-                aLvlProps[sal::static_int_cast<sal_uInt32>(aLvlProps.getLength()) - 2] = MAKE_PROPVAL( PROP_PARENT_NUMBERING, nParentNum );
+                aLvlProps.push_back(comphelper::makePropertyValue(getPropertyName(PROP_SUFFIX), rSuffix));
+                aLvlProps.push_back(comphelper::makePropertyValue(getPropertyName(PROP_PARENT_NUMBERING), nParentNum));
 
-                aLvlProps[sal::static_int_cast<sal_uInt32>(aLvlProps.getLength()) - 1] = MAKE_PROPVAL( PROP_POSITION_AND_SPACE_MODE,
-                            sal_Int16( text::PositionAndSpaceMode::LABEL_ALIGNMENT ) );
+                aLvlProps.push_back(comphelper::makePropertyValue(getPropertyName(PROP_POSITION_AND_SPACE_MODE), sal_Int16(text::PositionAndSpaceMode::LABEL_ALIGNMENT)));
 
 
                 // Replace the numbering rules for the level
-                m_xNumRules->replaceByIndex( nLevel, uno::makeAny( aLvlProps ) );
+                m_xNumRules->replaceByIndex(nLevel, uno::makeAny(comphelper::containerToSequence(aLvlProps)));
 
                 // Handle the outline level here
                 if ( pAbsLevel->isOutlineNumbering())
@@ -667,18 +629,16 @@ void ListDef::CreateNumberingRules( DomainMapper& rDMapper,
                         xOutlines->getChapterNumberingRules( );
 
                     StyleSheetEntryPtr pParaStyle = pAbsLevel->GetParaStyle( );
-                    aLvlProps.realloc( aLvlProps.getLength() + 1 );
-                    aLvlProps[sal::static_int_cast<sal_uInt32>(aLvlProps.getLength()) - 1] = MAKE_PROPVAL( PROP_HEADING_STYLE_NAME,
-                        pParaStyle->sConvertedStyleName );
+                    aLvlProps.push_back(comphelper::makePropertyValue(getPropertyName(PROP_HEADING_STYLE_NAME), pParaStyle->sConvertedStyleName));
 
-                    xOutlineRules->replaceByIndex( nLevel, uno::makeAny( aLvlProps ) );
+                    xOutlineRules->replaceByIndex(nLevel, uno::makeAny(comphelper::containerToSequence(aLvlProps)));
                 }
 
                 nLevel++;
             }
 
             // Create the numbering style for these rules
-            OUString sNumRulesName = aPropNameSupplier.GetName( PROP_NUMBERING_RULES );
+            OUString sNumRulesName = getPropertyName( PROP_NUMBERING_RULES );
             xStyle->setPropertyValue( sNumRulesName, uno::makeAny( m_xNumRules ) );
         }
         catch( const lang::IllegalArgumentException& e )
