@@ -345,7 +345,7 @@ void SchXMLChartContext::StartElement( const uno::Reference< xml::sax::XAttribut
 
     if( bHasAddin )
     {
-        //correct charttype serveice name when having an addin
+        //correct charttype service name when having an addin
         //and don't refresh addin during load
         uno::Reference< beans::XPropertySet > xDocProp( mrImportHelper.GetChartDocument(), uno::UNO_QUERY );
         if( xDocProp.is() )
@@ -373,7 +373,7 @@ void SchXMLChartContext::StartElement( const uno::Reference< xml::sax::XAttribut
             const SvXMLStyleContext* pStyle = pStylesCtxt->FindStyleChildContext(
                 SchXMLImportHelper::GetChartFamilyID(), sAutoStyleName );
 
-            if( pStyle && pStyle->ISA( XMLPropStyleContext ))
+            if( pStyle && dynamic_cast< const XMLPropStyleContext*>(pStyle) !=  nullptr)
                 const_cast<XMLPropStyleContext*>( static_cast< const XMLPropStyleContext* >( pStyle ) )->FillPropertySet( xProp );
         }
     }
@@ -867,7 +867,7 @@ void SchXMLChartContext::EndElement()
 
         // set autostyles for series and data points
         const SvXMLStylesContext* pStylesCtxt = mrImportHelper.GetAutoStylesContext();
-        const SvXMLStyleContext* pStyle = NULL;
+        const SvXMLStyleContext* pStyle = nullptr;
         OUString sCurrStyleName;
 
         if( pStylesCtxt )
@@ -957,27 +957,27 @@ void SchXMLChartContext::MergeSeriesForStockChart()
                 if( bHasJapaneseCandlestick )
                 {
                     // open values
-                    lcl_setRoleAtFirstSequence( aSeriesSeq[ nSeriesIndex ], OUString( "values-first" ));
+                    lcl_setRoleAtFirstSequence( aSeriesSeq[ nSeriesIndex ], "values-first");
                     aNewSeries[i] = aSeriesSeq[ nSeriesIndex ];
                     // low values
                     lcl_MoveDataToCandleStickSeries(
                         uno::Reference< chart2::data::XDataSource >( aSeriesSeq[ ++nSeriesIndex ], uno::UNO_QUERY_THROW ),
-                        aNewSeries[i], OUString( "values-min" ));
+                        aNewSeries[i], "values-min");
                 }
                 else
                 {
                     // low values
-                    lcl_setRoleAtFirstSequence( aSeriesSeq[ nSeriesIndex ], OUString( "values-min" ));
+                    lcl_setRoleAtFirstSequence( aSeriesSeq[ nSeriesIndex ], "values-min");
                     aNewSeries[i] = aSeriesSeq[ nSeriesIndex ];
                 }
                 // high values
                 lcl_MoveDataToCandleStickSeries(
                     uno::Reference< chart2::data::XDataSource >( aSeriesSeq[ ++nSeriesIndex ], uno::UNO_QUERY_THROW ),
-                    aNewSeries[i], OUString( "values-max" ));
+                    aNewSeries[i], "values-max");
                 // close values
                 lcl_MoveDataToCandleStickSeries(
                     uno::Reference< chart2::data::XDataSource >( aSeriesSeq[ ++nSeriesIndex ], uno::UNO_QUERY_THROW ),
-                    aNewSeries[i], OUString( "values-last" ));
+                    aNewSeries[i], "values-last");
             }
             xDSContainer->setDataSeries( aNewSeries );
         }
@@ -993,7 +993,7 @@ SvXMLImportContext* SchXMLChartContext::CreateChildContext(
     const OUString& rLocalName,
     const uno::Reference< xml::sax::XAttributeList >& xAttrList )
 {
-    SvXMLImportContext* pContext = 0;
+    SvXMLImportContext* pContext = nullptr;
     const SvXMLTokenMap& rTokenMap = mrImportHelper.GetChartElemTokenMap();
     uno::Reference< chart::XChartDocument > xDoc = mrImportHelper.GetChartDocument();
     uno::Reference< beans::XPropertySet > xProp( xDoc, uno::UNO_QUERY );
@@ -1080,7 +1080,7 @@ SvXMLImportContext* SchXMLChartContext::CreateChildContext(
             {
                 uno::Reference< drawing::XDrawPageSupplier  > xSupp( xDoc, uno::UNO_QUERY );
                 if( xSupp.is())
-                    mxDrawPage = uno::Reference< drawing::XShapes >( xSupp->getDrawPage(), uno::UNO_QUERY );
+                    mxDrawPage.set( xSupp->getDrawPage(), uno::UNO_QUERY );
 
                 SAL_WARN_IF( !mxDrawPage.is(), "xmloff.chart", "Invalid Chart Page" );
             }
@@ -1115,10 +1115,10 @@ void SchXMLChartContext::InitChart(
     uno::Reference< chart2::XChartDocument > xNewDoc( mrImportHelper.GetChartDocument(), uno::UNO_QUERY );
     if( xNewDoc.is())
     {
-        xNewDoc->setFirstDiagram( 0 );
+        xNewDoc->setFirstDiagram( nullptr );
         uno::Reference< chart2::XTitled > xTitled( xNewDoc, uno::UNO_QUERY );
         if( xTitled.is())
-            xTitled->setTitleObject( 0 );
+            xTitled->setTitleObject( nullptr );
     }
 
     //  Set the chart type via setting the diagram.
@@ -1199,7 +1199,7 @@ void SchXMLTitleContext::StartElement( const uno::Reference< xml::sax::XAttribut
                 const SvXMLStyleContext* pStyle = pStylesCtxt->FindStyleChildContext(
                     SchXMLImportHelper::GetChartFamilyID(), msAutoStyleName );
 
-                if( pStyle && pStyle->ISA( XMLPropStyleContext ))
+                if( pStyle && dynamic_cast< const XMLPropStyleContext*>(pStyle) !=  nullptr)
                     const_cast<XMLPropStyleContext*>( static_cast< const XMLPropStyleContext* >( pStyle ) )->FillPropertySet( xProp );
             }
         }
@@ -1211,7 +1211,7 @@ SvXMLImportContext* SchXMLTitleContext::CreateChildContext(
     const OUString& rLocalName,
     const uno::Reference< xml::sax::XAttributeList >& )
 {
-    SvXMLImportContext* pContext = 0;
+    SvXMLImportContext* pContext = nullptr;
 
     if( (nPrefix == XML_NAMESPACE_TEXT ||
                 nPrefix == XML_NAMESPACE_LO_EXT) &&
