@@ -55,8 +55,6 @@ struct ltint32
   }
 };
 
-typedef std::map<sal_Int32,com::sun::star::uno::Reference< com::sun::star::drawing::XShape >,ltint32> IdShapeMap;
-
 struct ConnectionHint
 {
     com::sun::star::uno::Reference< com::sun::star::drawing::XShape > mxConnector;
@@ -97,7 +95,8 @@ struct XMLShapeImportHelperImpl
     // context for sorting shapes
     ShapeSortContext*           mpSortContext;
 
-    IdShapeMap                  maShapeIds;
+    std::map<sal_Int32, com::sun::star::uno::Reference< com::sun::star::drawing::XShape >, ltint32>
+                                maShapeIds;
 
     std::vector<ConnectionHint> maConnections;
 
@@ -112,24 +111,25 @@ XMLShapeImportHelper::XMLShapeImportHelper(
         SvXMLImport& rImporter,
         const uno::Reference< frame::XModel>& rModel,
         SvXMLImportPropertyMapper *pExtMapper )
-:   mpPageContext(NULL),
+:   mpImpl( new XMLShapeImportHelperImpl() ),
+    mpPageContext(nullptr),
     mxModel(rModel),
 
-    mpPropertySetMapper(0L),
-    mpPresPagePropsMapper(0L),
-    mpStylesContext(0L),
-    mpAutoStylesContext(0L),
-    mpGroupShapeElemTokenMap(0L),
-    mpFrameShapeElemTokenMap(0L),
-    mp3DSceneShapeElemTokenMap(0L),
-    mp3DObjectAttrTokenMap(0L),
-    mp3DPolygonBasedAttrTokenMap(0L),
-    mp3DCubeObjectAttrTokenMap(0L),
-    mp3DSphereObjectAttrTokenMap(0L),
-    mp3DSceneShapeAttrTokenMap(0L),
-    mp3DLightAttrTokenMap(0L),
-    mpPathShapeAttrTokenMap(0L),
-    mpPolygonShapeAttrTokenMap(0L),
+    mpPropertySetMapper(nullptr),
+    mpPresPagePropsMapper(nullptr),
+    mpStylesContext(nullptr),
+    mpAutoStylesContext(nullptr),
+    mpGroupShapeElemTokenMap(nullptr),
+    mpFrameShapeElemTokenMap(nullptr),
+    mp3DSceneShapeElemTokenMap(nullptr),
+    mp3DObjectAttrTokenMap(nullptr),
+    mp3DPolygonBasedAttrTokenMap(nullptr),
+    mp3DCubeObjectAttrTokenMap(nullptr),
+    mp3DSphereObjectAttrTokenMap(nullptr),
+    mp3DSceneShapeAttrTokenMap(nullptr),
+    mp3DLightAttrTokenMap(nullptr),
+    mpPathShapeAttrTokenMap(nullptr),
+    mpPolygonShapeAttrTokenMap(nullptr),
     msStartShape("StartShape"),
     msEndShape("EndShape"),
     msStartGluePointIndex("StartGluePointIndex"),
@@ -137,8 +137,7 @@ XMLShapeImportHelper::XMLShapeImportHelper(
 
     mrImporter( rImporter )
 {
-    mpImpl = new XMLShapeImportHelperImpl();
-    mpImpl->mpSortContext = 0;
+    mpImpl->mpSortContext = nullptr;
 
     // #88546# init to sal_False
     mpImpl->mbHandleProgressBar = false;
@@ -165,13 +164,10 @@ XMLShapeImportHelper::XMLShapeImportHelper(
     mpPropertySetMapper->ChainImportMapper(XMLTextImportHelper::CreateParaDefaultExtPropMapper(rImporter));
 
     // construct PresPagePropsMapper
-    xMapper = new XMLPropertySetMapper((XMLPropertyMapEntry*)aXMLSDPresPageProps, mpSdPropHdlFactory, false);
+    xMapper = new XMLPropertySetMapper(aXMLSDPresPageProps, mpSdPropHdlFactory, false);
     mpPresPagePropsMapper = new SvXMLImportPropertyMapper( xMapper, rImporter );
-    if(mpPresPagePropsMapper)
-    {
-        // set lock to avoid deletion
-        mpPresPagePropsMapper->acquire();
-    }
+    // set lock to avoid deletion
+    mpPresPagePropsMapper->acquire();
 
     uno::Reference< lang::XServiceInfo > xInfo( rImporter.GetModel(), uno::UNO_QUERY );
     const OUString aSName( "com.sun.star.presentation.PresentationDocument" );
@@ -186,35 +182,35 @@ XMLShapeImportHelper::~XMLShapeImportHelper()
     if(mpSdPropHdlFactory)
     {
         mpSdPropHdlFactory->release();
-        mpSdPropHdlFactory = 0L;
+        mpSdPropHdlFactory = nullptr;
     }
 
     // cleanup mapper, decrease refcount. Should lead to destruction.
     if(mpPropertySetMapper)
     {
         mpPropertySetMapper->release();
-        mpPropertySetMapper = 0L;
+        mpPropertySetMapper = nullptr;
     }
 
     // cleanup presPage mapper, decrease refcount. Should lead to destruction.
     if(mpPresPagePropsMapper)
     {
         mpPresPagePropsMapper->release();
-        mpPresPagePropsMapper = 0L;
+        mpPresPagePropsMapper = nullptr;
     }
 
-    if(mpGroupShapeElemTokenMap) delete mpGroupShapeElemTokenMap;
-    if(mpFrameShapeElemTokenMap) delete mpFrameShapeElemTokenMap;
+    delete mpGroupShapeElemTokenMap;
+    delete mpFrameShapeElemTokenMap;
 
-    if(mpPolygonShapeAttrTokenMap) delete mpPolygonShapeAttrTokenMap;
-    if(mpPathShapeAttrTokenMap) delete mpPathShapeAttrTokenMap;
-    if(mp3DSceneShapeElemTokenMap) delete mp3DSceneShapeElemTokenMap;
-    if(mp3DObjectAttrTokenMap) delete mp3DObjectAttrTokenMap;
-    if(mp3DPolygonBasedAttrTokenMap) delete mp3DPolygonBasedAttrTokenMap;
-    if(mp3DCubeObjectAttrTokenMap) delete mp3DCubeObjectAttrTokenMap;
-    if(mp3DSphereObjectAttrTokenMap) delete mp3DSphereObjectAttrTokenMap;
-    if(mp3DSceneShapeAttrTokenMap) delete mp3DSceneShapeAttrTokenMap;
-    if(mp3DLightAttrTokenMap) delete mp3DLightAttrTokenMap;
+    delete mpPolygonShapeAttrTokenMap;
+    delete mpPathShapeAttrTokenMap;
+    delete mp3DSceneShapeElemTokenMap;
+    delete mp3DObjectAttrTokenMap;
+    delete mp3DPolygonBasedAttrTokenMap;
+    delete mp3DCubeObjectAttrTokenMap;
+    delete mp3DSphereObjectAttrTokenMap;
+    delete mp3DSceneShapeAttrTokenMap;
+    delete mp3DLightAttrTokenMap;
 
     // Styles or AutoStyles context?
     if(mpStylesContext)
@@ -228,8 +224,6 @@ XMLShapeImportHelper::~XMLShapeImportHelper()
         mpAutoStylesContext->Clear();
         mpAutoStylesContext->ReleaseRef();
     }
-
-    delete mpImpl;
 }
 
 const SvXMLTokenMap& XMLShapeImportHelper::GetGroupShapeElemTokenMap()
@@ -409,7 +403,7 @@ SvXMLShapeContext* XMLShapeImportHelper::Create3DSceneChildContext(
     const uno::Reference< xml::sax::XAttributeList>& xAttrList,
     uno::Reference< drawing::XShapes >& rShapes)
 {
-    SdXMLShapeContext *pContext = 0L;
+    SdXMLShapeContext *pContext = nullptr;
 
     if(rShapes.is())
     {
@@ -486,7 +480,7 @@ SvXMLShapeContext* XMLShapeImportHelper::CreateGroupChildContext(
     uno::Reference< drawing::XShapes >& rShapes,
     bool bTemporaryShape)
 {
-    SdXMLShapeContext *pContext = 0L;
+    SdXMLShapeContext *pContext = nullptr;
 
     const SvXMLTokenMap& rTokenMap = GetGroupShapeElemTokenMap();
     sal_Int16 nAttrCount = xAttrList.is() ? xAttrList->getLength() : 0;
@@ -529,7 +523,7 @@ SvXMLShapeContext* XMLShapeImportHelper::CreateGroupChildContext(
         {
             // draw:polygon or draw:polyline inside group context
             pContext = new SdXMLPolygonShapeContext( rImport, p_nPrefix, rLocalName, xAttrList, rShapes,
-                rTokenMap.Get(p_nPrefix, rLocalName) == XML_TOK_GROUP_POLYGON ? sal_True : sal_False, bTemporaryShape );
+                rTokenMap.Get(p_nPrefix, rLocalName) == XML_TOK_GROUP_POLYGON, bTemporaryShape );
             break;
         }
         case XML_TOK_GROUP_PATH:
@@ -610,7 +604,7 @@ SvXMLShapeContext* XMLShapeImportHelper::CreateGroupChildContext(
     return pContext;
 }
 
-// This method is called from SdXMLFrameShapeContext to create children of drawe:frame
+// This method is called from SdXMLFrameShapeContext to create children of draw:frame
 SvXMLShapeContext* XMLShapeImportHelper::CreateFrameChildContext(
     SvXMLImport& rImport,
     sal_uInt16 p_nPrefix,
@@ -619,7 +613,7 @@ SvXMLShapeContext* XMLShapeImportHelper::CreateFrameChildContext(
     uno::Reference< drawing::XShapes >& rShapes,
     const uno::Reference< xml::sax::XAttributeList>& rFrameAttrList)
 {
-    SdXMLShapeContext *pContext = 0L;
+    SdXMLShapeContext *pContext = nullptr;
 
     const SvXMLTokenMap& rTokenMap = GetFrameShapeElemTokenMap();
 
@@ -704,9 +698,9 @@ SvXMLImportContext *XMLShapeImportHelper::CreateFrameChildContext(
     const OUString& rLocalName,
     const uno::Reference< xml::sax::XAttributeList>& xAttrList )
 {
-    SvXMLImportContext * pContext = NULL;
+    SvXMLImportContext * pContext = nullptr;
 
-    SdXMLFrameShapeContext *pFrameContext = PTR_CAST( SdXMLFrameShapeContext, pThisContext );
+    SdXMLFrameShapeContext *pFrameContext = dynamic_cast<SdXMLFrameShapeContext*>( pThisContext  );
     if( pFrameContext )
         pContext = pFrameContext->CreateChildContext( nPrefix, rLocalName, xAttrList );
 
@@ -754,13 +748,11 @@ void XMLShapeImportHelper::finishShape(
     {
         if ( mrImporter.IsShapePositionInHoriL2R() &&
              xPropSet->getPropertySetInfo()->hasPropertyByName(
-                OUString("PositionLayoutDir")) )
+                "PositionLayoutDir") )
         {
             uno::Any aPosLayoutDir;
             aPosLayoutDir <<= text::PositionLayoutDir::PositionInHoriL2R;
-            xPropSet->setPropertyValue(
-                OUString("PositionLayoutDir"),
-                aPosLayoutDir );
+            xPropSet->setPropertyValue( "PositionLayoutDir", aPosLayoutDir );
         }
     }
 }
@@ -778,21 +770,21 @@ class ShapeSortContext
 {
 public:
     uno::Reference< drawing::XShapes > mxShapes;
-    list<ZOrderHint>              maZOrderList;
-    list<ZOrderHint>              maUnsortedList;
+    vector<ZOrderHint>              maZOrderList;
+    vector<ZOrderHint>              maUnsortedList;
 
-    sal_Int32                     mnCurrentZ;
-    ShapeSortContext*             mpParentContext;
-    const OUString                msZOrder;
+    sal_Int32                       mnCurrentZ;
+    ShapeSortContext*               mpParentContext;
 
-    ShapeSortContext( uno::Reference< drawing::XShapes >& rShapes, ShapeSortContext* pParentContext = NULL );
+    ShapeSortContext( uno::Reference< drawing::XShapes >& rShapes, ShapeSortContext* pParentContext = nullptr );
 
+    void popGroupAndSort();
+private:
     void moveShape( sal_Int32 nSourcePos, sal_Int32 nDestPos );
 };
 
 ShapeSortContext::ShapeSortContext( uno::Reference< drawing::XShapes >& rShapes, ShapeSortContext* pParentContext )
-:   mxShapes( rShapes ), mnCurrentZ( 0 ), mpParentContext( pParentContext ),
-    msZOrder("ZOrder")
+:   mxShapes( rShapes ), mnCurrentZ( 0 ), mpParentContext( pParentContext )
 {
 }
 
@@ -802,39 +794,97 @@ void ShapeSortContext::moveShape( sal_Int32 nSourcePos, sal_Int32 nDestPos )
     uno::Reference< beans::XPropertySet > xPropSet;
     aAny >>= xPropSet;
 
-    if( xPropSet.is() && xPropSet->getPropertySetInfo()->hasPropertyByName( msZOrder ) )
+    if( xPropSet.is() && xPropSet->getPropertySetInfo()->hasPropertyByName( "ZOrder" ) )
     {
         aAny <<= nDestPos;
-        xPropSet->setPropertyValue( msZOrder, aAny );
+        xPropSet->setPropertyValue( "ZOrder", aAny );
 
-        list<ZOrderHint>::iterator aIter = maZOrderList.begin();
-        list<ZOrderHint>::iterator aEnd = maZOrderList.end();
-
-        while( aIter != aEnd )
+        for( ZOrderHint& rHint : maZOrderList )
         {
-            if( (*aIter).nIs < nSourcePos )
+            if( rHint.nIs < nSourcePos )
             {
-                DBG_ASSERT( (*aIter).nIs >= nDestPos, "Shape sorting failed" );
-                (*aIter).nIs++;
+                DBG_ASSERT(rHint.nIs >= nDestPos, "Shape sorting failed" );
+                rHint.nIs++;
             }
-            ++aIter;
         }
 
-        aIter = maUnsortedList.begin();
-        aEnd = maUnsortedList.end();
-
-        while( aIter != aEnd )
+        for( ZOrderHint& rHint : maUnsortedList )
         {
-            if( (*aIter).nIs < nSourcePos )
+            if( rHint.nIs < nSourcePos )
             {
-                DBG_ASSERT( (*aIter).nIs >= nDestPos, "shape sorting failed" );
-                (*aIter).nIs++;
+                DBG_ASSERT( rHint.nIs >= nDestPos, "shape sorting failed" );
+                rHint.nIs++;
             }
-            ++aIter;
         }
     }
 }
 
+// sort shapes
+void ShapeSortContext::popGroupAndSort()
+{
+    // only do something if we have shapes to sort
+    if( maZOrderList.empty() )
+        return;
+
+    // check if there are more shapes than inserted with ::shapeWithZIndexAdded()
+    // This can happen if there where already shapes on the page before import
+    // Since the writer may delete some of this shapes during import, we need
+    // to do this here and not in our c'tor anymore
+
+    // check if we have more shapes than we know of
+    sal_Int32 nCount = mxShapes->getCount();
+
+    nCount -= maZOrderList.size();
+    nCount -= maUnsortedList.size();
+
+    if( nCount > 0 )
+    {
+        // first update offsets of added shapes
+        for (ZOrderHint& rHint : maZOrderList)
+            rHint.nIs += nCount;
+        for (ZOrderHint& rHint : maUnsortedList)
+            rHint.nIs += nCount;
+
+        // second add the already existing shapes in the unsorted list
+        ZOrderHint aNewHint;
+        do
+        {
+            nCount--;
+
+            aNewHint.nIs = nCount;
+            aNewHint.nShould = -1;
+
+            maUnsortedList.insert(maUnsortedList.begin(), aNewHint);
+        }
+        while( nCount );
+    }
+
+    // sort z-ordered shapes by nShould field
+    std::sort(maZOrderList.begin(), maZOrderList.end());
+
+    // this is the current index, all shapes before that
+    // index are finished
+    sal_Int32 nIndex = 0;
+    for (ZOrderHint& rHint : maZOrderList)
+    {
+        while( nIndex < rHint.nShould && !maUnsortedList.empty() )
+        {
+            auto it = maUnsortedList.begin();
+
+            ZOrderHint aGapHint(*it);
+            maUnsortedList.erase(it);
+
+            moveShape( aGapHint.nIs, nIndex++ );
+        }
+
+        if(rHint.nIs != nIndex )
+            moveShape( rHint.nIs, nIndex );
+
+        nIndex++;
+    }
+    maZOrderList.clear();
+}
+
 void XMLShapeImportHelper::pushGroupForSorting( uno::Reference< drawing::XShapes >& rShapes )
 {
     mpImpl->mpSortContext = new ShapeSortContext( rShapes, mpImpl->mpSortContext );
@@ -843,88 +893,19 @@ void XMLShapeImportHelper::pushGroupForSorting( uno::Reference< drawing::XShapes
 void XMLShapeImportHelper::popGroupAndSort()
 {
     DBG_ASSERT( mpImpl->mpSortContext, "No context to sort!" );
-    if( mpImpl->mpSortContext == NULL )
+    if( mpImpl->mpSortContext == nullptr )
         return;
 
     try
     {
-        list<ZOrderHint>& rZList = mpImpl->mpSortContext->maZOrderList;
-        list<ZOrderHint>& rUnsortedList = mpImpl->mpSortContext->maUnsortedList;
-
-        // sort shapes
-        if( !rZList.empty() )
-        {
-            // only do something if we have shapes to sort
-
-            // check if there are more shapes than inserted with ::shapeWithZIndexAdded()
-            // This can happen if there where already shapes on the page before import
-            // Since the writer may delete some of this shapes during import, we need
-            // to do this here and not in our c'tor anymore
-
-            // check if we have more shapes than we know of
-            sal_Int32 nCount = mpImpl->mpSortContext->mxShapes->getCount();
-
-            nCount -= rZList.size();
-            nCount -= rUnsortedList.size();
-
-            if( nCount > 0 )
-            {
-                // first update offsets of added shapes
-                list<ZOrderHint>::iterator aIter( rZList.begin() );
-                while( aIter != rZList.end() )
-                    (*aIter++).nIs += nCount;
-
-                aIter = rUnsortedList.begin();
-                while( aIter != rUnsortedList.end() )
-                    (*aIter++).nIs += nCount;
-
-                // second add the already existing shapes in the unsorted list
-                ZOrderHint aNewHint;
-
-                do
-                {
-                    nCount--;
-
-                    aNewHint.nIs = nCount;
-                    aNewHint.nShould = -1;
-
-                    rUnsortedList.insert(rUnsortedList.begin(), aNewHint);
-                }
-                while( nCount );
-            }
-
-            // sort z ordered shapes
-            rZList.sort();
-
-            // this is the current index, all shapes before that
-            // index are finished
-            sal_Int32 nIndex = 0;
-            while( !rZList.empty() )
-            {
-                list<ZOrderHint>::iterator aIter( rZList.begin() );
-
-                while( nIndex < (*aIter).nShould && !rUnsortedList.empty() )
-                {
-                    ZOrderHint aGapHint( *rUnsortedList.begin() );
-                    rUnsortedList.pop_front();
-
-                    mpImpl->mpSortContext->moveShape( aGapHint.nIs, nIndex++ );
-                }
-
-                if( (*aIter).nIs != nIndex )
-                    mpImpl->mpSortContext->moveShape( (*aIter).nIs, nIndex );
-
-                rZList.pop_front();
-                nIndex++;
-            }
-        }
+        mpImpl->mpSortContext->popGroupAndSort();
     }
     catch( uno::Exception& )
     {
         OSL_FAIL("exception while sorting shapes, sorting failed!");
     }
 
-    // put parent on top and delete current context, were done
+    // put parent on top and delete current context, we are done
     ShapeSortContext* pContext = mpImpl->mpSortContext;
     mpImpl->mpSortContext = pContext->mpParentContext;
     delete pContext;
@@ -1111,14 +1092,10 @@ void XMLShapeImportHelper::startPage( com::sun::star::uno::Reference< com::sun::
 }
 
 /** this method must be calling after the last shape is imported for the given page */
-void XMLShapeImportHelper::endPage( com::sun::star::uno::Reference< com::sun::star::drawing::XShapes >&
-#ifdef DBG_UTIL
-rShapes
-#endif
-)
+void XMLShapeImportHelper::endPage( com::sun::star::uno::Reference< com::sun::star::drawing::XShapes >& rShapes )
 {
     DBG_ASSERT( mpPageContext && (mpPageContext->mxShapes == rShapes), "wrong call to endPage(), no startPage called or wrong page" );
-    if( NULL == mpPageContext )
+    if( nullptr == mpPageContext )
         return;
 
     restoreConnections();
@@ -1128,7 +1105,6 @@ rShapes
     mpPageContext = pNextContext;
 }
 
-// #88546#
 /** defines if the import should increment the progress bar or not */
 void XMLShapeImportHelper::enableHandleProgressBar( bool bEnable )
 {
