@@ -99,7 +99,7 @@ namespace xmloff
     void OPropertyExport::exportRemainingProperties()
     {
         // the properties tag (will be created if we have at least one no-default property)
-        SvXMLElementExport* pPropertiesTag = NULL;
+        SvXMLElementExport* pPropertiesTag = nullptr;
 
         try
         {
@@ -467,7 +467,7 @@ namespace xmloff
                 return;
         }
 
-        // finally add the attribuite to the context
+        // finally add the attribute to the context
         AddAttribute(_nAttributeNamespaceKey, _pAttributeName, sValue);
     }
 
