@@ -22,10 +22,12 @@
 #include <comphelper/types.hxx>
 #include <com/sun/star/table/BorderLine2.hpp>
 #include <xmloff/PageMasterStyleMap.hxx>
-#include <tools/debug.hxx>
 #include <rtl/ustrbuf.hxx>
 #include <comphelper/extract.hxx>
 
+//UUUU
+#include <xmloff/txtprmap.hxx>
+
 using namespace ::com::sun::star;
 using namespace ::com::sun::star::uno;
 using namespace ::com::sun::star::beans;
@@ -63,7 +65,7 @@ static void lcl_RemoveStateIfZero16( XMLPropertyState* pState )
 static void lcl_AddState(::std::vector< XMLPropertyState >& rPropState, sal_Int32 nIndex, const OUString& rProperty, uno::Reference< beans::XPropertySet >& xProps)
 {
     if(::cppu::any2bool(xProps->getPropertyValue(rProperty)))
-        rPropState.push_back(XMLPropertyState (nIndex, cppu::bool2any(sal_True)));
+        rPropState.push_back(XMLPropertyState (nIndex, css::uno::Any(true)));
 }
 
 // helper struct to handle equal XMLPropertyState's for page, header and footer
@@ -99,29 +101,29 @@ struct XMLPropertyStateBuffer
 };
 
 XMLPropertyStateBuffer::XMLPropertyStateBuffer()
-    :   pPMMarginAll( NULL )
-    ,   pPMMarginTop( NULL )
-    ,   pPMMarginBottom( NULL )
-    ,   pPMMarginLeft( NULL )
-    ,   pPMMarginRight( NULL )
+    :   pPMMarginAll( nullptr )
+    ,   pPMMarginTop( nullptr )
+    ,   pPMMarginBottom( nullptr )
+    ,   pPMMarginLeft( nullptr )
+    ,   pPMMarginRight( nullptr )
     ,
-        pPMBorderAll( NULL ),
-        pPMBorderTop( NULL ),
-        pPMBorderBottom( NULL ),
-        pPMBorderLeft( NULL ),
-        pPMBorderRight( NULL ),
+        pPMBorderAll( nullptr ),
+        pPMBorderTop( nullptr ),
+        pPMBorderBottom( nullptr ),
+        pPMBorderLeft( nullptr ),
+        pPMBorderRight( nullptr ),
 
-        pPMBorderWidthAll( NULL ),
-        pPMBorderWidthTop( NULL ),
-        pPMBorderWidthBottom( NULL ),
-        pPMBorderWidthLeft( NULL ),
-        pPMBorderWidthRight( NULL ),
+        pPMBorderWidthAll( nullptr ),
+        pPMBorderWidthTop( nullptr ),
+        pPMBorderWidthBottom( nullptr ),
+        pPMBorderWidthLeft( nullptr ),
+        pPMBorderWidthRight( nullptr ),
 
-        pPMPaddingAll( NULL ),
-        pPMPaddingTop( NULL ),
-        pPMPaddingBottom( NULL ),
-        pPMPaddingLeft( NULL ),
-        pPMPaddingRight( NULL )
+        pPMPaddingAll( nullptr ),
+        pPMPaddingTop( nullptr ),
+        pPMPaddingBottom( nullptr ),
+        pPMPaddingLeft( nullptr ),
+        pPMPaddingRight( nullptr )
 {
 }
 
@@ -211,7 +213,7 @@ void XMLPropertyStateBuffer::ContextFilter( ::std::vector< XMLPropertyState >& )
 }
 
 XMLPageMasterExportPropMapper::XMLPageMasterExportPropMapper(
-        const UniReference< XMLPropertySetMapper >& rMapper,
+        const rtl::Reference< XMLPropertySetMapper >& rMapper,
         SvXMLExport& rExport ) :
     SvXMLExportPropertyMapper( rMapper ),
     aBackgroundImageExport( rExport ),
@@ -227,11 +229,11 @@ XMLPageMasterExportPropMapper::~XMLPageMasterExportPropMapper()
 void XMLPageMasterExportPropMapper::handleElementItem(
         SvXMLExport&,
         const XMLPropertyState& rProperty,
-        sal_uInt16 /*nFlags*/,
+        SvXmlExportFlags /*nFlags*/,
         const ::std::vector< XMLPropertyState >* pProperties,
         sal_uInt32 nIdx ) const
 {
-    XMLPageMasterExportPropMapper* pThis = (XMLPageMasterExportPropMapper*) this;
+    XMLPageMasterExportPropMapper* pThis = const_cast<XMLPageMasterExportPropMapper*>(this);
 
     sal_uInt32 nContextId = getPropertySetMapper()->GetEntryContextId( rProperty.mnIndex );
     switch( nContextId )
@@ -240,9 +242,10 @@ void XMLPageMasterExportPropMapper::handleElementItem(
         case CTF_PM_HEADERGRAPHICURL:
         case CTF_PM_FOOTERGRAPHICURL:
             {
-                DBG_ASSERT( pProperties && (nIdx >= 2), "property vector missing" );
-                sal_Int32 nPos;
-                sal_Int32 nFilter;
+                assert(pProperties);
+                assert(nIdx >= 2 && "horrible array ordering borked again");
+                sal_Int32 nPos(-1);
+                sal_Int32 nFilter(-1);
                 switch( nContextId  )
                 {
                 case CTF_PM_GRAPHICURL:
@@ -258,27 +261,25 @@ void XMLPageMasterExportPropMapper::handleElementItem(
                     nFilter = CTF_PM_FOOTERGRAPHICFILTER;
                     break;
                 default:
-                    nPos = 0;  // TODO What values should this be?
-                    nFilter = 0;
+                    assert(false);
                 }
-                const Any*  pPos    = NULL;
-                const Any*  pFilter = NULL;
-                if( pProperties && (nIdx >= 2) )
+                const Any*  pPos    = nullptr;
+                const Any*  pFilter = nullptr;
+                sal_uInt32 nIndex(nIdx - 1);
+                const XMLPropertyState& rFilter = (*pProperties)[nIndex];
+                if (getPropertySetMapper()->GetEntryContextId(rFilter.mnIndex) == nFilter)
                 {
-                    const XMLPropertyState& rPos = (*pProperties)[nIdx - 2];
-                    DBG_ASSERT( getPropertySetMapper()->GetEntryContextId( rPos.mnIndex ) == nPos,
-                                "invalid property map: pos expected" );
-                    if( getPropertySetMapper()->GetEntryContextId( rPos.mnIndex ) == nPos )
-                        pPos = &rPos.maValue;
-
-                    const XMLPropertyState& rFilter = (*pProperties)[nIdx - 1];
-                    DBG_ASSERT( getPropertySetMapper()->GetEntryContextId( rFilter.mnIndex ) == nFilter,
-                                "invalid property map: filter expected" );
-                    if( getPropertySetMapper()->GetEntryContextId( rFilter.mnIndex ) == nFilter )
-                        pFilter = &rFilter.maValue;
+                    pFilter = &rFilter.maValue;
+                    --nIndex;
+                }
+                const XMLPropertyState& rPos = (*pProperties)[nIndex];
+                if (getPropertySetMapper()->GetEntryContextId(rPos.mnIndex) == nPos)
+                {
+                    pPos = &rPos.maValue;
+                    --nIndex;
                 }
                 sal_uInt32 nPropIndex = rProperty.mnIndex;
-                pThis->aBackgroundImageExport.exportXML( rProperty.maValue, pPos, pFilter, NULL,
+                pThis->aBackgroundImageExport.exportXML( rProperty.maValue, pPos, pFilter, nullptr,
                     getPropertySetMapper()->GetEntryNameSpace( nPropIndex ),
                     getPropertySetMapper()->GetEntryXMLName( nPropIndex ) );
             }
@@ -312,27 +313,35 @@ void XMLPageMasterExportPropMapper::ContextFilter(
     XMLPropertyStateBuffer  aHeaderBuffer;
     XMLPropertyStateBuffer  aFooterBuffer;
 
-    XMLPropertyState*       pPMHeaderHeight     = NULL;
-    XMLPropertyState*       pPMHeaderMinHeight  = NULL;
-    XMLPropertyState*       pPMHeaderDynamic    = NULL;
+    XMLPropertyState*       pPMHeaderHeight     = nullptr;
+    XMLPropertyState*       pPMHeaderMinHeight  = nullptr;
+    XMLPropertyState*       pPMHeaderDynamic    = nullptr;
 
-    XMLPropertyState*       pPMFooterHeight     = NULL;
-    XMLPropertyState*       pPMFooterMinHeight  = NULL;
-    XMLPropertyState*       pPMFooterDynamic    = NULL;
+    XMLPropertyState*       pPMFooterHeight     = nullptr;
+    XMLPropertyState*       pPMFooterMinHeight  = nullptr;
+    XMLPropertyState*       pPMFooterDynamic    = nullptr;
 
-    XMLPropertyState*       pPMScaleTo          = NULL;
-    XMLPropertyState*       pPMScaleToPages     = NULL;
-    XMLPropertyState*       pPMScaleToX         = NULL;
-    XMLPropertyState*       pPMScaleToY         = NULL;
-    XMLPropertyState*       pPMStandardMode     = NULL;
-    XMLPropertyState*       pPMGridBaseWidth    = NULL;
+    XMLPropertyState*       pPMScaleTo          = nullptr;
+    XMLPropertyState*       pPMScaleToPages     = nullptr;
+    XMLPropertyState*       pPMScaleToX         = nullptr;
+    XMLPropertyState*       pPMScaleToY         = nullptr;
+    XMLPropertyState*       pPMStandardMode     = nullptr;
+    XMLPropertyState*       pPMGridBaseWidth    = nullptr;
     // same as pPMGridSnapTo but for backward compatibility only
-    XMLPropertyState*       pPMGridSnapToChars  = NULL;
-    XMLPropertyState*       pPMGridSnapTo       = NULL;
+    XMLPropertyState*       pPMGridSnapToChars  = nullptr;
+    XMLPropertyState*       pPMGridSnapTo       = nullptr;
 
-    XMLPropertyState*       pPrint              = NULL;
+    XMLPropertyState*       pPrint              = nullptr;
 
-    UniReference < XMLPropertySetMapper > aPropMapper(getPropertySetMapper());
+    //UUUU
+    XMLPropertyState* pRepeatOffsetX = nullptr;
+    XMLPropertyState* pRepeatOffsetY = nullptr;
+    XMLPropertyState* pHeaderRepeatOffsetX = nullptr;
+    XMLPropertyState* pHeaderRepeatOffsetY = nullptr;
+    XMLPropertyState* pFooterRepeatOffsetX = nullptr;
+    XMLPropertyState* pFooterRepeatOffsetY = nullptr;
+
+    rtl::Reference < XMLPropertySetMapper > aPropMapper(getPropertySetMapper());
 
     for( ::std::vector< XMLPropertyState >::iterator aIter = rPropState.begin(); aIter != rPropState.end(); ++aIter )
     {
@@ -390,7 +399,64 @@ void XMLPageMasterExportPropMapper::ContextFilter(
             case CTP_PM_GRID_BASE_WIDTH:        pPMGridBaseWidth    = pProp;    break;
             case CTP_PM_GRID_SNAP_TO_CHARS:     pPMGridSnapToChars  = pProp;    break;
             case CTP_PM_GRID_SNAP_TO:       pPMGridSnapTo = pProp;    break;
+
+            //UUUU
+            case CTF_PM_REPEAT_OFFSET_X:
+                pRepeatOffsetX = pProp;
+                break;
+
+            //UUUU
+            case CTF_PM_REPEAT_OFFSET_Y:
+                pRepeatOffsetY = pProp;
+                break;
+
+            //UUUU
+            case CTF_PM_HEADERREPEAT_OFFSET_X:
+                pHeaderRepeatOffsetX = pProp;
+                break;
+
+            //UUUU
+            case CTF_PM_HEADERREPEAT_OFFSET_Y:
+                pHeaderRepeatOffsetY = pProp;
+                break;
+
+            //UUUU
+            case CTF_PM_FOOTERREPEAT_OFFSET_X:
+                pFooterRepeatOffsetX = pProp;
+                break;
+
+            //UUUU
+            case CTF_PM_FOOTERREPEAT_OFFSET_Y:
+                pFooterRepeatOffsetY = pProp;
+                break;
+
+            //UUUU Sort out empty entries
+            case CTF_PM_FILLGRADIENTNAME:
+            case CTF_PM_FILLHATCHNAME:
+            case CTF_PM_FILLBITMAPNAME:
+            case CTF_PM_FILLTRANSNAME:
+
+            case CTF_PM_HEADERFILLGRADIENTNAME:
+            case CTF_PM_HEADERFILLHATCHNAME:
+            case CTF_PM_HEADERFILLBITMAPNAME:
+            case CTF_PM_HEADERFILLTRANSNAME:
+
+            case CTF_PM_FOOTERFILLGRADIENTNAME:
+            case CTF_PM_FOOTERFILLHATCHNAME:
+            case CTF_PM_FOOTERFILLBITMAPNAME:
+            case CTF_PM_FOOTERFILLTRANSNAME:
+            {
+                rtl::OUString aStr;
+
+                if( (pProp->maValue >>= aStr) && 0 == aStr.getLength() )
+                {
+                    pProp->mnIndex = -1;
+                }
+
+                break;
+            }
         }
+
         if (nPrintId == CTF_PM_PRINTMASK)
         {
             pPrint = pProp;
@@ -398,6 +464,54 @@ void XMLPageMasterExportPropMapper::ContextFilter(
         }
     }
 
+    //UUUU These entries need to be reduced to a single one for XML export.
+    // Both would be exported as 'draw:tile-repeat-offset' following a percent
+    // value and a 'vertical' or 'horizontal' tag as mark. If both would be active
+    // and both would be exported this would create an XML error (same property twice)
+    if(pRepeatOffsetX && pRepeatOffsetY)
+    {
+        sal_Int32 nOffset(0);
+
+        if((pRepeatOffsetX->maValue >>= nOffset) && (!nOffset))
+        {
+            pRepeatOffsetX->mnIndex = -1;
+        }
+        else
+        {
+            pRepeatOffsetY->mnIndex = -1;
+        }
+    }
+
+    //UUUU Same as above for Header
+    if(pHeaderRepeatOffsetX && pHeaderRepeatOffsetY)
+    {
+        sal_Int32 nOffset(0);
+
+        if((pHeaderRepeatOffsetX->maValue >>= nOffset) && (!nOffset))
+        {
+            pHeaderRepeatOffsetX->mnIndex = -1;
+        }
+        else
+        {
+            pHeaderRepeatOffsetY->mnIndex = -1;
+        }
+    }
+
+    //UUUU Same as above for Footer
+    if(pFooterRepeatOffsetX && pFooterRepeatOffsetY)
+    {
+        sal_Int32 nOffset(0);
+
+        if((pFooterRepeatOffsetX->maValue >>= nOffset) && (!nOffset))
+        {
+            pFooterRepeatOffsetX->mnIndex = -1;
+        }
+        else
+        {
+            pFooterRepeatOffsetY->mnIndex = -1;
+        }
+    }
+
     if( pPMStandardMode && !getBOOL(pPMStandardMode->maValue) )
     {
         lcl_RemoveState(pPMStandardMode);
@@ -418,14 +532,14 @@ void XMLPageMasterExportPropMapper::ContextFilter(
     aHeaderBuffer.ContextFilter( rPropState );
     aFooterBuffer.ContextFilter( rPropState );
 
-    if( pPMHeaderHeight && (!pPMHeaderDynamic || (pPMHeaderDynamic && getBOOL( pPMHeaderDynamic->maValue ))) )
+    if( pPMHeaderHeight && (!pPMHeaderDynamic || getBOOL( pPMHeaderDynamic->maValue )) )
         lcl_RemoveState( pPMHeaderHeight );
     if( pPMHeaderMinHeight && pPMHeaderDynamic && !getBOOL( pPMHeaderDynamic->maValue ) )
         lcl_RemoveState( pPMHeaderMinHeight );
     if( pPMHeaderDynamic )
         lcl_RemoveState( pPMHeaderDynamic );
 
-    if( pPMFooterHeight && (!pPMFooterDynamic || (pPMFooterDynamic && getBOOL( pPMFooterDynamic->maValue ))) )
+    if( pPMFooterHeight && (!pPMFooterDynamic || getBOOL( pPMFooterDynamic->maValue )) )
         lcl_RemoveState( pPMFooterHeight );
     if( pPMFooterMinHeight && pPMFooterDynamic && !getBOOL( pPMFooterDynamic->maValue ) )
         lcl_RemoveState( pPMFooterMinHeight );
