@@ -186,12 +186,9 @@ XMLMeasurePropHdl::~XMLMeasurePropHdl()
 
 bool XMLMeasurePropHdl::importXML( const OUString& rStrImpValue, Any& rValue, const SvXMLUnitConverter& rUnitConverter ) const
 {
-    bool bRet = false;
-
     sal_Int32 nValue = 0;
-    bRet = rUnitConverter.convertMeasureToCore( nValue, rStrImpValue );
+    bool bRet = rUnitConverter.convertMeasureToCore( nValue, rStrImpValue );
     lcl_xmloff_setAny( rValue, nValue, nBytes );
-
     return bRet;
 }
 
@@ -240,7 +237,7 @@ bool XMLBoolPropHdl::importXML( const OUString& rStrImpValue, Any& rValue, const
 {
     bool bValue(false);
     bool const bRet = ::sax::Converter::convertBool( bValue, rStrImpValue );
-    rValue <<= sal_Bool(bValue);
+    rValue <<= bValue;
 
     return bRet;
 }
@@ -248,11 +245,11 @@ bool XMLBoolPropHdl::importXML( const OUString& rStrImpValue, Any& rValue, const
 bool XMLBoolPropHdl::exportXML( OUString& rStrExpValue, const Any& rValue, const SvXMLUnitConverter& ) const
 {
     bool bRet = false;
-      OUStringBuffer aOut;
-    sal_Bool bValue = sal_Bool();
+    bool bValue;
 
     if (rValue >>= bValue)
     {
+        OUStringBuffer aOut;
         ::sax::Converter::convertBool( aOut, bValue );
         rStrExpValue = aOut.makeStringAndClear();
 
@@ -273,7 +270,7 @@ bool XMLNBoolPropHdl::importXML( const OUString& rStrImpValue, Any& rValue, cons
 {
     bool bValue(false);
     bool const bRet = ::sax::Converter::convertBool( bValue, rStrImpValue );
-    rValue <<= sal_Bool(!bValue);
+    rValue <<= !bValue;
 
     return bRet;
 }
@@ -281,11 +278,11 @@ bool XMLNBoolPropHdl::importXML( const OUString& rStrImpValue, Any& rValue, cons
 bool XMLNBoolPropHdl::exportXML( OUString& rStrExpValue, const Any& rValue, const SvXMLUnitConverter& ) const
 {
     bool bRet = false;
-      OUStringBuffer aOut;
-    sal_Bool bValue = sal_Bool();
+    bool bValue;
 
     if (rValue >>= bValue)
     {
+        OUStringBuffer aOut;
         ::sax::Converter::convertBool( aOut, !bValue );
         rStrExpValue = aOut.makeStringAndClear();
 
@@ -407,7 +404,6 @@ bool XMLNegPercentPropHdl::exportXML( OUString& rStrExpValue, const Any& rValue,
 }
 
 // class XMLMeasurePxPropHdl
-
 XMLMeasurePxPropHdl::~XMLMeasurePxPropHdl()
 {
     // nothing to do
@@ -415,12 +411,9 @@ XMLMeasurePxPropHdl::~XMLMeasurePxPropHdl()
 
 bool XMLMeasurePxPropHdl::importXML( const OUString& rStrImpValue, Any& rValue, const SvXMLUnitConverter& ) const
 {
-    bool bRet = false;
-
     sal_Int32 nValue = 0;
-    bRet = ::sax::Converter::convertMeasurePx( nValue, rStrImpValue );
+    bool bRet = ::sax::Converter::convertMeasurePx( nValue, rStrImpValue );
     lcl_xmloff_setAny( rValue, nValue, nBytes );
-
     return bRet;
 }
 
@@ -519,10 +512,8 @@ XMLHexPropHdl::~XMLHexPropHdl()
 
 bool XMLHexPropHdl::importXML( const OUString& rStrImpValue, Any& rValue, const SvXMLUnitConverter& ) const
 {
-    bool bRet = false;
     sal_uInt32 nRsid;
-
-    bRet = SvXMLUnitConverter::convertHex( nRsid, rStrImpValue );
+    bool bRet = SvXMLUnitConverter::convertHex( nRsid, rStrImpValue );
     rValue <<= nRsid;
 
     return bRet;
@@ -558,12 +549,8 @@ XMLStringPropHdl::~XMLStringPropHdl()
 
 bool XMLStringPropHdl::importXML( const OUString& rStrImpValue, Any& rValue, const SvXMLUnitConverter& ) const
 {
-    bool bRet = false;
-
     rValue <<= rStrImpValue;
-    bRet = true;
-
-    return bRet;
+    return true;
 }
 
 bool XMLStringPropHdl::exportXML( OUString& rStrExpValue, const Any& rValue, const SvXMLUnitConverter& ) const
@@ -693,8 +680,8 @@ XMLIsTransparentPropHdl::~XMLIsTransparentPropHdl()
 
 bool XMLIsTransparentPropHdl::importXML( const OUString& rStrImpValue, Any& rValue, const SvXMLUnitConverter& ) const
 {
-    sal_Bool bValue = (sal_Bool) ( (bool) (rStrImpValue == sTransparent) == bTransPropValue);
-    rValue.setValue( &bValue, ::getBooleanCppuType() );
+    bool bValue = ( (bool) (rStrImpValue == sTransparent) == bTransPropValue);
+    rValue <<= bValue;
 
     return true;
 }
@@ -706,7 +693,7 @@ bool XMLIsTransparentPropHdl::exportXML( OUString& rStrExpValue, const Any& rVal
     // MIB: This looks a bit strange, because bTransPropValue == bValue should
     // do the same, but this only applies if 'true' is represented by the same
     // 8 bit value in bValue and bTransPropValue. Who will ensure this?
-    sal_Bool bValue = *(sal_Bool *)rValue.getValue();
+    bool bValue = *static_cast<sal_Bool const *>(rValue.getValue());
     bool bIsTrans = bTransPropValue ? bValue : !bValue;
 
     if( bIsTrans )
@@ -812,13 +799,13 @@ XMLCompareOnlyPropHdl::~XMLCompareOnlyPropHdl()
 
 bool XMLCompareOnlyPropHdl::importXML( const OUString&, Any&, const SvXMLUnitConverter& ) const
 {
-    DBG_ASSERT( !this, "importXML called for compare-only-property" );
+    DBG_ASSERT( false, "importXML called for compare-only-property" );
     return false;
 }
 
 bool XMLCompareOnlyPropHdl::exportXML( OUString&, const Any&, const SvXMLUnitConverter& ) const
 {
-    DBG_ASSERT( !this, "exportXML called for compare-only-property" );
+    DBG_ASSERT( false, "exportXML called for compare-only-property" );
     return false;
 }
 
@@ -889,10 +876,11 @@ bool XMLNumberWithAutoInsteadZeroPropHdl::exportXML( OUString& rStrExpValue, con
 {
 
     sal_Int32 nValue = 0;
-    lcl_xmloff_getAny( rValue, nValue, 2 );
+    bool bRet = lcl_xmloff_getAny( rValue, nValue, 2 );
+    bRet &= nValue != 0;
 
     // FIXME: 0 is not a valid value - write "auto" instead
-    if (0 == nValue || !rValue.hasValue())
+    if (!bRet)
         rStrExpValue = GetXMLToken( XML_AUTO );
     else
     {
