@@ -46,14 +46,12 @@
 #include <xmloff/xmlexp.hxx>
 
 #include <set>
-#include <boost/ptr_container/ptr_vector.hpp>
+#include <vector>
 
 using namespace ::com::sun::star;
 using namespace ::xmloff::token;
 using namespace ::svt;
 
-#define XMLNUM_MAX_PARTS    3
-
 struct LessuInt32
 {
     bool operator() (const sal_uInt32 rValue1, const sal_uInt32 rValue2) const
@@ -64,16 +62,26 @@ struct LessuInt32
 
 typedef std::set< sal_uInt32, LessuInt32 >  SvXMLuInt32Set;
 
+struct SvXMLEmbeddedTextEntry
+{
+    sal_uInt16      nSourcePos;     // position in NumberFormat (to skip later)
+    sal_Int32       nFormatPos;     // resulting position in embedded-text element
+    OUString   aText;
+
+    SvXMLEmbeddedTextEntry( sal_uInt16 nSP, sal_Int32 nFP, const OUString& rT ) :
+        nSourcePos(nSP), nFormatPos(nFP), aText(rT) {}
+};
+
 class SvXMLEmbeddedTextEntryArr
 {
-    typedef boost::ptr_vector<SvXMLEmbeddedTextEntry> DataType;
+    typedef std::vector<SvXMLEmbeddedTextEntry> DataType;
     DataType maData;
 
 public:
 
-    void push_back( SvXMLEmbeddedTextEntry* p )
+    void push_back( SvXMLEmbeddedTextEntry const& r )
     {
-        maData.push_back(p);
+        maData.push_back(r);
     }
 
     const SvXMLEmbeddedTextEntry& operator[] ( size_t i ) const
@@ -111,16 +119,6 @@ public:
     void SetWasUsed(const uno::Sequence<sal_Int32>& rWasUsed);
 };
 
-struct SvXMLEmbeddedTextEntry
-{
-    sal_uInt16      nSourcePos;     // position in NumberFormat (to skip later)
-    sal_Int32       nFormatPos;     // resulting position in embedded-text element
-    OUString   aText;
-
-    SvXMLEmbeddedTextEntry( sal_uInt16 nSP, sal_Int32 nFP, const OUString& rT ) :
-        nSourcePos(nSP), nFormatPos(nFP), aText(rT) {}
-};
-
 //! SvXMLNumUsedList_Impl should be optimized!
 
 SvXMLNumUsedList_Impl::SvXMLNumUsedList_Impl() :
@@ -218,7 +216,7 @@ void SvXMLNumUsedList_Impl::SetWasUsed(const uno::Sequence<sal_Int32>& rWasUsed)
     DBG_ASSERT(nWasUsedCount == 0, "WasUsed should be empty");
     sal_Int32 nCount(rWasUsed.getLength());
     const sal_Int32* pWasUsed = rWasUsed.getConstArray();
-    for (sal_uInt16 i = 0; i < nCount; i++, pWasUsed++)
+    for (sal_Int32 i = 0; i < nCount; i++, pWasUsed++)
     {
         std::pair<SvXMLuInt32Set::const_iterator, bool> aPair = aWasUsed.insert( *pWasUsed );
         if (aPair.second)
@@ -231,9 +229,9 @@ SvXMLNumFmtExport::SvXMLNumFmtExport(
             const uno::Reference< util::XNumberFormatsSupplier >& rSupp ) :
     rExport( rExp ),
     sPrefix( OUString("N") ),
-    pFormatter( NULL ),
-    pCharClass( NULL ),
-    pLocaleData( NULL )
+    pFormatter( nullptr ),
+    pCharClass( nullptr ),
+    pLocaleData( nullptr )
 {
     //  supplier must be SvNumberFormatsSupplierObj
     SvNumberFormatsSupplierObj* pObj =
@@ -266,9 +264,9 @@ SvXMLNumFmtExport::SvXMLNumFmtExport(
                        const OUString& rPrefix ) :
     rExport( rExp ),
     sPrefix( rPrefix ),
-    pFormatter( NULL ),
-    pCharClass( NULL ),
-    pLocaleData( NULL )
+    pFormatter( nullptr ),
+    pCharClass( nullptr ),
+    pLocaleData( nullptr )
 {
     //  supplier must be SvNumberFormatsSupplierObj
     SvNumberFormatsSupplierObj* pObj =
@@ -616,7 +614,7 @@ void SvXMLNumFmtExport::WriteNumberElement_Impl(
     sal_uInt16 nEntryCount = rEmbeddedEntries.size();
     for (sal_uInt16 nEntry=0; nEntry<nEntryCount; nEntry++)
     {
-        const SvXMLEmbeddedTextEntry* pObj = &rEmbeddedEntries[nEntry];
+        const SvXMLEmbeddedTextEntry *const pObj = &rEmbeddedEntries[nEntry];
 
         //  position attribute
         rExport.AddAttribute( XML_NAMESPACE_NUMBER, XML_POSITION,
@@ -761,15 +759,15 @@ void SvXMLNumFmtExport::WriteMapElement_Impl( sal_Int32 nOp, double fLimit,
         // style namespace
 
         OUStringBuffer aCondStr(20);
-        aCondStr.appendAscii( "value()" );          //! define constant
+        aCondStr.append( "value()" );          //! define constant
         switch ( nOp )
         {
             case NUMBERFORMAT_OP_EQ: aCondStr.append( '=' );  break;
-            case NUMBERFORMAT_OP_NE: aCondStr.appendAscii( "!=" );          break;
+            case NUMBERFORMAT_OP_NE: aCondStr.append( "!=" );          break;
             case NUMBERFORMAT_OP_LT: aCondStr.append( '<' );  break;
-            case NUMBERFORMAT_OP_LE: aCondStr.appendAscii( "<=" );          break;
+            case NUMBERFORMAT_OP_LE: aCondStr.append( "<=" );          break;
             case NUMBERFORMAT_OP_GT: aCondStr.append( '>' );  break;
-            case NUMBERFORMAT_OP_GE: aCondStr.appendAscii( ">=" );          break;
+            case NUMBERFORMAT_OP_GE: aCondStr.append( ">=" );          break;
             default:
                 OSL_FAIL("unknown operator");
         }
@@ -855,8 +853,7 @@ bool SvXMLNumFmtExport::WriteTextWithCurrency_Impl( const OUString& rString,
             AddToTextElement_Impl( rString.copy( 0, nPos ) );
         }
         //  currency symbol (empty string -> default)
-        OUString sEmpty;
-        WriteCurrencyElement_Impl( sEmpty, sEmpty );
+        WriteCurrencyElement_Impl( "", "" );
         bRet = true;
 
         //  text after currency symbol
@@ -927,7 +924,7 @@ static bool lcl_IsDefaultDateFormat( const SvNumberformat& rFormat, bool bSystem
     short nLastType = 0;
     while (!bEnd)
     {
-        short nElemType = rFormat.GetNumForType( 0, nPos, false );
+        short nElemType = rFormat.GetNumForType( 0, nPos );
         switch ( nElemType )
         {
             case 0:
@@ -1008,9 +1005,6 @@ void SvXMLNumFmtExport::ExportPart_Impl( const SvNumberformat& rFormat, sal_uInt
 
     // #101606# An empty subformat is a valid number-style resulting in an
     // empty display string for the condition of the subformat.
-    if ( nFmtType == css::util::NumberFormat::UNDEFINED && rFormat.GetNumForType( nPart,
-                0, false ) == 0 )
-        nFmtType = 0;
 
     XMLTokenEnum eType = XML_TOKEN_INVALID;
     switch ( nFmtType )
@@ -1018,6 +1012,7 @@ void SvXMLNumFmtExport::ExportPart_Impl( const SvNumberformat& rFormat, sal_uInt
         // type is 0 if a format contains no recognized elements
         // (like text only) - this is handled as a number-style.
         case 0:
+        case css::util::NumberFormat::EMPTY:
         case css::util::NumberFormat::NUMBER:
         case css::util::NumberFormat::SCIENTIFIC:
         case css::util::NumberFormat::FRACTION:
@@ -1184,6 +1179,7 @@ void SvXMLNumFmtExport::ExportPart_Impl( const SvNumberformat& rFormat, sal_uInt
         bool bCurrFound  = false;
         bool bInInteger  = true;
         bool bExpSign = true;
+        bool bDecAlign   = false;               // decimal alignment with "?"
         sal_Int32 nExpDigits = 0;
         sal_Int32 nIntegerSymbols = 0;          // for embedded-text, including "#"
         sal_Int32 nTrailingThousands = 0;       // thousands-separators after all digits
@@ -1194,8 +1190,8 @@ void SvXMLNumFmtExport::ExportPart_Impl( const SvNumberformat& rFormat, sal_uInt
         bool bEnd = false;
         while (!bEnd)
         {
-            short nElemType = rFormat.GetNumForType( nPart, nPos, false );
-            const OUString* pElemStr = rFormat.GetNumForString( nPart, nPos, false );
+            short nElemType = rFormat.GetNumForType( nPart, nPos );
+            const OUString* pElemStr = rFormat.GetNumForString( nPart, nPos );
 
             switch ( nElemType )
             {
@@ -1212,9 +1208,17 @@ void SvXMLNumFmtExport::ExportPart_Impl( const SvNumberformat& rFormat, sal_uInt
                     }
                     else if ( !bInInteger && pElemStr )
                     {
-                        for ( sal_Int32 i = pElemStr->getLength()-1; i >= 0 && (*pElemStr)[i] == '#'; i-- )
+                        for ( sal_Int32 i = pElemStr->getLength()-1; i >= 0 ; i-- )
                         {
-                            nMinDecimals --;
+                            sal_Unicode aChar = (*pElemStr)[i];
+                            if ( aChar == '#' || aChar == '?' )
+                            {
+                                nMinDecimals --;
+                                if ( aChar == '?' )
+                                    bDecAlign = true;
+                            }
+                            else
+                                break;
                         }
                     }
                     if ( bInInteger && pElemStr )
@@ -1267,8 +1271,8 @@ void SvXMLNumFmtExport::ExportPart_Impl( const SvNumberformat& rFormat, sal_uInt
             bEnd = false;
             while (!bEnd)
             {
-                short nElemType = rFormat.GetNumForType( nPart, nPos, false );
-                const OUString* pElemStr = rFormat.GetNumForString( nPart, nPos, false );
+                short nElemType = rFormat.GetNumForType( nPart, nPos );
+                const OUString* pElemStr = rFormat.GetNumForString( nPart, nPos );
 
                 switch ( nElemType )
                 {
@@ -1291,14 +1295,14 @@ void SvXMLNumFmtExport::ExportPart_Impl( const SvNumberformat& rFormat, sal_uInt
                             {
                                 aEmbeddedStr = *pElemStr;
                             }
-                            else
+                            else if (pElemStr->getLength() >= 2)
                             {
                                 SvNumberformat::InsertBlanks( aEmbeddedStr, 0, (*pElemStr)[1] );
                             }
                             sal_Int32 nEmbedPos = nIntegerSymbols - nDigitsPassed;
 
-                            SvXMLEmbeddedTextEntry* pObj = new SvXMLEmbeddedTextEntry( nPos, nEmbedPos, aEmbeddedStr );
-                            aEmbeddedEntries.push_back( pObj );
+                            aEmbeddedEntries.push_back(
+                                SvXMLEmbeddedTextEntry(nPos, nEmbedPos, aEmbeddedStr));
                         }
                         break;
                 }
@@ -1315,8 +1319,8 @@ void SvXMLNumFmtExport::ExportPart_Impl( const SvNumberformat& rFormat, sal_uInt
         bEnd = false;
         while (!bEnd)
         {
-            short nElemType = rFormat.GetNumForType( nPart, nPos, false );
-            const OUString* pElemStr = rFormat.GetNumForString( nPart, nPos, false );
+            short nElemType = rFormat.GetNumForType( nPart, nPos );
+            const OUString* pElemStr = rFormat.GetNumForString( nPart, nPos );
 
             switch ( nElemType )
             {
@@ -1363,7 +1367,8 @@ void SvXMLNumFmtExport::ExportPart_Impl( const SvNumberformat& rFormat, sal_uInt
                         //  (#i20396# the spaces may also be in embedded-text elements)
 
                         OUString aBlanks;
-                        SvNumberformat::InsertBlanks( aBlanks, 0, (*pElemStr)[1] );
+                        if (pElemStr->getLength() >= 2)
+                            SvNumberformat::InsertBlanks( aBlanks, 0, (*pElemStr)[1] );
                         AddToTextElement_Impl( aBlanks );
                     }
                     break;
@@ -1434,6 +1439,9 @@ void SvXMLNumFmtExport::ExportPart_Impl( const SvNumberformat& rFormat, sal_uInt
                                     OUStringBuffer sDashStr;
                                     if (bDecDashes && nPrecision > 0)
                                         comphelper::string::padToLength(sDashStr, nPrecision, '-');
+                                    // "?" in decimal part are replaced by space character
+                                    if (bDecAlign && nPrecision > 0)
+                                        sDashStr = " ";
 
                                     WriteNumberElement_Impl(nDecimals, nMinDecimals, nInteger, sDashStr.makeStringAndClear(),
                                         bThousand, nTrailingThousands, aEmbeddedEntries);
@@ -1450,9 +1458,9 @@ void SvXMLNumFmtExport::ExportPart_Impl( const SvNumberformat& rFormat, sal_uInt
                             case css::util::NumberFormat::FRACTION:
                                 {
                                     sal_Int32 nInteger = nLeading;
-                                    if ( pElemStr && (*pElemStr)[0] == '?' )
+                                    if ( rFormat.GetNumForNumberElementCount( nPart ) == 3 )
                                     {
-                                        //  If the first digit character is a question mark,
+                                        //  If there is only two numbers + fraction in format string
                                         //  the fraction doesn't have an integer part, and no
                                         //  min-integer-digits attribute must be written.
                                         nInteger = -1;
@@ -1479,7 +1487,7 @@ void SvXMLNumFmtExport::ExportPart_Impl( const SvNumberformat& rFormat, sal_uInt
                     }
                     break;
                 case NF_SYMBOLTYPE_DEL:
-                    if ( pElemStr && comphelper::string::equals(*pElemStr, '@') )
+                    if ( pElemStr && *pElemStr == "@" )
                     {
                         WriteTextContentElement_Impl();
                         bAnyContent = true;
@@ -1647,11 +1655,23 @@ void SvXMLNumFmtExport::ExportPart_Impl( const SvNumberformat& rFormat, sal_uInt
         if ( rFormat.HasTextFormat() )
         {
             //  4th part is for text -> make an "all other numbers" condition for the 3rd part
-            //  by reversing the 2nd condition
+            //  by reversing the 2nd condition.
+            //  For a trailing text format like  0;@  that has no conditions
+            //  use a "less or equal than biggest" condition for the number
+            //  part, ODF can't store subformats (style maps) without
+            //  conditions.
 
             SvNumberformatLimitOps eOp3 = NUMBERFORMAT_OP_NO;
             double fLimit3 = fLimit2;
-            switch ( eOp2 )
+            sal_uInt16 nLastPart = 2;
+            SvNumberformatLimitOps eOpLast = eOp2;
+            if (eOp2 == NUMBERFORMAT_OP_NO)
+            {
+                eOpLast = eOp1;
+                fLimit3 = fLimit1;
+                nLastPart = (eOp1 == NUMBERFORMAT_OP_NO) ? 0 : 1;
+            }
+            switch ( eOpLast )
             {
                 case NUMBERFORMAT_OP_EQ: eOp3 = NUMBERFORMAT_OP_NE; break;
                 case NUMBERFORMAT_OP_NE: eOp3 = NUMBERFORMAT_OP_EQ; break;
@@ -1659,8 +1679,7 @@ void SvXMLNumFmtExport::ExportPart_Impl( const SvNumberformat& rFormat, sal_uInt
                 case NUMBERFORMAT_OP_LE: eOp3 = NUMBERFORMAT_OP_GT; break;
                 case NUMBERFORMAT_OP_GT: eOp3 = NUMBERFORMAT_OP_LE; break;
                 case NUMBERFORMAT_OP_GE: eOp3 = NUMBERFORMAT_OP_LT; break;
-                default:
-                    break;
+                case NUMBERFORMAT_OP_NO: eOp3 = NUMBERFORMAT_OP_LE; fLimit3 = DBL_MAX; break;
             }
 
             if ( fLimit1 == fLimit2 &&
@@ -1673,7 +1692,7 @@ void SvXMLNumFmtExport::ExportPart_Impl( const SvNumberformat& rFormat, sal_uInt
                 eOp3 = NUMBERFORMAT_OP_EQ;
             }
 
-            WriteMapElement_Impl( eOp3, fLimit3, nKey, 2 );
+            WriteMapElement_Impl( eOp3, fLimit3, nKey, nLastPart );
         }
     }
 }
@@ -1682,11 +1701,17 @@ void SvXMLNumFmtExport::ExportPart_Impl( const SvNumberformat& rFormat, sal_uInt
 
 void SvXMLNumFmtExport::ExportFormat_Impl( const SvNumberformat& rFormat, sal_uInt32 nKey )
 {
+    const sal_uInt16 XMLNUM_MAX_PARTS = 4;
+    bool bParts[XMLNUM_MAX_PARTS] = { false, false, false, false };
     sal_uInt16 nUsedParts = 0;
-    sal_uInt16 nPart;
-    for (nPart=0; nPart<XMLNUM_MAX_PARTS; nPart++)
-        if (rFormat.GetNumForType( nPart, 0, false ) != 0)
-            nUsedParts = nPart+1;
+    for (sal_uInt16 nPart=0; nPart<XMLNUM_MAX_PARTS; ++nPart)
+    {
+        if (rFormat.GetNumForInfoScannedType( nPart) != css::util::NumberFormat::UNDEFINED)
+        {
+            bParts[nPart] = true;
+            nUsedParts = nPart + 1;
+        }
+    }
 
     SvNumberformatLimitOps eOp1, eOp2;
     double fLimit1, fLimit2;
@@ -1694,17 +1719,32 @@ void SvXMLNumFmtExport::ExportFormat_Impl( const SvNumberformat& rFormat, sal_uI
 
     //  if conditions are set, even empty formats must be written
 
-    if ( eOp1 != NUMBERFORMAT_OP_NO && nUsedParts < 2 )
-        nUsedParts = 2;
-    if ( eOp2 != NUMBERFORMAT_OP_NO && nUsedParts < 3 )
-        nUsedParts = 3;
-    if ( rFormat.HasTextFormat() && nUsedParts < 4 )
-        nUsedParts = 4;
-
-    for (nPart=0; nPart<nUsedParts; nPart++)
+    if ( eOp1 != NUMBERFORMAT_OP_NO )
     {
-        bool bDefault = ( nPart+1 == nUsedParts );          // last = default
-        ExportPart_Impl( rFormat, nKey, nPart, bDefault );
+        bParts[1] = true;
+        if (nUsedParts < 2)
+            nUsedParts = 2;
+    }
+    if ( eOp2 != NUMBERFORMAT_OP_NO )
+    {
+        bParts[2] = true;
+        if (nUsedParts < 3)
+            nUsedParts = 3;
+    }
+    if ( rFormat.HasTextFormat() )
+    {
+        bParts[3] = true;
+        if (nUsedParts < 4)
+            nUsedParts = 4;
+    }
+
+    for (sal_uInt16 nPart=0; nPart<XMLNUM_MAX_PARTS; ++nPart)
+    {
+        if (bParts[nPart])
+        {
+            bool bDefault = ( nPart+1 == nUsedParts );          // last = default
+            ExportPart_Impl( rFormat, nKey, nPart, bDefault );
+        }
     }
 }
 
@@ -1716,7 +1756,7 @@ void SvXMLNumFmtExport::Export( bool bIsAutoStyle )
         return;                         // no formatter -> no entries
 
     sal_uInt32 nKey;
-    const SvNumberformat* pFormat = NULL;
+    const SvNumberformat* pFormat = nullptr;
     bool bNext(pUsedList->GetFirstUsed(nKey));
     while(bNext)
     {
@@ -1770,7 +1810,7 @@ OUString SvXMLNumFmtExport::GetStyleName( sal_uInt32 nKey )
 
 void SvXMLNumFmtExport::SetUsed( sal_uInt32 nKey )
 {
-    DBG_ASSERT( pFormatter != NULL, "missing formatter" );
+    DBG_ASSERT( pFormatter != nullptr, "missing formatter" );
     if( !pFormatter )
         return;
 
@@ -1796,7 +1836,7 @@ void SvXMLNumFmtExport::SetWasUsed(const uno::Sequence<sal_Int32>& rWasUsed)
 static const SvNumberformat* lcl_GetFormat( SvNumberFormatter* pFormatter,
                            sal_uInt32 nKey )
 {
-    return ( pFormatter != NULL ) ? pFormatter->GetEntry( nKey ) : NULL;
+    return ( pFormatter != nullptr ) ? pFormatter->GetEntry( nKey ) : nullptr;
 }
 
 sal_uInt32 SvXMLNumFmtExport::ForceSystemLanguage( sal_uInt32 nKey )
@@ -1804,9 +1844,9 @@ sal_uInt32 SvXMLNumFmtExport::ForceSystemLanguage( sal_uInt32 nKey )
     sal_uInt32 nRet = nKey;
 
     const SvNumberformat* pFormat = lcl_GetFormat( pFormatter, nKey );
-    if( pFormat != NULL )
+    if( pFormat != nullptr )
     {
-        DBG_ASSERT( pFormatter != NULL, "format without formatter?" );
+        DBG_ASSERT( pFormatter != nullptr, "format without formatter?" );
 
         sal_Int32 nErrorPos;
         short nType = pFormat->GetType();
