@@ -41,7 +41,6 @@ using ::com::sun::star::uno::Any;
 using ::com::sun::star::xml::sax::XAttributeList;
 
 
-TYPEINIT1(XMLIndexBibliographySourceContext, XMLIndexSourceBaseContext);
 
 
 XMLIndexBibliographySourceContext::XMLIndexBibliographySourceContext(
@@ -50,7 +49,7 @@ XMLIndexBibliographySourceContext::XMLIndexBibliographySourceContext(
     const OUString& rLocalName,
     Reference<XPropertySet> & rPropSet) :
         XMLIndexSourceBaseContext(rImport, nPrfx, rLocalName,
-                                  rPropSet, sal_False)
+                                  rPropSet, false)
 {
 }
 
