@@ -95,15 +95,16 @@ void XMLFieldParamImportContext::StartElement(const ::com::sun::star::uno::Refer
 }
 
 
-TYPEINIT1( XMLTextMarkImportContext, SvXMLImportContext);
 
 XMLTextMarkImportContext::XMLTextMarkImportContext(
     SvXMLImport& rImport,
     XMLTextImportHelper& rHlp,
+    uno::Reference<uno::XInterface> & io_rxCrossRefHeadingBookmark,
     sal_uInt16 nPrefix,
     const OUString& rLocalName )
     : SvXMLImportContext(rImport, nPrefix, rLocalName)
     , m_rHelper(rHlp)
+    , m_rxCrossRefHeadingBookmark(io_rxCrossRefHeadingBookmark)
     , m_bHaveAbout(false)
 {
 }
@@ -132,26 +133,23 @@ static const char *lcl_getFormFieldmarkName(OUString &name)
 {
     static const char sCheckbox[]=ODF_FORMCHECKBOX;
     static const char sFormDropDown[]=ODF_FORMDROPDOWN;
-    if (name.equalsAscii("msoffice.field.FORMCHECKBOX") ||
-            name.equalsAscii("ecma.office-open-xml.field.FORMCHECKBOX") )
+    if (name == "msoffice.field.FORMCHECKBOX" ||
+        name == "ecma.office-open-xml.field.FORMCHECKBOX")
         return sCheckbox;
-    else if (name.equalsAscii(ODF_FORMCHECKBOX) )
+    else if (name == ODF_FORMCHECKBOX)
         return sCheckbox;
-    if (name.equalsAscii(ODF_FORMDROPDOWN) ||
-            name.equalsAscii("ecma.office-open-xml.field.FORMDROPDOWN") )
+    if (name == ODF_FORMDROPDOWN ||
+        name == "ecma.office-open-xml.field.FORMDROPDOWN")
         return sFormDropDown;
     else
-        return NULL;
+        return nullptr;
 }
 
 static OUString lcl_getFieldmarkName(OUString const& name)
 {
-    static const char sFormtext[]=ODF_FORMTEXT;
-    if (name.equalsAscii("msoffice.field.FORMTEXT") ||
-            name.equalsAscii("ecma.office-open-xml.field.FORMTEXT") )
-        return OUString::createFromAscii(sFormtext);
-    else if (name.equalsAscii(ODF_FORMTEXT) )
-        return OUString::createFromAscii(sFormtext);
+    if (name == "msoffice.field.FORMTEXT" ||
+        name == "ecma.office-open-xml.field.FORMTEXT")
+        return OUString(ODF_FORMTEXT);
     else
         return name;
 }
@@ -206,11 +204,25 @@ void XMLTextMarkImportContext::EndElement()
                         OUString());
                     break;
 
-                case TypeFieldmark:
                 case TypeBookmark:
+                    {
+                        // tdf#94804: detect duplicate heading cross reference bookmarks
+                        if (m_sBookmarkName.startsWith("__RefHeading__"))
+                        {
+                            if (m_rxCrossRefHeadingBookmark.is())
+                            {
+                                uno::Reference<container::XNamed> const xNamed(
+                                    m_rxCrossRefHeadingBookmark, uno::UNO_QUERY);
+                                m_rHelper.AddCrossRefHeadingMapping(
+                                    m_sBookmarkName, xNamed->getName());
+                                break; // don't insert
+                            }
+                        }
+                    } // fall through
+                case TypeFieldmark:
                     {
                         const char *formFieldmarkName=lcl_getFormFieldmarkName(m_sFieldName);
-                        bool bImportAsField=((lcl_MarkType)nTmp==TypeFieldmark && formFieldmarkName!=NULL); //@TODO handle abbreviation cases..
+                        bool bImportAsField=((lcl_MarkType)nTmp==TypeFieldmark && formFieldmarkName!=nullptr); //@TODO handle abbreviation cases..
                         // export point bookmark
                         const Reference<XInterface> xContent(
                             CreateAndInsertMark(GetImport(),
@@ -229,6 +241,12 @@ void XMLTextMarkImportContext::EndElement()
                             }
                             m_rHelper.popFieldCtx();
                         }
+                        if (TypeBookmark == nTmp
+                            && m_sBookmarkName.startsWith("__RefHeading__"))
+                        {
+                            assert(xContent.is());
+                            m_rxCrossRefHeadingBookmark = xContent;
+                        }
                     }
                     break;
 
@@ -236,12 +254,12 @@ void XMLTextMarkImportContext::EndElement()
                 case TypeBookmarkStart:
                     // save XTextRange for later construction of bookmark
                     {
-                        ::boost::shared_ptr< ::xmloff::ParsedRDFaAttributes >
-                            pRDFaAttributes;
+                        std::shared_ptr< ::xmloff::ParsedRDFaAttributes >
+                            xRDFaAttributes;
                         if (m_bHaveAbout && (TypeBookmarkStart
                                 == static_cast<lcl_MarkType>(nTmp)))
                         {
-                            pRDFaAttributes =
+                            xRDFaAttributes =
                                 GetImport().GetRDFaImportHelper().ParseRDFa(
                                     m_sAbout, m_sProperty,
                                     m_sContent, m_sDatatype);
@@ -249,20 +267,34 @@ void XMLTextMarkImportContext::EndElement()
                         m_rHelper.InsertBookmarkStartRange(
                             m_sBookmarkName,
                             m_rHelper.GetCursorAsRange()->getStart(),
-                            m_sXmlId, pRDFaAttributes);
+                            m_sXmlId, xRDFaAttributes);
                     }
                     break;
 
-                case TypeFieldmarkEnd:
                 case TypeBookmarkEnd:
+                    {
+                        // tdf#94804: detect duplicate heading cross reference bookmarks
+                        if (m_sBookmarkName.startsWith("__RefHeading__"))
+                        {
+                            if (m_rxCrossRefHeadingBookmark.is())
+                            {
+                                uno::Reference<container::XNamed> const xNamed(
+                                    m_rxCrossRefHeadingBookmark, uno::UNO_QUERY);
+                                m_rHelper.AddCrossRefHeadingMapping(
+                                    m_sBookmarkName, xNamed->getName());
+                                break; // don't insert
+                            }
+                        }
+                    } // fall through
+                case TypeFieldmarkEnd:
                 {
                     // get old range, and construct
                     Reference<XTextRange> xStartRange;
-                    ::boost::shared_ptr< ::xmloff::ParsedRDFaAttributes >
-                        pRDFaAttributes;
+                    std::shared_ptr< ::xmloff::ParsedRDFaAttributes >
+                        xRDFaAttributes;
                     if (m_rHelper.FindAndRemoveBookmarkStartRange(
                             m_sBookmarkName, xStartRange,
-                            m_sXmlId, pRDFaAttributes))
+                            m_sXmlId, xRDFaAttributes))
                     {
                         Reference<XTextRange> xEndRange(
                             m_rHelper.GetCursorAsRange()->getStart());
@@ -316,12 +348,12 @@ void XMLTextMarkImportContext::EndElement()
                                         m_sBookmarkName,
                                         xInsertionCursor,
                                         m_sXmlId);
-                                if (pRDFaAttributes)
+                                if (xRDFaAttributes)
                                 {
                                     const Reference<rdf::XMetadatable>
                                         xMeta(xContent, UNO_QUERY);
                                     GetImport().GetRDFaImportHelper().AddRDFa(
-                                        xMeta, pRDFaAttributes);
+                                        xMeta, xRDFaAttributes);
                                 }
                             }
 
@@ -337,6 +369,12 @@ void XMLTextMarkImportContext::EndElement()
                                 }
                                 m_rHelper.popFieldCtx();
                             }
+                            if (TypeBookmarkEnd == nTmp
+                                && m_sBookmarkName.startsWith("__RefHeading__"))
+                            {
+                                assert(xContent.is());
+                                m_rxCrossRefHeadingBookmark = xContent;
+                            }
                         }
                         // else: beginning/end in different XText -> ignore!
                     }
@@ -385,7 +423,7 @@ Reference<XTextContent> XMLTextMarkImportContext::CreateAndInsertMark(
         if (!xIfc.is())
         {
             OSL_FAIL("CreateAndInsertMark: cannot create service?");
-            return 0;
+            return nullptr;
         }
 
         // set name (unless there is no name (text:meta))
@@ -399,7 +437,7 @@ Reference<XTextContent> XMLTextMarkImportContext::CreateAndInsertMark(
             if (!sMarkName.isEmpty())
             {
                 OSL_FAIL("name given, but XNamed not supported?");
-                return 0;
+                return nullptr;
             }
         }
 
@@ -422,11 +460,11 @@ Reference<XTextContent> XMLTextMarkImportContext::CreateAndInsertMark(
             catch (com::sun::star::lang::IllegalArgumentException &)
             {
                 OSL_FAIL("CreateAndInsertMark: cannot insert?");
-                return 0;
+                return nullptr;
             }
         }
     }
-    return 0;
+    return nullptr;
 }
 
 bool XMLTextMarkImportContext::FindName(
