@@ -17,13 +17,16 @@
  *   the License at http://www.apache.org/licenses/LICENSE-2.0 .
  */
 
+#include <sal/config.h>
+
+#include <osl/diagnose.h>
+#include <com/sun/star/uno/XComponentContext.hpp>
 #include <cppuhelper/supportsservice.hxx>
 #include "xmldocumentwrapper_xmlsecimpl.hxx"
 
 #include <xmloff/attrlist.hxx>
 #include "xmlelementwrapper_xmlsecimpl.hxx"
 
-#include <stdio.h>
 #include <stdlib.h>
 #include <string.h>
 
@@ -56,8 +59,8 @@ namespace cssxw = com::sun::star::xml::wrapper;
 
 XMLDocumentWrapper_XmlSecImpl::XMLDocumentWrapper_XmlSecImpl()
     : m_nCurrentPosition(0)
-    , m_pStopAtNode(0)
-    , m_pCurrentReservedNode(0)
+    , m_pStopAtNode(nullptr)
+    , m_pCurrentReservedNode(nullptr)
     , m_nReservedNodeIndex(0)
 {
     saxHelper.startDocument();
@@ -115,7 +118,7 @@ void XMLDocumentWrapper_XmlSecImpl::getNextSAXEvent()
  *  Email: michael.mi@sun.com
  ******************************************************************************/
 {
-    OSL_ASSERT( m_pCurrentElement != NULL );
+    OSL_ASSERT( m_pCurrentElement != nullptr );
 
         /*
          * Get the next event through tree order.
@@ -133,7 +136,7 @@ void XMLDocumentWrapper_XmlSecImpl::getNextSAXEvent()
              * type. Otherwise, the endElement of current node is the
              * next event.
              */
-        if (m_pCurrentElement->children != NULL)
+        if (m_pCurrentElement->children != nullptr)
         {
             m_pCurrentElement = m_pCurrentElement->children;
             m_nCurrentPosition
@@ -161,7 +164,7 @@ void XMLDocumentWrapper_XmlSecImpl::getNextSAXEvent()
              * type. Otherwise, the endElement of current node's parent
              * becomes the next event.
              */
-        if (pNextSibling != NULL)
+        if (pNextSibling != nullptr)
         {
             m_pCurrentElement = pNextSibling;
             m_nCurrentPosition
@@ -179,7 +182,7 @@ void XMLDocumentWrapper_XmlSecImpl::getNextSAXEvent()
 void XMLDocumentWrapper_XmlSecImpl::sendStartElement(
     const cssu::Reference< cssxs::XDocumentHandler >& xHandler,
     const cssu::Reference< cssxs::XDocumentHandler >& xHandler2,
-    const xmlNodePtr pNode) const
+    const xmlNodePtr pNode)
     throw (cssxs::SAXException)
 /****** XMLDocumentWrapper_XmlSecImpl/sendStartElement ************************
  *
@@ -211,28 +214,28 @@ void XMLDocumentWrapper_XmlSecImpl::sendStartElement(
  ******************************************************************************/
 {
     SvXMLAttributeList* pAttributeList = new SvXMLAttributeList();
-    cssu::Reference < cssxs::XAttributeList > xAttrList = cssu::Reference< cssxs::XAttributeList > (pAttributeList);
+    cssu::Reference < cssxs::XAttributeList > xAttrList(pAttributeList);
 
     xmlNsPtr pNsDef = pNode->nsDef;
 
-    while (pNsDef != NULL)
+    while (pNsDef != nullptr)
     {
         const xmlChar* pNsPrefix = pNsDef->prefix;
         const xmlChar* pNsHref = pNsDef->href;
 
-        if (pNsDef->prefix == NULL)
+        if (pNsDef->prefix == nullptr)
         {
             pAttributeList->AddAttribute(
                 OUString(C2U( STRXMLNS )),
-                OUString(C2U( (sal_Char*)pNsHref )));
+                OUString(C2U( reinterpret_cast<char const *>(pNsHref) )));
         }
         else
         {
             pAttributeList->AddAttribute(
                 OUString(C2U( STRXMLNS ))
                 +OUString(C2U( ":" ))
-                +OUString(C2U( (sal_Char*)pNsPrefix )),
-                OUString(C2U( (sal_Char*)pNsHref )));
+                +OUString(C2U( reinterpret_cast<char const *>(pNsPrefix) )),
+                OUString(C2U( reinterpret_cast<char const *>(pNsHref) )));
         }
 
         pNsDef = pNsDef->next;
@@ -240,26 +243,25 @@ void XMLDocumentWrapper_XmlSecImpl::sendStartElement(
 
     xmlAttrPtr pAttr = pNode->properties;
 
-    while (pAttr != NULL)
+    while (pAttr != nullptr)
     {
         const xmlChar* pAttrName = pAttr->name;
         xmlNsPtr pAttrNs = pAttr->ns;
 
         OUString ouAttrName;
-        if (pAttrNs == NULL)
+        if (pAttrNs == nullptr)
         {
-            ouAttrName = OUString(C2U( (sal_Char*)pAttrName ));
+            ouAttrName = OUString(C2U( reinterpret_cast<char const *>(pAttrName) ));
         }
         else
         {
-            ouAttrName = OUString(C2U( (sal_Char*)pAttrNs->prefix))
-                +OUString(C2U( (sal_Char*)":" ))
-                +OUString(C2U( (sal_Char*)pAttrName ));
+            ouAttrName = OUString(C2U( reinterpret_cast<char const *>(pAttrNs->prefix)))
+                + ":" + OUString(C2U( reinterpret_cast<char const *>(pAttrName) ));
         }
 
         pAttributeList->AddAttribute(
             ouAttrName,
-            OUString(C2U( (sal_Char*)(pAttr->children->content))));
+            OUString(C2U( reinterpret_cast<char*>(pAttr->children->content))));
         pAttr = pAttr->next;
     }
 
@@ -268,19 +270,19 @@ void XMLDocumentWrapper_XmlSecImpl::sendStartElement(
     if (xHandler.is())
     {
         xHandler->startElement(
-            OUString(C2U ( ((sal_Char*)(sNodeName.getStr())) )),
+            OUString(C2U ( sNodeName.getStr() )),
             xAttrList);
     }
 
     xHandler2->startElement(
-        OUString(C2U ( ((sal_Char*)(sNodeName.getStr())) )),
+        OUString(C2U ( sNodeName.getStr() )),
         xAttrList);
 }
 
 void XMLDocumentWrapper_XmlSecImpl::sendEndElement(
     const cssu::Reference< cssxs::XDocumentHandler >& xHandler,
     const cssu::Reference< cssxs::XDocumentHandler >& xHandler2,
-    const xmlNodePtr pNode) const
+    const xmlNodePtr pNode)
     throw (cssxs::SAXException)
 /****** XMLDocumentWrapper_XmlSecImpl/sendEndElement **************************
  *
@@ -315,16 +317,16 @@ void XMLDocumentWrapper_XmlSecImpl::sendEndElement(
 
     if (xHandler.is())
     {
-        xHandler->endElement(OUString(C2U ( ((sal_Char*)(sNodeName.getStr())) )));
+        xHandler->endElement(OUString(C2U ( sNodeName.getStr() )));
     }
 
-    xHandler2->endElement(OUString(C2U ( ((sal_Char*)(sNodeName.getStr())) )));
+    xHandler2->endElement(OUString(C2U ( sNodeName.getStr() )));
 }
 
 void XMLDocumentWrapper_XmlSecImpl::sendNode(
     const cssu::Reference< cssxs::XDocumentHandler >& xHandler,
     const cssu::Reference< cssxs::XDocumentHandler >& xHandler2,
-    const xmlNodePtr pNode) const
+    const xmlNodePtr pNode)
     throw (cssxs::SAXException)
 /****** XMLDocumentWrapper_XmlSecImpl/sendNode ********************************
  *
@@ -365,27 +367,27 @@ void XMLDocumentWrapper_XmlSecImpl::sendNode(
     {
         if (xHandler.is())
         {
-            xHandler->characters(OUString(C2U ( ((sal_Char*)(pNode->content)) )));
+            xHandler->characters(OUString(C2U ( reinterpret_cast<char*>(pNode->content) )));
         }
 
-        xHandler2->characters(OUString(C2U ( ((sal_Char*)(pNode->content)) )));
+        xHandler2->characters(OUString(C2U ( reinterpret_cast<char*>(pNode->content) )));
     }
     else if (type == XML_PI_NODE)
     {
         if (xHandler.is())
         {
             xHandler->processingInstruction(
-                OUString(C2U ( ((sal_Char*)(pNode->name)) )),
-                OUString(C2U ( ((sal_Char*)(pNode->content)) )));
+                OUString(C2U ( reinterpret_cast<char const *>(pNode->name) )),
+                OUString(C2U ( reinterpret_cast<char const *>(pNode->content) )));
         }
 
         xHandler2->processingInstruction(
-            OUString(C2U ( ((sal_Char*)(pNode->name)) )),
-            OUString(C2U ( ((sal_Char*)(pNode->content)) )));
+            OUString(C2U ( reinterpret_cast<char const *>(pNode->name) )),
+            OUString(C2U ( reinterpret_cast<char*>(pNode->content) )));
     }
 }
 
-OString XMLDocumentWrapper_XmlSecImpl::getNodeQName(const xmlNodePtr pNode) const
+OString XMLDocumentWrapper_XmlSecImpl::getNodeQName(const xmlNodePtr pNode)
 /****** XMLDocumentWrapper_XmlSecImpl/getNodeQName ****************************
  *
  *   NAME
@@ -408,14 +410,14 @@ OString XMLDocumentWrapper_XmlSecImpl::getNodeQName(const xmlNodePtr pNode) cons
  *  Email: michael.mi@sun.com
  ******************************************************************************/
 {
-    OString sNodeName((const sal_Char*)pNode->name);
-    if (pNode->ns != NULL)
+    OString sNodeName(reinterpret_cast<const char*>(pNode->name));
+    if (pNode->ns != nullptr)
     {
         xmlNsPtr pNs = pNode->ns;
 
-        if (pNs->prefix != NULL)
+        if (pNs->prefix != nullptr)
         {
-            OString sPrefix((const sal_Char*)pNs->prefix);
+            OString sPrefix(reinterpret_cast<const char*>(pNs->prefix));
             sNodeName = sPrefix+OString(":")+sNodeName;
         }
     }
@@ -423,7 +425,7 @@ OString XMLDocumentWrapper_XmlSecImpl::getNodeQName(const xmlNodePtr pNode) cons
     return sNodeName;
 }
 
-xmlNodePtr XMLDocumentWrapper_XmlSecImpl::checkElement( const cssu::Reference< cssxw::XXMLElementWrapper >& xXMLElement) const
+xmlNodePtr XMLDocumentWrapper_XmlSecImpl::checkElement( const cssu::Reference< cssxw::XXMLElementWrapper >& xXMLElement)
 /****** XMLDocumentWrapper_XmlSecImpl/checkElement ****************************
  *
  *   NAME
@@ -447,7 +449,7 @@ xmlNodePtr XMLDocumentWrapper_XmlSecImpl::checkElement( const cssu::Reference< c
  *  Email: michael.mi@sun.com
  ******************************************************************************/
 {
-    xmlNodePtr rc = NULL;
+    xmlNodePtr rc = nullptr;
 
     if (xXMLElement.is())
     {
@@ -463,7 +465,7 @@ xmlNodePtr XMLDocumentWrapper_XmlSecImpl::checkElement( const cssu::Reference< c
                     xNodTunnel->getSomething(
                         XMLElementWrapper_XmlSecImpl::getUnoTunnelImplementationId() ))) ;
 
-        if( pElement == NULL ) {
+        if( pElement == nullptr ) {
             throw cssu::RuntimeException() ;
         }
 
@@ -478,14 +480,14 @@ sal_Int32 XMLDocumentWrapper_XmlSecImpl::recursiveDelete(
 /****** XMLDocumentWrapper_XmlSecImpl/recursiveDelete *************************
  *
  *   NAME
- *  recursiveDelete -- Deletes a paticular node with its branch.
+ *  recursiveDelete -- Deletes a particular node with its branch.
  *
  *   SYNOPSIS
  *  result = recursiveDelete(pNode);
  *
  *   FUNCTION
- *  Deletes a paticular node with its branch, while reserving the nodes
- *  (and their brance) listed in the m_aReservedNodes.
+ *  Deletes a particular node with its branch, while reserving the nodes
+ *  (and their branches) listed in the m_aReservedNodes.
  *  The deletion process is preformed in the tree order, that is, a node
  *  is deleted after its previous sibling node is deleted, a parent node
  *  is deleted after its branch is deleted.
@@ -528,7 +530,7 @@ sal_Int32 XMLDocumentWrapper_XmlSecImpl::recursiveDelete(
         bool bIsRemoved = true;
         sal_Int32 nResult;
 
-        while( pChild != NULL )
+        while( pChild != nullptr )
         {
             pNextSibling = pChild->next;
             nResult = recursiveDelete(pChild);
@@ -599,7 +601,7 @@ void XMLDocumentWrapper_XmlSecImpl::getNextReservedNode()
     }
     else
     {
-        m_pCurrentReservedNode = NULL;
+        m_pCurrentReservedNode = nullptr;
     }
 }
 
@@ -631,9 +633,9 @@ void XMLDocumentWrapper_XmlSecImpl::removeNode(const xmlNodePtr pNode) const
 
     xmlAttrPtr pAttr = pNode->properties;
 
-    while (pAttr != NULL)
+    while (pAttr != nullptr)
     {
-        if (!stricmp((sal_Char*)pAttr->name,"id"))
+        if (!stricmp(reinterpret_cast<char const *>(pAttr->name), "id"))
         {
             xmlRemoveID(m_pDocument, pAttr);
         }
@@ -668,16 +670,16 @@ void XMLDocumentWrapper_XmlSecImpl::buildIDAttr(xmlNodePtr pNode) const
  *  Email: michael.mi@sun.com
  ******************************************************************************/
 {
-    xmlAttrPtr idAttr = xmlHasProp( pNode, (const unsigned char *)"id" );
-    if (idAttr == NULL)
+    xmlAttrPtr idAttr = xmlHasProp( pNode, reinterpret_cast<const unsigned char *>("id") );
+    if (idAttr == nullptr)
     {
-        idAttr = xmlHasProp( pNode, (const unsigned char *)"Id" );
+        idAttr = xmlHasProp( pNode, reinterpret_cast<const unsigned char *>("Id") );
     }
 
-    if (idAttr != NULL)
+    if (idAttr != nullptr)
     {
         xmlChar* idValue = xmlNodeListGetString( m_pDocument, idAttr->children, 1 ) ;
-        xmlAddID( NULL, m_pDocument, idValue, idAttr );
+        xmlAddID( nullptr, m_pDocument, idValue, idAttr );
     }
 }
 
@@ -704,12 +706,12 @@ void XMLDocumentWrapper_XmlSecImpl::rebuildIDLink(xmlNodePtr pNode) const
  *  Email: michael.mi@sun.com
  ******************************************************************************/
 {
-    if (pNode != NULL && pNode->type == XML_ELEMENT_NODE)
+    if (pNode != nullptr && pNode->type == XML_ELEMENT_NODE)
     {
         buildIDAttr( pNode );
 
         xmlNodePtr child = pNode->children;
-        while (child != NULL)
+        while (child != nullptr)
         {
             rebuildIDLink(child);
             child = child->next;
@@ -722,7 +724,7 @@ cssu::Reference< cssxw::XXMLElementWrapper > SAL_CALL XMLDocumentWrapper_XmlSecI
     throw (cssu::RuntimeException, std::exception)
 {
     XMLElementWrapper_XmlSecImpl* pElement = new XMLElementWrapper_XmlSecImpl(m_pCurrentElement);
-    return (cssu::Reference< cssxw::XXMLElementWrapper >)pElement;
+    return cssu::Reference< cssxw::XXMLElementWrapper >(pElement);
 }
 
 void SAL_CALL XMLDocumentWrapper_XmlSecImpl::setCurrentElement( const cssu::Reference< cssxw::XXMLElementWrapper >& element )
@@ -735,7 +737,7 @@ void SAL_CALL XMLDocumentWrapper_XmlSecImpl::setCurrentElement( const cssu::Refe
 void SAL_CALL XMLDocumentWrapper_XmlSecImpl::removeCurrentElement(  )
     throw (cssu::RuntimeException, std::exception)
 {
-    OSL_ASSERT( m_pCurrentElement != NULL );
+    OSL_ASSERT( m_pCurrentElement != nullptr );
 
     xmlNodePtr pOldCurrentElement = m_pCurrentElement;
 
@@ -748,7 +750,7 @@ void SAL_CALL XMLDocumentWrapper_XmlSecImpl::removeCurrentElement(  )
     saxHelper.endElement(
         OUString(
             C2U (
-                (sal_Char*)(pOldCurrentElement->name)
+                reinterpret_cast<char const *>(pOldCurrentElement->name)
             )));
     m_pCurrentElement = saxHelper.getCurrentNode();
 
@@ -770,7 +772,7 @@ sal_Bool SAL_CALL XMLDocumentWrapper_XmlSecImpl::isCurrentElementEmpty(  )
 {
     bool rc = false;
 
-    if (m_pCurrentElement->children == NULL)
+    if (m_pCurrentElement->children == nullptr)
     {
         rc = true;
     }
@@ -782,7 +784,7 @@ OUString SAL_CALL XMLDocumentWrapper_XmlSecImpl::getNodeName( const cssu::Refere
     throw (cssu::RuntimeException, std::exception)
 {
     xmlNodePtr pNode = checkElement(node);
-    return OUString(C2U ( (sal_Char*)pNode->name ));
+    return OUString(C2U ( reinterpret_cast<char const *>(pNode->name) ));
 }
 
 void SAL_CALL XMLDocumentWrapper_XmlSecImpl::clearUselessData(
@@ -808,9 +810,9 @@ void SAL_CALL XMLDocumentWrapper_XmlSecImpl::collapse( const cssu::Reference< cs
     xmlNodePtr pTargetNode = checkElement(node);
     xmlNodePtr pParent;
 
-    while (pTargetNode != NULL)
+    while (pTargetNode != nullptr)
     {
-        if (pTargetNode->children != NULL || pTargetNode == m_pCurrentElement)
+        if (pTargetNode->children != nullptr || pTargetNode == m_pCurrentElement)
         {
             break;
         }
@@ -824,7 +826,7 @@ void SAL_CALL XMLDocumentWrapper_XmlSecImpl::collapse( const cssu::Reference< cs
 void SAL_CALL XMLDocumentWrapper_XmlSecImpl::getTree( const cssu::Reference< cssxs::XDocumentHandler >& handler )
     throw (cssxs::SAXException, cssu::RuntimeException, std::exception)
 {
-    if (m_pRootElement != NULL)
+    if (m_pRootElement != nullptr)
     {
         xmlNodePtr pTempCurrentElement = m_pCurrentElement;
         sal_Int32 nTempCurrentPosition = m_nCurrentPosition;
@@ -839,13 +841,13 @@ void SAL_CALL XMLDocumentWrapper_XmlSecImpl::getTree( const cssu::Reference< css
             switch (m_nCurrentPosition)
             {
             case NODEPOSITION_STARTELEMENT:
-                sendStartElement(NULL, xHandler, m_pCurrentElement);
+                sendStartElement(nullptr, xHandler, m_pCurrentElement);
                 break;
             case NODEPOSITION_ENDELEMENT:
-                sendEndElement(NULL, xHandler, m_pCurrentElement);
+                sendEndElement(nullptr, xHandler, m_pCurrentElement);
                 break;
             case NODEPOSITION_NORMAL:
-                sendNode(NULL, xHandler, m_pCurrentElement);
+                sendNode(nullptr, xHandler, m_pCurrentElement);
                 break;
             }
 
@@ -873,7 +875,7 @@ void SAL_CALL XMLDocumentWrapper_XmlSecImpl::generateSAXEvents(
          * The first SAX event is the startElement of the startNode
          * element.
          */
-    bool bHasCurrentElementChild = (m_pCurrentElement->children != NULL);
+    bool bHasCurrentElementChild = (m_pCurrentElement->children != nullptr);
 
     xmlNodePtr pTempCurrentElement = m_pCurrentElement;
 
@@ -913,10 +915,10 @@ void SAL_CALL XMLDocumentWrapper_XmlSecImpl::generateSAXEvents(
 
         if (xSAXEventKeeper->isBlocking())
         {
-            xHandler = NULL;
+            xHandler = nullptr;
         }
 
-        if (pEndNode == NULL &&
+        if (pEndNode == nullptr &&
             ((bHasCurrentElementChild && m_pCurrentElement == xmlGetLastChild(pTempCurrentElement) && m_nCurrentPosition != NODEPOSITION_STARTELEMENT) ||
              (!bHasCurrentElementChild && m_pCurrentElement == pTempCurrentElement && m_nCurrentPosition == NODEPOSITION_STARTELEMENT)))
         {
@@ -930,7 +932,7 @@ void SAL_CALL XMLDocumentWrapper_XmlSecImpl::generateSAXEvents(
              * the current node equals to the end point. If so, stop
              * generating.
              */
-        if (pEndNode != NULL && m_pCurrentElement == pEndNode)
+        if (pEndNode != nullptr && m_pCurrentElement == pEndNode)
         {
             break;
         }
@@ -999,10 +1001,9 @@ void SAL_CALL XMLDocumentWrapper_XmlSecImpl::processingInstruction( const OUStri
     saxHelper.processingInstruction(aTarget, aData);
 }
 
-void SAL_CALL XMLDocumentWrapper_XmlSecImpl::setDocumentLocator( const cssu::Reference< cssxs::XLocator >& xLocator )
+void SAL_CALL XMLDocumentWrapper_XmlSecImpl::setDocumentLocator( const cssu::Reference< cssxs::XLocator >& )
     throw (cssxs::SAXException, cssu::RuntimeException, std::exception)
 {
-    saxHelper.setDocumentLocator(xLocator);
 }
 
 /* XCompressedDocumentHandler */
@@ -1063,9 +1064,7 @@ OUString XMLDocumentWrapper_XmlSecImpl_getImplementationName ()
 cssu::Sequence< OUString > SAL_CALL XMLDocumentWrapper_XmlSecImpl_getSupportedServiceNames(  )
     throw (cssu::RuntimeException)
 {
-    cssu::Sequence < OUString > aRet(1);
-    OUString* pArray = aRet.getArray();
-    pArray[0] = "com.sun.star.xml.wrapper.XMLDocumentWrapper";
+    cssu::Sequence<OUString> aRet { "com.sun.star.xml.wrapper.XMLDocumentWrapper" };
     return aRet;
 }
 
@@ -1073,7 +1072,7 @@ cssu::Reference< cssu::XInterface > SAL_CALL XMLDocumentWrapper_XmlSecImpl_creat
     const cssu::Reference< cssu::XComponentContext > &)
     throw( cssu::Exception )
 {
-    return (cppu::OWeakObject*) new XMLDocumentWrapper_XmlSecImpl( );
+    return static_cast<cppu::OWeakObject*>(new XMLDocumentWrapper_XmlSecImpl( ));
 }
 
 /* XServiceInfo */
